@@ -1,6 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
@@ -53,7 +52,7 @@
  *    Varies from 10->13; 10->9, 10->10, 10->1, 10->11
  */
 #define ONE_NTESTS 5
-int one_tests[ONE_NTESTS] = {3, -1, 0, -9, 1};
+static int one_tests[ONE_NTESTS] = {3, -1, 0, -9, 1};
 
 /*
  * Test variations (retained original) for two-dimensional dataset:
@@ -62,14 +61,15 @@ int one_tests[ONE_NTESTS] = {3, -1, 0, -9, 1};
  *            {4,10}->{4,12}; {4,10}->{4,9}; {4,10}->{4,10}
  */
 #define TWO_NTESTS 9
-int two_tests[TWO_NTESTS][2] = {{2, 2}, {2, -1}, {2, 0}, {-1, 2}, {-1, -1}, {-1, 0}, {0, 2}, {0, -1}, {0, 0}};
+static int two_tests[TWO_NTESTS][2] = {{2, 2},  {2, -1}, {2, 0},  {-1, 2}, {-1, -1},
+                                       {-1, 0}, {0, 2},  {0, -1}, {0, 0}};
 
 /* Verify that the two input values are the same */
 #define VERIFY_EQUAL(_x, _y)                                                                                 \
     {                                                                                                        \
         long __x = (long)_x, __y = (long)_y;                                                                 \
         if (__x != __y)                                                                                      \
-            TEST_ERROR                                                                                       \
+            TEST_ERROR;                                                                                      \
     }
 
 /* Temporary buffer for reading in the test file */
@@ -130,13 +130,13 @@ char g_tmp_buf[TMP_BUF_SIZE];
         }                                                                                                    \
         else if (type == TWO_CMPD_VALID1) {                                                                  \
             test_valid_fields1 *vb1 = (test_valid_fields1 *)_ldbuf;                                          \
-            set_t *             cb  = (set_t *)_buf;                                                         \
+            set_t              *cb  = (set_t *)_buf;                                                         \
                                                                                                              \
             VERIFY_ELMTS_VALID1(vb1[k], cb[ind + n])                                                         \
         }                                                                                                    \
         else if (type == TWO_CMPD_VALID2) {                                                                  \
             test_valid_fields2 *vb2 = (test_valid_fields2 *)_ldbuf;                                          \
-            set_t *             cb  = (set_t *)_buf;                                                         \
+            set_t              *cb  = (set_t *)_buf;                                                         \
                                                                                                              \
             VERIFY_ELMTS_VALID2(vb2[k], cb[ind + n])                                                         \
         }                                                                                                    \
@@ -189,7 +189,7 @@ typedef struct set_t {
  * This will fail on heiwa and amani when VALID_FIELDS1 is "field1,field3,field4"
  * because of alignment problems:
  *    amani and heiwa - 8 byte alignment
- *    jam - 4 byte alignemnt
+ *    jam - 4 byte alignment
  * This will need to be fixed in the library for H5Tget_native_type().
  */
 /* VALID_FIELDS1 "field1,field2.a,field3,field4" */
@@ -211,12 +211,12 @@ typedef struct test_valid_fields2 {
 
 /* Temporary buffers for tests: test_LD_elmts_one() & test_LD_elmts_two() */
 #define TEST_BUF_SIZE 100
-int *               iibuf; /* buffer for storing retrieved elements */
-int *               ibuf;  /* buffer for storing retrieved elements (integer) */
-set_t *             cbuf;  /* buffer for storing retrieved elemnets (compound) */
-set_t *             ccbuf; /* buffer for storing retrieved elemnets (compound) */
-test_valid_fields1 *vbuf1; /* buffer for storing retrieved elements (FIELDS1) */
-test_valid_fields2 *vbuf2; /* buffer for storing retrieved elements (FIELDS2) */
+static int                *iibuf; /* buffer for storing retrieved elements */
+static int                *ibuf;  /* buffer for storing retrieved elements (integer) */
+static set_t              *cbuf;  /* buffer for storing retrieved elements (compound) */
+static set_t              *ccbuf; /* buffer for storing retrieved elements (compound) */
+static test_valid_fields1 *vbuf1; /* buffer for storing retrieved elements (FIELDS1) */
+static test_valid_fields2 *vbuf2; /* buffer for storing retrieved elements (FIELDS2) */
 
 /*
  *********************************************************************************
@@ -247,7 +247,7 @@ test_LD_dims_params(const char *file)
 
     /* Open the copied file */
     if ((fid = H5Fopen(filename, H5F_ACC_RDONLY, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /*
      * 1. Verify failure with negative dataset id
@@ -256,45 +256,45 @@ test_LD_dims_params(const char *file)
     {
         ret = H5LDget_dset_dims(invalid_id, one_cur_dims);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY_EQUAL(ret, FAIL)
 
     /*
      * 2. Verify failure for NULL cur_dims
      */
     if ((did = H5Dopen2(fid, DSET_ALLOC_EARLY, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     H5E_BEGIN_TRY
     {
         ret = H5LDget_dset_dims(did, NULL);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY_EQUAL(ret, FAIL)
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /*
      * 3. Verify for nonNULL cur_dims
      */
     if ((did = H5Dopen2(fid, DSET_ALLOC_LATE, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5LDget_dset_dims(did, one_cur_dims) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     VERIFY_EQUAL(one_cur_dims[0], 10)
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /*
      * 4. Verify nonNULL cur_dims for a 2-dimensional dataset
      */
     if ((did = H5Dopen2(fid, DSET_CMPD_TWO, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5LDget_dset_dims(did, two_cur_dims) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     VERIFY_EQUAL(two_cur_dims[0], TWO_DIM_1)
     VERIFY_EQUAL(two_cur_dims[1], TWO_DIM_2)
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /*
      * 5. Verify nonNULL cur_dims for dataset with H5S_NULL dataspace
@@ -302,13 +302,13 @@ test_LD_dims_params(const char *file)
     one_cur_dims[0] = 0;
 
     if ((did = H5Dopen2(fid, DSET_NULL, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5LDget_dset_dims(did, one_cur_dims) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     VERIFY_EQUAL(one_cur_dims[0], 0)
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /*
      * 6. Verify nonNULL cur_dims for dataset with H5S_SCALAR dataspace
@@ -316,17 +316,17 @@ test_LD_dims_params(const char *file)
     one_cur_dims[0] = 0;
 
     if ((did = H5Dopen2(fid, DSET_SCALAR, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5LDget_dset_dims(did, one_cur_dims) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     VERIFY_EQUAL(one_cur_dims[0], 0)
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Close the file */
     if (H5Fclose(fid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     PASSED();
     return 0;
@@ -337,7 +337,7 @@ error:
         H5Dclose(did);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return (-1);
 } /* test_LD_dims_params() */
@@ -396,21 +396,21 @@ test_LD_dims(const char *file)
 
     /* Make a copy of the test file */
     if (h5_make_local_copy(file, COPY_FILENAME) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     /* Open the copied file */
     if ((fid = H5Fopen(COPY_FILENAME, H5F_ACC_RDWR, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /*
      * Testing with one-dimensional dataset: DSET_ONE
      */
     if ((did = H5Dopen2(fid, DSET_ONE, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Retrieve dimension sizes */
     if (H5LDget_dset_dims(did, one_prev_dims) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     for (i = 0; i < ONE_NTESTS; i++) {
 
@@ -419,11 +419,11 @@ test_LD_dims(const char *file)
 
         /* Change the dimension size */
         if (H5Dset_extent(did, one_ext_dims) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
 
         /* Retrieve the dimension size */
         if (H5LDget_dset_dims(did, one_cur_dims) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
 
         /* Verify that the retrieved dimension size is correct as expected */
         VERIFY_EQUAL(one_cur_dims[0], one_ext_dims[0])
@@ -431,17 +431,17 @@ test_LD_dims(const char *file)
 
     /* Close the dataset */
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /*
      * Testing with two-dimensional dataset: DSET_TWO
      */
     if ((did = H5Dopen2(fid, DSET_TWO, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Retrieve the dimension sizes */
     if (H5LDget_dset_dims(did, two_prev_dims) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     for (i = 0; i < TWO_NTESTS; i++) {
 
@@ -451,11 +451,11 @@ test_LD_dims(const char *file)
 
         /* Change the dimension sizes */
         if (H5Dset_extent(did, two_ext_dims) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
 
         /* Retrieve the dimension sizes */
         if (H5LDget_dset_dims(did, two_cur_dims) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
 
         /* Verify that the retrieved dimension sizes are correct as expected */
         VERIFY_EQUAL(two_cur_dims[0], two_ext_dims[0])
@@ -464,11 +464,11 @@ test_LD_dims(const char *file)
 
     /* Close the dataset */
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Close the file */
     if (H5Fclose(fid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Remove the copied file */
     HDremove(COPY_FILENAME);
@@ -482,7 +482,7 @@ error:
         H5Dclose(did);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return (-1);
 
 } /* test_LD_dims() */
@@ -537,7 +537,7 @@ test_LD_size(const char *file)
 
     /* Open the file */
     if ((fid = H5Fopen(filename, H5F_ACC_RDONLY, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /*
      * Verify failure with an invalid dataset id
@@ -546,7 +546,7 @@ test_LD_size(const char *file)
     {
         dsize = H5LDget_dset_type_size(invalid_id, NULL);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY_EQUAL(dsize, 0)
 
     /*
@@ -556,90 +556,90 @@ test_LD_size(const char *file)
 
     /* Open dataset DSET_CMPD */
     if ((did = H5Dopen2(fid, DSET_CMPD, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Return size of the whole element */
     if ((dsize = H5LDget_dset_type_size(did, NULL)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get the dataset's datatype and then its datatype size */
     if ((dtid = H5Tget_native_type(H5Dget_type(did), H5T_DIR_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if ((ck_dsize = H5Tget_size(dtid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify case #1 */
     VERIFY_EQUAL(dsize, ck_dsize)
 
     /* Get datatype id for each member */
     if ((memb0_tid = H5Tget_member_type(dtid, 0)) < 0) /* "field1" */
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((memb1_tid = H5Tget_member_type(dtid, 1)) < 0) /* "field2" */
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((memb2_tid = H5Tget_member_type(dtid, 2)) < 0) /* "field3" */
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((memb3_tid = H5Tget_member_type(dtid, 3)) < 0) /* "field4" */
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Obtain size for VALID_FIELDS1: "field1,field2.a,field3,field4" */
     if ((dsize = H5LDget_dset_type_size(did, VALID_FIELDS1)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get the datatype size for "field1" */
     if ((ck_dsize = H5Tget_size(memb0_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Add the datatype size for "field2.a" */
     if ((memb_tid = H5Tget_member_type(memb1_tid, 0)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((ck_dsize += H5Tget_size(memb_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Add the datatype size for "field3" */
     if ((ck_dsize += H5Tget_size(memb2_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Add the datatype size for "field4" */
     if ((ck_dsize += H5Tget_size(memb3_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify case #2 */
     VERIFY_EQUAL(dsize, ck_dsize)
 
     /* Obtain datatype size for VALID_FIELDS2: "field2.b.a,field2.c,field4.b" */
     if ((dsize = H5LDget_dset_type_size(did, VALID_FIELDS2)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get the datatype size for "field2.b.a" */
     if ((memb_tid = H5Tget_member_type(memb1_tid, 1)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((memb_tid2 = H5Tget_member_type(memb_tid, 0)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((ck_dsize = H5Tget_size(memb_tid2)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb_tid2) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Add the datatype size for "field2.c" */
     if ((memb_tid = H5Tget_member_type(memb1_tid, 2)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((ck_dsize += H5Tget_size(memb_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Add the datatype size for "field4.b" */
     if ((memb_tid = H5Tget_member_type(memb3_tid, 1)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((ck_dsize += H5Tget_size(memb_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify case #3 */
     VERIFY_EQUAL(dsize, ck_dsize)
@@ -664,17 +664,17 @@ test_LD_size(const char *file)
 
     /* Closing */
     if (H5Tclose(memb0_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb1_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb2_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb3_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(dtid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /*
      * Testing one-dimensional dataset with compound datatype and
@@ -684,54 +684,54 @@ test_LD_size(const char *file)
 
     /* Open dataset DSET_CMPD_ESC */
     if ((did = H5Dopen2(fid, DSET_CMPD_ESC, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Return size of the whole element */
     if ((dsize = H5LDget_dset_type_size(did, NULL)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get the dataset's datatype and then its datatype size */
     if ((dtid = H5Tget_native_type(H5Dget_type(did), H5T_DIR_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((ck_dsize = H5Tget_size(dtid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify case #1 */
     VERIFY_EQUAL(dsize, ck_dsize)
 
     /* Get datatype id for each member */
     if ((memb0_tid = H5Tget_member_type(dtid, 0)) < 0) /* "field,1" */
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((memb1_tid = H5Tget_member_type(dtid, 1)) < 0) /* "field2." */
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((memb2_tid = H5Tget_member_type(dtid, 2)) < 0) /* "field\3" */
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((memb3_tid = H5Tget_member_type(dtid, 3)) < 0) /* "field4," */
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Obtain size for VALID_ESC_FIELDS1: "field\\,1,field2\\..\\.a,field\\\\3,field4\\," */
     if ((dsize = H5LDget_dset_type_size(did, VALID_ESC_FIELDS1)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get the datatype size for "field\\,1" */
     if ((ck_dsize = H5Tget_size(memb0_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Add the datatype size for "field2\\..\\.a" */
     if ((memb_tid = H5Tget_member_type(memb1_tid, 0)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((ck_dsize += H5Tget_size(memb_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Add the datatype size for "field\\\\3" */
     if ((ck_dsize += H5Tget_size(memb2_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Add the datatype size for "field4\\," */
     if ((ck_dsize += H5Tget_size(memb3_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify case #2 */
     VERIFY_EQUAL(dsize, ck_dsize)
@@ -739,35 +739,35 @@ test_LD_size(const char *file)
     /* Obtain datatype size for VALID_ESC_FIELDS2:
         "field2\\..\\,b.a,field2\\..\\\\c,field4\\,.b\\," */
     if ((dsize = H5LDget_dset_type_size(did, VALID_ESC_FIELDS2)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get the datatype size for "field2\..,b.a" */
     if ((memb_tid = H5Tget_member_type(memb1_tid, 1)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((memb_tid2 = H5Tget_member_type(memb_tid, 0)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((ck_dsize = H5Tget_size(memb_tid2)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb_tid2) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Add the datatype size for "field2\..\\c" */
     if ((memb_tid = H5Tget_member_type(memb1_tid, 2)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((ck_dsize += H5Tget_size(memb_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Add the datatype size for "field4\,.b\," */
     if ((memb_tid = H5Tget_member_type(memb3_tid, 1)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if ((ck_dsize += H5Tget_size(memb_tid)) == 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify case #3 */
     VERIFY_EQUAL(dsize, ck_dsize)
@@ -792,20 +792,20 @@ test_LD_size(const char *file)
 
     /* Closing */
     if (H5Tclose(memb0_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb1_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb2_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(memb3_tid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Tclose(dtid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     if (H5Fclose(fid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     PASSED();
     return 0;
@@ -823,7 +823,7 @@ error:
         H5Dclose(did);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return (-1);
 
 } /* test_LD_size() */
@@ -868,7 +868,7 @@ test_LD_elmts_invalid(const char *file)
 
     /* Open the copied file */
     if ((fid = H5Fopen(filename, H5F_ACC_RDONLY, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /*
      * Testing two-dimensional dataset: DSET_TWO
@@ -876,7 +876,7 @@ test_LD_elmts_invalid(const char *file)
 
     /* Open dataset: DSET_TWO */
     if ((did = H5Dopen2(fid, DSET_TWO, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Verify failure from case #1: cur_dims and prev_dims are NULL */
     ret = H5LDget_dset_elmts(did, NULL, NULL, NULL, NULL);
@@ -891,11 +891,11 @@ test_LD_elmts_invalid(const char *file)
     VERIFY_EQUAL(ret, FAIL)
 
     if ((sid = H5Dget_space(did)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get the # of dimensions and current dimension sizes */
     if ((ndims = H5Sget_simple_extent_dims(sid, cur_dims, NULL)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Set up valid cur_dims and prev_dims */
     for (i = 0; i < ndims; i++)
@@ -917,7 +917,7 @@ test_LD_elmts_invalid(const char *file)
 
     /* Close DSET_TWO */
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /*
      * Testing one-dimensional dataset with compound datatype:
@@ -929,16 +929,16 @@ test_LD_elmts_invalid(const char *file)
     {
         ret = H5LDget_dset_elmts(invalid_id, prev_dims, cur_dims, NULL, tbuf);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY_EQUAL(ret, FAIL)
 
     /* Open dataset: DSET_CMPD */
     if ((did = H5Dopen2(fid, DSET_CMPD, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Retrieve the current dimension sizes */
     if (H5LDget_dset_dims(did, cur_dims) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Set up valid cur_dims, prev_dims */
     prev_dims[0] = cur_dims[0] - 1;
@@ -949,11 +949,11 @@ test_LD_elmts_invalid(const char *file)
 
     /* Close DSET_CMPD */
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Close the file */
     if (H5Fclose(fid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     PASSED();
     return 0;
@@ -965,7 +965,7 @@ error:
         H5Dclose(did);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return (-1);
 
 } /* test_LD_elmts_invalid() */
@@ -1004,7 +1004,7 @@ test_LD_elmts_one(const char *file, const char *dname, const char *fields)
 
     /* Copy the test file */
     if (h5_make_local_copy(file, COPY_FILENAME) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     for (i = 0; i < TEST_BUF_SIZE; i++) {
         cbuf[i].field1     = i;
@@ -1021,68 +1021,68 @@ test_LD_elmts_one(const char *file, const char *dname, const char *fields)
 
     /* Open the copied file */
     if ((fid = H5Fopen(COPY_FILENAME, H5F_ACC_RDWR, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Open the dataset */
     if ((did = H5Dopen2(fid, dname, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get the dataset's data type */
     if ((dtype = H5Tget_native_type(H5Dget_type(did), H5T_DIR_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get current dimension sizes before extending the dataset's dimension sizes */
     if (H5LDget_dset_dims(did, prev_dims) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Loop through different variations of extending the dataset */
     for (i = 0; i < ONE_NTESTS; i++) {
-        HDmemset(vbuf1, 0, TEST_BUF_SIZE * sizeof(test_valid_fields1));
-        HDmemset(vbuf2, 0, TEST_BUF_SIZE * sizeof(test_valid_fields2));
-        HDmemset(ccbuf, 0, TEST_BUF_SIZE * sizeof(set_t));
-        HDmemset(iibuf, 0, TEST_BUF_SIZE * sizeof(int));
+        memset(vbuf1, 0, TEST_BUF_SIZE * sizeof(test_valid_fields1));
+        memset(vbuf2, 0, TEST_BUF_SIZE * sizeof(test_valid_fields2));
+        memset(ccbuf, 0, TEST_BUF_SIZE * sizeof(set_t));
+        memset(iibuf, 0, TEST_BUF_SIZE * sizeof(int));
 
         ext_dims[0] = (hsize_t)((int)prev_dims[0] + one_tests[i]);
 
         /* Change the dimension sizes of the dataset */
         if (H5Dset_extent(did, ext_dims) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
 
         /* Initialize data */
-        if (!HDstrcmp(dname, DSET_CMPD) || !HDstrcmp(dname, DSET_CMPD_ESC)) {
+        if (!strcmp(dname, DSET_CMPD) || !strcmp(dname, DSET_CMPD_ESC)) {
             if (H5Dwrite(did, dtype, H5S_ALL, H5S_ALL, H5P_DEFAULT, cbuf) < 0)
-                FAIL_STACK_ERROR
+                FAIL_STACK_ERROR;
         } /* end if */
-        else if (!HDstrcmp(dname, DSET_ONE)) {
+        else if (!strcmp(dname, DSET_ONE)) {
             if (H5Dwrite(did, dtype, H5S_ALL, H5S_ALL, H5P_DEFAULT, ibuf) < 0)
-                FAIL_STACK_ERROR
+                FAIL_STACK_ERROR;
         } /* end if */
 
         /* There are changes in dimension sizes */
         if (one_tests[i] > 0) {
-            if (!HDstrcmp(dname, DSET_CMPD) || !HDstrcmp(dname, DSET_CMPD_ESC)) {
+            if (!strcmp(dname, DSET_CMPD) || !strcmp(dname, DSET_CMPD_ESC)) {
                 if (fields) {
-                    if (!HDstrcmp(fields, VALID_FIELDS1) || !HDstrcmp(fields, VALID_ESC_FIELDS1)) {
+                    if (!strcmp(fields, VALID_FIELDS1) || !strcmp(fields, VALID_ESC_FIELDS1)) {
                         /* Retrieve the elmemts in BUF */
                         if (H5LDget_dset_elmts(did, prev_dims, ext_dims, fields, vbuf1) < 0)
-                            TEST_ERROR
+                            TEST_ERROR;
                         for (j = 0; j < one_tests[i]; j++)
                             VERIFY_ELMTS_VALID1(vbuf1[j], cbuf[prev_dims[0] + (hsize_t)j])
                     } /* end if */
-                    else if (!HDstrcmp(fields, VALID_FIELDS2) || !HDstrcmp(fields, VALID_ESC_FIELDS2)) {
+                    else if (!strcmp(fields, VALID_FIELDS2) || !strcmp(fields, VALID_ESC_FIELDS2)) {
                         /* Retrieve the elmemts in BUF */
                         if (H5LDget_dset_elmts(did, prev_dims, ext_dims, fields, vbuf2) < 0)
-                            TEST_ERROR
+                            TEST_ERROR;
                         for (j = 0; j < one_tests[i]; j++)
                             VERIFY_ELMTS_VALID2(vbuf2[j], cbuf[prev_dims[0] + (hsize_t)j])
                     } /* end else-if */
                     else
-                        TEST_ERROR
+                        TEST_ERROR;
                 } /* end if */
                 else {
                     /* Retrieve the elmemts in BUF */
                     if (H5LDget_dset_elmts(did, prev_dims, ext_dims, fields, ccbuf) < 0)
-                        TEST_ERROR
+                        TEST_ERROR;
                     for (j = 0; j < one_tests[i]; j++)
                         VERIFY_ELMTS_ALL(ccbuf[j], cbuf[prev_dims[0] + (hsize_t)j])
                 } /* end else-if */
@@ -1090,7 +1090,7 @@ test_LD_elmts_one(const char *file, const char *dname, const char *fields)
             else {
                 /* Retrieve the elmemts in BUF */
                 if (H5LDget_dset_elmts(did, prev_dims, ext_dims, fields, iibuf) < 0)
-                    TEST_ERROR
+                    TEST_ERROR;
                 for (j = 0; j < one_tests[i]; j++)
                     VERIFY_EQUAL(iibuf[j], ibuf[prev_dims[0] + (hsize_t)j])
             } /* end else */
@@ -1104,11 +1104,11 @@ test_LD_elmts_one(const char *file, const char *dname, const char *fields)
 
     /* Closing */
     if (H5Tclose(dtype) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Dclose(did) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Fclose(fid) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Remove the copied file */
     HDremove(COPY_FILENAME);
@@ -1123,7 +1123,7 @@ error:
         H5Dclose(did);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return (-1);
 } /* test_LD_elmts_one() */
 
@@ -1215,7 +1215,7 @@ test_LD_elmts_two(const char *file, const char *dname, const char *fields)
 
     /* Copy the test file */
     if (h5_make_local_copy(file, COPY_FILENAME) < 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     for (i = 0; i < TEST_BUF_SIZE; i++) {
         cbuf[i].field1     = i;
@@ -1232,81 +1232,81 @@ test_LD_elmts_two(const char *file, const char *dname, const char *fields)
 
     /* Open the copied file */
     if ((fid = H5Fopen(COPY_FILENAME, H5F_ACC_RDWR, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Open the dataset */
     if ((did = H5Dopen2(fid, dname, H5P_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get the dataset's data type */
     if ((dtype = H5Tget_native_type(H5Dget_type(did), H5T_DIR_DEFAULT)) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Get current dimension sizes before extending the dataset's dimension sizes */
     if (H5LDget_dset_dims(did, prev_dims) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* Loop through different variations of extending the dataset */
     for (i = 0; i < TWO_NTESTS; i++) {
-        HDmemset(vbuf1, 0, TEST_BUF_SIZE * sizeof(test_valid_fields1));
-        HDmemset(vbuf2, 0, TEST_BUF_SIZE * sizeof(test_valid_fields2));
-        HDmemset(ccbuf, 0, TEST_BUF_SIZE * sizeof(set_t));
-        HDmemset(iibuf, 0, TEST_BUF_SIZE * sizeof(int));
+        memset(vbuf1, 0, TEST_BUF_SIZE * sizeof(test_valid_fields1));
+        memset(vbuf2, 0, TEST_BUF_SIZE * sizeof(test_valid_fields2));
+        memset(ccbuf, 0, TEST_BUF_SIZE * sizeof(set_t));
+        memset(iibuf, 0, TEST_BUF_SIZE * sizeof(int));
 
         ext_dims[0] = (hsize_t)((int)prev_dims[0] + two_tests[i][0]);
         ext_dims[1] = (hsize_t)((int)prev_dims[1] + two_tests[i][1]);
 
         /* Change the dimension sizes of the dataset */
         if (H5Dset_extent(did, ext_dims) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
 
         /* Initialize data */
-        if (!HDstrcmp(dname, DSET_CMPD_TWO)) {
+        if (!strcmp(dname, DSET_CMPD_TWO)) {
             if (H5Dwrite(did, dtype, H5S_ALL, H5S_ALL, H5P_DEFAULT, cbuf) < 0)
-                FAIL_STACK_ERROR
+                FAIL_STACK_ERROR;
         } /* end if */
-        else if (!HDstrcmp(dname, DSET_TWO)) {
+        else if (!strcmp(dname, DSET_TWO)) {
             if (H5Dwrite(did, dtype, H5S_ALL, H5S_ALL, H5P_DEFAULT, ibuf) < 0)
-                FAIL_STACK_ERROR
+                FAIL_STACK_ERROR;
         } /* end else-if */
         else
-            TEST_ERROR
+            TEST_ERROR;
 
         /* There are changes in dimension sizes */
         if (two_tests[i][0] > 0 || two_tests[i][1] > 0) {
-            if (!HDstrcmp(dname, DSET_CMPD_TWO)) {
+            if (!strcmp(dname, DSET_CMPD_TWO)) {
                 if (fields) {
-                    if (!HDstrcmp(fields, VALID_FIELDS1) || !HDstrcmp(fields, VALID_ESC_FIELDS1)) {
+                    if (!strcmp(fields, VALID_FIELDS1) || !strcmp(fields, VALID_ESC_FIELDS1)) {
                         /* Retrieve the elmemts in BUF */
                         if (H5LDget_dset_elmts(did, prev_dims, ext_dims, fields, vbuf1) < 0)
-                            TEST_ERROR
+                            TEST_ERROR;
                         if (verify_elmts_two(TWO_CMPD_VALID1, ext_dims, prev_dims, vbuf1, cbuf) < 0)
-                            TEST_ERROR
+                            TEST_ERROR;
                     } /* end if */
-                    else if (!HDstrcmp(fields, VALID_FIELDS2) || !HDstrcmp(fields, VALID_ESC_FIELDS2)) {
+                    else if (!strcmp(fields, VALID_FIELDS2) || !strcmp(fields, VALID_ESC_FIELDS2)) {
                         /* Retrieve the elmemts in BUF */
                         if (H5LDget_dset_elmts(did, prev_dims, ext_dims, fields, vbuf2) < 0)
-                            TEST_ERROR
+                            TEST_ERROR;
                         if (verify_elmts_two(TWO_CMPD_VALID2, ext_dims, prev_dims, vbuf2, cbuf) < 0)
-                            TEST_ERROR
+                            TEST_ERROR;
                     } /* end else-if */
                     else
-                        TEST_ERROR
+                        TEST_ERROR;
                 } /* end if */
                 else {
                     /* Retrieve the elmemts in BUF */
                     if (H5LDget_dset_elmts(did, prev_dims, ext_dims, fields, ccbuf) < 0)
-                        TEST_ERROR
+                        TEST_ERROR;
                     if (verify_elmts_two(TWO_CMPD_NULL, ext_dims, prev_dims, ccbuf, cbuf) < 0)
-                        TEST_ERROR
+                        TEST_ERROR;
                 }  /* end else */
             }      /* end if */
             else { /* DSET_TWO */
                 /* Retrieve the elmemts in BUF */
                 if (H5LDget_dset_elmts(did, prev_dims, ext_dims, fields, iibuf) < 0)
-                    TEST_ERROR
+                    TEST_ERROR;
                 if (verify_elmts_two(TWO_NONE, ext_dims, prev_dims, iibuf, ibuf) < 0)
-                    TEST_ERROR
+                    TEST_ERROR;
             } /* end else */
         }     /* end if */
         else {
@@ -1337,7 +1337,7 @@ error:
         H5Dclose(did);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return (-1);
 } /* test_LD_elmts_two() */
 
@@ -1351,19 +1351,19 @@ main(void)
     int nerrors = 0;
 
     /* Set up temporary buffers for tests: test_LD_elmts_one() & test_LD_elmts_two() */
-    if (NULL == (ibuf = (int *)HDmalloc(sizeof(int) * TEST_BUF_SIZE)))
+    if (NULL == (ibuf = (int *)malloc(sizeof(int) * TEST_BUF_SIZE)))
         FAIL_STACK_ERROR;
-    if (NULL == (iibuf = (int *)HDmalloc(sizeof(int) * TEST_BUF_SIZE)))
+    if (NULL == (iibuf = (int *)malloc(sizeof(int) * TEST_BUF_SIZE)))
         FAIL_STACK_ERROR;
 
-    if (NULL == (cbuf = (set_t *)HDmalloc(sizeof(set_t) * TEST_BUF_SIZE)))
+    if (NULL == (cbuf = (set_t *)malloc(sizeof(set_t) * TEST_BUF_SIZE)))
         FAIL_STACK_ERROR;
-    if (NULL == (ccbuf = (set_t *)HDmalloc(sizeof(set_t) * TEST_BUF_SIZE)))
+    if (NULL == (ccbuf = (set_t *)malloc(sizeof(set_t) * TEST_BUF_SIZE)))
         FAIL_STACK_ERROR;
 
-    if (NULL == (vbuf1 = (test_valid_fields1 *)HDmalloc(sizeof(test_valid_fields1) * TEST_BUF_SIZE)))
+    if (NULL == (vbuf1 = (test_valid_fields1 *)malloc(sizeof(test_valid_fields1) * TEST_BUF_SIZE)))
         FAIL_STACK_ERROR;
-    if (NULL == (vbuf2 = (test_valid_fields2 *)HDmalloc(sizeof(test_valid_fields2) * TEST_BUF_SIZE)))
+    if (NULL == (vbuf2 = (test_valid_fields2 *)malloc(sizeof(test_valid_fields2) * TEST_BUF_SIZE)))
         FAIL_STACK_ERROR;
 
     /*
@@ -1415,17 +1415,17 @@ main(void)
 
     /* Free temporary buffers */
     if (ibuf)
-        HDfree(ibuf);
+        free(ibuf);
     if (iibuf)
-        HDfree(iibuf);
+        free(iibuf);
     if (cbuf)
-        HDfree(cbuf);
+        free(cbuf);
     if (ccbuf)
-        HDfree(ccbuf);
+        free(ccbuf);
     if (vbuf1)
-        HDfree(vbuf1);
+        free(vbuf1);
     if (vbuf2)
-        HDfree(vbuf2);
+        free(vbuf2);
 
     /* check for errors */
     if (nerrors)
