@@ -27,20 +27,20 @@
  *    This tool uses H5LD_memb_t data structure declared in H5LDprivate.h
  */
 
-const char          *progname         = "h5watch"; /* tool name */
+static const char   *progname         = "h5watch"; /* tool name */
 static char         *g_list_of_fields = NULL;      /* command line input for "list_of_fields" */
 static char         *g_dup_fields     = NULL;      /* copy of "list_of_fields" */
 static H5LD_memb_t **g_listv          = NULL;      /* vector info for "list_of_fields" */
 
-static hbool_t  g_monitor_size_only = FALSE; /* monitor changes in dataset dimension sizes */
+static bool     g_monitor_size_only = false; /* monitor changes in dataset dimension sizes */
 static unsigned g_polling_interval  = 1;     /* polling interval to check appended data */
 
-static hbool_t  g_label         = FALSE;  /* label compound values */
+static bool     g_label         = false;  /* label compound values */
 static int      g_display_width = 80;     /* output width in characters */
-static hbool_t  g_simple_output = FALSE;  /* make output more machine-readable */
+static bool     g_simple_output = false;  /* make output more machine-readable */
 static unsigned g_retry = DEFAULT_RETRY;  /* # of times to try opening the file if somehow file is unstable */
-static hbool_t  g_display_hex    = FALSE; /* display data in hexadecimal format : LATER */
-static hbool_t  g_user_interrupt = FALSE; /* Flag to indicate that user interrupted execution */
+static bool     g_display_hex    = false; /* display data in hexadecimal format : LATER */
+static bool     g_user_interrupt = false; /* Flag to indicate that user interrupted execution */
 
 static herr_t doprint(hid_t did, const hsize_t *start, const hsize_t *block, int rank);
 static herr_t slicendump(hid_t did, hsize_t *prev_dims, hsize_t *cur_dims, hsize_t *start, hsize_t *block,
@@ -57,27 +57,27 @@ static void   parse_command_line(int argc, const char *const *argv);
  * The long-named ones can be partially spelled. When
  * adding more, make sure that they don't clash with each other.
  */
-static const char         *s_opts   = "?";
-static struct long_options l_opts[] = {{"help", no_arg, 'h'},         {"hel", no_arg, 'h'},
-                                       {"dim", no_arg, 'd'},          {"di", no_arg, 'd'},
-                                       {"label", no_arg, 'l'},        {"labe", no_arg, 'l'},
-                                       {"lab", no_arg, 'l'},          {"la", no_arg, 'l'},
-                                       {"simple", no_arg, 'S'},       {"simpl", no_arg, 'S'},
-                                       {"simp", no_arg, 'S'},         {"sim", no_arg, 'S'},
-                                       {"si", no_arg, 'S'},           {"hexdump", no_arg, 'x'},
-                                       {"hexdum", no_arg, 'x'},       {"hexdu", no_arg, 'x'},
-                                       {"hexd", no_arg, 'x'},         {"hex", no_arg, 'x'},
-                                       {"width", require_arg, 'w'},   {"widt", require_arg, 'w'},
-                                       {"wid", require_arg, 'w'},     {"wi", require_arg, 'w'},
-                                       {"polling", require_arg, 'p'}, {"pollin", require_arg, 'p'},
-                                       {"polli", require_arg, 'p'},   {"poll", require_arg, 'p'},
-                                       {"pol", require_arg, 'p'},     {"po", require_arg, 'p'},
-                                       {"fields", require_arg, 'f'},  {"field", require_arg, 'f'},
-                                       {"fiel", require_arg, 'f'},    {"fie", require_arg, 'f'},
-                                       {"fi", require_arg, 'f'},      {"version", no_arg, 'V'},
-                                       {"versio", no_arg, 'V'},       {"versi", no_arg, 'V'},
-                                       {"vers", no_arg, 'V'},         {"ver", no_arg, 'V'},
-                                       {"ve", no_arg, 'V'},           {NULL, 0, '\0'}};
+static const char            *s_opts   = "?";
+static struct h5_long_options l_opts[] = {{"help", no_arg, 'h'},         {"hel", no_arg, 'h'},
+                                          {"dim", no_arg, 'd'},          {"di", no_arg, 'd'},
+                                          {"label", no_arg, 'l'},        {"labe", no_arg, 'l'},
+                                          {"lab", no_arg, 'l'},          {"la", no_arg, 'l'},
+                                          {"simple", no_arg, 'S'},       {"simpl", no_arg, 'S'},
+                                          {"simp", no_arg, 'S'},         {"sim", no_arg, 'S'},
+                                          {"si", no_arg, 'S'},           {"hexdump", no_arg, 'x'},
+                                          {"hexdum", no_arg, 'x'},       {"hexdu", no_arg, 'x'},
+                                          {"hexd", no_arg, 'x'},         {"hex", no_arg, 'x'},
+                                          {"width", require_arg, 'w'},   {"widt", require_arg, 'w'},
+                                          {"wid", require_arg, 'w'},     {"wi", require_arg, 'w'},
+                                          {"polling", require_arg, 'p'}, {"pollin", require_arg, 'p'},
+                                          {"polli", require_arg, 'p'},   {"poll", require_arg, 'p'},
+                                          {"pol", require_arg, 'p'},     {"po", require_arg, 'p'},
+                                          {"fields", require_arg, 'f'},  {"field", require_arg, 'f'},
+                                          {"fiel", require_arg, 'f'},    {"fie", require_arg, 'f'},
+                                          {"fi", require_arg, 'f'},      {"version", no_arg, 'V'},
+                                          {"versio", no_arg, 'V'},       {"versi", no_arg, 'V'},
+                                          {"vers", no_arg, 'V'},         {"ver", no_arg, 'V'},
+                                          {"ve", no_arg, 'V'},           {NULL, 0, '\0'}};
 
 /*-------------------------------------------------------------------------
  * Function: doprint()
@@ -89,8 +89,6 @@ static struct long_options l_opts[] = {{"help", no_arg, 'h'},         {"hel", no
  *
  * Return: 0 on success; negative on failure
  *
- * Programmer: Vailin Choi; August 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -121,11 +119,11 @@ doprint(hid_t did, const hsize_t *start, const hsize_t *block, int rank)
         subset.block.data[i]  = block[i];
     } /* end for */
 
-    HDmemset(&ctx, 0, sizeof(ctx));
+    memset(&ctx, 0, sizeof(ctx));
     ctx.sset = &subset;
 
     /* Set to all default values and then override */
-    HDmemset(&info, 0, sizeof info);
+    memset(&info, 0, sizeof info);
 
     if (g_simple_output) {
         info.idx_fmt        = "";
@@ -173,9 +171,9 @@ doprint(hid_t did, const hsize_t *start, const hsize_t *block, int rank)
     } /* end else */
 
     /* Floating point types should display full precision */
-    sprintf(fmt_float, "%%1.%dg", FLT_DIG);
+    snprintf(fmt_float, sizeof(fmt_float), "%%1.%dg", FLT_DIG);
     info.fmt_float = fmt_float;
-    sprintf(fmt_double, "%%1.%dg", DBL_DIG);
+    snprintf(fmt_double, sizeof(fmt_double), "%%1.%dg", DBL_DIG);
     info.fmt_double = fmt_double;
 
     info.dset_format     = "DSET-%s ";
@@ -192,14 +190,14 @@ doprint(hid_t did, const hsize_t *start, const hsize_t *block, int rank)
     if (g_display_hex) {
         /* Print all data in hexadecimal format if the `-x' or `--hexdump'
          * command line switch was given. */
-        info.raw = TRUE;
+        info.raw = true;
     } /* end if */
 
     /* Print the values. */
     if ((ret_value = h5tools_dump_dset(stdout, &info, &ctx, did)) < 0)
         error_msg("unable to print data\n");
 
-    HDfprintf(stdout, "\n");
+    fprintf(stdout, "\n");
 
     return ret_value;
 
@@ -221,8 +219,6 @@ doprint(hid_t did, const hsize_t *start, const hsize_t *block, int rank)
  * Return:      Non-negative on success
  *              Negative on failure
  *
- * Programmer:  Vailin Choi; August 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -277,8 +273,6 @@ done:
  * Return:      Non-negative on success: dataset can be monitored
  *              Negative on failure: dataset cannot be monitored
  *
- * Programmer:  Vailin Choi; August 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -292,7 +286,7 @@ monitor_dataset(hid_t fid, char *dsetname)
     hsize_t cur_dims[H5S_MAX_RANK];  /* previous dataspace dimensions */
     herr_t  ret_value = SUCCEED;     /* return value */
 
-    HDfprintf(stdout, "Monitoring dataset %s...\n", dsetname);
+    fprintf(stdout, "Monitoring dataset %s...\n", dsetname);
 
     /* Open the dataset for minitoring */
     if ((did = H5Dopen2(fid, dsetname, H5P_DEFAULT)) < 0) {
@@ -312,7 +306,7 @@ monitor_dataset(hid_t fid, char *dsetname)
         ret_value = FAIL;
         goto done;
     }
-    HDfflush(stdout);
+    fflush(stdout);
 
     /* Loop until an error occurs or the user interrupts execution */
     while (!g_user_interrupt) {
@@ -339,14 +333,13 @@ monitor_dataset(hid_t fid, char *dsetname)
         if (i != ndims) {
             /* Printing changes in dimension sizes */
             for (u = 0; u < ndims; u++) {
-                HDfprintf(stdout, "dimension %d: %" PRIuHSIZE "->%" PRIuHSIZE "", u, prev_dims[u],
-                          cur_dims[u]);
+                fprintf(stdout, "dimension %d: %" PRIuHSIZE "->%" PRIuHSIZE "", u, prev_dims[u], cur_dims[u]);
                 if (cur_dims[u] > prev_dims[u])
-                    HDfprintf(stdout, " (increases)\n");
+                    fprintf(stdout, " (increases)\n");
                 else if (cur_dims[u] < prev_dims[u])
-                    HDfprintf(stdout, " (decreases)\n");
+                    fprintf(stdout, " (decreases)\n");
                 else
-                    HDfprintf(stdout, " (unchanged)\n");
+                    fprintf(stdout, " (unchanged)\n");
             }
 
             /* Printing elements appended to the dataset if there is */
@@ -360,7 +353,7 @@ monitor_dataset(hid_t fid, char *dsetname)
 
                     /* Print the new appended data to the dataset */
                     if (cur_dims[u] > prev_dims[u]) {
-                        HDfprintf(stdout, "    Data:\n");
+                        fprintf(stdout, "    Data:\n");
 
                         for (j = 0; j < ndims; j++) {
                             start[j] = 0;
@@ -374,17 +367,17 @@ monitor_dataset(hid_t fid, char *dsetname)
                     }
                 } /* end for */
             }
-            HDfflush(stdout);
+            fflush(stdout);
         }
 
         /* Save the current dimension sizes */
-        HDmemcpy(prev_dims, cur_dims, (size_t)ndims * sizeof(hsize_t));
+        memcpy(prev_dims, cur_dims, (size_t)ndims * sizeof(hsize_t));
 
         /* Sleep before next monitor */
         HDsleep(g_polling_interval);
     } /* end while */
 
-    HDfflush(stdout);
+    fflush(stdout);
 
 done:
     /* Closing */
@@ -403,8 +396,6 @@ done:
  *
  * Return: 0 on success; negative on failure
  *
- * Programmer:  Vailin Choi; August 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -415,7 +406,7 @@ process_cmpd_fields(hid_t fid, char *dsetname)
     size_t len;                 /* number of comma-separated fields in "g_list_of_fields" */
     herr_t ret_value = SUCCEED; /* Return value */
 
-    HDassert(g_list_of_fields && *g_list_of_fields);
+    assert(g_list_of_fields && *g_list_of_fields);
 
     /* Open the dataset */
     if ((did = H5Dopen2(fid, dsetname, H5P_DEFAULT)) < 0) {
@@ -439,17 +430,17 @@ process_cmpd_fields(hid_t fid, char *dsetname)
     }
 
     /* Make a copy of "g_list_of_fields" */
-    if ((g_dup_fields = HDstrdup(g_list_of_fields)) == NULL) {
+    if ((g_dup_fields = strdup(g_list_of_fields)) == NULL) {
         error_msg("error in duplicating g_list_of_fields\n");
         ret_value = FAIL;
         goto done;
     }
 
     /* Estimate the number of comma-separated fields in "g_list of_fields" */
-    len = HDstrlen(g_list_of_fields) / 2 + 2;
+    len = strlen(g_list_of_fields) / 2 + 2;
 
     /* Allocate memory for a list vector of H5LD_memb_t structures to store "g_list_of_fields" info */
-    if ((g_listv = (H5LD_memb_t **)HDcalloc(len, sizeof(H5LD_memb_t *))) == NULL) {
+    if ((g_listv = (H5LD_memb_t **)calloc(len, sizeof(H5LD_memb_t *))) == NULL) {
         error_msg("error in allocating memory for H5LD_memb_t\n");
         ret_value = FAIL;
         goto done;
@@ -482,8 +473,6 @@ done:
  * Return:      Non-negative on success: dataset can be monitored
  *              Negative on failure: dataset cannot be monitored
  *
- * Programmer:  Vailin Choi; August 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -496,7 +485,7 @@ check_dataset(hid_t fid, char *dsetname)
     unsigned     u;                      /* Local index variable */
     hsize_t      cur_dims[H5S_MAX_RANK]; /* size of dataspace dimensions */
     hsize_t      max_dims[H5S_MAX_RANK]; /* maximum size of dataspace dimensions */
-    hbool_t      unlim_max_dims = FALSE; /* whether dataset has unlimited or max. dimension setting */
+    bool         unlim_max_dims = false; /* whether dataset has unlimited or max. dimension setting */
     void        *edata;
     H5E_auto2_t  func;
     H5D_layout_t layout;
@@ -532,8 +521,8 @@ check_dataset(hid_t fid, char *dsetname)
         goto done;
     }
 
-    HDmemset(cur_dims, 0, sizeof cur_dims);
-    HDmemset(max_dims, 0, sizeof max_dims);
+    memset(cur_dims, 0, sizeof cur_dims);
+    memset(max_dims, 0, sizeof max_dims);
 
     /* Get dataset's dataspace */
     if ((sid = H5Dget_space(did)) < 0) {
@@ -552,7 +541,7 @@ check_dataset(hid_t fid, char *dsetname)
     /* Check whether dataset has unlimited dimension or max. dimension setting */
     for (u = 0; u < (unsigned)ndims; u++)
         if (max_dims[u] == H5S_UNLIMITED || cur_dims[u] != max_dims[u]) {
-            unlim_max_dims = TRUE;
+            unlim_max_dims = true;
             break;
         }
 
@@ -581,8 +570,6 @@ done:
  *
  * Return:      Does not return
  *
- * Programmer:  Vailin Choi; August 2010
- *
  *
  *-------------------------------------------------------------------------
  */
@@ -601,53 +588,51 @@ leave(int ret)
  *
  * Return:      void
  *
- * Programmer:  Vailin Choi; August 2010
- *
  *-------------------------------------------------------------------------
  */
 static void
 usage(const char *prog)
 {
-    HDfflush(stdout);
-    HDfprintf(stdout, "Usage: %s [OPTIONS] [OBJECT]\n", prog);
-    HDfprintf(stdout, "\n");
-    HDfprintf(stdout, "     OPTIONS\n");
-    HDfprintf(stdout, "        --help            Print a usage message and exit.\n");
-    HDfprintf(stdout, "        --version         Print version number and exit.\n");
-    HDfprintf(stdout, "        --label           Label members of compound typed dataset.\n");
-    HDfprintf(stdout, "        --simple          Use a machine-readable output format.\n");
-    HDfprintf(stdout, "        --dim             Monitor changes in size of dataset dimensions only.\n");
-    HDfprintf(stdout, "        --width=N         Set the number of columns to N for output.\n");
-    HDfprintf(stdout, "                              A value of 0 sets the number of columns to the\n");
-    HDfprintf(stdout, "                              maximum (65535). The default width is 80 columns.\n");
-    HDfprintf(stdout, "        --polling=N       Set the polling interval to N (in seconds) when the\n");
-    HDfprintf(stdout,
-              "                              dataset will be checked for appended data.  The default\n");
-    HDfprintf(stdout, "                              polling interval is 1.\n");
-    HDfprintf(stdout, "        --fields=<list_of_fields>\n");
-    HDfprintf(stdout,
-              "                              Display data for the fields specified in <list_of_fields>\n");
-    HDfprintf(stdout, "                              for a compound data type.  <list_of_fields> can be\n");
-    HDfprintf(stdout, "                              specified as follows:\n");
-    HDfprintf(stdout, "                                   1) A comma-separated list of field names in a\n");
-    HDfprintf(stdout, "                                   compound data type.  \",\" is the separator\n");
-    HDfprintf(stdout, "                                   for field names while \".\" is the separator\n");
-    HDfprintf(stdout, "                                   for a nested field.\n");
-    HDfprintf(stdout, "                                   2) A single field name in a compound data type.\n");
-    HDfprintf(stdout, "                                   Can use this option multiple times.\n");
-    HDfprintf(stdout, "                              Note that backslash is the escape character to avoid\n");
-    HDfprintf(stdout,
-              "                              characters in field names that conflict with the tool's\n");
-    HDfprintf(stdout, "                              separators.\n");
-    HDfprintf(stdout, "\n");
-    HDfprintf(stdout, "     OBJECT is specified as [<filename>/<path_to_dataset>/<dsetname>]\n");
-    HDfprintf(stdout, "        <filename>            Name of the HDF5 file.  It may be preceded by path\n");
-    HDfprintf(stdout, "                              separated by slashes to the specified HDF5 file.\n");
-    HDfprintf(stdout, "        <path_to_dataset>     Path separated by slashes to the specified dataset\n");
-    HDfprintf(stdout, "        <dsetname>            Name of the dataset\n");
-    HDfprintf(stdout, "\n");
-    HDfprintf(stdout,
-              "     User can end the h5watch process by ctrl-C (SIGINT) or kill the process (SIGTERM).\n");
+    fflush(stdout);
+    fprintf(stdout, "Usage: %s [OPTIONS] [OBJECT]\n", prog);
+    fprintf(stdout, "\n");
+    fprintf(stdout, "     OPTIONS\n");
+    fprintf(stdout, "        --help            Print a usage message and exit.\n");
+    fprintf(stdout, "        --version         Print version number and exit.\n");
+    fprintf(stdout, "        --label           Label members of compound typed dataset.\n");
+    fprintf(stdout, "        --simple          Use a machine-readable output format.\n");
+    fprintf(stdout, "        --dim             Monitor changes in size of dataset dimensions only.\n");
+    fprintf(stdout, "        --width=N         Set the number of columns to N for output.\n");
+    fprintf(stdout, "                              A value of 0 sets the number of columns to the\n");
+    fprintf(stdout, "                              maximum (65535). The default width is 80 columns.\n");
+    fprintf(stdout, "        --polling=N       Set the polling interval to N (in seconds) when the\n");
+    fprintf(stdout,
+            "                              dataset will be checked for appended data.  The default\n");
+    fprintf(stdout, "                              polling interval is 1.\n");
+    fprintf(stdout, "        --fields=<list_of_fields>\n");
+    fprintf(stdout,
+            "                              Display data for the fields specified in <list_of_fields>\n");
+    fprintf(stdout, "                              for a compound data type.  <list_of_fields> can be\n");
+    fprintf(stdout, "                              specified as follows:\n");
+    fprintf(stdout, "                                   1) A comma-separated list of field names in a\n");
+    fprintf(stdout, "                                   compound data type.  \",\" is the separator\n");
+    fprintf(stdout, "                                   for field names while \".\" is the separator\n");
+    fprintf(stdout, "                                   for a nested field.\n");
+    fprintf(stdout, "                                   2) A single field name in a compound data type.\n");
+    fprintf(stdout, "                                   Can use this option multiple times.\n");
+    fprintf(stdout, "                              Note that backslash is the escape character to avoid\n");
+    fprintf(stdout,
+            "                              characters in field names that conflict with the tool's\n");
+    fprintf(stdout, "                              separators.\n");
+    fprintf(stdout, "\n");
+    fprintf(stdout, "     OBJECT is specified as [<filename>/<path_to_dataset>/<dsetname>]\n");
+    fprintf(stdout, "        <filename>            Name of the HDF5 file.  It may be preceded by path\n");
+    fprintf(stdout, "                              separated by slashes to the specified HDF5 file.\n");
+    fprintf(stdout, "        <path_to_dataset>     Path separated by slashes to the specified dataset\n");
+    fprintf(stdout, "        <dsetname>            Name of the dataset\n");
+    fprintf(stdout, "\n");
+    fprintf(stdout,
+            "     User can end the h5watch process by ctrl-C (SIGINT) or kill the process (SIGTERM).\n");
 
 } /* usage() */
 
@@ -659,8 +644,6 @@ usage(const char *prog)
  * Return:      Success:    Set the corresponding command flags and return void
  *              Failure:    Exits program with EXIT_FAILURE value.
  *
- * Programmer:  Vailin Choi; August 2010
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -676,7 +659,7 @@ parse_command_line(int argc, const char *const *argv)
     }
 
     /* parse command line options */
-    while ((opt = get_option(argc, argv, s_opts, l_opts)) != EOF) {
+    while ((opt = H5_get_option(argc, argv, s_opts, l_opts)) != EOF) {
         switch ((char)opt) {
             case '?':
             case 'h': /* --help */
@@ -690,7 +673,7 @@ parse_command_line(int argc, const char *const *argv)
                 break;
 
             case 'w': /* --width=N */
-                g_display_width = (int)HDstrtol(opt_arg, NULL, 0);
+                g_display_width = (int)strtol(H5_optarg, NULL, 0);
                 if (g_display_width < 0) {
                     usage(h5tools_getprogname());
                     leave(EXIT_FAILURE);
@@ -698,20 +681,20 @@ parse_command_line(int argc, const char *const *argv)
                 break;
 
             case 'd': /* --dim */
-                g_monitor_size_only = TRUE;
+                g_monitor_size_only = true;
                 break;
 
             case 'S': /* --simple */
-                g_simple_output = TRUE;
+                g_simple_output = true;
                 break;
 
             case 'l': /* --label */
-                g_label = TRUE;
+                g_label = true;
                 break;
 
             case 'p': /* --polling=N */
-                /* g_polling_interval = HDstrtod(opt_arg, NULL); */
-                if ((tmp = (int)HDstrtol(opt_arg, NULL, 10)) <= 0) {
+                /* g_polling_interval = strtod(H5_optarg, NULL); */
+                if ((tmp = (int)strtol(H5_optarg, NULL, 10)) <= 0) {
                     usage(h5tools_getprogname());
                     leave(EXIT_FAILURE);
                 }
@@ -720,7 +703,7 @@ parse_command_line(int argc, const char *const *argv)
 
             case 'f': /* --fields=<list_of_fields> */
                 if (g_list_of_fields == NULL) {
-                    if ((g_list_of_fields = HDstrdup(opt_arg)) == NULL) {
+                    if ((g_list_of_fields = strdup(H5_optarg)) == NULL) {
                         error_msg("memory allocation failed (file %s:line %d)\n", __FILE__, __LINE__);
                         leave(EXIT_FAILURE);
                     }
@@ -728,17 +711,17 @@ parse_command_line(int argc, const char *const *argv)
                 else {
                     char *str;
 
-                    if ((str = HDstrdup(opt_arg)) == NULL) {
+                    if ((str = strdup(H5_optarg)) == NULL) {
                         error_msg("memory allocation failed (file %s:line %d)\n", __FILE__, __LINE__);
                         leave(EXIT_FAILURE);
                     }
-                    if ((g_list_of_fields = (char *)HDrealloc(
-                             g_list_of_fields, HDstrlen(g_list_of_fields) + HDstrlen(str) + 2)) == NULL) {
+                    if ((g_list_of_fields = (char *)realloc(g_list_of_fields, strlen(g_list_of_fields) +
+                                                                                  strlen(str) + 2)) == NULL) {
                         error_msg("memory allocation failed (file %s:line %d)\n", __FILE__, __LINE__);
                         leave(EXIT_FAILURE);
                     }
-                    HDstrcat(g_list_of_fields, FIELD_SEP);
-                    HDstrcat(g_list_of_fields, str);
+                    strcat(g_list_of_fields, FIELD_SEP);
+                    strcat(g_list_of_fields, str);
                 }
 
                 break;
@@ -750,7 +733,7 @@ parse_command_line(int argc, const char *const *argv)
     }
 
     /* check for object to be processed */
-    if (argc <= opt_ind) {
+    if (argc <= H5_optind) {
         error_msg("missing dataset name\n");
         usage(h5tools_getprogname());
         leave(EXIT_FAILURE);
@@ -765,15 +748,13 @@ parse_command_line(int argc, const char *const *argv)
  *
  * Return:      No return
  *
- * Programmer:  Vailin Choi; November 2014
- *
  *-------------------------------------------------------------------------
  */
 static void
 catch_signal(int H5_ATTR_UNUSED signo)
 {
     /* Set the flag to get out of the main loop */
-    g_user_interrupt = TRUE;
+    g_user_interrupt = true;
 } /* catch_signal() */
 
 /*-------------------------------------------------------------------------
@@ -784,8 +765,6 @@ catch_signal(int H5_ATTR_UNUSED signo)
  * Return:      Success:    0
  *              Failure:    1
  *
- * Programmer:  Vailin Choi; August 2010
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -806,13 +785,13 @@ main(int argc, char *argv[])
     h5tools_init();
 
     /* To exit from h5watch for SIGTERM signal */
-    if (HDsignal(SIGTERM, catch_signal) == SIG_ERR) {
+    if (signal(SIGTERM, catch_signal) == SIG_ERR) {
         error_msg("An error occurred while setting a signal handler.\n");
         leave(EXIT_FAILURE);
     }
 
     /* To exit from h5watch for SIGINT signal */
-    if (HDsignal(SIGINT, catch_signal) == SIG_ERR) {
+    if (signal(SIGINT, catch_signal) == SIG_ERR) {
         error_msg("An error occurred while setting a signal handler.\n");
         leave(EXIT_FAILURE);
     }
@@ -820,7 +799,7 @@ main(int argc, char *argv[])
     /* parse command line options */
     parse_command_line(argc, (const char *const *)argv);
 
-    if (argc <= opt_ind) {
+    if (argc <= H5_optind) {
         error_msg("missing dataset name\n");
         usage(h5tools_getprogname());
         leave(EXIT_FAILURE);
@@ -844,7 +823,7 @@ main(int argc, char *argv[])
      * then there must have been something wrong with the file (perhaps it
      * doesn't exist).
      */
-    if ((fname = HDstrdup(argv[opt_ind])) == NULL) {
+    if ((fname = strdup(argv[H5_optind])) == NULL) {
         error_msg("memory allocation failed (file %s:line %d)\n", __FILE__, __LINE__);
         h5tools_setstatus(EXIT_FAILURE);
         goto done;
@@ -864,17 +843,17 @@ main(int argc, char *argv[])
 
     do {
         while (fname && *fname) {
-            fid = h5tools_fopen(fname, H5F_ACC_RDONLY | H5F_ACC_SWMR_READ, fapl, FALSE, drivername,
+            fid = h5tools_fopen(fname, H5F_ACC_RDONLY | H5F_ACC_SWMR_READ, fapl, false, drivername,
                                 sizeof drivername);
 
             if (fid >= 0) {
-                HDfprintf(stdout, "Opened \"%s\" with %s driver.\n", fname, drivername);
+                fprintf(stdout, "Opened \"%s\" with %s driver.\n", fname, drivername);
                 break; /*success*/
             }          /* end if */
 
             /* Shorten the file name; lengthen the object name */
             x     = dname;
-            dname = HDstrrchr(fname, '/');
+            dname = strrchr(fname, '/');
             if (x)
                 *x = '/';
             if (!dname)
@@ -898,7 +877,7 @@ main(int argc, char *argv[])
     else {
         *dname = '/';
         x      = dname;
-        if ((dname = HDstrdup(dname)) == NULL) {
+        if ((dname = strdup(dname)) == NULL) {
             error_msg("memory allocation failed (file %s:line %d)\n", __FILE__, __LINE__);
             h5tools_setstatus(EXIT_FAILURE);
             goto done;
@@ -928,17 +907,17 @@ main(int argc, char *argv[])
 done:
     /* Free spaces */
     if (fname)
-        HDfree(fname);
+        free(fname);
     if (dname)
-        HDfree(dname);
+        free(dname);
     if (g_list_of_fields)
-        HDfree(g_list_of_fields);
+        free(g_list_of_fields);
     if (g_listv) {
         H5LD_clean_vector(g_listv);
-        HDfree(g_listv);
+        free(g_listv);
     }
     if (g_dup_fields)
-        HDfree(g_dup_fields);
+        free(g_dup_fields);
 
     /* Close the file access property list */
     if (fapl >= 0 && H5Pclose(fapl) < 0) {
