@@ -10,12 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/*
- *  For details of the HDF libraries, see the HDF Documentation at:
- *    http://hdfgroup.org/HDF5/doc/
- *
- */
-
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -27,9 +21,6 @@ extern "C" {
  *  Each routine wraps a single HDF entry point, generally with the
  *  analogous arguments and return codes.
  *
- *  For details of the HDF libraries, see the HDF Documentation at:
- *   http://www.hdfgroup.org/HDF5/doc/
- *
  */
 
 #include <jni.h>
@@ -298,7 +289,7 @@ Java_hdf_hdf5lib_H5_H5Eget_1class_1name(JNIEnv *env, jclass clss, jlong cls_id)
     if (!buf_size)
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Eget_class_name: no class name");
 
-    if (NULL == (namePtr = (char *)HDmalloc(sizeof(char) * (size_t)buf_size + 1)))
+    if (NULL == (namePtr = (char *)malloc(sizeof(char) * (size_t)buf_size + 1)))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Eget_class_name: malloc failed");
 
     if ((H5Eget_class_name((hid_t)cls_id, (char *)namePtr, (size_t)buf_size + 1)) < 0)
@@ -310,7 +301,7 @@ Java_hdf_hdf5lib_H5_H5Eget_1class_1name(JNIEnv *env, jclass clss, jlong cls_id)
 
 done:
     if (namePtr)
-        HDfree(namePtr);
+        free(namePtr);
 
     return str;
 } /* end Java_hdf_hdf5lib_H5_H5Eget_1class_1name */
@@ -452,7 +443,7 @@ Java_hdf_hdf5lib_H5_H5Eget_1msg(JNIEnv *env, jclass clss, jlong msg_id, jintArra
     if (!buf_size)
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Eget_msg: invalid message");
 
-    if (NULL == (namePtr = (char *)HDmalloc(sizeof(char) * (size_t)buf_size + 1)))
+    if (NULL == (namePtr = (char *)malloc(sizeof(char) * (size_t)buf_size + 1)))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Eget_msg: malloc failed");
 
     PIN_INT_ARRAY(ENVONLY, error_msg_type_list, theArray, NULL, "H5Eget_msg: error_msg_type_list not pinned");
@@ -461,7 +452,7 @@ Java_hdf_hdf5lib_H5_H5Eget_1msg(JNIEnv *env, jclass clss, jlong msg_id, jintArra
         H5_LIBRARY_ERROR(ENVONLY);
     namePtr[buf_size] = '\0';
 
-    theArray[0] = error_msg_type;
+    theArray[0] = (jint)error_msg_type;
 
     if (NULL == (str = ENVPTR->NewStringUTF(ENVONLY, namePtr)))
         CHECK_JNI_EXCEPTION(ENVONLY, JNI_FALSE);
@@ -470,7 +461,7 @@ done:
     if (theArray)
         UNPIN_INT_ARRAY(ENVONLY, error_msg_type_list, theArray, 0);
     if (namePtr)
-        HDfree(namePtr);
+        free(namePtr);
 
     return str;
 } /* end Java_hdf_hdf5lib_H5_H5Eget_1msg */
