@@ -47,23 +47,27 @@ import org.junit.rules.TestName;
  */
 public class TestH5 {
     @Rule
-    public TestName testname                     = new TestName();
-    private static final String H5_FILE          = "testData.h5";
-    private static final String EXPORT_FILE      = "testExport.txt";
-    private static final String H5_DREG_FILE     = "trefer_reg.h5";
-    private static final String EXPORT_DREG_FILE = "testExportReg.txt";
-    private static final String H5_AREG_FILE     = "tattrreg.h5";
-    private static final String EXPORT_AREG_FILE = "testExportAReg.txt";
-    private static final int DIM_X               = 4;
-    private static final int DIM_Y               = 6;
-    private static final int DIM_BLKS            = 36;
-    private static final int DIM_PNTS            = 10;
-    private static final int DIM_ATTR            = 12;
-    private static final int RANK                = 2;
-    long H5fid                                   = HDF5Constants.H5I_INVALID_HID;
-    long H5dsid                                  = HDF5Constants.H5I_INVALID_HID;
-    long H5did                                   = HDF5Constants.H5I_INVALID_HID;
-    long[] H5dims                                = {DIM_X, DIM_Y};
+    public TestName testname                       = new TestName();
+    private static final String H5_FILE            = "testData.h5";
+    private static final String EXPORT_FILE        = "testExport.txt";
+    private static final String H5_REGION_FILE     = "trefer_reg.h5";
+    private static final String EXPORT_REGION_FILE = "testExportReg.txt";
+    private static final String H5_ATTR_FILE       = "trefer_attr.h5";
+    private static final String EXPORT_ATTR_FILE   = "testExportAttr.txt";
+    private static final String H5_DREG_FILE       = "tdatareg.h5";
+    private static final String EXPORT_DREG_FILE   = "testExportDReg.txt";
+    private static final String H5_AREG_FILE       = "tattrreg.h5";
+    private static final String EXPORT_AREG_FILE   = "testExportAReg.txt";
+    private static final int DIM_X                 = 4;
+    private static final int DIM_Y                 = 6;
+    private static final int DIM_BLKS              = 36;
+    private static final int DIM_PNTS              = 10;
+    private static final int DIM_ATTR              = 12;
+    private static final int RANK                  = 2;
+    long H5fid                                     = HDF5Constants.H5I_INVALID_HID;
+    long H5dsid                                    = HDF5Constants.H5I_INVALID_HID;
+    long H5did                                     = HDF5Constants.H5I_INVALID_HID;
+    long[] H5dims                                  = {DIM_X, DIM_Y};
 
     private final void _deleteFile(String filename)
     {
@@ -309,7 +313,7 @@ public class TestH5 {
     @Test
     public void testH5get_libversion()
     {
-        int libversion[] = {1, 10, 9};
+        int libversion[] = {1, 14, 5};
 
         try {
             H5.H5get_libversion(libversion);
@@ -350,7 +354,7 @@ public class TestH5 {
     @Test
     public void testH5check_version()
     {
-        int majnum = 1, minnum = 10, relnum = 10;
+        int majnum = 1, minnum = 14, relnum = 5;
 
         try {
             H5.H5check_version(majnum, minnum, relnum);
@@ -419,7 +423,7 @@ public class TestH5 {
         }
     }
 
-    @Test
+    @Ignore
     public void testH5export_dataset()
     {
         int[][] dset_data   = new int[DIM_X][DIM_Y];
@@ -485,7 +489,91 @@ public class TestH5 {
         _deleteH5file();
     }
 
-    @Test
+    @Ignore
+    public void testH5export_region()
+    {
+        int[] dset_data_expect = {66,  69,  72,  75,  78,  81,  96,  99,  102, 105, 108, 111,
+                                  126, 129, 132, 135, 138, 141, 156, 159, 162, 165, 168, 171,
+                                  186, 189, 192, 195, 198, 201, 216, 219, 222, 225, 228, 231,
+                                  207, 66,  252, 48,  84,  96,  12,  14,  213, 99};
+        int[] dset_indata      = new int[DIM_BLKS + DIM_PNTS];
+        String objName         = "/Dataset1";
+
+        _openH5File(H5_REGION_FILE, objName);
+
+        try {
+            H5.H5export_dataset(EXPORT_REGION_FILE, H5fid, objName, 99);
+        }
+        catch (HDF5LibraryException err) {
+            err.printStackTrace();
+            fail("H5export_dataset failed: " + err);
+        }
+
+        File file = new File(EXPORT_REGION_FILE);
+
+        try {
+            Reader reader                   = new FileReader(EXPORT_REGION_FILE);
+            StreamTokenizer streamTokenizer = new StreamTokenizer(reader);
+            int indx                        = 0;
+            while (streamTokenizer.nextToken() != StreamTokenizer.TT_EOF) {
+                if (streamTokenizer.ttype == StreamTokenizer.TT_NUMBER) {
+                    dset_indata[indx] = (int)streamTokenizer.nval;
+                    indx++;
+                }
+            }
+            reader.close();
+        }
+        catch (IOException err) {
+            err.printStackTrace();
+            fail("read file failed: " + err);
+        }
+        for (int row = 0; row < DIM_X; row++)
+            assertTrue("testH5export_region: <" + row + ">" + dset_indata[row],
+                       dset_indata[row] == dset_data_expect[row]);
+    }
+
+    @Ignore
+    public void testH5export_attribute()
+    {
+        int[] dset_data_expect = {0, 3, 6, 9, 1, 4, 7, 10, 2, 5, 8, 11};
+        int[] dset_indata      = new int[DIM_ATTR];
+        String objName         = "/Dataset3";
+
+        _openH5File(H5_ATTR_FILE, objName);
+
+        try {
+            H5.H5export_dataset(EXPORT_ATTR_FILE, H5did, objName, 99);
+        }
+        catch (HDF5LibraryException err) {
+            err.printStackTrace();
+            fail("H5export_dataset failed: " + err);
+        }
+
+        File file = new File(EXPORT_ATTR_FILE);
+
+        try {
+            Reader reader                   = new FileReader(EXPORT_ATTR_FILE);
+            StreamTokenizer streamTokenizer = new StreamTokenizer(reader);
+            int indx                        = 0;
+            int jndx                        = 0;
+            while (streamTokenizer.nextToken() != StreamTokenizer.TT_EOF) {
+                if (streamTokenizer.ttype == StreamTokenizer.TT_NUMBER) {
+                    dset_indata[indx] = (int)streamTokenizer.nval;
+                    indx++;
+                }
+            }
+            reader.close();
+        }
+        catch (IOException err) {
+            err.printStackTrace();
+            fail("read file failed: " + err);
+        }
+        for (int row = 0; row < DIM_X; row++)
+            assertTrue("testH5export_attribute: <" + row + ">" + dset_indata[row],
+                       dset_indata[row] == dset_data_expect[row]);
+    }
+
+    @Ignore
     public void testH5export_regdataset()
     {
         int[] dset_data_expect = {66,  69,  72,  75,  78,  81,  96,  99,  102, 105, 108, 111,
@@ -528,7 +616,7 @@ public class TestH5 {
                        dset_indata[row] == dset_data_expect[row]);
     }
 
-    @Test
+    @Ignore
     public void testH5export_attrdataset()
     {
         int[] dset_data_expect = {66,  69,  72,  75,  78,  81,  96,  99,  102, 105, 108, 111,
