@@ -23,6 +23,7 @@ import hdf.hdf5lib.H5;
 import hdf.hdf5lib.HDF5Constants;
 import hdf.hdf5lib.exceptions.HDF5LibraryException;
 import hdf.hdf5lib.structs.H5G_info_t;
+import hdf.hdf5lib.structs.H5O_token_t;
 
 import org.junit.After;
 import org.junit.Before;
@@ -324,14 +325,14 @@ public class TestH5G {
         }
         assertNotNull("TestH5G.testH5Gget_obj_info_all: ", info);
         assertTrue("TestH5G.testH5Gget_obj_info_all: number of links is empty", info.nlinks > 0);
-        String objNames[] = new String[(int)info.nlinks];
-        int objTypes[]    = new int[(int)info.nlinks];
-        int lnkTypes[]    = new int[(int)info.nlinks];
-        long objRefs[]    = new long[(int)info.nlinks];
+        String objNames[]       = new String[(int)info.nlinks];
+        int objTypes[]          = new int[(int)info.nlinks];
+        int lnkTypes[]          = new int[(int)info.nlinks];
+        H5O_token_t objTokens[] = new H5O_token_t[(int)info.nlinks];
 
         int names_found = 0;
         try {
-            names_found = H5.H5Gget_obj_info_all(H5fid, GROUPS[0], objNames, objTypes, lnkTypes, objRefs,
+            names_found = H5.H5Gget_obj_info_all(H5fid, GROUPS[0], objNames, objTypes, lnkTypes, objTokens,
                                                  HDF5Constants.H5_INDEX_NAME);
         }
         catch (Throwable err) {
@@ -358,14 +359,14 @@ public class TestH5G {
             info = H5.H5Gget_info(gid);
             assertNotNull("TestH5G.testH5Gget_obj_info_all_gid: ", info);
             assertTrue("TestH5G.testH5Gget_obj_info_all_gid: number of links is empty", info.nlinks > 0);
-            String objNames[] = new String[(int)info.nlinks];
-            long objRefs[]    = new long[(int)info.nlinks];
-            int lnkTypes[]    = new int[(int)info.nlinks];
-            int objTypes[]    = new int[(int)info.nlinks];
+            String objNames[]       = new String[(int)info.nlinks];
+            H5O_token_t objTokens[] = new H5O_token_t[(int)info.nlinks];
+            int lnkTypes[]          = new int[(int)info.nlinks];
+            int objTypes[]          = new int[(int)info.nlinks];
 
             int names_found = 0;
             try {
-                names_found = H5.H5Gget_obj_info_all(gid, null, objNames, objTypes, lnkTypes, objRefs,
+                names_found = H5.H5Gget_obj_info_all(gid, null, objNames, objTypes, lnkTypes, objTokens,
                                                      HDF5Constants.H5_INDEX_NAME);
             }
             catch (Throwable err) {
@@ -406,14 +407,14 @@ public class TestH5G {
             info = H5.H5Gget_info(gid);
             assertNotNull("TestH5G.testH5Gget_obj_info_all_gid2: ", info);
             assertTrue("TestH5G.testH5Gget_obj_info_all_gid2: number of links is empty", info.nlinks > 0);
-            String objNames[] = new String[(int)info.nlinks];
-            long objRefs[]    = new long[(int)info.nlinks];
-            int lnkTypes[]    = new int[(int)info.nlinks];
-            int objTypes[]    = new int[(int)info.nlinks];
+            String objNames[]       = new String[(int)info.nlinks];
+            H5O_token_t objTokens[] = new H5O_token_t[(int)info.nlinks];
+            int lnkTypes[]          = new int[(int)info.nlinks];
+            int objTypes[]          = new int[(int)info.nlinks];
 
             int names_found = 0;
             try {
-                names_found = H5.H5Gget_obj_info_all(gid, null, objNames, objTypes, lnkTypes, objRefs,
+                names_found = H5.H5Gget_obj_info_all(gid, null, objNames, objTypes, lnkTypes, objTokens,
                                                      HDF5Constants.H5_INDEX_NAME);
             }
             catch (Throwable err) {
@@ -446,16 +447,17 @@ public class TestH5G {
     @Test
     public void testH5Gget_obj_info_max()
     {
-        long gid             = _openGroup(H5fid, GROUPS[0]);
-        long groups_max_size = GROUPS.length + 1;
-        String objNames[]    = new String[(int)groups_max_size];
-        int objTypes[]       = new int[(int)groups_max_size];
-        int lnkTypes[]       = new int[(int)groups_max_size];
-        long objRefs[]       = new long[(int)groups_max_size];
+        long gid                = _openGroup(H5fid, GROUPS[0]);
+        long groups_max_size    = GROUPS.length + 1;
+        String objNames[]       = new String[(int)groups_max_size];
+        int objTypes[]          = new int[(int)groups_max_size];
+        int lnkTypes[]          = new int[(int)groups_max_size];
+        H5O_token_t objTokens[] = new H5O_token_t[(int)groups_max_size];
 
         int names_found = 0;
         try {
-            names_found = H5.H5Gget_obj_info_max(gid, objNames, objTypes, lnkTypes, objRefs, groups_max_size);
+            names_found =
+                H5.H5Gget_obj_info_max(gid, objNames, objTypes, lnkTypes, objTokens, groups_max_size);
         }
         catch (Throwable err) {
             err.printStackTrace();
@@ -482,16 +484,17 @@ public class TestH5G {
     @Test
     public void testH5Gget_obj_info_max_limit()
     {
-        long gid             = _openGroup(H5fid, GROUPS[0]);
-        long groups_max_size = GROUPS.length - 3;
-        String objNames[]    = new String[(int)groups_max_size];
-        int objTypes[]       = new int[(int)groups_max_size];
-        int lnkTypes[]       = new int[(int)groups_max_size];
-        long objRefs[]       = new long[(int)groups_max_size];
+        long gid                = _openGroup(H5fid, GROUPS[0]);
+        long groups_max_size    = GROUPS.length - 3;
+        String objNames[]       = new String[(int)groups_max_size];
+        int objTypes[]          = new int[(int)groups_max_size];
+        int lnkTypes[]          = new int[(int)groups_max_size];
+        H5O_token_t objTokens[] = new H5O_token_t[(int)groups_max_size];
 
         int names_found = 0;
         try {
-            names_found = H5.H5Gget_obj_info_max(gid, objNames, objTypes, lnkTypes, objRefs, groups_max_size);
+            names_found =
+                H5.H5Gget_obj_info_max(gid, objNames, objTypes, lnkTypes, objTokens, groups_max_size);
         }
         catch (Throwable err) {
             err.printStackTrace();
@@ -539,13 +542,13 @@ public class TestH5G {
 
         assertNotNull("TestH5G.testH5Gget_obj_info_all_byIndexType: ", info);
         assertTrue("TestH5G.testH5Gget_obj_info_all_byIndexType: number of links is empty", info.nlinks > 0);
-        String objNames[] = new String[(int)info.nlinks];
-        int objTypes[]    = new int[(int)info.nlinks];
-        int lnkTypes[]    = new int[(int)info.nlinks];
-        long objRefs[]    = new long[(int)info.nlinks];
+        String objNames[]       = new String[(int)info.nlinks];
+        int objTypes[]          = new int[(int)info.nlinks];
+        int lnkTypes[]          = new int[(int)info.nlinks];
+        H5O_token_t objTokens[] = new H5O_token_t[(int)info.nlinks];
 
         try {
-            H5.H5Gget_obj_info_all(H5fid2, GROUPS2[0], objNames, objTypes, lnkTypes, objRefs,
+            H5.H5Gget_obj_info_all(H5fid2, GROUPS2[0], objNames, objTypes, lnkTypes, objTokens,
                                    HDF5Constants.H5_INDEX_CRT_ORDER);
         }
         catch (Throwable err) {
@@ -558,7 +561,7 @@ public class TestH5G {
         assertEquals("G11", objNames[3]);
 
         try {
-            H5.H5Gget_obj_info_all(H5fid2, GROUPS2[0], objNames, objTypes, lnkTypes, objRefs,
+            H5.H5Gget_obj_info_all(H5fid2, GROUPS2[0], objNames, objTypes, lnkTypes, objTokens,
                                    HDF5Constants.H5_INDEX_NAME);
         }
         catch (Throwable err) {
