@@ -16,10 +16,10 @@
 #ifndef H5Apublic_H
 #define H5Apublic_H
 
-/* Public headers needed by this file */
-#include "H5Ipublic.h" /* IDs			  		*/
-#include "H5Opublic.h" /* Object Headers			*/
-#include "H5Tpublic.h" /* Datatypes				*/
+#include "H5public.h"  /* Generic Functions                        */
+#include "H5Ipublic.h" /* Identifiers                              */
+#include "H5Opublic.h" /* Object Headers                           */
+#include "H5Tpublic.h" /* Datatypes                                */
 
 //! <!-- [H5A_info_t_snip] -->
 /**
@@ -39,10 +39,10 @@ typedef struct {
  * \param[in] location_id The identifier for the group, dataset
  *            or named datatype being iterated over
  * \param[in] attr_name The name of the current object attribute
- * \param[in] ainfo The attribute’s info struct
- * \param[in,out] op_data A pointer to the operator data passed in to
+ * \param[in] ainfo The attribute's info struct
+ * \param[in,out] op_data A pointer to the operator data passed into
  *                H5Aiterate2() or H5Aiterate_by_name()
- * \returns The return values from an operator are:
+ * \return The return values from an operator are:
  *          \li Zero causes the iterator to continue, returning zero when
  *              all attributes have been processed.
  *          \li Positive causes the iterator to immediately return that
@@ -51,6 +51,9 @@ typedef struct {
  *          \li Negative causes the iterator to immediately return that value,
  *              indicating failure. The iterator can be restarted at the next
  *              attribute.
+ *
+ * \since 1.8.0
+ *
  */
 typedef herr_t (*H5A_operator2_t)(hid_t location_id /*in*/, const char *attr_name /*in*/,
                                   const H5A_info_t *ainfo /*in*/, void *op_data /*in,out*/);
@@ -88,6 +91,17 @@ extern "C" {
  * \see H5Acreate(), H5Aopen()
  */
 H5_DLL herr_t H5Aclose(hid_t attr_id);
+/*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Aclose}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Aclose_async(const char *app_file, const char *app_func, unsigned app_line, hid_t attr_id,
+                             hid_t es_id);
+#else
+H5_DLL herr_t H5Aclose_async(hid_t attr_id, hid_t es_id);
+#endif
 /* --------------------------------------------------------------------------*/
 /**
  * \ingroup H5A
@@ -101,7 +115,7 @@ H5_DLL herr_t H5Aclose(hid_t attr_id);
  * \acpl_id
  * \aapl_id
  *
- * \return \hid_tv{attribute}
+ * \return \hid_ti{attribute}
  *
  * \details H5Acreate2() creates an attribute, \p attr_name, which is attached
  *          to the object specified by the identifier \p loc_id.
@@ -111,13 +125,13 @@ H5_DLL herr_t H5Aclose(hid_t attr_id);
  *          The attribute is created with the specified datatype and dataspace,
  *          \p type_id and \p space_id.
  *
- *          \plist_unused{acpl}
+ *          \plist_unused{aapl_id}
  *
  *          The attribute identifier returned by this function must be released
- *          with H5Aclose() resource leaks will develop.
+ *          with H5Aclose() or resource leaks will develop.
  *
- * \note If \p loc_id is a file identifier, the attribute will be attached
- *       that file’s root group.
+ * \note If \p loc_id is a file identifier, the attribute will be attached to
+ *       that file's root group.
  *
  * \par Example
  * \snippet H5A_examples.c create
@@ -129,6 +143,20 @@ H5_DLL herr_t H5Aclose(hid_t attr_id);
  */
 H5_DLL hid_t H5Acreate2(hid_t loc_id, const char *attr_name, hid_t type_id, hid_t space_id, hid_t acpl_id,
                         hid_t aapl_id);
+/*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Acreate}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL hid_t H5Acreate_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
+                             const char *attr_name, hid_t type_id, hid_t space_id, hid_t acpl_id,
+                             hid_t aapl_id, hid_t es_id);
+#else
+H5_DLL hid_t  H5Acreate_async(hid_t loc_id, const char *attr_name, hid_t type_id, hid_t space_id,
+                              hid_t acpl_id, hid_t aapl_id, hid_t es_id);
+#endif
+
 /*--------------------------------------------------------------------------*/
 /**
  * \ingroup H5A
@@ -145,7 +173,7 @@ H5_DLL hid_t H5Acreate2(hid_t loc_id, const char *attr_name, hid_t type_id, hid_
  * \aapl_id
  * \lapl_id
  *
- * \return \hid_tv{attribute}
+ * \return \hid_ti{attribute}
  *
  * \details H5Acreate_by_name() creates an attribute, \p attr_name, which is
  *          attached to the object specified by \p loc_id and \p obj_name.
@@ -158,7 +186,7 @@ H5_DLL hid_t H5Acreate2(hid_t loc_id, const char *attr_name, hid_t type_id, hid_
  *          The attribute is created with the specified datatype and
  *          dataspace, \p type_id and \p space_id.
  *
- *          \plist_unused{aapl}
+ *          \plist_unused{aapl_id}
  *
  *          The link access property list, \p lapl_id, may provide
  *          information regarding the properties of links required to access
@@ -169,6 +197,22 @@ H5_DLL hid_t H5Acreate2(hid_t loc_id, const char *attr_name, hid_t type_id, hid_
  */
 H5_DLL hid_t H5Acreate_by_name(hid_t loc_id, const char *obj_name, const char *attr_name, hid_t type_id,
                                hid_t space_id, hid_t acpl_id, hid_t aapl_id, hid_t lapl_id);
+/*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Acreate_by_name}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL hid_t H5Acreate_by_name_async(const char *app_file, const char *app_func, unsigned app_line,
+                                     hid_t loc_id, const char *obj_name, const char *attr_name, hid_t type_id,
+                                     hid_t space_id, hid_t acpl_id, hid_t aapl_id, hid_t lapl_id,
+                                     hid_t es_id);
+#else
+H5_DLL hid_t H5Acreate_by_name_async(hid_t loc_id, const char *obj_name, const char *attr_name, hid_t type_id,
+                                     hid_t space_id, hid_t acpl_id, hid_t aapl_id, hid_t lapl_id,
+                                     hid_t es_id);
+#endif
+
 /*-------------------------------------------------------------------------*/
 /**
  * \ingroup H5A
@@ -205,13 +249,13 @@ H5_DLL herr_t H5Adelete(hid_t loc_id, const char *attr_name);
  * \param[in] obj_name Name of object, relative to location, from which
  *                     attribute is to be removed
  * \param[in] idx_type Type of index
- * \param[in] order    Order in which to iterate over index
- * \param[in] n        Offset within index
+ * \param[in] order    Order in which to iterate over the index
+ * \param[in] n        Offset within the index
  * \lapl_id
  *
  * \return \herr_t
  *
- * \details H5Adelete_by_idx() removes an attribute, specified by its
+ * \details H5Adelete_by_idx() removes an attribute specified by its
  *          location in an index, from an object.
  *
  *          The object from which the attribute is to be removed is
@@ -223,7 +267,7 @@ H5_DLL herr_t H5Adelete(hid_t loc_id, const char *attr_name);
  *          The order in which the index is to be traversed is specified by
  *          \p order. For example, if \p idx_type, \p order,
  *          and \p n are set to #H5_INDEX_NAME, #H5_ITER_INC, and 5,
- *          respectively, the fifth attribute in lexicographic order of
+ *          respectively, the fifth attribute in the lexicographic order of
  *          attribute names will be removed.
  *
  *          The link access property list, \p lapl_id, may provide
@@ -280,6 +324,18 @@ H5_DLL herr_t H5Adelete_by_name(hid_t loc_id, const char *obj_name, const char *
  *
  */
 H5_DLL htri_t H5Aexists(hid_t obj_id, const char *attr_name);
+/*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Aexists}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Aexists_async(const char *app_file, const char *app_func, unsigned app_line, hid_t obj_id,
+                              const char *attr_name, hbool_t *exists, hid_t es_id);
+#else
+H5_DLL herr_t H5Aexists_async(hid_t obj_id, const char *attr_name, hbool_t *exists, hid_t es_id);
+#endif
+
 /*-------------------------------------------------------------------------*/
 /**
  * \ingroup H5A
@@ -301,7 +357,7 @@ H5_DLL htri_t H5Aexists(hid_t obj_id, const char *attr_name);
  *          \p loc_id specifies a location in the file containing the object.
  *          \p obj_name is the name of the object to which the attribute is
  *          attached and can be a relative name, relative to \p loc_id,
- *          or an absolute name, based in the root group of the file.
+ *          or an absolute name, based on the root group of the file.
  *
  *          The link access property list, \p lapl_id, may provide
  *          information regarding the properties of links required to access
@@ -311,6 +367,20 @@ H5_DLL htri_t H5Aexists(hid_t obj_id, const char *attr_name);
  *
  */
 H5_DLL htri_t H5Aexists_by_name(hid_t obj_id, const char *obj_name, const char *attr_name, hid_t lapl_id);
+/*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Aexists_by_name}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Aexists_by_name_async(const char *app_file, const char *app_func, unsigned app_line,
+                                      hid_t loc_id, const char *obj_name, const char *attr_name,
+                                      hbool_t *exists, hid_t lapl_id, hid_t es_id);
+#else
+H5_DLL herr_t H5Aexists_by_name_async(hid_t loc_id, const char *obj_name, const char *attr_name,
+                                      hbool_t *exists, hid_t lapl_id, hid_t es_id);
+#endif
+
 /*-------------------------------------------------------------------------*/
 /**
  * \ingroup H5A
@@ -319,12 +389,15 @@ H5_DLL htri_t H5Aexists_by_name(hid_t obj_id, const char *obj_name, const char *
  *
  * \attr_id
  *
- * \return \hid_tv{attribute's creation property list}
+ * \return \hid_ti{attribute's creation property list}
  *
  * \details H5Aget_create_plist() returns an identifier for the attribute
  *          creation property list associated with the attribute specified
  *          by \p attr_id.
  *
+ *          The creation property list identifier should be released with
+ *          H5Pclose() to prevent resource leaks.
+ *
  * \since 1.8.0
  *
  */
@@ -333,7 +406,7 @@ H5_DLL hid_t H5Aget_create_plist(hid_t attr_id);
 /**
  * \ingroup H5A
  *
- * \brief Retrieves attribute information, by attribute identifier
+ * \brief Retrieves attribute information by attribute identifier
  *
  * \attr_id
  * \param[out]  ainfo   Attribute information struct
@@ -359,7 +432,7 @@ H5_DLL herr_t H5Aget_info(hid_t attr_id, H5A_info_t *ainfo /*out*/);
  *                       relative to location
  * \param[in]  idx_type  Type of index
  * \param[in]  order     Index traversal order
- * \param[in]  n         Attribute’s position in index
+ * \param[in]  n         Attribute's position in index
  * \param[out] ainfo     Struct containing returned attribute information
  * \lapl_id
  *
@@ -368,7 +441,7 @@ H5_DLL herr_t H5Aget_info(hid_t attr_id, H5A_info_t *ainfo /*out*/);
  * \details H5Aget_info_by_idx() retrieves information for an attribute
  *          that is attached to an object, which is specified by its
  *          location and name, \p loc_id and \p obj_name, respectively.
- *          The attribute is located by its index position and the attribute
+ *          The attribute is located by its index position, and the attribute
  *          information is returned in the \p ainfo struct.
  *
  *          The attribute is located by means of an index type, an index
@@ -388,7 +461,7 @@ H5_DLL herr_t H5Aget_info_by_idx(hid_t loc_id, const char *obj_name, H5_index_t
 /**
  * \ingroup H5A
  *
- * \brief Retrieves attribute information, by attribute name
+ * \brief Retrieves attribute information by attribute name
  *
  * \fgdt_loc_id
  * \param[in] obj_name   Name of the object to which an attribute is attached,
@@ -424,19 +497,13 @@ H5_DLL herr_t H5Aget_info_by_name(hid_t loc_id, const char *obj_name, const char
  * \param[out] buf       Buffer to store name in
  *
  * \return  Returns the length of the attribute's name, which may be longer
- *          than \p buf_size, if successful. Otherwise returns a negative
+ *          than \p buf_size, if successful. Otherwise, returns a negative
  *          value.
  *
  * \details H5Aget_name() retrieves the name of an attribute specified by
- *          the identifier, \p attr_id. Up to \p buf_size characters are
- *          stored in \p buf followed by a \0 string terminator. If the
- *          name of the attribute is longer than (\p buf_size -1), the
- *          string terminator is stored in the last position of the buffer
- *          to properly terminate the string.
+ *          the identifier, \p attr_id.
  *
- *          If the user only wants to retrieve the name length, the
- *          values 0 and NULL should be passed for the parameters
- *          \p bufsize and \p buf.
+ *          \details_namelen{attribute,H5Aget_name}
  *
  * \since 1.0.0
  *
@@ -453,13 +520,13 @@ H5_DLL ssize_t H5Aget_name(hid_t attr_id, size_t buf_size, char *buf);
  *                        relative to location
  * \param[in]  idx_type   Type of index
  * \param[in]  order      Index traversal order
- * \param[in]  n          Attribute’s position in index
+ * \param[in]  n          Attribute's position in index
  * \param[out] name       Attribute name
  * \param[in]  size       Size, in bytes, of attribute name
  * \lapl_id
  *
  * \return Returns attribute name size, in bytes, if successful;
- *         otherwise returns a negative value.
+ *         otherwise, returns a negative value.
  *
  * \details H5Aget_name_by_idx() retrieves the name of an attribute that is
  *          attached to an object, which is specified by its location and
@@ -471,10 +538,7 @@ H5_DLL ssize_t H5Aget_name(hid_t attr_id, size_t buf_size, char *buf);
  *          traversal order, and a position in the index, \p idx_type,
  *          \p order and \p n, respectively.
  *
- *          If the attribute name’s size is unknown, the values 0 and NULL
- *          can be passed in for the parameters \p size and \p name. The
- *          function’s return value will provide the correct value for
- *          \p size.
+ *          \details_namelen{attribute,H5Aget_name_by_idx}
  *
  *          The link access property list, \p lapl_id, may provide
  *          information regarding the properties of links required to access
@@ -494,7 +558,7 @@ H5_DLL ssize_t H5Aget_name_by_idx(hid_t loc_id, const char *obj_name, H5_index_t
  *
  * \attr_id
  *
- * \return \hid_tv{attribute dataspace}
+ * \return \hid_ti{attribute dataspace}
  *
  * \details  H5Aget_space() retrieves a copy of the dataspace for an
  *           attribute. The dataspace identifier returned from this
@@ -514,7 +578,7 @@ H5_DLL hid_t H5Aget_space(hid_t attr_id);
  * \attr_id
  *
  * \return Returns the amount of storage size allocated for the attribute;
- *         otherwise returns 0 (zero).
+ *         otherwise, returns 0 (zero).
  *
  * \details H5Aget_storage_size() returns the amount of storage that is
  *          required for the specified attribute, \p attr_id.
@@ -568,14 +632,14 @@ H5_DLL hid_t H5Aget_type(hid_t attr_id);
  * \details H5Aiterate2() iterates over the attributes attached to a
  *          dataset, named datatype, or group, as specified by \p loc_id.
  *          For each attribute, user-provided data, \p op_data, with
- *          additional information as defined below, is passed to a
+ *          additional information, as defined below, is passed to a
  *          user-defined function, \p op, which operates on that
  *          attribute.
  *
  *          The order of the iteration and the attributes iterated over
  *          are specified by three parameters: the index type,
  *          \p idx_type; the order in which the index is to be traversed,
- *          \p order; and the attribute’s position in the index, \p idx.
+ *          \p order; and the attribute's position in the index, \p idx.
  *          The next attribute to be operated on is specified by \p idx,
  *          a position in the index.
  *
@@ -594,6 +658,9 @@ H5_DLL hid_t H5Aget_type(hid_t attr_id);
  *
  * \note This function is also available through the H5Aiterate() macro.
  *
+ * \warning   Adding or removing attributes to the object during iteration
+ *            will lead to undefined behavior.
+ *
  * \since 1.8.0
  *
  */
@@ -617,20 +684,20 @@ H5_DLL herr_t H5Aiterate2(hid_t loc_id, H5_index_t idx_type, H5_iter_order_t ord
  *
  * \return \herr_t
  *         Further note that this function returns the return value of
- *         the last operator if it was non-zero, which can be a negative
+ *         the last operator if it is non-zero, which can be a negative
  *         value, zero if all attributes were processed, or a positive value
  *         indicating short-circuit success.
  *
  * \details H5Aiterate_by_name() iterates over the attributes attached
  *          to the dataset or group specified with \p loc_id and \p obj_name.
  *          For each attribute, user-provided data, \p op_data, with
- *          additional information as defined below, is passed to a
+ *          additional information, as defined below, is passed to a
  *          user-defined function, \p op, which operates on that attribute.
  *
  *          The order of the iteration and the attributes iterated over
  *          are specified by three parameters: the index type, \p idx_type;
  *          the order in which the index is to be traversed, \p order;
- *          and the attribute’s position in the index, \p idx.
+ *          and the attribute's position in the index, \p idx.
  *          The next attribute to be operated on is specified by \p idx,
  *          a position in the index.
  *
@@ -651,6 +718,9 @@ H5_DLL herr_t H5Aiterate2(hid_t loc_id, H5_index_t idx_type, H5_iter_order_t ord
  *          information regarding the properties of links required to access
  *          the object, \p obj_name.
  *
+ * \warning   Adding or removing attributes to the object during iteration
+ *            will lead to undefined behavior.
+ *
  * \since 1.8.0
  *
  */
@@ -668,10 +738,10 @@ H5_DLL herr_t H5Aiterate_by_name(hid_t loc_id, const char *obj_name, H5_index_t
  * \param[in]  attr_name    Name of attribute to open
  * \aapl_id
  *
- * \return \hid_tv{attribute}
+ * \return \hid_ti{attribute}
  *
  * \details H5Aopen() opens an existing attribute, \p attr_name, that is
- *          attached to object specified by an object identifier, \p obj_id.
+ *          attached to the object specified by an object identifier, \p obj_id.
  *
  *          \plist_unused{aapl_id}
  *
@@ -691,6 +761,17 @@ H5_DLL herr_t H5Aiterate_by_name(hid_t loc_id, const char *obj_name, H5_index_t
  */
 H5_DLL hid_t H5Aopen(hid_t obj_id, const char *attr_name, hid_t aapl_id);
 /*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Aopen}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL hid_t H5Aopen_async(const char *app_file, const char *app_func, unsigned app_line, hid_t obj_id,
+                           const char *attr_name, hid_t aapl_id, hid_t es_id);
+#else
+H5_DLL hid_t  H5Aopen_async(hid_t obj_id, const char *attr_name, hid_t aapl_id, hid_t es_id);
+#endif
+/*--------------------------------------------------------------------------*/
 /**
  * \ingroup H5A
  *
@@ -701,11 +782,11 @@ H5_DLL hid_t H5Aopen(hid_t obj_id, const char *attr_name, hid_t aapl_id);
  *                      relative to location
  * \param[in] idx_type  Type of index
  * \param[in] order     Index traversal order
- * \param[in] n         Attribute’s position in index
+ * \param[in] n         Attribute's position in index
  * \aapl_id
  * \lapl_id
  *
- * \return \hid_tv{attribute}
+ * \return \hid_ti{attribute}
  *
  * \details H5Aopen_by_idx() opens an existing attribute that is attached
  *          to an object specified by location and name, \p loc_id and
@@ -734,6 +815,20 @@ H5_DLL hid_t H5Aopen(hid_t obj_id, const char *attr_name, hid_t aapl_id);
 H5_DLL hid_t H5Aopen_by_idx(hid_t loc_id, const char *obj_name, H5_index_t idx_type, H5_iter_order_t order,
                             hsize_t n, hid_t aapl_id, hid_t lapl_id);
 /*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Aopen_by_idx}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL hid_t H5Aopen_by_idx_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
+                                  const char *obj_name, H5_index_t idx_type, H5_iter_order_t order, hsize_t n,
+                                  hid_t aapl_id, hid_t lapl_id, hid_t es_id);
+#else
+H5_DLL hid_t  H5Aopen_by_idx_async(hid_t loc_id, const char *obj_name, H5_index_t idx_type,
+                                   H5_iter_order_t order, hsize_t n, hid_t aapl_id, hid_t lapl_id,
+                                   hid_t es_id);
+#endif
+/*--------------------------------------------------------------------------*/
 /**
  * \ingroup H5A
  *
@@ -746,7 +841,7 @@ H5_DLL hid_t H5Aopen_by_idx(hid_t loc_id, const char *obj_name, H5_index_t idx_t
  * \aapl_id
  * \lapl_id
  *
- * \return \hid_tv{attribute}
+ * \return \hid_ti{attribute}
  *
  * \details H5Aopen_by_name() opens an existing attribute, \p attr_name,
  *          that is attached to an object specified by location and name,
@@ -774,6 +869,20 @@ H5_DLL hid_t H5Aopen_by_idx(hid_t loc_id, const char *obj_name, H5_index_t idx_t
  */
 H5_DLL hid_t H5Aopen_by_name(hid_t loc_id, const char *obj_name, const char *attr_name, hid_t aapl_id,
                              hid_t lapl_id);
+/*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Aopen_by_name}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL hid_t H5Aopen_by_name_async(const char *app_file, const char *app_func, unsigned app_line,
+                                   hid_t loc_id, const char *obj_name, const char *attr_name, hid_t aapl_id,
+                                   hid_t lapl_id, hid_t es_id);
+#else
+H5_DLL hid_t  H5Aopen_by_name_async(hid_t loc_id, const char *obj_name, const char *attr_name, hid_t aapl_id,
+                                    hid_t lapl_id, hid_t es_id);
+#endif
+
 /*-------------------------------------------------------------------------- */
 /**
  * \ingroup H5A
@@ -805,6 +914,17 @@ H5_DLL hid_t H5Aopen_by_name(hid_t loc_id, const char *obj_name, const char *att
  *
  */
 H5_DLL herr_t H5Aread(hid_t attr_id, hid_t type_id, void *buf);
+/*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Aread}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Aread_async(const char *app_file, const char *app_func, unsigned app_line, hid_t attr_id,
+                            hid_t dtype_id, void *buf, hid_t es_id);
+#else
+H5_DLL herr_t H5Aread_async(hid_t attr_id, hid_t dtype_id, void *buf, hid_t es_id);
+#endif
 /*-------------------------------------------------------------------------*/
 /**
  * \ingroup H5A
@@ -828,6 +948,30 @@ H5_DLL herr_t H5Aread(hid_t attr_id, hid_t type_id, void *buf);
  */
 H5_DLL herr_t H5Arename(hid_t loc_id, const char *old_name, const char *new_name);
 /*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Arename}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Arename_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
+                              const char *old_name, const char *new_name, hid_t es_id);
+#else
+H5_DLL herr_t H5Arename_async(hid_t loc_id, const char *old_name, const char *new_name, hid_t es_id);
+#endif
+/*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Arename_by_name}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Arename_by_name_async(const char *app_file, const char *app_func, unsigned app_line,
+                                      hid_t loc_id, const char *obj_name, const char *old_attr_name,
+                                      const char *new_attr_name, hid_t lapl_id, hid_t es_id);
+#else
+H5_DLL herr_t H5Arename_by_name_async(hid_t loc_id, const char *obj_name, const char *old_attr_name,
+                                      const char *new_attr_name, hid_t lapl_id, hid_t es_id);
+#endif
+/*--------------------------------------------------------------------------*/
 /**
  * \ingroup H5A
  *
@@ -856,6 +1000,17 @@ H5_DLL herr_t H5Arename(hid_t loc_id, const char *old_name, const char *new_name
  *
  */
 H5_DLL herr_t H5Awrite(hid_t attr_id, hid_t type_id, const void *buf);
+/*--------------------------------------------------------------------------*/
+/**
+ * \ingroup ASYNC
+ * \async_variant_of{H5Awrite}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Awrite_async(const char *app_file, const char *app_func, unsigned app_line, hid_t attr_id,
+                             hid_t type_id, const void *buf, hid_t es_id);
+#else
+H5_DLL herr_t H5Awrite_async(hid_t attr_id, hid_t type_id, const void *buf, hid_t es_id);
+#endif
 /*-------------------------------------------------------------------------*/
 /**
  * \ingroup H5A
@@ -882,6 +1037,42 @@ H5_DLL herr_t H5Awrite(hid_t attr_id, hid_t type_id, const void *buf);
 H5_DLL herr_t H5Arename_by_name(hid_t loc_id, const char *obj_name, const char *old_attr_name,
                                 const char *new_attr_name, hid_t lapl_id);
 
+/// \cond DEV
+/* API Wrappers for async routines */
+/* (Must be defined _after_ the function prototype) */
+/* (And must only defined when included in application code, not the library) */
+#ifndef H5A_MODULE
+#define H5Acreate_async(...)         H5Acreate_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Acreate_by_name_async(...) H5Acreate_by_name_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Aopen_async(...)           H5Aopen_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Aopen_by_name_async(...)   H5Aopen_by_name_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Aopen_by_idx_async(...)    H5Aopen_by_idx_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Awrite_async(...)          H5Awrite_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Aread_async(...)           H5Aread_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Arename_async(...)         H5Arename_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Arename_by_name_async(...) H5Arename_by_name_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Aexists_async(...)         H5Aexists_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Aexists_by_name_async(...) H5Aexists_by_name_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Aclose_async(...)          H5Aclose_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+
+/* Define "wrapper" versions of function calls, to allow compile-time values to
+ *      be passed in by language wrapper or library layer on top of HDF5.
+ */
+#define H5Acreate_async_wrap         H5_NO_EXPAND(H5Acreate_async)
+#define H5Acreate_by_name_async_wrap H5_NO_EXPAND(H5Acreate_by_name_async)
+#define H5Aopen_async_wrap           H5_NO_EXPAND(H5Aopen_async)
+#define H5Aopen_by_name_async_wrap   H5_NO_EXPAND(H5Aopen_by_name_async)
+#define H5Aopen_by_idx_async_wrap    H5_NO_EXPAND(H5Aopen_by_idx_async)
+#define H5Awrite_async_wrap          H5_NO_EXPAND(H5Awrite_async)
+#define H5Aread_async_wrap           H5_NO_EXPAND(H5Aread_async)
+#define H5Arename_async_wrap         H5_NO_EXPAND(H5Arename_async)
+#define H5Arename_by_name_async_wrap H5_NO_EXPAND(H5Arename_by_name_async)
+#define H5Aexists_async_wrap         H5_NO_EXPAND(H5Aexists_async)
+#define H5Aexists_by_name_async_wrap H5_NO_EXPAND(H5Aexists_by_name_async)
+#define H5Aclose_async_wrap          H5_NO_EXPAND(H5Aclose_async)
+#endif /* H5A_MODULE */
+/// \endcond
+
 /* Symbols defined for compatibility with previous versions of the HDF5 API.
  *
  * Use of these symbols is deprecated.
@@ -899,9 +1090,9 @@ H5_DLL herr_t H5Arename_by_name(hid_t loc_id, const char *obj_name, const char *
  * \param[in] location_id The identifier for the group, dataset
  *            or named datatype being iterated over
  * \param[in] attr_name The name of the current object attribute
- * \param[in,out] operator_data A pointer to the operator data passed in to
+ * \param[in,out] operator_data A pointer to the operator data passed into
  *                H5Aiterate1()
- * \returns The return values from an operator are:
+ * \return The return values from an operator are:
  *          \li Zero causes the iterator to continue, returning zero when
  *              all attributes have been processed.
  *          \li Positive causes the iterator to immediately return that
@@ -928,7 +1119,7 @@ typedef herr_t (*H5A_operator1_t)(hid_t location_id /*in*/, const char *attr_nam
  * \space_id
  * \acpl_id
  *
- * \return \hid_tv{attribute}
+ * \return \hid_ti{attribute}
  *
  * \deprecation_note{H5Acreate2()}
  *
@@ -959,7 +1150,7 @@ H5_DLL hid_t H5Acreate1(hid_t loc_id, const char *name, hid_t type_id, hid_t spa
  *
  * \fgdt_loc_id
  *
- * \return Returns the number of attributes if successful; otherwise returns
+ * \return Returns the number of attributes if successful; otherwise, returns
  *         a negative value.
  *
  * \deprecation_note{H5Oget_info(), H5Oget_info_by_name(), and H5Oget_info_by_idx()}
@@ -975,12 +1166,12 @@ H5_DLL int H5Aget_num_attrs(hid_t loc_id);
 /**
  * \ingroup H5A
  *
- * \brief Calls a user’s function for each attribute on an object
+ * \brief Calls a user's function for each attribute on an object
  *
  * \loc_id
  * \param[in,out] idx     Starting (in) and ending (out) attribute index
  * \param[in]     op      User's function to pass each attribute to
- * \param[in,out] op_data User's data to pass through to iterator operator
+ * \param[in,out] op_data User's data to pass through to the iterator operator
  *                        function
  *
  * \return \herr_t
@@ -997,6 +1188,9 @@ H5_DLL int H5Aget_num_attrs(hid_t loc_id);
  *          \p op, is returned in \p idx. If \p idx is the null pointer,
  *          then all attributes are processed.
  *
+ * \warning   Adding or removing attributes to the object during iteration
+ *            will lead to undefined behavior.
+ *
  * \version 1.8.0 The function \p H5Aiterate was renamed to H5Aiterate1()
  *                and deprecated in this release.
  * \since 1.0.0
@@ -1012,15 +1206,15 @@ H5_DLL herr_t H5Aiterate1(hid_t loc_id, unsigned *idx, H5A_operator1_t op, void
  * \loc_id
  * \param[in] idx Index of the attribute to open
  *
- * \return \hid_tv{attribute}
+ * \return \hid_ti{attribute}
  *
  * \deprecation_note{H5Aopen_by_idx()}
  *
- * \details H5Aopen_idx() opens an attribute which is attached to the
- *          object specified with \p loc_id . The location object may be
+ * \details H5Aopen_idx() opens an attribute that is attached to the
+ *          object specified with \p loc_id. The location object may be
  *          either a group, dataset, or named datatype, all of which may
  *          have any sort of attribute. The attribute specified by the index,
- *          \p idx , indicates the attribute to access. The value of \p idx
+ *          \p idx, indicates the attribute to access. The value of \p idx
  *          is a 0-based, non-negative integer. The attribute identifier
  *          returned from this function must be released with H5Aclose()
  *          or resource leaks will develop.
@@ -1038,7 +1232,7 @@ H5_DLL hid_t H5Aopen_idx(hid_t loc_id, unsigned idx);
  * \loc_id
  * \param[in] name Attribute name
  *
- * \return \hid_tv{attribute}
+ * \return \hid_ti{attribute}
  *
  * \deprecation_note{H5Aopen_by_name()}
  *
