@@ -13,21 +13,28 @@
 /*-------------------------------------------------------------------------
  *
  * Created:     H5Cprefetched.c
- *              December 28 2016
- *              Quincey Koziol
  *
- * Purpose:     Metadata cache prefetched entry callbacks.
+ * Purpose:     Metadata cache prefetched entry callbacks
  *
  *-------------------------------------------------------------------------
  */
 
+/****************/
+/* Module Setup */
+/****************/
+
+#include "H5Cmodule.h" /* This source code file is part of the H5C module */
+
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"   /* Generic Functions			*/
-#include "H5ACprivate.h" /* Metadata cache                       */
-#include "H5FLprivate.h" /* Free Lists                           */
-#include "H5MMprivate.h" /* Memory management			*/
+#include "H5private.h"   /* Generic Functions                        */
+#include "H5ACprivate.h" /* Metadata Cache                           */
+#include "H5Cpkg.h"      /* Cache                                    */
+#include "H5Eprivate.h"  /* Error Handling                           */
+#include "H5Fprivate.h"  /* Files                                    */
+#include "H5FLprivate.h" /* Free Lists                               */
+#include "H5MMprivate.h" /* Memory Management                        */
 
 /****************/
 /* Local Macros */
@@ -51,7 +58,7 @@ static herr_t H5C__prefetched_entry_get_final_load_size(const void *image_ptr, s
                                                         void *udata_ptr, size_t *actual_len_ptr);
 static htri_t H5C__prefetched_entry_verify_chksum(const void *image_ptr, size_t len, void *udata_ptr);
 static void  *H5C__prefetched_entry_deserialize(const void *image_ptr, size_t len, void *udata,
-                                                hbool_t *dirty_ptr);
+                                                bool *dirty_ptr);
 static herr_t H5C__prefetched_entry_image_len(const void *thing, size_t *image_len_ptr);
 static herr_t H5C__prefetched_entry_pre_serialize(H5F_t *f, void *thing, haddr_t addr, size_t len,
                                                   haddr_t *new_addr_ptr, size_t *new_len_ptr,
@@ -108,7 +115,7 @@ static herr_t
 H5C__prefetched_entry_get_initial_load_size(void H5_ATTR_UNUSED   *udata_ptr,
                                             size_t H5_ATTR_UNUSED *image_len_ptr)
 {
-    FUNC_ENTER_STATIC_NOERR /* Yes, even though this pushes an error on the stack */
+    FUNC_ENTER_PACKAGE_NOERR /* Yes, even though this pushes an error on the stack */
 
         HERROR(H5E_CACHE, H5E_SYSTEM, "called unreachable fcn.");
 
@@ -120,7 +127,7 @@ H5C__prefetched_entry_get_final_load_size(const void H5_ATTR_UNUSED *image_ptr,
                                           size_t H5_ATTR_UNUSED image_len, void H5_ATTR_UNUSED *udata_ptr,
                                           size_t H5_ATTR_UNUSED *actual_len_ptr)
 {
-    FUNC_ENTER_STATIC_NOERR /* Yes, even though this pushes an error on the stack */
+    FUNC_ENTER_PACKAGE_NOERR /* Yes, even though this pushes an error on the stack */
 
         HERROR(H5E_CACHE, H5E_SYSTEM, "called unreachable fcn.");
 
@@ -131,7 +138,7 @@ static htri_t
 H5C__prefetched_entry_verify_chksum(const void H5_ATTR_UNUSED *image_ptr, size_t H5_ATTR_UNUSED len,
                                     void H5_ATTR_UNUSED *udata_ptr)
 {
-    FUNC_ENTER_STATIC_NOERR /* Yes, even though this pushes an error on the stack */
+    FUNC_ENTER_PACKAGE_NOERR /* Yes, even though this pushes an error on the stack */
 
         HERROR(H5E_CACHE, H5E_SYSTEM, "called unreachable fcn.");
 
@@ -140,9 +147,9 @@ H5C__prefetched_entry_verify_chksum(const void H5_ATTR_UNUSED *image_ptr, size_t
 
 static void *
 H5C__prefetched_entry_deserialize(const void H5_ATTR_UNUSED *image_ptr, size_t H5_ATTR_UNUSED len,
-                                  void H5_ATTR_UNUSED *udata, hbool_t H5_ATTR_UNUSED *dirty_ptr)
+                                  void H5_ATTR_UNUSED *udata, bool H5_ATTR_UNUSED *dirty_ptr)
 {
-    FUNC_ENTER_STATIC_NOERR /* Yes, even though this pushes an error on the stack */
+    FUNC_ENTER_PACKAGE_NOERR /* Yes, even though this pushes an error on the stack */
 
         HERROR(H5E_CACHE, H5E_SYSTEM, "called unreachable fcn.");
 
@@ -152,7 +159,7 @@ H5C__prefetched_entry_deserialize(const void H5_ATTR_UNUSED *image_ptr, size_t H
 static herr_t
 H5C__prefetched_entry_image_len(const void H5_ATTR_UNUSED *thing, size_t H5_ATTR_UNUSED *image_len_ptr)
 {
-    FUNC_ENTER_STATIC_NOERR /* Yes, even though this pushes an error on the stack */
+    FUNC_ENTER_PACKAGE_NOERR /* Yes, even though this pushes an error on the stack */
 
         HERROR(H5E_CACHE, H5E_SYSTEM, "called unreachable fcn.");
 
@@ -165,7 +172,7 @@ H5C__prefetched_entry_pre_serialize(H5F_t H5_ATTR_UNUSED *f, void H5_ATTR_UNUSED
                                     haddr_t H5_ATTR_UNUSED *new_addr_ptr, size_t H5_ATTR_UNUSED *new_len_ptr,
                                     unsigned H5_ATTR_UNUSED *flags_ptr)
 {
-    FUNC_ENTER_STATIC_NOERR /* Yes, even though this pushes an error on the stack */
+    FUNC_ENTER_PACKAGE_NOERR /* Yes, even though this pushes an error on the stack */
 
         HERROR(H5E_CACHE, H5E_SYSTEM, "called unreachable fcn.");
 
@@ -176,7 +183,7 @@ static herr_t
 H5C__prefetched_entry_serialize(const H5F_t H5_ATTR_UNUSED *f, void H5_ATTR_UNUSED *image_ptr,
                                 size_t H5_ATTR_UNUSED len, void H5_ATTR_UNUSED *thing)
 {
-    FUNC_ENTER_STATIC_NOERR /* Yes, even though this pushes an error on the stack */
+    FUNC_ENTER_PACKAGE_NOERR /* Yes, even though this pushes an error on the stack */
 
         HERROR(H5E_CACHE, H5E_SYSTEM, "called unreachable fcn.");
 
@@ -195,9 +202,6 @@ H5C__prefetched_entry_serialize(const H5F_t H5_ATTR_UNUSED *f, void H5_ATTR_UNUS
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              8/13/15
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -207,12 +211,11 @@ H5C__prefetched_entry_notify(H5C_notify_action_t action, void *_thing)
     unsigned           u;
     herr_t             ret_value = SUCCEED;
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(entry_ptr);
-    HDassert(entry_ptr->magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-    HDassert(entry_ptr->prefetched);
+    assert(entry_ptr);
+    assert(entry_ptr->prefetched);
 
     switch (action) {
         case H5C_NOTIFY_ACTION_AFTER_INSERT:
@@ -232,16 +235,15 @@ H5C__prefetched_entry_notify(H5C_notify_action_t action, void *_thing)
                 H5C_cache_entry_t *parent_ptr;
 
                 /* Sanity checks */
-                HDassert(entry_ptr->flush_dep_parent);
+                assert(entry_ptr->flush_dep_parent);
                 parent_ptr = entry_ptr->flush_dep_parent[u];
-                HDassert(parent_ptr);
-                HDassert(parent_ptr->magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-                HDassert(parent_ptr->flush_dep_nchildren > 0);
+                assert(parent_ptr);
+                assert(parent_ptr->flush_dep_nchildren > 0);
 
                 /* Destroy flush dependency with flush dependency parent */
                 if (H5C_destroy_flush_dependency(parent_ptr, entry_ptr) < 0)
                     HGOTO_ERROR(H5E_CACHE, H5E_CANTUNDEPEND, FAIL,
-                                "unable to destroy prefetched entry flush dependency")
+                                "unable to destroy prefetched entry flush dependency");
 
                 if (parent_ptr->prefetched) {
                     /* In prefetched entries, the fd_child_count field is
@@ -249,14 +251,14 @@ H5C__prefetched_entry_notify(H5C_notify_action_t action, void *_thing)
                      * field to reflect the destruction of the flush
                      * dependency relationship.
                      */
-                    HDassert(parent_ptr->fd_child_count > 0);
+                    assert(parent_ptr->fd_child_count > 0);
                     (parent_ptr->fd_child_count)--;
                 } /* end if */
             }     /* end for */
             break;
 
         default:
-            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unknown action from metadata cache")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unknown action from metadata cache");
             break;
     } /* end switch */
 
@@ -274,9 +276,6 @@ done:
  * Return:      Success:        SUCCEED
  *              Failure:        FAIL
  *
- * Programmer:  John Mainzer
- *              8/13/15
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -285,23 +284,22 @@ H5C__prefetched_entry_free_icr(void *_thing)
     H5C_cache_entry_t *entry_ptr = (H5C_cache_entry_t *)_thing;
     herr_t             ret_value = SUCCEED;
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(entry_ptr);
-    HDassert(entry_ptr->magic == H5C__H5C_CACHE_ENTRY_T_BAD_MAGIC);
-    HDassert(entry_ptr->prefetched);
+    assert(entry_ptr);
+    assert(entry_ptr->prefetched);
 
     /* Release array for flush dependency parent addresses */
     if (entry_ptr->fd_parent_addrs != NULL) {
-        HDassert(entry_ptr->fd_parent_count > 0);
+        assert(entry_ptr->fd_parent_count > 0);
         entry_ptr->fd_parent_addrs = (haddr_t *)H5MM_xfree((void *)entry_ptr->fd_parent_addrs);
     } /* end if */
     else
-        HDassert(entry_ptr->fd_parent_count == 0);
+        assert(entry_ptr->fd_parent_count == 0);
 
     if (entry_ptr->image_ptr != NULL)
-        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "prefetched entry image buffer still attached?")
+        HGOTO_ERROR(H5E_CACHE, H5E_SYSTEM, FAIL, "prefetched entry image buffer still attached?");
 
     entry_ptr = H5FL_FREE(H5C_cache_entry_t, entry_ptr);
 
@@ -312,7 +310,7 @@ done:
 static herr_t
 H5C__prefetched_entry_fsf_size(const void H5_ATTR_UNUSED *thing, hsize_t H5_ATTR_UNUSED *fsf_size_ptr)
 {
-    FUNC_ENTER_STATIC_NOERR /* Yes, even though this pushes an error on the stack */
+    FUNC_ENTER_PACKAGE_NOERR /* Yes, even though this pushes an error on the stack */
 
         HERROR(H5E_CACHE, H5E_SYSTEM, "called unreachable fcn.");
 
