@@ -11,15 +11,16 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Quincey Koziol
- *              Monday, April 17, 2000
- *
- * Purpose:	The public header file for the log driver.
+ * Purpose:	The public header file for the log virtual file driver (VFD)
  */
 #ifndef H5FDlog_H
 #define H5FDlog_H
 
-#define H5FD_LOG (H5FD_log_init())
+/** Initializer for the log VFD */
+#define H5FD_LOG (H5FDperform_init(H5FD_log_init))
+
+/** Identifier for the log VFD */
+#define H5FD_LOG_VALUE H5_VFD_LOG
 
 /* Flags for H5Pset_fapl_log() */
 /* Flags for tracking 'meta' operations (truncate) */
@@ -64,6 +65,10 @@
 extern "C" {
 #endif
 
+/** @private
+ *
+ * \brief Private initializer for the log VFD
+ */
 H5_DLL hid_t H5FD_log_init(void);
 
 /**
@@ -90,7 +95,7 @@ H5_DLL hid_t H5FD_log_init(void);
  *          table. Multiple flags can be set through the use of a logical \c OR
  *          contained in parentheses. For example, logging read and write
  *          locations would be specified as
- *          \Code{(H5FD_LOG_LOC_READ|H5FD_LOG_LOC_WRITE)}.
+ *          \TText{(H5FD_LOG_LOC_READ|H5FD_LOG_LOC_WRITE)}.
  *
  * <table>
  * <caption>Table1: Logging Flags</caption>
@@ -110,7 +115,7 @@ H5_DLL hid_t H5FD_log_init(void);
  * </td>
  * <td>
  * Track all I/O locations and lengths. The logical equivalent of the following:
- * \Code{(#H5FD_LOG_LOC_READ | #H5FD_LOG_LOC_WRITE | #H5FD_LOG_LOC_SEEK)}
+ * \TText{(#H5FD_LOG_LOC_READ | #H5FD_LOG_LOC_WRITE | #H5FD_LOG_LOC_SEEK)}
  * </td>
  * </tr>
  * <tr>
@@ -129,7 +134,7 @@ H5_DLL hid_t H5FD_log_init(void);
  * <td>
  * Track the number of times each byte is read and written. The logical
  * equivalent of the following:
- * \Code{(#H5FD_LOG_FILE_READ | #H5FD_LOG_FILE_WRITE)}
+ * \TText{(#H5FD_LOG_FILE_READ | #H5FD_LOG_FILE_WRITE)}
  * </td>
  * </tr>
  * <tr>
@@ -158,7 +163,7 @@ H5_DLL hid_t H5FD_log_init(void);
  * <td>
  * Track the total number of all types of I/O operations. The logical equivalent
  * of the following:
- * \Code{(#H5FD_LOG_NUM_READ | #H5FD_LOG_NUM_WRITE | #H5FD_LOG_NUM_SEEK | #H5FD_LOG_NUM_TRUNCATE)}
+ * \TText{(#H5FD_LOG_NUM_READ | #H5FD_LOG_NUM_WRITE | #H5FD_LOG_NUM_SEEK | #H5FD_LOG_NUM_TRUNCATE)}
  * </td>
  * </tr>
  * <tr>
@@ -181,7 +186,7 @@ H5_DLL hid_t H5FD_log_init(void);
  * <td>
  * Track the time spent in each of the above operations. The logical equivalent
  * of the following:
- * \Code{(#H5FD_LOG_TIME_OPEN | #H5FD_LOG_TIME_STAT | #H5FD_LOG_TIME_READ | #H5FD_LOG_TIME_WRITE |
+ * \TText{(#H5FD_LOG_TIME_OPEN | #H5FD_LOG_TIME_STAT | #H5FD_LOG_TIME_READ | #H5FD_LOG_TIME_WRITE |
  *        #H5FD_LOG_TIME_SEEK | #H5FD_LOG_TIME_CLOSE)}
  * </td>
  * </tr>
@@ -199,7 +204,7 @@ H5_DLL hid_t H5FD_log_init(void);
  * </td>
  * <td>
  * Track everything. The logical equivalent of the following:
- * \Code{(#H5FD_LOG_ALLOC | #H5FD_LOG_TIME_IO | #H5FD_LOG_NUM_IO | #H5FD_LOG_FLAVOR | #H5FD_LOG_FILE_IO |
+ * \TText{(#H5FD_LOG_ALLOC | #H5FD_LOG_TIME_IO | #H5FD_LOG_NUM_IO | #H5FD_LOG_FLAVOR | #H5FD_LOG_FILE_IO |
  *        #H5FD_LOG_LOC_IO)}
  * </td>
  * </tr>
@@ -229,19 +234,19 @@ H5_DLL hid_t H5FD_log_init(void);
  * <td>#H5FD_LOG_LOC_READ</td>
  * <td>Read</td>
  * <td>
- * \Code{%10a-%10a (%10Zu bytes) (%s) Read}\n\n
+ * \TText{%10a-%10a (%10Zu bytes) (%s) Read}\n\n
  * Start position\n
  * End position\n
  * Number of bytes\n
  * Flavor of read\n\n
- * Adds \Code{(\%f s)} and seek time if #H5FD_LOG_TIME_SEEK is also set.
+ * Adds \TText{(\%f s)} and seek time if #H5FD_LOG_TIME_SEEK is also set.
  * </td>
  * </tr>
  * <tr>
  * <td>#H5FD_LOG_LOC_READ</td>
  * <td>Read Error</td>
  * <td>
- * \Code{Error! Reading: %10a-%10a (%10Zu bytes)}\n\n
+ * \TText{Error! Reading: %10a-%10a (%10Zu bytes)}\n\n
  * Same parameters as non-error entry.
  * </td>
  * </tr>
@@ -249,19 +254,19 @@ H5_DLL hid_t H5FD_log_init(void);
  * <td>#H5FD_LOG_LOC_WRITE</td>
  * <td>Write</td>
  * <td>
- * \Code{%10a-%10a (%10Zu bytes) (%s) Written}\n\n
+ * \TText{%10a-%10a (%10Zu bytes) (%s) Written}\n\n
  * Start position\n
  * End position\n
  * Number of bytes\n
  * Flavor of write\n\n
- * Adds \Code{(\%f s)} and seek time if #H5FD_LOG_TIME_SEEK is also set.
+ * Adds \TText{(\%f s)} and seek time if #H5FD_LOG_TIME_SEEK is also set.
  * </td>
  * </tr>
  * <tr>
  * <td>#H5FD_LOG_LOC_WRITE</td>
  * <td>Write Error</td>
  * <td>
- * \Code{Error! Writing: %10a-%10a (%10Zu bytes)}\n\n
+ * \TText{Error! Writing: %10a-%10a (%10Zu bytes)}\n\n
  * Same parameters as non-error entry.
  * </td>
  * </tr>
@@ -269,10 +274,10 @@ H5_DLL hid_t H5FD_log_init(void);
  * <td>#H5FD_LOG_LOC_SEEK</td>
  * <td>Read, Write</td>
  * <td>
- * \Code{Seek: From %10a-%10a}\n\n
+ * \TText{Seek: From %10a-%10a}\n\n
  * Start position\n
  * End position\n\n
- * Adds \Code{(\%f s)} and seek time if #H5FD_LOG_TIME_SEEK is also set.
+ * Adds \TText{(\%f s)} and seek time if #H5FD_LOG_TIME_SEEK is also set.
  * </td>
  * </tr>
  * <tr>
@@ -282,7 +287,7 @@ H5_DLL hid_t H5FD_log_init(void);
  * Begins with:\n
  * Dumping read I/O information\n\n
  * Then, for each range of identical values, there is this line:\n
- * \Code{Addr %10-%10 (%10lu bytes) read from %3d times}\n\n
+ * \TText{Addr %10-%10 (%10lu bytes) read from %3d times}\n\n
  * Start address\n
  * End address\n
  * Number of bytes\n
@@ -298,7 +303,7 @@ H5_DLL hid_t H5FD_log_init(void);
  * Begins with:\n
  * Dumping read I/O information\n\n
  * Then, for each range of identical values, there is this line:\n
- * \Code{Addr %10-%10 (%10lu bytes) written to %3d times}\n\n
+ * \TText{Addr %10-%10 (%10lu bytes) written to %3d times}\n\n
  * Start address\n
  * End address\n
  * Number of bytes\n
@@ -314,7 +319,7 @@ H5_DLL hid_t H5FD_log_init(void);
  * Begins with:\n
  * Dumping I/O flavor information\n\n
  * Then, for each range of identical values, there is this line:\n
- * \Code{Addr %10-%10 (%10lu bytes) flavor is %s}\n\n
+ * \TText{Addr %10-%10 (%10lu bytes) flavor is %s}\n\n
  * Start address\n
  * End address\n
  * Number of bytes\n
@@ -327,42 +332,42 @@ H5_DLL hid_t H5FD_log_init(void);
  * <td>#H5FD_LOG_NUM_READ</td>
  * <td>Close</td>
  * <td>
- * Total number of read operations: \Code{%11u}
+ * Total number of read operations: \TText{%11u}
  * </td>
  * </tr>
  * <tr>
  * <td>#H5FD_LOG_NUM_WRITE</td>
  * <td>Close</td>
  * <td>
- * Total number of write operations: \Code{%11u}
+ * Total number of write operations: \TText{%11u}
  * </td>
  * </tr>
  * <tr>
  * <td>#H5FD_LOG_NUM_SEEK</td>
  * <td>Close</td>
  * <td>
- * Total number of seek operations: \Code{%11u}
+ * Total number of seek operations: \TText{%11u}
  * </td>
  * </tr>
  * <tr>
  * <td>#H5FD_LOG_NUM_TRUNCATE</td>
  * <td>Close</td>
  * <td>
- * Total number of truncate operations: \Code{%11u}
+ * Total number of truncate operations: \TText{%11u}
  * </td>
  * </tr>
  * <tr>
  * <td>#H5FD_LOG_TIME_OPEN</td>
  * <td>Open</td>
  * <td>
- * Open took: \Code{(\%f s)}
+ * Open took: \TText{(\%f s)}
  * </td>
  * </tr>
  * <tr>
  * <td>#H5FD_LOG_TIME_READ</td>
  * <td>Close, Read</td>
  * <td>
- * Total time in read operations: \Code{\%f s}\n\n
+ * Total time in read operations: \TText{\%f s}\n\n
  * See also: #H5FD_LOG_LOC_READ
  * </td>
  * </tr>
@@ -371,7 +376,7 @@ H5_DLL hid_t H5FD_log_init(void);
  * <td>#H5FD_LOG_TIME_WRITE</td>
  * <td>Close, Write</td>
  * <td>
- * Total time in write operations: \Code{\%f s}\n\n
+ * Total time in write operations: \TText{\%f s}\n\n
  * See also: #H5FD_LOG_LOC_WRITE
  * </td>
  * </tr>
@@ -379,7 +384,7 @@ H5_DLL hid_t H5FD_log_init(void);
  * <td>#H5FD_LOG_TIME_SEEK</td>
  * <td>Close, Read, Write</td>
  * <td>
- * Total time in write operations: \Code{\%f s}\n\n
+ * Total time in write operations: \TText{\%f s}\n\n
  * See also: #H5FD_LOG_LOC_SEEK or #H5FD_LOG_LOC_WRITE
  * </td>
  * </tr>
@@ -387,21 +392,21 @@ H5_DLL hid_t H5FD_log_init(void);
  * <td>#H5FD_LOG_TIME_CLOSE</td>
  * <td>Close</td>
  * <td>
- * Close took: \Code{(\%f s)}
+ * Close took: \TText{(\%f s)}
  * </td>
  * </tr>
  * <tr>
  * <td>#H5FD_LOG_TIME_STAT</td>
  * <td>Open</td>
  * <td>
- * Stat took: \Code{(\%f s)}
+ * Stat took: \TText{(\%f s)}
  * </td>
  * </tr>
  * <tr>
  * <td>#H5FD_LOG_ALLOC</td>
  * <td>Alloc</td>
  * <td>
- * \Code{%10-%10 (%10Hu bytes) (\%s) Allocated}\n\n
+ * \TText{%10-%10 (%10Hu bytes) (\%s) Allocated}\n\n
  * Start of address space\n
  * End of address space\n
  * Total size allocation\n
@@ -457,14 +462,14 @@ H5_DLL hid_t H5FD_log_init(void);
  * </tr>
  * </table>
  *
- * \version 1.8.7 The flags parameter has been changed from \Code{unsigned int}
- *          to \Code{unsigned long long}.
+ * \version 1.8.7 The flags parameter has been changed from \TText{unsigned int}
+ *          to \TText{unsigned long long}.
  *          The implementation of the #H5FD_LOG_TIME_OPEN, #H5FD_LOG_TIME_READ,
  *          #H5FD_LOG_TIME_WRITE, and #H5FD_LOG_TIME_SEEK flags has been finished.
  *          New flags were added: #H5FD_LOG_NUM_TRUNCATE and #H5FD_LOG_TIME_STAT.
  * \version 1.6.0 The \c verbosity parameter has been removed.
- *          Two new parameters have been added: \p flags of type \Code{unsigned} and
- *          \p buf_size of type \Code{size_t}.
+ *          Two new parameters have been added: \p flags of type \TText{unsigned} and
+ *          \p buf_size of type \TText{size_t}.
  * \since 1.4.0
  *
  */
