@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:		H5FDspace.c
- *			Jan  3 2008
- *			Quincey Koziol
  *
  * Purpose:		Space allocation routines for the file driver code.
  *
@@ -73,7 +71,7 @@
 H5FL_DEFINE(H5FD_free_t);
 
 /*-------------------------------------------------------------------------
- * Function:    H5FD_extend
+ * Function:    H5FD__extend
  *
  * Purpose:     Extend the EOA space of a file.
  *
@@ -82,31 +80,28 @@ H5FL_DEFINE(H5FD_free_t);
  * Return:      Success:    The address of the previous EOA.
  *              Failure:    The undefined address HADDR_UNDEF
  *
- * Programmer:  Bill Wendling
- *              Wednesday, 04. December, 2002
- *
  *-------------------------------------------------------------------------
  */
 static haddr_t
-H5FD_extend(H5FD_t *file, H5FD_mem_t type, hsize_t size)
+H5FD__extend(H5FD_t *file, H5FD_mem_t type, hsize_t size)
 {
     haddr_t eoa;                     /* Address of end-of-allocated space */
     haddr_t ret_value = HADDR_UNDEF; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(file);
-    HDassert(file->cls);
-    HDassert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
-    HDassert(size > 0);
+    assert(file);
+    assert(file->cls);
+    assert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
+    assert(size > 0);
 
     /* Get current end-of-allocated space address */
     eoa = file->cls->get_eoa(file, type);
 
     /* Check for overflow when extending */
-    if (H5F_addr_overflow(eoa, size) || (eoa + size) > file->maxaddr)
-        HGOTO_ERROR(H5E_VFL, H5E_NOSPACE, HADDR_UNDEF, "file allocation request failed")
+    if (H5_addr_overflow(eoa, size) || (eoa + size) > file->maxaddr)
+        HGOTO_ERROR(H5E_VFL, H5E_NOSPACE, HADDR_UNDEF, "file allocation request failed");
 
     /* Set the [NOT aligned] address to return */
     ret_value = eoa;
@@ -114,11 +109,11 @@ H5FD_extend(H5FD_t *file, H5FD_mem_t type, hsize_t size)
     /* Extend the end-of-allocated space address */
     eoa += size;
     if (file->cls->set_eoa(file, type, eoa) < 0)
-        HGOTO_ERROR(H5E_VFL, H5E_NOSPACE, HADDR_UNDEF, "file allocation request failed")
+        HGOTO_ERROR(H5E_VFL, H5E_NOSPACE, HADDR_UNDEF, "file allocation request failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5FD_extend() */
+} /* end H5FD__extend() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5FD__alloc_real
@@ -130,9 +125,6 @@ done:
  * Return:      Success:    The format address of the new file memory.
  *              Failure:    The undefined address HADDR_UNDEF
  *
- * Programmer:  Robb Matzke
- *              Wednesday, August  4, 1999
- *
  *-------------------------------------------------------------------------
  */
 haddr_t
@@ -142,19 +134,19 @@ H5FD__alloc_real(H5FD_t *file, H5FD_mem_t type, hsize_t size, haddr_t *frag_addr
     haddr_t       eoa;                     /* Address of end-of-allocated space */
     hsize_t       extra;                   /* Extra space to allocate, to align request */
     unsigned long flags = 0;               /* Driver feature flags */
-    hbool_t       use_alloc_size;          /* Just pass alloc size to the driver */
+    bool          use_alloc_size;          /* Just pass alloc size to the driver */
     haddr_t       ret_value = HADDR_UNDEF; /* Return value */
 
     FUNC_ENTER_PACKAGE
 #ifdef H5FD_ALLOC_DEBUG
-    HDfprintf(stderr, "%s: type = %u, size = %" PRIuHSIZE "\n", FUNC, (unsigned)type, size);
+    fprintf(stderr, "%s: type = %u, size = %" PRIuHSIZE "\n", __func__, (unsigned)type, size);
 #endif /* H5FD_ALLOC_DEBUG */
 
     /* check args */
-    HDassert(file);
-    HDassert(file->cls);
-    HDassert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
-    HDassert(size > 0);
+    assert(file);
+    assert(file->cls);
+    assert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
+    assert(size > 0);
 
     /* Check for query driver and call it */
     if (file->cls->query)
@@ -188,13 +180,13 @@ H5FD__alloc_real(H5FD_t *file, H5FD_mem_t type, hsize_t size, haddr_t *frag_addr
      * size */
     if (file->cls->alloc) {
         ret_value = (file->cls->alloc)(file, type, H5CX_get_dxpl(), use_alloc_size ? size : size + extra);
-        if (!H5F_addr_defined(ret_value))
-            HGOTO_ERROR(H5E_VFL, H5E_NOSPACE, HADDR_UNDEF, "driver allocation request failed")
+        if (!H5_addr_defined(ret_value))
+            HGOTO_ERROR(H5E_VFL, H5E_NOSPACE, HADDR_UNDEF, "driver allocation request failed");
     } /* end if */
     else {
-        ret_value = H5FD_extend(file, type, size + extra);
-        if (!H5F_addr_defined(ret_value))
-            HGOTO_ERROR(H5E_VFL, H5E_NOSPACE, HADDR_UNDEF, "driver eoa update request failed")
+        ret_value = H5FD__extend(file, type, size + extra);
+        if (!H5_addr_defined(ret_value))
+            HGOTO_ERROR(H5E_VFL, H5E_NOSPACE, HADDR_UNDEF, "driver eoa update request failed");
     } /* end else */
 
     /* Set the [possibly aligned] address to return */
@@ -203,14 +195,14 @@ H5FD__alloc_real(H5FD_t *file, H5FD_mem_t type, hsize_t size, haddr_t *frag_addr
 
     /* Post-condition sanity check */
     if (!file->paged_aggr && file->alignment > 1 && orig_size >= file->threshold)
-        HDassert(!(ret_value % file->alignment));
+        assert(!(ret_value % file->alignment));
 
     /* Convert absolute file offset to relative address */
     ret_value -= file->base_addr;
 
 done:
 #ifdef H5FD_ALLOC_DEBUG
-    HDfprintf(stderr, "%s: ret_value = %" PRIuHADDR "\n", FUNC, ret_value);
+    fprintf(stderr, "%s: ret_value = %" PRIuHADDR "\n", __func__, ret_value);
 #endif /* H5FD_ALLOC_DEBUG */
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FD__alloc_real() */
@@ -228,9 +220,6 @@ done:
  * Return:      Success:    The format address of the new file memory.
  *              Failure:    The undefined address HADDR_UNDEF
  *
- * Programmer:  Quincey Koziol
- *              Friday, August 14, 2009
- *
  *-------------------------------------------------------------------------
  */
 haddr_t
@@ -241,19 +230,19 @@ H5FD_alloc(H5FD_t *file, H5FD_mem_t type, H5F_t *f, hsize_t size, haddr_t *frag_
     FUNC_ENTER_NOAPI(HADDR_UNDEF)
 
     /* check args */
-    HDassert(file);
-    HDassert(file->cls);
-    HDassert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
-    HDassert(size > 0);
+    assert(file);
+    assert(file->cls);
+    assert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
+    assert(size > 0);
 
     /* Call the real 'alloc' routine */
     ret_value = H5FD__alloc_real(file, type, size, frag_addr, frag_size);
-    if (!H5F_addr_defined(ret_value))
-        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, HADDR_UNDEF, "real 'alloc' request failed")
+    if (!H5_addr_defined(ret_value))
+        HGOTO_ERROR(H5E_VFL, H5E_CANTALLOC, HADDR_UNDEF, "real 'alloc' request failed");
 
     /* Mark EOA info dirty in cache, so change will get encoded */
     if (H5F_eoa_dirty(f) < 0)
-        HGOTO_ERROR(H5E_VFL, H5E_CANTMARKDIRTY, HADDR_UNDEF, "unable to mark EOA info as dirty")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTMARKDIRTY, HADDR_UNDEF, "unable to mark EOA info as dirty");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -267,9 +256,6 @@ done:
  * Return:      Success:        Non-negative
  *              Failure:        Negative
  *
- * Programmer:  Robb Matzke
- *              Wednesday, August  4, 1999
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -280,34 +266,34 @@ H5FD__free_real(H5FD_t *file, H5FD_mem_t type, haddr_t addr, hsize_t size)
     FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(file);
-    HDassert(file->cls);
-    HDassert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
-    HDassert(size > 0);
+    assert(file);
+    assert(file->cls);
+    assert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
+    assert(size > 0);
 
 #ifdef H5FD_ALLOC_DEBUG
-    HDfprintf(stderr, "%s: type = %u, addr = %" PRIuHADDR ", size = %" PRIuHSIZE "\n", FUNC, (unsigned)type,
-              addr, size);
+    fprintf(stderr, "%s: type = %u, addr = %" PRIuHADDR ", size = %" PRIuHSIZE "\n", __func__, (unsigned)type,
+            addr, size);
 #endif /* H5FD_ALLOC_DEBUG */
 
     /* Sanity checking */
-    if (!H5F_addr_defined(addr))
-        HGOTO_ERROR(H5E_VFL, H5E_BADVALUE, FAIL, "invalid file offset")
+    if (!H5_addr_defined(addr))
+        HGOTO_ERROR(H5E_VFL, H5E_BADVALUE, FAIL, "invalid file offset");
 
     /* Convert address to absolute file offset */
     addr += file->base_addr;
 
     /* More sanity checking */
-    if (addr > file->maxaddr || H5F_addr_overflow(addr, size) || (addr + size) > file->maxaddr)
-        HGOTO_ERROR(H5E_VFL, H5E_BADVALUE, FAIL, "invalid file free space region to free")
+    if (addr > file->maxaddr || H5_addr_overflow(addr, size) || (addr + size) > file->maxaddr)
+        HGOTO_ERROR(H5E_VFL, H5E_BADVALUE, FAIL, "invalid file free space region to free");
 
     /* Check for file driver 'free' callback and call it if available */
     if (file->cls->free) {
 #ifdef H5FD_ALLOC_DEBUG
-        HDfprintf(stderr, "%s: Letting VFD free space\n", FUNC);
+        fprintf(stderr, "%s: Letting VFD free space\n", __func__);
 #endif /* H5FD_ALLOC_DEBUG */
         if ((file->cls->free)(file, type, H5CX_get_dxpl(), addr, size) < 0)
-            HGOTO_ERROR(H5E_VFL, H5E_CANTFREE, FAIL, "driver free request failed")
+            HGOTO_ERROR(H5E_VFL, H5E_CANTFREE, FAIL, "driver free request failed");
     } /* end if */
     /* Check if this free block is at the end of file allocated space.
      * Truncate it if this is true.
@@ -317,21 +303,21 @@ H5FD__free_real(H5FD_t *file, H5FD_mem_t type, haddr_t addr, hsize_t size)
 
         eoa = file->cls->get_eoa(file, type);
 #ifdef H5FD_ALLOC_DEBUG
-        HDfprintf(stderr, "%s: eoa = %" PRIuHADDR "\n", FUNC, eoa);
+        fprintf(stderr, "%s: eoa = %" PRIuHADDR "\n", __func__, eoa);
 #endif /* H5FD_ALLOC_DEBUG */
         if (eoa == (addr + size)) {
 #ifdef H5FD_ALLOC_DEBUG
-            HDfprintf(stderr, "%s: Reducing file size to = %" PRIuHADDR "\n", FUNC, addr);
+            fprintf(stderr, "%s: Reducing file size to = %" PRIuHADDR "\n", __func__, addr);
 #endif /* H5FD_ALLOC_DEBUG */
             if (file->cls->set_eoa(file, type, addr) < 0)
-                HGOTO_ERROR(H5E_VFL, H5E_CANTSET, FAIL, "set end of space allocation request failed")
+                HGOTO_ERROR(H5E_VFL, H5E_CANTSET, FAIL, "set end of space allocation request failed");
         } /* end if */
     }     /* end else-if */
     else {
         /* leak memory */
 #ifdef H5FD_ALLOC_DEBUG
-        HDfprintf(stderr, "%s: LEAKED MEMORY!!! type = %u, addr = %" PRIuHADDR ", size = %" PRIuHSIZE "\n",
-                  FUNC, (unsigned)type, addr, size);
+        fprintf(stderr, "%s: LEAKED MEMORY!!! type = %u, addr = %" PRIuHADDR ", size = %" PRIuHSIZE "\n",
+                __func__, (unsigned)type, addr, size);
 #endif /* H5FD_ALLOC_DEBUG */
     }  /* end else */
 
@@ -352,9 +338,6 @@ done:
  * Return:      Success:        Non-negative
  *              Failure:        Negative
  *
- * Programmer:  Quincey Koziol
- *              Friday, August 14, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -365,18 +348,18 @@ H5FD_free(H5FD_t *file, H5FD_mem_t type, H5F_t *f, haddr_t addr, hsize_t size)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check args */
-    HDassert(file);
-    HDassert(file->cls);
-    HDassert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
-    HDassert(size > 0);
+    assert(file);
+    assert(file->cls);
+    assert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
+    assert(size > 0);
 
     /* Call the real 'free' routine */
     if (H5FD__free_real(file, type, addr, size) < 0)
-        HGOTO_ERROR(H5E_VFL, H5E_CANTFREE, FAIL, "real 'free' request failed")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTFREE, FAIL, "real 'free' request failed");
 
     /* Mark EOA info dirty in cache, so change will get encoded */
     if (H5F_eoa_dirty(f) < 0)
-        HGOTO_ERROR(H5E_VFL, H5E_CANTMARKDIRTY, FAIL, "unable to mark EOA info as dirty")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTMARKDIRTY, FAIL, "unable to mark EOA info as dirty");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -391,49 +374,46 @@ done:
  *		marking an entry dirty without a H5F_t*, this routine should
  *		be changed to take a H5F_super_t* directly.
  *
- * Return:	Success:	TRUE(1)  - Block was extended
- *                              FALSE(0) - Block could not be extended
+ * Return:	Success:	true(1)  - Block was extended
+ *                              false(0) - Block could not be extended
  * 		Failure:	FAIL
  *
- * Programmer:  Quincey Koziol
- *              Thursday, 17. January, 2008
- *
  *-------------------------------------------------------------------------
  */
 htri_t
 H5FD_try_extend(H5FD_t *file, H5FD_mem_t type, H5F_t *f, haddr_t blk_end, hsize_t extra_requested)
 {
     haddr_t eoa;               /* End of allocated space in file */
-    htri_t  ret_value = FALSE; /* Return value */
+    htri_t  ret_value = false; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
     /* check args */
-    HDassert(file);
-    HDassert(file->cls);
-    HDassert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
-    HDassert(extra_requested > 0);
-    HDassert(f);
+    assert(file);
+    assert(file->cls);
+    assert(type >= H5FD_MEM_DEFAULT && type < H5FD_MEM_NTYPES);
+    assert(extra_requested > 0);
+    assert(f);
 
     /* Retrieve the end of the address space */
     if (HADDR_UNDEF == (eoa = file->cls->get_eoa(file, type)))
-        HGOTO_ERROR(H5E_VFL, H5E_CANTGET, FAIL, "driver get_eoa request failed")
+        HGOTO_ERROR(H5E_VFL, H5E_CANTGET, FAIL, "driver get_eoa request failed");
 
     /* Adjust block end by base address of the file, to create absolute address */
     blk_end += file->base_addr;
 
     /* Check if the block is exactly at the end of the file */
-    if (H5F_addr_eq(blk_end, eoa)) {
+    if (H5_addr_eq(blk_end, eoa)) {
         /* Extend the object by extending the underlying file */
-        if (HADDR_UNDEF == H5FD_extend(file, type, extra_requested))
-            HGOTO_ERROR(H5E_VFL, H5E_CANTEXTEND, FAIL, "driver extend request failed")
+        if (HADDR_UNDEF == H5FD__extend(file, type, extra_requested))
+            HGOTO_ERROR(H5E_VFL, H5E_CANTEXTEND, FAIL, "driver extend request failed");
 
         /* Mark EOA info dirty in cache, so change will get encoded */
         if (H5F_eoa_dirty(f) < 0)
-            HGOTO_ERROR(H5E_VFL, H5E_CANTMARKDIRTY, FAIL, "unable to mark EOA info as dirty")
+            HGOTO_ERROR(H5E_VFL, H5E_CANTMARKDIRTY, FAIL, "unable to mark EOA info as dirty");
 
         /* Indicate success */
-        HGOTO_DONE(TRUE)
+        HGOTO_DONE(true);
     } /* end if */
 
 done:
