@@ -10,9 +10,7 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer:  Robb Matzke
- *              Wednesday, October 22, 1997
- *
+/*
  * Purpose: The C STDIO virtual file driver which only uses calls from stdio.h.
  *          This also serves as an example of coding a simple file driver,
  *          therefore, it should not use any non-public definitions.
@@ -20,6 +18,7 @@
  * NOTE:    This driver is not as well tested as the standard SEC2 driver
  *          and is not intended for production use!
  */
+
 #include <assert.h>
 #include <errno.h>
 #include <stdio.h>
@@ -84,7 +83,7 @@ typedef struct H5FD_stdio_t {
     haddr_t            eof;          /* end of file; current file size   */
     haddr_t            pos;          /* current file I/O position        */
     unsigned           write_access; /* Flag to indicate the file was opened with write access */
-    hbool_t            ignore_disabled_file_locks;
+    bool               ignore_disabled_file_locks;
     H5FD_stdio_file_op op; /* last operation */
 #ifndef H5_HAVE_WIN32_API
     /* On most systems the combination of device and i-node number uniquely
@@ -175,44 +174,53 @@ static herr_t  H5FD_stdio_read(H5FD_t *lf, H5FD_mem_t type, hid_t fapl_id, haddr
                                void *buf);
 static herr_t  H5FD_stdio_write(H5FD_t *lf, H5FD_mem_t type, hid_t fapl_id, haddr_t addr, size_t size,
                                 const void *buf);
-static herr_t  H5FD_stdio_flush(H5FD_t *_file, hid_t dxpl_id, hbool_t closing);
-static herr_t  H5FD_stdio_truncate(H5FD_t *_file, hid_t dxpl_id, hbool_t closing);
-static herr_t  H5FD_stdio_lock(H5FD_t *_file, hbool_t rw);
+static herr_t  H5FD_stdio_flush(H5FD_t *_file, hid_t dxpl_id, bool closing);
+static herr_t  H5FD_stdio_truncate(H5FD_t *_file, hid_t dxpl_id, bool closing);
+static herr_t  H5FD_stdio_lock(H5FD_t *_file, bool rw);
 static herr_t  H5FD_stdio_unlock(H5FD_t *_file);
+static herr_t  H5FD_stdio_delete(const char *filename, hid_t fapl_id);
 
 static const H5FD_class_t H5FD_stdio_g = {
-    "stdio",               /* name         */
-    MAXADDR,               /* maxaddr      */
-    H5F_CLOSE_WEAK,        /* fc_degree    */
-    H5FD_stdio_term,       /* terminate    */
-    NULL,                  /* sb_size      */
-    NULL,                  /* sb_encode    */
-    NULL,                  /* sb_decode    */
-    0,                     /* fapl_size    */
-    NULL,                  /* fapl_get     */
-    NULL,                  /* fapl_copy    */
-    NULL,                  /* fapl_free    */
-    0,                     /* dxpl_size    */
-    NULL,                  /* dxpl_copy    */
-    NULL,                  /* dxpl_free    */
-    H5FD_stdio_open,       /* open         */
-    H5FD_stdio_close,      /* close        */
-    H5FD_stdio_cmp,        /* cmp          */
-    H5FD_stdio_query,      /* query        */
-    NULL,                  /* get_type_map */
-    H5FD_stdio_alloc,      /* alloc        */
-    NULL,                  /* free         */
-    H5FD_stdio_get_eoa,    /* get_eoa      */
-    H5FD_stdio_set_eoa,    /* set_eoa      */
-    H5FD_stdio_get_eof,    /* get_eof      */
-    H5FD_stdio_get_handle, /* get_handle   */
-    H5FD_stdio_read,       /* read         */
-    H5FD_stdio_write,      /* write        */
-    H5FD_stdio_flush,      /* flush        */
-    H5FD_stdio_truncate,   /* truncate     */
-    H5FD_stdio_lock,       /* lock         */
-    H5FD_stdio_unlock,     /* unlock       */
-    H5FD_FLMAP_DICHOTOMY   /* fl_map       */
+    H5FD_CLASS_VERSION,    /* struct version  */
+    H5_VFD_STDIO,          /* value           */
+    "stdio",               /* name            */
+    MAXADDR,               /* maxaddr         */
+    H5F_CLOSE_WEAK,        /* fc_degree       */
+    H5FD_stdio_term,       /* terminate       */
+    NULL,                  /* sb_size         */
+    NULL,                  /* sb_encode       */
+    NULL,                  /* sb_decode       */
+    0,                     /* fapl_size       */
+    NULL,                  /* fapl_get        */
+    NULL,                  /* fapl_copy       */
+    NULL,                  /* fapl_free       */
+    0,                     /* dxpl_size       */
+    NULL,                  /* dxpl_copy       */
+    NULL,                  /* dxpl_free       */
+    H5FD_stdio_open,       /* open            */
+    H5FD_stdio_close,      /* close           */
+    H5FD_stdio_cmp,        /* cmp             */
+    H5FD_stdio_query,      /* query           */
+    NULL,                  /* get_type_map    */
+    H5FD_stdio_alloc,      /* alloc           */
+    NULL,                  /* free            */
+    H5FD_stdio_get_eoa,    /* get_eoa         */
+    H5FD_stdio_set_eoa,    /* set_eoa         */
+    H5FD_stdio_get_eof,    /* get_eof         */
+    H5FD_stdio_get_handle, /* get_handle      */
+    H5FD_stdio_read,       /* read            */
+    H5FD_stdio_write,      /* write           */
+    NULL,                  /* read_vector     */
+    NULL,                  /* write_vector    */
+    NULL,                  /* read_selection  */
+    NULL,                  /* write_selection */
+    H5FD_stdio_flush,      /* flush           */
+    H5FD_stdio_truncate,   /* truncate        */
+    H5FD_stdio_lock,       /* lock            */
+    H5FD_stdio_unlock,     /* unlock          */
+    H5FD_stdio_delete,     /* del             */
+    NULL,                  /* ctl             */
+    H5FD_FLMAP_DICHOTOMY   /* fl_map          */
 };
 
 /*-------------------------------------------------------------------------
@@ -225,9 +233,6 @@ static const H5FD_class_t H5FD_stdio_g = {
  *
  *    Failure:  Negative.
  *
- * Programmer:  Robb Matzke
- *              Thursday, July 29, 1999
- *
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -239,7 +244,7 @@ H5FD_stdio_init(void)
     H5Eclear2(H5E_DEFAULT);
 
     /* Check the use disabled file locks environment variable */
-    lock_env_var = getenv("HDF5_USE_FILE_LOCKING");
+    lock_env_var = getenv(HDF5_USE_FILE_LOCKING);
     if (lock_env_var && !strcmp(lock_env_var, "BEST_EFFORT"))
         ignore_disabled_file_locks_s = 1; /* Override: Ignore disabled locks */
     else if (lock_env_var && (!strcmp(lock_env_var, "TRUE") || !strcmp(lock_env_var, "1")))
@@ -260,9 +265,6 @@ H5FD_stdio_init(void)
  *
  * Returns:     Non-negative on success or negative on failure
  *
- * Programmer:  Quincey Koziol
- *              Friday, Jan 30, 2004
- *
  *---------------------------------------------------------------------------
  */
 static herr_t
@@ -283,9 +285,6 @@ H5FD_stdio_term(void)
  *
  * Return:  Non-negative on success/Negative on failure
  *
- * Programmer:  Robb Matzke
- *    Thursday, February 19, 1998
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -293,8 +292,6 @@ H5Pset_fapl_stdio(hid_t fapl_id)
 {
     static const char *func = "H5FDset_fapl_stdio"; /*for error reporting*/
 
-    /*NO TRACE*/
-
     /* Clear the error stack */
     H5Eclear2(H5E_DEFAULT);
 
@@ -323,9 +320,6 @@ H5Pset_fapl_stdio(hid_t fapl_id)
  *
  *      Failure:    NULL
  *
- * Programmer:  Robb Matzke
- *    Wednesday, October 22, 1997
- *
  *-------------------------------------------------------------------------
  */
 static H5FD_t *
@@ -416,7 +410,7 @@ H5FD_stdio_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr
         /* The environment variable was set, so use that preferentially */
         file->ignore_disabled_file_locks = ignore_disabled_file_locks_s;
     else {
-        hbool_t unused;
+        bool unused;
 
         /* Use the value in the property list */
         if (H5Pget_file_locking(fapl_id, &unused, &file->ignore_disabled_file_locks) < 0) {
@@ -480,9 +474,6 @@ H5FD_stdio_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxaddr
  *
  * Return:  Non-negative on success/Negative on failure
  *
- * Programmer:  Robb Matzke
- *    Wednesday, October 22, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -513,9 +504,6 @@ H5FD_stdio_close(H5FD_t *_file)
  *
  *      Failure:    never fails (arguments were checked by the caller).
  *
- * Programmer:  Robb Matzke
- *              Thursday, July 29, 1999
- *
  *-------------------------------------------------------------------------
  */
 static int
@@ -577,9 +565,6 @@ H5FD_stdio_cmp(const H5FD_t *_f1, const H5FD_t *_f2)
  *
  *    Failure:  negative
  *
- * Programmer:  Quincey Koziol
- *              Friday, August 25, 2000
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -619,9 +604,6 @@ H5FD_stdio_query(const H5FD_t *_f, unsigned long /*OUT*/ *flags)
  *
  *      Failure:    HADDR_UNDEF
  *
- * Programmer:  Raymond Lu
- *              30 March 2007
- *
  *-------------------------------------------------------------------------
  */
 static haddr_t
@@ -656,9 +638,6 @@ H5FD_stdio_alloc(H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type, hid_t /*UNUSED*/ dxp
  *
  *    Failure:  HADDR_UNDEF
  *
- * Programmer:  Robb Matzke
- *              Monday, August  2, 1999
- *
  *-------------------------------------------------------------------------
  */
 static haddr_t
@@ -686,9 +665,6 @@ H5FD_stdio_get_eoa(const H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type)
  *
  *    Failure:  Does not fail
  *
- * Programmer:  Robb Matzke
- *              Thursday, July 29, 1999
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -720,9 +696,6 @@ H5FD_stdio_set_eoa(H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type, haddr_t addr)
  *
  *    Failure:  HADDR_UNDEF
  *
- * Programmer:  Robb Matzke
- *              Thursday, July 29, 1999
- *
  *-------------------------------------------------------------------------
  */
 static haddr_t
@@ -749,9 +722,6 @@ H5FD_stdio_get_eof(const H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type)
  *
  * Returns:        Non-negative if succeed or negative if fails.
  *
- * Programmer:     Raymond Lu
- *                 Sept. 16, 2002
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -786,9 +756,6 @@ H5FD_stdio_get_handle(H5FD_t *_file, hid_t /*UNUSED*/ fapl, void **file_handle)
  *
  * Return:  Non-negative on success/Negative on failure
  *
- * Programmer:  Robb Matzke
- *    Wednesday, October 22, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -889,9 +856,6 @@ H5FD_stdio_read(H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type, hid_t /*UNUSED*/ dxpl
  *
  * Return:  Non-negative on success/Negative on failure
  *
- * Programmer:  Robb Matzke
- *    Wednesday, October 22, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -977,13 +941,10 @@ H5FD_stdio_write(H5FD_t *_file, H5FD_mem_t /*UNUSED*/ type, hid_t /*UNUSED*/ dxp
  *
  * Return:  Non-negative on success/Negative on failure
  *
- * Programmer:  Robb Matzke
- *    Wednesday, October 22, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_stdio_flush(H5FD_t *_file, hid_t /*UNUSED*/ dxpl_id, hbool_t closing)
+H5FD_stdio_flush(H5FD_t *_file, hid_t /*UNUSED*/ dxpl_id, bool closing)
 {
     H5FD_stdio_t      *file = (H5FD_stdio_t *)_file;
     static const char *func = "H5FD_stdio_flush"; /* Function Name for error reporting */
@@ -1021,13 +982,10 @@ H5FD_stdio_flush(H5FD_t *_file, hid_t /*UNUSED*/ dxpl_id, hbool_t closing)
  *
  * Return:  Non-negative on success/Negative on failure
  *
- * Programmer:  Quincey Koziol
- *    Thursday, January 31, 2008
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_stdio_truncate(H5FD_t *_file, hid_t /*UNUSED*/ dxpl_id, hbool_t /*UNUSED*/ closing)
+H5FD_stdio_truncate(H5FD_t *_file, hid_t /*UNUSED*/ dxpl_id, bool /*UNUSED*/ closing)
 {
     H5FD_stdio_t      *file = (H5FD_stdio_t *)_file;
     static const char *func = "H5FD_stdio_truncate"; /* Function Name for error reporting */
@@ -1056,7 +1014,7 @@ H5FD_stdio_truncate(H5FD_t *_file, hid_t /*UNUSED*/ dxpl_id, hbool_t /*UNUSED*/
             rewind(file->fp);
 
             /* Windows uses this odd QuadPart union for 32/64-bit portability */
-            li.QuadPart = (__int64)file->eoa;
+            li.QuadPart = (LONGLONG)file->eoa;
 
             /* Extend the file to make sure it's large enough.
              *
@@ -1112,12 +1070,10 @@ H5FD_stdio_truncate(H5FD_t *_file, hid_t /*UNUSED*/ dxpl_id, hbool_t /*UNUSED*/
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Vailin Choi; March 2015
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5FD_stdio_lock(H5FD_t *_file, hbool_t rw)
+H5FD_stdio_lock(H5FD_t *_file, bool rw)
 {
 #ifdef H5_HAVE_FLOCK
     H5FD_stdio_t      *file = (H5FD_stdio_t *)_file; /* VFD file struct                      */
@@ -1163,8 +1119,6 @@ H5FD_stdio_lock(H5FD_t *_file, hbool_t rw)
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Vailin Choi; March 2015
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1199,6 +1153,34 @@ H5FD_stdio_unlock(H5FD_t *_file)
     return 0;
 } /* end H5FD_stdio_unlock() */
 
+/*-------------------------------------------------------------------------
+ * Function:    H5FD_stdio_delete
+ *
+ * Purpose:     Delete a file
+ *
+ * Return:      Non-negative on success/Negative on failure
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+H5FD_stdio_delete(const char *filename, hid_t /*UNUSED*/ fapl_id)
+{
+    static const char *func = "H5FD_stdio_delete"; /* Function Name for error reporting    */
+
+    /* Clear the error stack */
+    H5Eclear2(H5E_DEFAULT);
+
+    assert(filename);
+
+    /* Quiet compiler */
+    (void)fapl_id;
+
+    if (remove(filename) < 0)
+        H5Epush_ret(func, H5E_ERR_CLS, H5E_VFL, H5E_CANTDELETEFILE, "can't delete file)", -1);
+
+    return 0;
+} /* end H5FD_stdio_delete() */
+
 #ifdef H5private_H
 /*
  * This is not related to the functionality of the driver code.
