@@ -11,12 +11,9 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:	Quincey Koziol
- *		Saturday, September 12, 2015
- *
- * Purpose:	This file contains declarations which define macros for the
- *		H5F package.  Including this header means that the source file
- *		is part of the H5F package.
+ * Purpose: This file contains declarations which define macros for the
+ *          H5F package.  Including this header means that the source file
+ *          is part of the H5F package.
  */
 #ifndef H5Fmodule_H
 #define H5Fmodule_H
@@ -25,11 +22,10 @@
  *      reporting macros.
  */
 #define H5F_MODULE
-#define H5_MY_PKG      H5F
-#define H5_MY_PKG_ERR  H5E_FILE
-#define H5_MY_PKG_INIT YES
+#define H5_MY_PKG     H5F
+#define H5_MY_PKG_ERR H5E_FILE
 
-/** \page H5F_UG  The HDF5 File
+/** \page H5F_UG HDF5 File
  *
  * \section sec_file The HDF5 File
  * \subsection subsec_file_intro Introduction
@@ -47,7 +43,7 @@
  * \li The use of low-level file drivers
  *
  * This chapter assumes an understanding of the material presented in the data model chapter. For
- * more information, @see @ref sec_data_model.
+ * more information, see \ref sec_data_model.
  *
  * \subsection subsec_file_access_modes File Access Modes
  * There are two issues regarding file access:
@@ -105,7 +101,7 @@
  * a user-definable data block; the size of data address parameters; properties of the B-trees that are
  * used to manage the data in the file; and certain HDF5 Library versioning information.
  *
- * For more information, @see @ref subsubsec_file_property_lists_props.
+ * For more information, see \ref subsubsec_file_property_lists_props.
  *
  * This section has a more detailed discussion of file creation properties. If you have no special
  * requirements for these file characteristics, you can simply specify #H5P_DEFAULT for the default
@@ -116,7 +112,7 @@
  * settings, and parallel I/O. Data alignment, metadata block and cache sizes, and data sieve buffer
  * size are factors in improving I/O performance.
  *
- * For more information, @see @ref subsubsec_file_property_lists_access.
+ * For more information, see \ref subsubsec_file_property_lists_access.
  *
  * This section has a more detailed discussion of file access properties. If you have no special
  * requirements for these file access characteristics, you can simply specify #H5P_DEFAULT for the
@@ -137,7 +133,7 @@
  * \li Single file on a standard file system
  * \li Multiple files on a standard file system
  * \li Multiple files on a parallel file system
- * \li Block of memory within an application’s memory space
+ * \li Block of memory within an application's memory space
  * \li More abstract situations such as virtual files
  *
  * This HDF5 address space is generally referred to as an HDF5 file regardless of its organization at
@@ -239,11 +235,11 @@
  * Note that the root group, indicated above by /, was automatically created when the file was created.
  *
  * h5dump is described on the
- * <a href="https://portal.hdfgroup.org/display/HDF5/h5dump">Tools</a>
+ * <a href="https://\DOXURL/_view_tools_view.html#subsecViewToolsViewContent_h5dump">
+ * Tools</a>
  * page under
- * <a href="https://portal.hdfgroup.org/display/HDF5/Libraries+and+Tools+Reference">
- * Libraries and Tools Reference</a>.
- * The HDF5 DDL grammar is described in the document \ref DDLBNF110.
+ * <a href="https://\DOXURL/_view_tools_command.html">Command-line Tools</a>.
+ * The HDF5 DDL grammar is described in the document \ref DDLBNF114.
  *
  * \subsection subsec_file_summary File Function Summaries
  * General library (\ref H5 functions and macros), (\ref H5F functions), file related
@@ -269,7 +265,7 @@
  * </tr>
  * <tr>
  * <td>#H5garbage_collect</td>
- * <td>Garbage collects on all free-lists of all types.</td>
+ * <td>Performs garbage collection (GC) on all free-lists of all types.</td>
  * </tr>
  * <tr>
  * <td>#H5get_libversion</td>
@@ -347,15 +343,15 @@
  * </tr>
  * <tr>
  * <td>#H5Fget_mdc_config</td>
- * <td>Obtain current metadata cache configuration for target file.</td>
+ * <td>Obtains current metadata cache configuration for target file.</td>
  * </tr>
  * <tr>
  * <td>#H5Fget_mdc_hit_rate</td>
- * <td>Obtain target file’s metadata cache hit rate.</td>
+ * <td>Obtains target file's metadata cache hit rate.</td>
  * </tr>
  * <tr>
  * <td>#H5Fget_mdc_size</td>
- * <td>Obtain current metadata cache size data for specified file.</td>
+ * <td>Obtains current metadata cache size data for specified file.</td>
  * </tr>
  * <tr>
  * <td>#H5Fget_mpi_atomicity</td>
@@ -395,15 +391,15 @@
  * </tr>
  * <tr>
  * <td>#H5Freset_mdc_hit_rate_stats</td>
- * <td>Reset hit rate statistics counters for the target file.</td>
+ * <td>Resets hit rate statistics counters for the target file.</td>
  * </tr>
  * <tr>
  * <td>#H5Fset_mdc_config</td>
- * <td>Use to configure metadata cache of target file.</td>
+ * <td>Configures metadata cache of target file.</td>
  * </tr>
  * <tr>
  * <td>#H5Fset_mpi_atomicity</td>
- * <td>Use to set the MPI atomicity mode.</td>
+ * <td>Sets the MPI atomicity mode.</td>
  * </tr>
  * <tr>
  * <td>#H5Funmount</td>
@@ -412,14 +408,19 @@
  * </table>
  *
  * \anchor fcpl_table_tag File creation property list functions (H5P)
+ * <div>
  * \snippet{doc} tables/propertyLists.dox fcpl_table
+ * </div>
  *
  * \anchor fapl_table_tag File access property list functions (H5P)
+ * <div>
  * \snippet{doc} tables/propertyLists.dox fapl_table
+ * </div>
  *
  * \anchor fd_pl_table_tag File driver property list functions (H5P)
+ * <div>
  * \snippet{doc} tables/propertyLists.dox fd_pl_table
- *
+ * </div>
  *
  * \subsection subsec_file_create Creating or Opening an HDF5 File
  * This section describes in more detail how to create and how to open files.
@@ -440,7 +441,7 @@
  *
  * The new file is created with the properties specified in the property lists fcpl_id and fapl_id.
  * fcpl is short for file creation property list. fapl is short for file access property list. Specifying
- * #H5P_DEFAULT for either the creation or access property list will use the library’s default
+ * #H5P_DEFAULT for either the creation or access property list will use the library's default
  * creation or access properties.
  *
  * If #H5Fcreate successfully creates the file, it returns a file identifier for the new file. This
@@ -465,8 +466,9 @@
  * remain valid. Each of these file identifiers must be released by calling #H5Fclose when it is no
  * longer needed.
  *
- * For more information, @see @ref subsubsec_file_property_lists_access.
- * For more information, @see @ref subsec_file_property_lists.
+ * For more information, see \ref subsubsec_file_property_lists_access.
+ *
+ * For more information, see \ref subsec_file_property_lists.
  *
  * \subsection subsec_file_closes Closing an HDF5 File
  * #H5Fclose both closes a file and releases the file identifier returned by #H5Fopen or #H5Fcreate.
@@ -511,7 +513,7 @@
  * information for every property list function is provided in the \ref H5P
  * section of the HDF5 Reference Manual.
  *
- * For more information, @see @ref sec_plist.
+ * For more information, @see \ref sec_plist.
  *
  * \subsubsection subsubsec_file_property_lists_create Creating a Property List
  * If you do not wish to rely on the default file creation and access properties, you must first create
@@ -593,7 +595,7 @@
  * \subsubsection subsubsec_file_property_lists_access File Access Properties
  * This section discusses file access properties that are not related to the low-level file drivers. File
  * drivers are discussed separately later in this chapter.
- * For more information, @see @ref subsec_file_alternate_drivers.
+ * For more information, @see \ref subsec_file_alternate_drivers.
  *
  * File access property lists control various aspects of file I/O and structure.
  *
@@ -633,7 +635,7 @@
  * #H5Pget_sieve_buf_size retrieves the current maximum size of the data sieve buffer.
  *
  * <h4>Garbage Collection References</h4>
- * Dataset region references and other reference types use space in an HDF5 file’s global heap. If
+ * Dataset region references and other reference types use space in an HDF5 file's global heap. If
  * garbage collection is on (1) and the user passes in an uninitialized value in a reference structure,
  * the heap might become corrupted. When garbage collection is off (0), however, and the user reuses
  * a reference, the previous heap block will be orphaned and not returned to the free heap
@@ -648,7 +650,7 @@
  * \li Single file on standard file system
  * \li Multiple files on standard file system
  * \li Multiple files on parallel file system
- * \li Block of memory within application’s memory space
+ * \li Block of memory within application's memory space
  * \li More abstract situations such as virtual files
  *
  * This HDF5 address space is generally referred to as an HDF5 file regardless of its organization at
@@ -656,7 +658,7 @@
  *
  * HDF5 employs an extremely flexible mechanism called the virtual file layer, or VFL, for file
  * I/O. A full understanding of the VFL is only necessary if you plan to write your own drivers
- * @see \ref VFL in the HDF5 Technical Notes.
+ * see \ref VFL in the HDF5 Technical Notes.
  *
  * For our
  * purposes here, it is sufficient to know that the low-level drivers used for file I/O reside in the
@@ -676,7 +678,9 @@
  * #H5FD_SEC2. Alternative layouts and drivers are designed to suit the needs of a variety of
  * systems, environments, and applications. The drivers are listed in the table below.
  *
+ * <div>
  * \snippet{doc} tables/fileDriverLists.dox supported_file_driver_table
+ * </div>
  *
  * For more information, see the HDF5 Reference Manual entries for the function calls shown in
  * the column on the right in the table above.
@@ -687,7 +691,7 @@
  *
  * If an application requires a special-purpose low-level driver, the VFL provides a public API for
  * creating one. For more information on how to create a driver,
- * @see @ref VFL in the HDF5 Technical Notes.
+ * see \ref VFL in the HDF5 Technical Notes.
  *
  * \subsubsection subsubsec_file_alternate_drivers_id Identifying the Previously‐used File Driver
  * When creating a new HDF5 file, no history exists, so the file driver must be specified if it is to be
@@ -709,7 +713,7 @@
  * If the application opens an HDF5 file without both determining the driver used to create the file
  * and setting up the use of that driver, the HDF5 Library will examine the superblock and the
  * driver definition block to identify the driver.
- * See the <a href="https://docs.hdfgroup.org/hdf5/develop/_s_p_e_c.html">HDF5 File Format Specification</a>
+ * See the <a href="https://\DOXURL/_s_p_e_c.html">HDF5 File Format Specification</a>
  * for detailed descriptions of the superblock and the driver definition block.
  *
  * \subsubsection subsubsec_file_alternate_drivers_sec2 The POSIX (aka SEC2) Driver
@@ -849,8 +853,8 @@
  *
  * <em>Managing file access for in-memory files</em>
  * \code
- *   herr_t H5Pset_fapl_core (hid_t access_properties, size_t block_size, hbool_t backing_store)
- *   herr_t H5Pget_fapl_core (hid_t access_properties, size_t *block_size), hbool_t *backing_store)
+ *   herr_t H5Pset_fapl_core (hid_t access_properties, size_t block_size, bool backing_store)
+ *   herr_t H5Pget_fapl_core (hid_t access_properties, size_t *block_size), bool *backing_store)
  * \endcode
  *
  * #H5Pset_fapl_core sets the file access property list to use the Memory driver; any previously
@@ -860,9 +864,9 @@
  *
  * The backing_store Boolean flag is set when the in-memory file is created.
  * backing_store indicates whether to write the file contents to disk when the file is closed. If
- * backing_store is set to 1 (TRUE), the file contents are flushed to a file with the same name as the
+ * backing_store is set to 1 (true), the file contents are flushed to a file with the same name as the
  * in-memory file when the file is closed or access to the file is terminated in memory. If
- * backing_store is set to 0 (FALSE), the file is not saved.
+ * backing_store is set to 0 (false), the file is not saved.
  *
  * The application is allowed to open an existing file with the #H5FD_CORE driver. While using
  * #H5Fopen to open an existing file, if backing_store is set to 1 and the flag for #H5Fopen is set to
@@ -885,10 +889,11 @@
  *
  * Additional parameters may be added to these functions in the future.
  *
- * @see <a href="https://portal.hdfgroup.org/display/HDF5/HDF5+File+Image+Operations">
+ * see <a href="https://\DOCURL/advanced_topics/file_image_ops.html">
  * HDF5 File Image Operations</a>
  * section for information on more advanced usage of the Memory file driver, and
- * @see <a href="http://www.hdfgroup.org/HDF5/doc/Advanced/ModifiedRegionWrites/ModifiedRegionWrites.pdf">
+ * see <a
+ * href="https://\DOCURL/advanced_topics/ModifiedRegionWrites.pdf">
  * Modified Region Writes</a>
  * section for information on how to set write operations so that only modified regions are written
  * to storage.
@@ -985,9 +990,9 @@
  * \code
  *   herr_t H5Pset_fapl_multi (hid_t fapl_id, const H5FD_mem_t *memb_map, const hid_t *memb_fapl,
  *                             const char * const *memb_name, const haddr_t *memb_addr,
- *                             hbool_t relax)
+ *                             bool relax)
  *  herr_t H5Pget_fapl_multi (hid_t fapl_id, const H5FD_mem_t *memb_map, const hid_t *memb_fapl,
- *                             const char **memb_name, const haddr_t *memb_addr, hbool_t *relax)
+ *                             const char **memb_name, const haddr_t *memb_addr, bool *relax)
  * \endcode
  *
  * #H5Pset_fapl_multi sets the file access properties to use the Multi driver; any previously defined
@@ -1002,7 +1007,7 @@
  * Additional parameters may be added to these functions in the future.
  *
  * \subsubsection subsubsec_file_alternate_drivers_split The Split Driver
- * The Split driver, H5FD_SPLIT, is a limited case of the Multi driver where only two files are
+ * The Split driver is a limited case of the Multi driver where only two files are
  * created. One file holds metadata, and the other file holds raw data.
  * The function #H5Pset_fapl_split is used to manage Split file access properties. See the example
  * below.
@@ -1033,7 +1038,7 @@
  * function.
  *
  * \subsubsection subsubsec_file_alternate_drivers_par The Parallel Driver
- * Parallel environments require a parallel low-level driver. HDF5’s default driver for parallel
+ * Parallel environments require a parallel low-level driver. HDF5's default driver for parallel
  * systems is called the Parallel driver, #H5FD_MPIO. This driver uses the MPI standard for both
  * communication and file I/O.
  *
@@ -1049,7 +1054,7 @@
  * The file access properties managed by #H5Pset_fapl_mpio and retrieved by
  * #H5Pget_fapl_mpio are the MPI communicator, comm, and the MPI info object, info. comm and
  * info are used for file open. info is an information object much like an HDF5 property list. Both
- * are defined in MPI_FILE_OPEN of MPI-2.
+ * are defined in MPI_FILE_OPEN of MPI.
  *
  * The communicator and the info object are saved in the file access property list fapl_id.
  * fapl_id can then be passed to MPI_FILE_OPEN to create and/or open the file.
@@ -1067,7 +1072,7 @@
  * name is FILE. If the function does not find an existing file, it will create one. If it does find an
  * existing file, it will empty the file in preparation for a new set of data. The identifier for the
  * "new" file will be passed back to the application program.
- * For more information, @see @ref subsec_file_access_modes.
+ * For more information, @see \ref subsec_file_access_modes.
  *
  * <em>Creating a file with default creation and access properties</em>
  * \code
@@ -1179,7 +1184,7 @@
  * Note: In the code example above, loc_id is the file identifier for File1, /B is the link path to the
  * group where File2 is mounted, child_id is the file identifier for File2, and plist_id is a property
  * list identifier.
- * For more information, @see @ref sec_group.
+ * For more information, @see \ref sec_group.
  *
  * See the entries for #H5Fmount, #H5Funmount, and #H5Lcreate_external in the HDF5 Reference Manual.
  *
