@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:             H5Gpublic.h
- *                      Jul 11 1997
- *                      Robb Matzke
  *
  * Purpose:             Public declarations for the H5G package
  *
@@ -23,14 +21,10 @@
 #ifndef H5Gpublic_H
 #define H5Gpublic_H
 
-/* System headers needed by this file */
-#include <sys/types.h>
-
-/* Public headers needed by this file */
-#include "H5public.h"  /* Generic Functions			*/
-#include "H5Lpublic.h" /* Links                                */
-#include "H5Opublic.h" /* Object headers			*/
-#include "H5Tpublic.h" /* Datatypes				*/
+#include "H5public.h"  /* Generic Functions                        */
+#include "H5Ipublic.h" /* Identifiers                              */
+#include "H5Lpublic.h" /* Links                                    */
+#include "H5Opublic.h" /* Object Headers                           */
 
 /*****************/
 /* Public Macros */
@@ -124,6 +118,19 @@ extern "C" {
  */
 H5_DLL hid_t H5Gcreate2(hid_t loc_id, const char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gcreate}
+ */
+#ifndef H5_DOXYGEN
+H5_DLL hid_t H5Gcreate_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
+                             const char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id, hid_t es_id);
+#else
+H5_DLL hid_t  H5Gcreate_async(hid_t loc_id, const char *name, hid_t lcpl_id, hid_t gcpl_id, hid_t gapl_id,
+                              hid_t es_id);
+#endif
+
 /**
  *-------------------------------------------------------------------------
  * \ingroup H5G
@@ -141,7 +148,7 @@ H5_DLL hid_t H5Gcreate2(hid_t loc_id, const char *name, hid_t lcpl_id, hid_t gcp
  *          provides similar functionality to that provided by
  *          H5Gcreate1(), with the differences described in the list below.
  *
- *          The new group’s creation and access properties are specified
+ *          The new group's creation and access properties are specified
  *          in \p gcpl_id and \p gapl_id, respectively.
  *
  *          H5Gcreate_anon() returns a new group identifier. This identifier
@@ -153,12 +160,12 @@ H5_DLL hid_t H5Gcreate2(hid_t loc_id, const char *name, hid_t lcpl_id, hid_t gcp
  *
  *          \li H5Gcreate1() does not provide for the use of custom property
  *              lists; H5Gcreate1() always uses default properties.
- *          \li H5Gcreate_anon() neither provides the new group’s name
+ *          \li H5Gcreate_anon() neither provides the new group's name
  *              nor links it into the HDF5 file structure; those actions
  *              must be performed separately through a call to H5Olink(),
  *              which offers greater control over linking.
  *          \li H5Gcreate_anon() does not directly provide a hint mechanism
- *              for the group’s heap size. Comparable information can be
+ *              for the group's heap size. Comparable information can be
  *              included in the group creation property list \p gcpl_id through
  *              a H5Pset_local_heap_size_hint() call.
  *
@@ -203,6 +210,21 @@ H5_DLL hid_t H5Gcreate_anon(hid_t loc_id, hid_t gcpl_id, hid_t gapl_id);
  */
 H5_DLL hid_t H5Gopen2(hid_t loc_id, const char *name, hid_t gapl_id);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gopen}
+ *
+ * \since 1.12.0
+ *
+ */
+#ifndef H5_DOXYGEN
+H5_DLL hid_t H5Gopen_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
+                           const char *name, hid_t gapl_id, hid_t es_id);
+#else
+H5_DLL hid_t  H5Gopen_async(hid_t loc_id, const char *name, hid_t gapl_id, hid_t es_id);
+#endif
+
 /**
  *-------------------------------------------------------------------------
  * \ingroup H5G
@@ -250,6 +272,21 @@ H5_DLL hid_t H5Gget_create_plist(hid_t group_id);
  */
 H5_DLL herr_t H5Gget_info(hid_t loc_id, H5G_info_t *ginfo);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gget_info}
+ *
+ * \since 1.12.0
+ *
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Gget_info_async(const char *app_file, const char *app_func, unsigned app_line, hid_t loc_id,
+                                H5G_info_t *ginfo /*out*/, hid_t es_id);
+#else
+H5_DLL herr_t H5Gget_info_async(hid_t loc_id, H5G_info_t *ginfo /*out*/, hid_t es_id);
+#endif
+
 /**
  *-------------------------------------------------------------------------
  * \ingroup H5G
@@ -282,11 +319,28 @@ H5_DLL herr_t H5Gget_info(hid_t loc_id, H5G_info_t *ginfo);
  */
 H5_DLL herr_t H5Gget_info_by_name(hid_t loc_id, const char *name, H5G_info_t *ginfo, hid_t lapl_id);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gget_info_by_name}
+ *
+ * \since 1.12.0
+ *
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Gget_info_by_name_async(const char *app_file, const char *app_func, unsigned app_line,
+                                        hid_t loc_id, const char *name, H5G_info_t *ginfo /*out*/,
+                                        hid_t lapl_id, hid_t es_id);
+#else
+H5_DLL herr_t H5Gget_info_by_name_async(hid_t loc_id, const char *name, H5G_info_t *ginfo /*out*/,
+                                        hid_t lapl_id, hid_t es_id);
+#endif
+
 /**
  *-------------------------------------------------------------------------
  * \ingroup H5G
  *
- * \brief Retrieves information about a group, according to the group’s
+ * \brief Retrieves information about a group, according to the group's
  *        position within an index
  *
  * \fgdta_loc_id
@@ -328,6 +382,25 @@ H5_DLL herr_t H5Gget_info_by_name(hid_t loc_id, const char *name, H5G_info_t *gi
 H5_DLL herr_t H5Gget_info_by_idx(hid_t loc_id, const char *group_name, H5_index_t idx_type,
                                  H5_iter_order_t order, hsize_t n, H5G_info_t *ginfo, hid_t lapl_id);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gget_info_by_idx}
+ *
+ * \since 1.12.0
+ *
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Gget_info_by_idx_async(const char *app_file, const char *app_func, unsigned app_line,
+                                       hid_t loc_id, const char *group_name, H5_index_t idx_type,
+                                       H5_iter_order_t order, hsize_t n, H5G_info_t *ginfo /*out*/,
+                                       hid_t lapl_id, hid_t es_id);
+#else
+H5_DLL herr_t H5Gget_info_by_idx_async(hid_t loc_id, const char *group_name, H5_index_t idx_type,
+                                       H5_iter_order_t order, hsize_t n, H5G_info_t *ginfo /*out*/,
+                                       hid_t lapl_id, hid_t es_id);
+#endif
+
 /**
  *-------------------------------------------------------------------------
  * \ingroup H5G
@@ -339,7 +412,7 @@ H5_DLL herr_t H5Gget_info_by_idx(hid_t loc_id, const char *group_name, H5_index_
  * \return \herr_t
  *
  * \details H5Gflush() causes all buffers associated with a group to be
- *          immediately flushed to disk without removing the data from
+ *          immediately flushed to the disk without removing the data from
  *          the cache.
  *
  * \attention
@@ -347,7 +420,7 @@ H5_DLL herr_t H5Gget_info_by_idx(hid_t loc_id, const char *group_name, H5_index_
  *          flushes the internal HDF5 buffers and then asks the operating
  *          system (the OS) to flush the system buffers for the open
  *          files. After that, the OS is responsible for ensuring that
- *          the data is actually flushed to disk.
+ *          the data is actually flushed to the disk.
  *
  * \since 1.8.0
  *
@@ -368,7 +441,7 @@ H5_DLL herr_t H5Gflush(hid_t group_id);
  *          cleared and immediately re-loaded with updated contents from disk.
  *
  *          This function essentially closes the group, evicts all
- *          metadata associated with it from the cache, and then re-opens
+ *          metadata associated with it from the cache, and then reopens
  *          the group. The reopened group is automatically re-registered
  *          with the same identifier.
  *
@@ -387,7 +460,7 @@ H5_DLL herr_t H5Grefresh(hid_t group_id);
  *
  * \return \herr_t
  *
- * \details H5Gclose() releases resources used by a group which was
+ * \details H5Gclose() releases resources used by a group that was
  *          opened by H5Gcreate() or H5Gopen().  After closing a group,
  *          \p group_id cannot be used again until another H5Gcreate()
  *          or H5Gopen() is called on it.
@@ -403,6 +476,45 @@ H5_DLL herr_t H5Grefresh(hid_t group_id);
  */
 H5_DLL herr_t H5Gclose(hid_t group_id);
 
+/**
+ * --------------------------------------------------------------------------
+ * \ingroup ASYNC
+ * \async_variant_of{H5Gclose}
+ *
+ * \since 1.12.0
+ *
+ */
+#ifndef H5_DOXYGEN
+H5_DLL herr_t H5Gclose_async(const char *app_file, const char *app_func, unsigned app_line, hid_t group_id,
+                             hid_t es_id);
+#else
+H5_DLL herr_t H5Gclose_async(hid_t group_id, hid_t es_id);
+#endif
+
+/// \cond DEV
+/* API Wrappers for async routines */
+/* (Must be defined _after_ the function prototype) */
+/* (And must only defined when included in application code, not the library) */
+#ifndef H5G_MODULE
+#define H5Gcreate_async(...)           H5Gcreate_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Gopen_async(...)             H5Gopen_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Gget_info_async(...)         H5Gget_info_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Gget_info_by_name_async(...) H5Gget_info_by_name_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Gget_info_by_idx_async(...)  H5Gget_info_by_idx_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+#define H5Gclose_async(...)            H5Gclose_async(__FILE__, __func__, __LINE__, __VA_ARGS__)
+
+/* Define "wrapper" versions of function calls, to allow compile-time values to
+ *      be passed in by language wrapper or library layer on top of HDF5.
+ */
+#define H5Gcreate_async_wrap           H5_NO_EXPAND(H5Gcreate_async)
+#define H5Gopen_async_wrap             H5_NO_EXPAND(H5Gopen_async)
+#define H5Gget_info_async_wrap         H5_NO_EXPAND(H5Gget_info_async)
+#define H5Gget_info_by_name_async_wrap H5_NO_EXPAND(H5Gget_info_by_name_async)
+#define H5Gget_info_by_idx_async_wrap  H5_NO_EXPAND(H5Gget_info_by_idx_async)
+#define H5Gclose_async_wrap            H5_NO_EXPAND(H5Gclose_async)
+#endif /* H5G_MODULE */
+/// \endcond
+
 /* Symbols defined for compatibility with previous versions of the HDF5 API.
  *
  * Use of these symbols is deprecated.
@@ -580,12 +692,14 @@ H5_DLL hid_t H5Gopen1(hid_t loc_id, const char *name);
  *          If \p link_type is #H5G_LINK_SOFT, then \p cur_name can be anything
  *          and is interpreted at lookup time relative to the group which
  *          contains the final component of \p new_name. For instance, if \p
- *          cur_name is \Code{./foo}, \p new_name is \Code{./x/y/bar}, and a
- *          request is made for \Code{./x/y/bar}, then the actual object looked
- *          up is \Code{./x/y/./foo}.
+ *          cur_name is \TText{./foo}, \p new_name is \TText{./x/y/bar}, and a
+ *          request is made for \TText{./x/y/bar}, then the actual object looked
+ *          up is \TText{./x/y/./foo}.
 
  * \version 1.8.0 Function deprecated in this release.
  *
+ * \since 1.0.0
+ *
  */
 H5_DLL herr_t H5Glink(hid_t cur_loc_id, H5G_link_t type, const char *cur_name, const char *new_name);
 /**
@@ -616,12 +730,14 @@ H5_DLL herr_t H5Glink(hid_t cur_loc_id, H5G_link_t type, const char *cur_name, c
  *          If \p link_type is #H5G_LINK_SOFT, then \p cur_name can be anything
  *          and is interpreted at lookup time relative to the group which
  *          contains the final component of \p new_name. For instance, if \p
- *          current_name is \Code{./foo}, \p new_name is \Code{./x/y/bar}, and a
- *          request is made for \Code{./x/y/bar}, then the actual object looked
- *          up is \Code{./x/y/./foo}.
-
+ *          current_name is \TText{./foo}, \p new_name is \TText{./x/y/bar}, and a
+ *          request is made for \TText{./x/y/bar}, then the actual object looked
+ *          up is \TText{./x/y/./foo}.
+ *
  * \version 1.8.0 Function deprecated in this release.
  *
+ * \since 1.6.0
+ *
  */
 H5_DLL herr_t H5Glink2(hid_t cur_loc_id, const char *cur_name, H5G_link_t type, hid_t new_loc_id,
                        const char *new_name);
@@ -651,6 +767,8 @@ H5_DLL herr_t H5Glink2(hid_t cur_loc_id, const char *cur_name, H5G_link_t type,
  *
  * \version 1.8.0 Function deprecated in this release.
  *
+ * \since 1.0.0
+ *
  */
 H5_DLL herr_t H5Gmove(hid_t src_loc_id, const char *src_name, const char *dst_name);
 /**
@@ -682,6 +800,8 @@ H5_DLL herr_t H5Gmove(hid_t src_loc_id, const char *src_name, const char *dst_na
  *
  * \version 1.8.0 Function deprecated in this release.
  *
+ * \since 1.6.0
+ *
  */
 H5_DLL herr_t H5Gmove2(hid_t src_loc_id, const char *src_name, hid_t dst_loc_id, const char *dst_name);
 /**
@@ -712,7 +832,7 @@ H5_DLL herr_t H5Gmove2(hid_t src_loc_id, const char *src_name, hid_t dst_loc_id,
  *          any object identifier is open for the object, the space will not be
  *          released until after the object identifier is closed.
  *
- *          Note that space identified as freespace is available for re-use only
+ *          Note that space identified as freespace is available for reuse only
  *          as long as the file remains open; once a file has been closed, the
  *          HDF5 library loses track of freespace. See “Freespace Management” in
  *          the \ref UG for further details.
@@ -723,6 +843,8 @@ H5_DLL herr_t H5Gmove2(hid_t src_loc_id, const char *src_name, hid_t dst_loc_id,
  *
  * \version 1.8.0 Function deprecated in this release.
  *
+ * \since 1.0.0
+ *
  */
 H5_DLL herr_t H5Gunlink(hid_t loc_id, const char *name);
 /**
@@ -761,6 +883,8 @@ H5_DLL herr_t H5Gunlink(hid_t loc_id, const char *name);
  *
  * \version 1.8.0 Function deprecated in this release.
  *
+ * \since 1.0.0
+ *
  */
 H5_DLL herr_t H5Gget_linkval(hid_t loc_id, const char *name, size_t size, char *buf /*out*/);
 /**
@@ -771,7 +895,7 @@ H5_DLL herr_t H5Gget_linkval(hid_t loc_id, const char *name, size_t size, char *
  *
  * \fgdt_loc_id
  * \param[in] name Name of the object whose comment is to be set or reset
- *                 name must be \Code{'.'} (dot) if \p loc_id fully specifies
+ *                 name must be \TText{'.'} (dot) if \p loc_id fully specifies
  *                 the object for which the comment is to be set.
  * \param[in] comment The new comment
  *
@@ -787,7 +911,7 @@ H5_DLL herr_t H5Gget_linkval(hid_t loc_id, const char *name, size_t size, char *
  *          \p loc_id can specify any object in the file. name can be one of the
  *          following:
  *          \li The name of the object relative to \p loc_id
- *          \li An absolute name of the object, starting from \c /, the file’s
+ *          \li An absolute name of the object, starting from \c /, the file's
  *              root group
  *          \li A dot (\c .), if \p loc_id fully specifies the object
  *
@@ -801,6 +925,8 @@ H5_DLL herr_t H5Gget_linkval(hid_t loc_id, const char *name, size_t size, char *
  *
  * \version 1.8.0 Function deprecated in this release.
  *
+ * \since 1.0.0
+ *
  */
 H5_DLL herr_t H5Gset_comment(hid_t loc_id, const char *name, const char *comment);
 /**
@@ -811,7 +937,7 @@ H5_DLL herr_t H5Gset_comment(hid_t loc_id, const char *name, const char *comment
  *
  * \fgdt_loc_id
  * \param[in] name Name of the object whose comment is to be set or reset
- *                 name must be \Code{'.'} (dot) if \p loc_id fully specifies
+ *                 name must be \TText{'.'} (dot) if \p loc_id fully specifies
  *                 the object for which the comment is to be set.
  * \param[in] bufsize Maximum number of comment characters to be returned in \p buf.
  * \param[in] buf The comment
@@ -823,29 +949,26 @@ H5_DLL herr_t H5Gset_comment(hid_t loc_id, const char *name, const char *comment
  * \deprecated This function is deprecated in favor of the function
  *             H5Oget_comment().
  *
- * \details H5Gget_comment() retrieves the comment for the the object specified
+ * \details H5Gget_comment() retrieves the comment for the object specified
  *          by \p loc_id and \p name. The comment is returned in the buffer \p
  *          buf.
  *
  *          \p loc_id can specify any object in the file. name can be one of the
  *          following:
  *          \li The name of the object relative to \p loc_id
- *          \li An absolute name of the object, starting from \c /, the file’s
+ *          \li An absolute name of the object, starting from \c /, the file's
  *              root group
  *          \li A dot (\c .), if \p loc_id fully specifies the object
  *
- *          At most bufsize characters, including a null-terminator, are
- *          returned in \p buf. The returned value is not null-terminated if the
- *          comment is longer than the supplied buffer. If the size of the
- *          comment is unknown, a preliminary \p H5Gget_comment() call will
- *          return the size of the comment, including space for the
- *          null-terminator.
+ *          \details_namelen{comment,H5Gget_comment}
  *
  *          If an object does not have a comment, the empty string is returned
  *          in comment.
  *
  * \version 1.8.0 Function deprecated in this release.
  *
+ * \since 1.0.0
+ *
  */
 H5_DLL int H5Gget_comment(hid_t loc_id, const char *name, size_t bufsize, char *buf);
 /**
@@ -884,7 +1007,7 @@ H5_DLL int H5Gget_comment(hid_t loc_id, const char *name, size_t bufsize, char *
  *          The operation receives the group identifier for the group being
  *          iterated over, \p group, the name of the current object within
  *          the group, \p name, and the pointer to the operator data
- *          passed in to H5Giterate(), \p op_data.
+ *          passed into H5Giterate(), \p op_data.
  *
  *          The return values from an operator are:
  *          \li Zero causes the iterator to continue, returning zero when all
@@ -905,9 +1028,14 @@ H5_DLL int H5Gget_comment(hid_t loc_id, const char *name, size_t bufsize, char *
  *          examine the members of \c subgroup_a. When recursive iteration is
  *          required, the application must handle the recursion, explicitly
  *          calling H5Giterate() on discovered subgroups.
-
+ *
+ * \warning  Adding or removing members to the group during iteration
+ *           will lead to undefined behavior.
+ *
  * \version 1.8.0 Function deprecated in this release.
  *
+ * \since 1.0.0
+ *
  */
 H5_DLL herr_t H5Giterate(hid_t loc_id, const char *name, int *idx, H5G_iterate_t op, void *op_data);
 /**
@@ -929,6 +1057,8 @@ H5_DLL herr_t H5Giterate(hid_t loc_id, const char *name, int *idx, H5G_iterate_t
  *
  * \version 1.8.0 Function deprecated in this release.
  *
+ * \since 1.6.0
+ *
  */
 H5_DLL herr_t H5Gget_num_objs(hid_t loc_id, hsize_t *num_objs);
 /**
@@ -986,6 +1116,8 @@ H5_DLL herr_t H5Gget_num_objs(hid_t loc_id, hsize_t *num_objs);
  * \version 1.6.1 Two new fields were added to the \ref H5G_stat_t struct in
  *                this release.
  *
+ * \since 1.0.0
+ *
  */
 H5_DLL herr_t H5Gget_objinfo(hid_t loc_id, const char *name, hbool_t follow_link,
                              H5G_stat_t *statbuf /*out*/);
@@ -993,7 +1125,7 @@ H5_DLL herr_t H5Gget_objinfo(hid_t loc_id, const char *name, hbool_t follow_link
  *-------------------------------------------------------------------------
  * \ingroup H5G
  *
- * \brief Returns a name of an object specified by an index
+ * \brief Returns the name of an object specified by an index
  *
  * \fg_loc_id
  * \param[in] idx Transient index identifying object
@@ -1006,7 +1138,7 @@ H5_DLL herr_t H5Gget_objinfo(hid_t loc_id, const char *name, hbool_t follow_link
  *
  * \deprecated This function is deprecated in favor of the function H5Lget_name_by_idx().
  *
- * \details H5Gget_objname_by_idx() returns a name of the object specified by
+ * \details H5Gget_objname_by_idx() returns the name of the object specified by
  *          the index \p idx in the group \p loc_id.
  *
  *          The group is specified by a group identifier \p loc_id. If
@@ -1023,7 +1155,7 @@ H5_DLL herr_t H5Gget_objinfo(hid_t loc_id, const char *name, hbool_t follow_link
  *
  *          If the size of the provided buffer \p name is less or equal the
  *          actual object name length, the object name is truncated to
- *          \Code{max_size - 1} characters.
+ *          \TText{max_size - 1} characters.
  *
  *          Note that if the size of the object's name is unknown, a preliminary
  *          call to H5Gget_objname_by_idx() with \p name set to \c NULL will
@@ -1061,6 +1193,12 @@ H5_DLL ssize_t H5Gget_objname_by_idx(hid_t loc_id, hsize_t idx, char *name, size
  *          the group. This parameter is described in more detail in the
  *          discussion of H5Gget_objname_by_idx().
  *
+ * \note    As of 1.12.0, H5Gget_objtype_by_idx() returns the type of the object
+ *          that the link points to, but it has been deprecated for H5Oget_info().
+ *          Previous behavior for this function returned H5G_LINK for any link type.
+ *          To get the link type, an application may use H5Lget_info_by_idx()
+ *          instead.
+ *
  * \version 1.8.0 Function deprecated in this release.
  * \version 1.6.0 The function return type changed from \c int to the enumerated
  *                type \ref H5G_obj_t.
