@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:     H5HFtiny.c
- *              Aug 14 2006
- *              Quincey Koziol
  *
  * Purpose:     Routines for "tiny" objects in fractal heap
  *
@@ -33,7 +31,7 @@
 #include "H5private.h"   /* Generic Functions        */
 #include "H5Eprivate.h"  /* Error handling           */
 #include "H5HFpkg.h"     /* Fractal heaps            */
-#include "H5MMprivate.h" /* Memory management        */
+#include "H5MMprivate.h" /* Memory management			*/
 
 /****************/
 /* Local Macros */
@@ -72,26 +70,23 @@ static herr_t H5HF__tiny_op_real(H5HF_hdr_t *hdr, const uint8_t *id, H5HF_operat
 /*******************/
 
 /*-------------------------------------------------------------------------
- * Function:    H5HF_tiny_init
+ * Function:    H5HF__tiny_init
  *
  * Purpose:     Initialize information for tracking 'tiny' objects
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Quincey Koziol
- *              Aug 14 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_tiny_init(H5HF_hdr_t *hdr)
+H5HF__tiny_init(H5HF_hdr_t *hdr)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /*
      * Check arguments.
      */
-    HDassert(hdr);
+    assert(hdr);
 
     /* Compute information about 'tiny' objects for the heap */
 
@@ -102,49 +97,46 @@ H5HF_tiny_init(H5HF_hdr_t *hdr)
      */
     if ((hdr->id_len - 1) <= H5HF_TINY_LEN_SHORT) {
         hdr->tiny_max_len      = hdr->id_len - 1;
-        hdr->tiny_len_extended = FALSE;
+        hdr->tiny_len_extended = false;
     } /* end if */
     else if ((hdr->id_len - 1) == (H5HF_TINY_LEN_SHORT + 1)) {
         hdr->tiny_max_len      = H5HF_TINY_LEN_SHORT;
-        hdr->tiny_len_extended = FALSE;
+        hdr->tiny_len_extended = false;
     } /* end if */
     else {
         hdr->tiny_max_len      = hdr->id_len - 2;
-        hdr->tiny_len_extended = TRUE;
+        hdr->tiny_len_extended = true;
     } /* end else */
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5HF_tiny_init() */
+} /* end H5HF__tiny_init() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5HF_tiny_insert
+ * Function:    H5HF__tiny_insert
  *
  * Purpose:     Pack a 'tiny' object in a heap ID
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Quincey Koziol
- *              Aug 14 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_tiny_insert(H5HF_hdr_t *hdr, size_t obj_size, const void *obj, void *_id)
+H5HF__tiny_insert(H5HF_hdr_t *hdr, size_t obj_size, const void *obj, void *_id)
 {
     uint8_t *id = (uint8_t *)_id; /* Pointer to ID buffer */
     size_t   enc_obj_size;        /* Encoded object size */
     herr_t   ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(obj_size <= hdr->tiny_max_len);
-    HDassert(obj_size <= (H5HF_TINY_MASK_EXT + 1));
-    HDassert(obj);
-    HDassert(id);
+    assert(hdr);
+    assert(obj_size <= hdr->tiny_max_len);
+    assert(obj_size <= (H5HF_TINY_MASK_EXT + 1));
+    assert(obj);
+    assert(id);
 
     /* Adjust object's size for encoding it */
     enc_obj_size = obj_size - 1;
@@ -160,45 +152,42 @@ H5HF_tiny_insert(H5HF_hdr_t *hdr, size_t obj_size, const void *obj, void *_id)
     } /* end else */
 
     H5MM_memcpy(id, obj, obj_size);
-    HDmemset(id + obj_size, 0, (hdr->id_len - ((size_t)1 + (size_t)hdr->tiny_len_extended + obj_size)));
+    memset(id + obj_size, 0, (hdr->id_len - ((size_t)1 + (size_t)hdr->tiny_len_extended + obj_size)));
 
     /* Update statistics about heap */
     hdr->tiny_size += obj_size;
     hdr->tiny_nobjs++;
 
     /* Mark heap header as modified */
-    if (H5HF_hdr_dirty(hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty")
+    if (H5HF__hdr_dirty(hdr) < 0)
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_tiny_insert() */
+} /* end H5HF__tiny_insert() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5HF_tiny_get_obj_len
+ * Function:    H5HF__tiny_get_obj_len
  *
  * Purpose:     Get the size of a 'tiny' object in a fractal heap
  *
  * Return:      SUCCEED (Can't fail)
  *
- * Programmer:  Quincey Koziol
- *              Aug 14 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_tiny_get_obj_len(H5HF_hdr_t *hdr, const uint8_t *id, size_t *obj_len_p)
+H5HF__tiny_get_obj_len(H5HF_hdr_t *hdr, const uint8_t *id, size_t *obj_len_p)
 {
     size_t enc_obj_size; /* Encoded object size */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(id);
-    HDassert(obj_len_p);
+    assert(hdr);
+    assert(id);
+    assert(obj_len_p);
 
     /* Check if 'tiny' object ID is in extended form, and retrieve encoded size */
     if (!hdr->tiny_len_extended)
@@ -213,7 +202,7 @@ H5HF_tiny_get_obj_len(H5HF_hdr_t *hdr, const uint8_t *id, size_t *obj_len_p)
     *obj_len_p = enc_obj_size + 1;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5HF_tiny_get_obj_len() */
+} /* end H5HF__tiny_get_obj_len() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5HF__tiny_op_real
@@ -222,9 +211,6 @@ H5HF_tiny_get_obj_len(H5HF_hdr_t *hdr, const uint8_t *id, size_t *obj_len_p)
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Quincey Koziol
- *              Sep 11 2006
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -233,18 +219,18 @@ H5HF__tiny_op_real(H5HF_hdr_t *hdr, const uint8_t *id, H5HF_operator_t op, void
     size_t enc_obj_size;        /* Encoded object size */
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(id);
-    HDassert(op);
+    assert(hdr);
+    assert(id);
+    assert(op);
 
     /* Get the object's encoded length */
-    /* H5HF_tiny_obj_len can't fail */
-    ret_value = H5HF_tiny_get_obj_len(hdr, id, &enc_obj_size);
+    /* H5HF__tiny_obj_len can't fail */
+    ret_value = H5HF__tiny_get_obj_len(hdr, id, &enc_obj_size);
 
     /* Advance past flag byte(s) */
     if (!hdr->tiny_len_extended)
@@ -259,118 +245,109 @@ H5HF__tiny_op_real(H5HF_hdr_t *hdr, const uint8_t *id, H5HF_operator_t op, void
 
     /* Call the user's 'op' callback */
     if (op(id, enc_obj_size, op_data) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "application's callback failed")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "application's callback failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF__tiny_op_real() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5HF_tiny_read
+ * Function:    H5HF__tiny_read
  *
  * Purpose:     Read a 'tiny' object from the heap
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Quincey Koziol
- *              Aug  8 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_tiny_read(H5HF_hdr_t *hdr, const uint8_t *id, void *obj)
+H5HF__tiny_read(H5HF_hdr_t *hdr, const uint8_t *id, void *obj)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(id);
-    HDassert(obj);
+    assert(hdr);
+    assert(id);
+    assert(obj);
 
     /* Call the internal 'op' routine */
-    if (H5HF__tiny_op_real(hdr, id, H5HF_op_read, obj) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "unable to operate on heap object")
+    if (H5HF__tiny_op_real(hdr, id, H5HF__op_read, obj) < 0)
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "unable to operate on heap object");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_tiny_read() */
+} /* end H5HF__tiny_read() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5HF_tiny_op
+ * Function:    H5HF__tiny_op
  *
  * Purpose:     Operate directly on a 'tiny' object
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Quincey Koziol
- *              Sept 11 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_tiny_op(H5HF_hdr_t *hdr, const uint8_t *id, H5HF_operator_t op, void *op_data)
+H5HF__tiny_op(H5HF_hdr_t *hdr, const uint8_t *id, H5HF_operator_t op, void *op_data)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(id);
-    HDassert(op);
+    assert(hdr);
+    assert(id);
+    assert(op);
 
     /* Call the internal 'op' routine routine */
     if (H5HF__tiny_op_real(hdr, id, op, op_data) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "unable to operate on heap object")
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "unable to operate on heap object");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_tiny_op() */
+} /* end H5HF__tiny_op() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5HF_tiny_remove
+ * Function:    H5HF__tiny_remove
  *
  * Purpose:     Remove a 'tiny' object from the heap statistics
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Quincey Koziol
- *              Aug 14 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_tiny_remove(H5HF_hdr_t *hdr, const uint8_t *id)
+H5HF__tiny_remove(H5HF_hdr_t *hdr, const uint8_t *id)
 {
     size_t enc_obj_size;        /* Encoded object size */
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
-    HDassert(hdr);
-    HDassert(id);
+    assert(hdr);
+    assert(id);
 
     /* Get the object's encoded length */
-    /* H5HF_tiny_obj_len can't fail */
-    ret_value = H5HF_tiny_get_obj_len(hdr, id, &enc_obj_size);
+    /* H5HF__tiny_obj_len can't fail */
+    ret_value = H5HF__tiny_get_obj_len(hdr, id, &enc_obj_size);
 
     /* Update statistics about heap */
     hdr->tiny_size -= enc_obj_size;
     hdr->tiny_nobjs--;
 
     /* Mark heap header as modified */
-    if (H5HF_hdr_dirty(hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty")
+    if (H5HF__hdr_dirty(hdr) < 0)
+        HGOTO_ERROR(H5E_HEAP, H5E_CANTDIRTY, FAIL, "can't mark heap header as dirty");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5HF_tiny_remove() */
+} /* end H5HF__tiny_remove() */
