@@ -25,9 +25,10 @@
 /***********/
 #include "H5private.h"   /* Generic Functions                        */
 #include "H5Eprivate.h"  /* Error handling                           */
-#include "H5Gprivate.h"  /* Groups                                   */
+#include "H5Fprivate.h"  /* Files                                    */
 #include "H5Ipkg.h"      /* IDs                                      */
 #include "H5MMprivate.h" /* Memory management                        */
+#include "H5Pprivate.h"  /* Property lists                           */
 
 /****************/
 /* Local Macros */
@@ -43,6 +44,11 @@ typedef struct {
     void             *ret_obj; /* Object to return */
 } H5I_search_ud_t;
 
+typedef struct {
+    H5I_iterate_func_t op;      /* Application's callback routine */
+    void              *op_data; /* Application's user data */
+} H5I_iterate_pub_ud_t;
+
 /********************/
 /* Package Typedefs */
 /********************/
@@ -52,6 +58,7 @@ typedef struct {
 /********************/
 
 static int H5I__search_cb(void *obj, hid_t id, void *_udata);
+static int H5I__iterate_pub_cb(void *obj, hid_t id, void *udata);
 
 /*********************/
 /* Package Variables */
@@ -83,14 +90,13 @@ static int H5I__search_cb(void *obj, hid_t id, void *_udata);
  *-------------------------------------------------------------------------
  */
 H5I_type_t
-H5Iregister_type(size_t H5_ATTR_DEBUG_API_USED hash_size, unsigned reserved, H5I_free_t free_func)
+H5Iregister_type(size_t H5_ATTR_UNUSED hash_size, unsigned reserved, H5I_free_t free_func)
 {
     H5I_class_t *cls       = NULL;      /* New ID class */
     H5I_type_t   new_type  = H5I_BADID; /* New ID type value */
     H5I_type_t   ret_value = H5I_BADID; /* Return value */
 
     FUNC_ENTER_API(H5I_BADID)
-    H5TRACE3("It", "zIux", hash_size, reserved, free_func);
 
     /* Generate a new H5I_type_t value */
 
@@ -100,27 +106,27 @@ H5Iregister_type(size_t H5_ATTR_DEBUG_API_USED hash_size, unsigned reserved, H5I
         H5I_next_type_g++;
     }
     else {
-        hbool_t done; /* Indicate that search was successful */
-        int     i;
+        bool done; /* Indicate that search was successful */
+        int  i;
 
         /* Look for a free type to give out */
-        done = FALSE;
-        for (i = H5I_NTYPES; i < H5I_MAX_NUM_TYPES && done == FALSE; i++) {
+        done = false;
+        for (i = H5I_NTYPES; i < H5I_MAX_NUM_TYPES && done == false; i++) {
             if (NULL == H5I_type_info_array_g[i]) {
                 /* Found a free type ID */
                 new_type = (H5I_type_t)i;
-                done     = TRUE;
+                done     = true;
             }
         }
 
         /* Verify that we found a type to give out */
-        if (done == FALSE)
-            HGOTO_ERROR(H5E_ATOM, H5E_NOSPACE, H5I_BADID, "Maximum number of ID types exceeded")
+        if (done == false)
+            HGOTO_ERROR(H5E_ID, H5E_NOSPACE, H5I_BADID, "Maximum number of ID types exceeded");
     }
 
     /* Allocate new ID class */
     if (NULL == (cls = H5MM_calloc(sizeof(H5I_class_t))))
-        HGOTO_ERROR(H5E_ATOM, H5E_CANTALLOC, H5I_BADID, "ID class allocation failed")
+        HGOTO_ERROR(H5E_ID, H5E_CANTALLOC, H5I_BADID, "ID class allocation failed");
 
     /* Initialize class fields */
     cls->type      = new_type;
@@ -130,7 +136,7 @@ H5Iregister_type(size_t H5_ATTR_DEBUG_API_USED hash_size, unsigned reserved, H5I
 
     /* Register the new ID class */
     if (H5I_register_type(cls) < 0)
-        HGOTO_ERROR(H5E_ATOM, H5E_CANTINIT, H5I_BADID, "can't initialize ID class")
+        HGOTO_ERROR(H5E_ID, H5E_CANTINIT, H5I_BADID, "can't initialize ID class");
 
     /* Set return value */
     ret_value = new_type;
@@ -150,26 +156,25 @@ done:
  * Purpose:     Query function to inform the user if a given type is
  *              currently registered with the library.
  *
- * Return:      TRUE/FALSE/FAIL
+ * Return:      true/false/FAIL
  *
  *-------------------------------------------------------------------------
  */
 htri_t
 H5Itype_exists(H5I_type_t type)
 {
-    htri_t ret_value = TRUE; /* Return value */
+    htri_t ret_value = true; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE1("t", "It", type);
 
     /* Validate parameter */
     if (H5I_IS_LIB_TYPE(type))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, FAIL, "cannot call public function on library type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, FAIL, "cannot call public function on library type");
     if (type <= H5I_BADID || (int)type >= H5I_next_type_g)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "invalid type number")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "invalid type number");
 
     if (NULL == H5I_type_info_array_g[type])
-        ret_value = FALSE;
+        ret_value = false;
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -185,10 +190,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  James Laird
- *              Nathaniel Furrer
- *              Friday, April 23, 2004
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -197,25 +198,24 @@ H5Inmembers(H5I_type_t type, hsize_t *num_members)
     herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE2("e", "It*h", type, num_members);
 
     if (H5I_IS_LIB_TYPE(type))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, FAIL, "cannot call public function on library type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, FAIL, "cannot call public function on library type");
 
     /* Validate parameters.  This needs to be done here, instead of letting
      * the private interface handle it, because the public interface throws
      * an error when the supplied type does not exist.
      */
     if (type <= H5I_BADID || (int)type >= H5I_next_type_g)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "invalid type number")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "invalid type number");
     if (NULL == H5I_type_info_array_g[type])
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "supplied type does not exist")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "supplied type does not exist");
 
     if (num_members) {
         int64_t members;
 
         if ((members = H5I_nmembers(type)) < 0)
-            HGOTO_ERROR(H5E_ATOM, H5E_CANTCOUNT, FAIL, "can't compute number of members")
+            HGOTO_ERROR(H5E_ID, H5E_CANTCOUNT, FAIL, "can't compute number of members");
 
         H5_CHECKED_ASSIGN(*num_members, hsize_t, members, int64_t);
     }
@@ -233,10 +233,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  James Laird
- *              Nathaniel Furrer
- *              Friday, April 23, 2004
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -245,12 +241,11 @@ H5Iclear_type(H5I_type_t type, hbool_t force)
     herr_t ret_value = FAIL; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE2("e", "Itb", type, force);
 
     if (H5I_IS_LIB_TYPE(type))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, FAIL, "cannot call public function on library type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, FAIL, "cannot call public function on library type");
 
-    ret_value = H5I_clear_type(type, force, TRUE);
+    ret_value = H5I_clear_type(type, force, true);
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -267,9 +262,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Nathaniel Furrer
- *              James Laird
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -278,10 +270,9 @@ H5Idestroy_type(H5I_type_t type)
     herr_t ret_value = FAIL; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE1("e", "It", type);
 
     if (H5I_IS_LIB_TYPE(type))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, FAIL, "cannot call public function on library type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, FAIL, "cannot call public function on library type");
 
     ret_value = H5I__destroy_type(type);
 
@@ -305,17 +296,50 @@ H5Iregister(H5I_type_t type, const void *object)
     hid_t ret_value = H5I_INVALID_HID; /* Return value */
 
     FUNC_ENTER_API(H5I_INVALID_HID)
-    H5TRACE2("i", "It*x", type, object);
 
     if (H5I_IS_LIB_TYPE(type))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, H5I_INVALID_HID, "cannot call public function on library type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, H5I_INVALID_HID, "cannot call public function on library type");
 
-    ret_value = H5I_register(type, object, TRUE);
+    /* Register the object */
+    if ((ret_value = H5I__register(type, object, true, NULL, NULL)) < 0)
+        HGOTO_ERROR(H5E_ID, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register object");
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Iregister() */
 
+/*-------------------------------------------------------------------------
+ * Function:    H5Iregister_future
+ *
+ * Purpose:     Register a "future" object.
+ *
+ * Return:      Success:    New future object ID
+ *              Failure:    H5I_INVALID_HID
+ *
+ *-------------------------------------------------------------------------
+ */
+hid_t
+H5Iregister_future(H5I_type_t type, const void *object, H5I_future_realize_func_t realize_cb,
+                   H5I_future_discard_func_t discard_cb)
+{
+    hid_t ret_value = H5I_INVALID_HID; /* Return value */
+
+    FUNC_ENTER_API(H5I_INVALID_HID)
+
+    /* Check arguments */
+    if (NULL == realize_cb)
+        HGOTO_ERROR(H5E_ID, H5E_BADVALUE, H5I_INVALID_HID, "NULL pointer for realize_cb not allowed");
+    if (NULL == discard_cb)
+        HGOTO_ERROR(H5E_ID, H5E_BADVALUE, H5I_INVALID_HID, "NULL pointer for realize_cb not allowed");
+
+    /* Register the future object */
+    if ((ret_value = H5I__register(type, object, true, realize_cb, discard_cb)) < 0)
+        HGOTO_ERROR(H5E_ID, H5E_CANTREGISTER, H5I_INVALID_HID, "unable to register object");
+
+done:
+    FUNC_LEAVE_API(ret_value)
+} /* end H5Iregister_future() */
+
 /*-------------------------------------------------------------------------
  * Function:    H5Iobject_verify
  *
@@ -335,13 +359,12 @@ H5Iobject_verify(hid_t id, H5I_type_t type)
     void *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_API(NULL)
-    H5TRACE2("*x", "iIt", id, type);
 
     /* Validate parameters */
     if (H5I_IS_LIB_TYPE(type))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, NULL, "cannot call public function on library type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, NULL, "cannot call public function on library type");
     if (type < 1 || (int)type >= H5I_next_type_g)
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, NULL, "identifier has invalid type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, NULL, "identifier has invalid type");
 
     ret_value = H5I_object_verify(id, type);
 
@@ -370,7 +393,6 @@ H5Iget_type(hid_t id)
     H5I_type_t ret_value = H5I_BADID; /* Return value */
 
     FUNC_ENTER_API(H5I_BADID)
-    H5TRACE1("It", "i", id);
 
     ret_value = H5I_get_type(id);
 
@@ -393,9 +415,6 @@ done:
  *                          calling H5I_object().
  *              Failure:    NULL
  *
- * Programmer:  James Laird
- *              Nathaniel Furrer
- *
  *-------------------------------------------------------------------------
  */
 void *
@@ -404,10 +423,9 @@ H5Iremove_verify(hid_t id, H5I_type_t type)
     void *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_API(NULL)
-    H5TRACE2("*x", "iIt", id, type);
 
     if (H5I_IS_LIB_TYPE(type))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, NULL, "cannot call public function on library type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, NULL, "cannot call public function on library type");
 
     /* Remove the id */
     ret_value = H5I__remove_verify(id, type);
@@ -426,9 +444,6 @@ done:
  * Return:      Success:    New reference count
  *              Failure:    -1
  *
- * Programmer:  Quincey Koziol
- *              Dec  7, 2003
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -437,15 +452,14 @@ H5Idec_ref(hid_t id)
     int ret_value = 0; /* Return value */
 
     FUNC_ENTER_API((-1))
-    H5TRACE1("Is", "i", id);
 
     /* Check arguments */
     if (id < 0)
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, (-1), "invalid ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, (-1), "invalid ID");
 
     /* Do actual decrement operation */
     if ((ret_value = H5I_dec_app_ref(id)) < 0)
-        HGOTO_ERROR(H5E_ATOM, H5E_CANTDEC, (-1), "can't decrement ID ref count")
+        HGOTO_ERROR(H5E_ID, H5E_CANTDEC, (-1), "can't decrement ID ref count");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -467,15 +481,14 @@ H5Iinc_ref(hid_t id)
     int ret_value = -1; /* Return value */
 
     FUNC_ENTER_API((-1))
-    H5TRACE1("Is", "i", id);
 
     /* Check arguments */
     if (id < 0)
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, (-1), "invalid ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, (-1), "invalid ID");
 
     /* Do actual increment operation */
-    if ((ret_value = H5I_inc_ref(id, TRUE)) < 0)
-        HGOTO_ERROR(H5E_ATOM, H5E_CANTINC, (-1), "can't increment ID ref count")
+    if ((ret_value = H5I_inc_ref(id, true)) < 0)
+        HGOTO_ERROR(H5E_ID, H5E_CANTINC, (-1), "can't increment ID ref count");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -497,15 +510,14 @@ H5Iget_ref(hid_t id)
     int ret_value = -1; /* Return value */
 
     FUNC_ENTER_API((-1))
-    H5TRACE1("Is", "i", id);
 
     /* Check arguments */
     if (id < 0)
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, (-1), "invalid ID")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, (-1), "invalid ID");
 
     /* Do actual retrieve operation */
-    if ((ret_value = H5I_get_ref(id, TRUE)) < 0)
-        HGOTO_ERROR(H5E_ATOM, H5E_CANTGET, (-1), "can't get ID ref count")
+    if ((ret_value = H5I_get_ref(id, true)) < 0)
+        HGOTO_ERROR(H5E_ID, H5E_CANTGET, (-1), "can't get ID ref count");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -527,17 +539,16 @@ H5Iinc_type_ref(H5I_type_t type)
     int ret_value = -1; /* Return value */
 
     FUNC_ENTER_API((-1))
-    H5TRACE1("Is", "It", type);
 
     /* Check arguments */
     if (type <= 0 || (int)type >= H5I_next_type_g)
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, (-1), "invalid ID type")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, (-1), "invalid ID type");
     if (H5I_IS_LIB_TYPE(type))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, (-1), "cannot call public function on library type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, (-1), "cannot call public function on library type");
 
     /* Do actual increment operation */
     if ((ret_value = H5I__inc_type_ref(type)) < 0)
-        HGOTO_ERROR(H5E_ATOM, H5E_CANTINC, (-1), "can't increment ID type ref count")
+        HGOTO_ERROR(H5E_ID, H5E_CANTINC, (-1), "can't increment ID type ref count");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -573,10 +584,9 @@ H5Idec_type_ref(H5I_type_t type)
     herr_t ret_value = 0; /* Return value */
 
     FUNC_ENTER_API((-1))
-    H5TRACE1("e", "It", type);
 
     if (H5I_IS_LIB_TYPE(type))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, (-1), "cannot call public function on library type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, (-1), "cannot call public function on library type");
 
     ret_value = H5I_dec_type_ref(type);
 
@@ -600,17 +610,16 @@ H5Iget_type_ref(H5I_type_t type)
     int ret_value = -1; /* Return value */
 
     FUNC_ENTER_API((-1))
-    H5TRACE1("Is", "It", type);
 
     /* Check arguments */
     if (type <= 0 || (int)type >= H5I_next_type_g)
-        HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, (-1), "invalid ID type")
+        HGOTO_ERROR(H5E_ID, H5E_BADID, (-1), "invalid ID type");
     if (H5I_IS_LIB_TYPE(type))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, (-1), "cannot call public function on library type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, (-1), "cannot call public function on library type");
 
     /* Do actual retrieve operation */
     if ((ret_value = H5I__get_type_ref(type)) < 0)
-        HGOTO_ERROR(H5E_ATOM, H5E_CANTGET, (-1), "can't get ID type ref count")
+        HGOTO_ERROR(H5E_ID, H5E_CANTGET, (-1), "can't get ID type ref count");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -622,7 +631,7 @@ done:
  * Purpose:     Check if the given id is valid.  An id is valid if it is in
  *              use and has an application reference count of at least 1.
  *
- * Return:      TRUE/FALSE/FAIL
+ * Return:      true/false/FAIL
  *
  *-------------------------------------------------------------------------
  */
@@ -630,16 +639,15 @@ htri_t
 H5Iis_valid(hid_t id)
 {
     H5I_id_info_t *info      = NULL; /* Pointer to the ID info */
-    htri_t         ret_value = TRUE; /* Return value */
+    htri_t         ret_value = true; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE1("t", "i", id);
 
     /* Find the ID */
     if (NULL == (info = H5I__find_id(id)))
-        ret_value = FALSE;
+        ret_value = false;
     else if (!info->app_count) /* Check if the found id is an internal id */
-        ret_value = FALSE;
+        ret_value = false;
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -664,7 +672,7 @@ H5I__search_cb(void *obj, hid_t id, void *_udata)
     herr_t           cb_ret_val;                        /* User callback return value */
     int              ret_value = H5_ITER_ERROR;         /* Callback return value */
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     cb_ret_val = (*udata->app_cb)(obj, id, udata->app_key);
 
@@ -706,11 +714,10 @@ H5Isearch(H5I_type_t type, H5I_search_func_t func, void *key)
     void           *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_API(NULL)
-    H5TRACE3("*x", "Itx*x", type, func, key);
 
     /* Check arguments */
     if (H5I_IS_LIB_TYPE(type))
-        HGOTO_ERROR(H5E_ATOM, H5E_BADGROUP, NULL, "cannot call public function on library type")
+        HGOTO_ERROR(H5E_ID, H5E_BADGROUP, NULL, "cannot call public function on library type");
 
     /* Set up udata struct */
     udata.app_cb  = func;
@@ -720,7 +727,7 @@ H5Isearch(H5I_type_t type, H5I_search_func_t func, void *key)
     /* Note that H5I_iterate returns an error code.  We ignore it
      * here, as we can't do anything with it without revising the API.
      */
-    (void)H5I_iterate(type, H5I__search_cb, &udata, TRUE);
+    (void)H5I_iterate(type, H5I__search_cb, &udata, true);
 
     /* Set return value */
     ret_value = udata.ret_obj;
@@ -729,6 +736,84 @@ done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Isearch() */
 
+/*-------------------------------------------------------------------------
+ * Function:    H5I__iterate_pub_cb
+ *
+ * Purpose:     Callback routine for H5Iiterate, when it calls
+ *              H5I_iterate.  Calls "user" callback search function, and
+ *              then sets return value, based on the result of that
+ *              callback.
+ *
+ * Return:      Success:    H5_ITER_CONT (0) or H5_ITER_STOP (1)
+ *              Failure:    H5_ITER_ERROR (-1)
+ *
+ *-------------------------------------------------------------------------
+ */
+static int
+H5I__iterate_pub_cb(void H5_ATTR_UNUSED *obj, hid_t id, void *_udata)
+{
+    H5I_iterate_pub_ud_t *udata      = (H5I_iterate_pub_ud_t *)_udata; /* User data for callback */
+    herr_t                cb_ret_val = FAIL;                           /* User callback return value */
+    int                   ret_value  = H5_ITER_ERROR;                  /* Callback return value */
+
+    FUNC_ENTER_PACKAGE_NOERR
+
+    /* Invoke the callback */
+    cb_ret_val = (*udata->op)(id, udata->op_data);
+
+    /* Set the return value based on the callback's return value */
+    if (cb_ret_val > 0)
+        ret_value = H5_ITER_STOP; /* terminate iteration early */
+    else if (cb_ret_val < 0)
+        ret_value = H5_ITER_ERROR; /* indicate failure (which terminates iteration) */
+    else
+        ret_value = H5_ITER_CONT; /* continue iteration */
+
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5I__iterate_pub_cb() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5Iiterate
+ *
+ * Purpose:     Call the callback function op for each member of the id
+ *              type type.  op takes as parameters the id and a
+ *              passthrough of op_data, and returns an herr_t.  A positive
+ *              return from op will cause the iteration to stop and
+ *              H5Iiterate will return the value returned by op.  A
+ *              negative return from op will cause the iteration to stop
+ *              and H5Iiterate will return failure.  A zero return from op
+ *              will allow iteration to continue, as long as there are
+ *              other ids remaining in type.
+ *
+ * Limitation:  Currently there is no way to start searching from where a
+ *              previous search left off.
+ *
+ * Return:      The last value returned by op
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5Iiterate(H5I_type_t type, H5I_iterate_func_t op, void *op_data)
+{
+    H5I_iterate_pub_ud_t int_udata;        /* Internal user data */
+    herr_t               ret_value = FAIL; /* Return value */
+
+    FUNC_ENTER_API(FAIL)
+
+    /* Set up udata struct */
+    int_udata.op      = op;
+    int_udata.op_data = op_data;
+
+    /* Note that H5I_iterate returns an error code.  We ignore it
+     * here, as we can't do anything with it without revising the API.
+     */
+    if ((ret_value = H5I_iterate(type, H5I__iterate_pub_cb, &int_udata, true)) < 0)
+        HGOTO_ERROR(H5E_ID, H5E_BADITER, FAIL, "can't iterate over ids");
+
+done:
+    FUNC_LEAVE_API(ret_value)
+} /* end H5Iiterate() */
+
 /*-------------------------------------------------------------------------
  * Function:    H5Iget_file_id
  *
@@ -748,7 +833,6 @@ H5Iget_file_id(hid_t obj_id)
     hid_t      ret_value = H5I_INVALID_HID; /* Return value */
 
     FUNC_ENTER_API(H5I_INVALID_HID)
-    H5TRACE1("i", "i", obj_id);
 
     /* Get object type */
     type = H5I_TYPE(obj_id);
@@ -756,11 +840,18 @@ H5Iget_file_id(hid_t obj_id)
     /* Call internal function */
     if (H5I_FILE == type || H5I_DATATYPE == type || H5I_GROUP == type || H5I_DATASET == type ||
         H5I_ATTR == type) {
-        if ((ret_value = H5I_get_file_id(obj_id, type)) < 0)
-            HGOTO_ERROR(H5E_ATOM, H5E_CANTGET, H5I_INVALID_HID, "can't retrieve file ID")
+        H5VL_object_t *vol_obj; /* Object of obj_id */
+
+        /* Get the VOL object */
+        if (NULL == (vol_obj = H5VL_vol_object(obj_id)))
+            HGOTO_ERROR(H5E_ID, H5E_BADTYPE, H5I_INVALID_HID, "invalid location identifier");
+
+        /* Get the file ID */
+        if ((ret_value = H5F_get_file_id(vol_obj, type, true)) < 0)
+            HGOTO_ERROR(H5E_ID, H5E_CANTGET, H5I_INVALID_HID, "can't retrieve file ID");
     }
     else
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, H5I_INVALID_HID, "not an ID of a file object")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, H5I_INVALID_HID, "not an ID of a file object");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -790,19 +881,34 @@ done:
 ssize_t
 H5Iget_name(hid_t id, char *name /*out*/, size_t size)
 {
-    H5G_loc_t loc;            /* Object location */
-    ssize_t   ret_value = -1; /* Return value */
+    H5VL_object_t         *vol_obj = NULL; /* Object stored in ID */
+    H5VL_object_get_args_t vol_cb_args;    /* Arguments to VOL callback */
+    H5VL_loc_params_t      loc_params;
+    size_t                 obj_name_len = 0;  /* Length of object's name */
+    ssize_t                ret_value    = -1; /* Return value */
 
     FUNC_ENTER_API((-1))
-    H5TRACE3("Zs", "ixz", id, name, size);
 
-    /* Get object location */
-    if (H5G_loc(id, &loc) < 0)
-        HGOTO_ERROR(H5E_ATOM, H5E_CANTGET, (-1), "can't retrieve object location")
+    /* Get the object pointer */
+    if (NULL == (vol_obj = H5VL_vol_object(id)))
+        HGOTO_ERROR(H5E_ID, H5E_BADTYPE, (-1), "invalid identifier");
+
+    /* Set location parameters */
+    loc_params.type     = H5VL_OBJECT_BY_SELF;
+    loc_params.obj_type = H5I_get_type(id);
+
+    /* Set up VOL callback arguments */
+    vol_cb_args.op_type                = H5VL_OBJECT_GET_NAME;
+    vol_cb_args.args.get_name.buf_size = size;
+    vol_cb_args.args.get_name.buf      = name;
+    vol_cb_args.args.get_name.name_len = &obj_name_len;
 
     /* Retrieve object's name */
-    if ((ret_value = H5G_get_name(&loc, name, size, NULL)) < 0)
-        HGOTO_ERROR(H5E_ATOM, H5E_CANTGET, (-1), "can't retrieve object name")
+    if (H5VL_object_get(vol_obj, &loc_params, &vol_cb_args, H5P_DATASET_XFER_DEFAULT, H5_REQUEST_NULL) < 0)
+        HGOTO_ERROR(H5E_ID, H5E_CANTGET, (-1), "can't retrieve object name");
+
+    /* Set return value */
+    ret_value = (ssize_t)obj_name_len;
 
 done:
     FUNC_LEAVE_API(ret_value)
