@@ -17,8 +17,7 @@
 #ifndef H5Ipublic_H
 #define H5Ipublic_H
 
-/* Public headers needed by this file */
-#include "H5public.h"
+#include "H5public.h" /* Generic Functions                        */
 
 /**
  * Library type values.
@@ -29,29 +28,29 @@
  *
  *           When adding types here, add a section to the 'misc19' test in
  *           test/tmisc.c to verify that the H5I{inc|dec|get}_ref() routines
- *           work correctly with it.
- *
- *           NOTE: H5I_REFERENCE is not used by the library and was removed
- *           in HDF5 1.12.0. \endinternal
+ *           work correctly with it. \endinternal
  */
 //! <!-- [H5I_type_t_snip] -->
 typedef enum H5I_type_t {
-    H5I_UNINIT = (-2), /**< uninitialized type                        */
-    H5I_BADID  = (-1), /**< invalid Type                              */
-    H5I_FILE   = 1,    /**< type ID for File objects                  */
-    H5I_GROUP,         /**< type ID for Group objects                 */
-    H5I_DATATYPE,      /**< type ID for Datatype objects              */
-    H5I_DATASPACE,     /**< type ID for Dataspace objects             */
-    H5I_DATASET,       /**< type ID for Dataset objects               */
-    H5I_ATTR,          /**< type ID for Attribute objects             */
-    H5I_REFERENCE,     /**< DEPRECATED* type ID for Reference objects */
-    H5I_VFL,           /**< type ID for virtual file layer            */
-    H5I_GENPROP_CLS,   /**< type ID for generic property list classes */
-    H5I_GENPROP_LST,   /**< type ID for generic property lists        */
-    H5I_ERROR_CLASS,   /**< type ID for error classes                 */
-    H5I_ERROR_MSG,     /**< type ID for error messages                */
-    H5I_ERROR_STACK,   /**< type ID for error stacks                  */
-    H5I_NTYPES         /**< number of library types, MUST BE LAST!    */
+    H5I_UNINIT = (-2),  /**< uninitialized type                        */
+    H5I_BADID  = (-1),  /**< invalid Type                              */
+    H5I_FILE   = 1,     /**< type ID for File objects                  */
+    H5I_GROUP,          /**< type ID for Group objects                 */
+    H5I_DATATYPE,       /**< type ID for Datatype objects              */
+    H5I_DATASPACE,      /**< type ID for Dataspace objects             */
+    H5I_DATASET,        /**< type ID for Dataset objects               */
+    H5I_MAP,            /**< type ID for Map objects                   */
+    H5I_ATTR,           /**< type ID for Attribute objects             */
+    H5I_VFL,            /**< type ID for virtual file layer            */
+    H5I_VOL,            /**< type ID for virtual object layer          */
+    H5I_GENPROP_CLS,    /**< type ID for generic property list classes */
+    H5I_GENPROP_LST,    /**< type ID for generic property lists        */
+    H5I_ERROR_CLASS,    /**< type ID for error classes                 */
+    H5I_ERROR_MSG,      /**< type ID for error messages                */
+    H5I_ERROR_STACK,    /**< type ID for error stacks                  */
+    H5I_SPACE_SEL_ITER, /**< type ID for dataspace selection iterator  */
+    H5I_EVENTSET,       /**< type ID for event sets                    */
+    H5I_NTYPES          /**< number of library types, MUST BE LAST!    */
 } H5I_type_t;
 //! <!-- [H5I_type_t_snip] -->
 
@@ -60,6 +59,11 @@ typedef enum H5I_type_t {
  */
 typedef int64_t hid_t;
 
+#define PRIdHID PRId64
+#define PRIxHID PRIx64
+#define PRIXHID PRIX64
+#define PRIoHID PRIo64
+
 /**
  * The size of identifiers
  */
@@ -71,13 +75,15 @@ typedef int64_t hid_t;
 #define H5I_INVALID_HID (-1)
 
 /**
- * A function for freeing objects. This function will be called with an object
- * ID type number and a pointer to the object. The function should free the
- * object and return non-negative to indicate that the object
- * can be removed from the ID type. If the function returns negative
- * (failure) then the object will remain in the ID type.
+ * A function for freeing objects. This function will be called with a pointer
+ * to the object and a pointer to a pointer to the asynchronous request object.
+ * The function should free the object and return non-negative to indicate that
+ * the object can be removed from the ID type. If the function returns negative
+ * (failure) then the object will remain in the ID type. For asynchronous
+ * operations and handling the request parameter, see the HDF5 user guide and
+ * VOL connector author guide.
  */
-typedef herr_t (*H5I_free_t)(void *);
+typedef herr_t (*H5I_free_t)(void *obj, void **request);
 
 /**
  * The type of a function to compare objects & keys
@@ -86,6 +92,13 @@ typedef herr_t (*H5I_free_t)(void *);
 typedef int (*H5I_search_func_t)(void *obj, hid_t id, void *key);
 //! <!-- [H5I_search_func_t_snip] -->
 
+/**
+ * The type of H5Iiterate() callback functions
+ */
+//! <!-- [H5I_iterate_func_t_snip] -->
+typedef herr_t (*H5I_iterate_func_t)(hid_t id, void *udata);
+//! <!-- [H5I_iterate_func_t_snip] -->
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -112,6 +125,8 @@ extern "C" {
  *          will be a reference to. This pointer will be stored by the library
  *          and returned via a call to H5Iobject_verify().
  *
+ * \since 1.8.0
+ *
  */
 H5_DLL hid_t H5Iregister(H5I_type_t type, const void *object);
 /**
@@ -131,10 +146,12 @@ H5_DLL hid_t H5Iregister(H5I_type_t type, const void *object);
  *
  * \note H5Iobject_verify() does not change the ID it is called on in any way
  *       (as opposed to H5Iremove_verify(), which removes the ID from its
- *       type’s hash table).
+ *       type's hash table).
  *
  * \see H5Iregister()
  *
+ * \since 1.8.0
+ *
  */
 H5_DLL void *H5Iobject_verify(hid_t id, H5I_type_t type);
 /**
@@ -165,6 +182,8 @@ H5_DLL void *H5Iobject_verify(hid_t id, H5I_type_t type);
  *       The pointer returned by H5Iregister() must be deallocated by the user
  *       to avoid memory leaks.
  *
+ * \since 1.8.0
+ *
  */
 H5_DLL void *H5Iremove_verify(hid_t id, H5I_type_t type);
 /**
@@ -189,6 +208,8 @@ H5_DLL void *H5Iremove_verify(hid_t id, H5I_type_t type);
  *       is valid identifier. Validity can be determined with a call to
  *       H5Iis_valid().
  *
+ * \since 1.0.0
+ *
  */
 H5_DLL H5I_type_t H5Iget_type(hid_t id);
 /**
@@ -221,9 +242,10 @@ H5_DLL hid_t H5Iget_file_id(hid_t id);
  * \brief Retrieves a name of an object based on the object identifier
  *
  * \obj_id{id}
- * \param[out] name A buffer for thename associated with the identifier
- * \param[in] size The size of the \p name buffer; usually the size of
- *                 the name in bytes plus 1 for a NULL terminator
+ * \param[out] name A buffer for the name associated with the identifier
+ * \param[in]  size The size, in bytes, of the \p name buffer. Must be the
+ *                  size of the object name in bytes plus 1 for a NULL
+ *                  terminator
  *
  * \return ssize_t
  *
@@ -233,12 +255,7 @@ H5_DLL hid_t H5Iget_file_id(hid_t id);
  *          additional characters, if any, are not returned to the user
  *          application.
  *
- *          If the length of the name, which determines the required value of
- *          \p size, is unknown, a preliminary H5Iget_name() call can be made.
- *          The return value of this call will be the size in bytes of the
- *          object name. That value, plus 1 for a NULL terminator, is then
- *          assigned to size for a second H5Iget_name() call, which will
- *          retrieve the actual name.
+ *          \details_namelen{object,H5Iget_name}
  *
  *          If the object identified by \p id is an attribute, as determined
  *          via H5Iget_type(), H5Iget_name() retrieves the name of the object
@@ -298,7 +315,7 @@ H5_DLL ssize_t H5Iget_name(hid_t id, char *name /*out*/, size_t size);
  *          safely closed or decremented and the HDF5 object will be closed
  *          when the reference count for that that object drops to zero.
  *
- * \since 1.6.2
+ * \since 1.6.3
  *
  */
 H5_DLL int H5Iinc_ref(hid_t id);
@@ -322,29 +339,29 @@ H5_DLL int H5Iinc_ref(hid_t id);
  *
  *          The reference count for a newly created object will be 1. Reference
  *          counts for objects may be explicitly modified with this function or
- *          with H5Iinc_ref(). When an object identifier’s reference count
+ *          with H5Iinc_ref(). When an object identifier's reference count
  *          reaches zero, the object will be closed. Calling an object
- *          identifier’s \c close function decrements the reference count for
- *          the identifier which normally closes the object, but if the
+ *          identifier's \c close function decrements the reference count for
+ *          the identifier, which normally closes the object, but if the
  *          reference count for the identifier has been incremented with
  *          H5Iinc_ref(), the object will only be closed when the reference
  *          count reaches zero with further calls to this function or the
- *          object identifier’s \c close function.
+ *          object identifier's \c close function.
  *
  *          If the object ID was created by a collective parallel call (such as
  *          H5Dcreate(), H5Gopen(), etc.), the reference count should be
  *          modified by all the processes which have copies of the ID.
- *          Generally this means that group, dataset, attribute, file and named
+ *          Generally, this means that group, dataset, attribute, file and named
  *          datatype IDs should be modified by all the processes and that all
  *          other types of IDs are safe to modify by individual processes.
  *
- *          This function is of particular value when an application is
- *          maintaining multiple copies of an object ID. The object ID can be
+ *          This function is of particular value when an application
+ *          maintains multiple copies of an object ID. The object ID can be
  *          incremented when a copy is made. Each copy of the ID can then be
  *          safely closed or decremented and the HDF5 object will be closed
- *          when the reference count for that that object drops to zero.
+ *          when the reference count for that object drops to zero.
  *
- * \since 1.6.2
+ * \since 1.6.3
  *
  */
 H5_DLL int H5Idec_ref(hid_t id);
@@ -368,7 +385,7 @@ H5_DLL int H5Idec_ref(hid_t id);
  *          The function H5Iis_valid() is used to determine whether a specific
  *          object identifier is valid.
  *
- * \since 1.6.2
+ * \since 1.6.3
  *
  */
 H5_DLL int H5Iget_ref(hid_t id);
@@ -378,7 +395,7 @@ H5_DLL int H5Iget_ref(hid_t id);
  * \brief Creates and returns a new ID type
  *
  * \param[in] hash_size Minimum hash table size (in entries) used to store IDs
- *                      for the new type
+ *                      for the new type (unused in 1.8.13 and later)
  * \param[in] reserved Number of reserved IDs for the new type
  * \param[in] free_func Function used to deallocate space for a single ID
  *
@@ -388,7 +405,8 @@ H5_DLL int H5Iget_ref(hid_t id);
  *          identifier for it.
  *
  *          The \p hash_size parameter indicates the minimum size of the hash
- *          table used to store IDs in the new type.
+ *          table used to store IDs in the new type. This parameter is unused
+ *          in 1.8.13 and later, when the implementation of ID storage changed.
  *
  *          The \p reserved parameter indicates the number of IDs in this new
  *          type to be reserved. Reserved IDs are valid IDs which are not
@@ -402,6 +420,8 @@ H5_DLL int H5Iget_ref(hid_t id);
  *          pointer which was passed in to the H5Iregister() function. The \p
  *          free_func function should return 0 on success and -1 on failure.
  *
+ * \since 1.8.0
+ *
  */
 H5_DLL H5I_type_t H5Iregister_type(size_t hash_size, unsigned reserved, H5I_free_t free_func);
 /**
@@ -426,6 +446,8 @@ H5_DLL H5I_type_t H5Iregister_type(size_t hash_size, unsigned reserved, H5I_free
  *          identifiers will be entirely unchanged. If the force flag is true,
  *          all identifiers of this type will be deleted.
  *
+ * \since 1.8.0
+ *
  */
 H5_DLL herr_t H5Iclear_type(H5I_type_t type, hbool_t force);
 /**
@@ -441,14 +463,16 @@ H5_DLL herr_t H5Iclear_type(H5I_type_t type, hbool_t force);
  *          identifiers of this type are destroyed and no new identifiers of
  *          this type can be registered.
  *
- *          The type’s free function is called on all of the identifiers which
+ *          The type's free function is called on all of the identifiers which
  *          are deleted by this function, freeing their memory. In addition,
- *          all memory used by this type’s hash table is freed.
+ *          all memory used by this type's hash table is freed.
  *
  *          Since the H5I_type_t values of destroyed identifier types are
  *          reused when new types are registered, it is a good idea to set the
  *          variable holding the value of the destroyed type to #H5I_UNINIT.
  *
+ * \since 1.8.0
+ *
  */
 H5_DLL herr_t H5Idestroy_type(H5I_type_t type);
 /**
@@ -468,6 +492,8 @@ H5_DLL herr_t H5Idestroy_type(H5I_type_t type);
  *          reference count is to be incremented. This identifier must have
  *          been created by a call to H5Iregister_type().
  *
+ * \since 1.8.0
+ *
  */
 H5_DLL int H5Iinc_type_ref(H5I_type_t type);
 /**
@@ -488,6 +514,8 @@ H5_DLL int H5Iinc_type_ref(H5I_type_t type);
  *          reference count is to be decremented. This identifier must have
  *          been created by a call to H5Iregister_type().
  *
+ * \since 1.8.0
+ *
  */
 H5_DLL int H5Idec_type_ref(H5I_type_t type);
 /**
@@ -507,6 +535,8 @@ H5_DLL int H5Idec_type_ref(H5I_type_t type);
  *          reference count is to be retrieved. This identifier must have been
  *          created by a call to H5Iregister_type().
  *
+ * \since 1.8.0
+ *
  */
 H5_DLL int H5Iget_type_ref(H5I_type_t type);
 /**
@@ -548,8 +578,42 @@ H5_DLL int H5Iget_type_ref(H5I_type_t type);
  *          The \p key parameter will be passed to the search function as a
  *          parameter. It can be used to further define the search at run-time.
  *
+ * \since 1.8.0
+ *
  */
 H5_DLL void *H5Isearch(H5I_type_t type, H5I_search_func_t func, void *key);
+/**
+ * \ingroup H5IUD
+ *
+ * \brief Calls a callback for each member of the identifier type specified
+ *
+ * \param[in] type The identifier type
+ * \param[in] op The callback function
+ * \param[in,out] op_data The data for the callback function
+ *
+ * \return The last value returned by \p op
+ *
+ * \details H5Iiterate() calls the callback function \p op for each member of
+ *          the identifier type \p type. The callback function type for \p op,
+ *          H5I_iterate_func_t, is defined in H5Ipublic.h as:
+ *          \snippet this H5I_iterate_func_t_snip
+ *          \p op takes as parameters the identifier and a pass through of
+ *          \p op_data, and returns an herr_t.
+ *
+ *          A positive return from op will cause the iteration to stop and
+ *          H5Iiterate() will return the value returned by \p op. A negative
+ *          return from \p op will cause the iteration to stop and H5Iiterate()
+ *          will return failure. A zero return from \p op will allow iteration
+ *          to continue, as long as there are other identifiers remaining in
+ *          type.
+ *
+ * \warning  Adding or removing members of the identifier type during iteration
+ *           will lead to undefined behavior.
+ *
+ * \since 1.12.0
+ *
+ */
+H5_DLL herr_t H5Iiterate(H5I_type_t type, H5I_iterate_func_t op, void *op_data);
 /**
  * \ingroup H5IUD
  *
@@ -568,6 +632,8 @@ H5_DLL void *H5Isearch(H5I_type_t type, H5I_search_func_t func, void *key);
  *          exist, or it has been destroyed, \p num_members is returned with
  *          the value 0.
  *
+ * \since 1.8.0
+ *
  */
 H5_DLL herr_t H5Inmembers(H5I_type_t type, hsize_t *num_members);
 /**
@@ -600,7 +666,7 @@ H5_DLL htri_t H5Itype_exists(H5I_type_t type);
  * \details Valid identifiers are those that have been obtained by an
  *          application and can still be used to access the original target.
  *          Examples of invalid identifiers include:
- *          \li Out of range values: negative, for example
+ *          \li Out-of-range values: negative, for example
  *          \li Previously-valid identifiers that have been released:
  *              for example, a dataset identifier for which the dataset has
  *              been closed
@@ -608,7 +674,7 @@ H5_DLL htri_t H5Itype_exists(H5I_type_t type);
  *          H5Iis_valid() can be used with any type of identifier: object
  *          identifier, property list identifier, attribute identifier, error
  *          message identifier, etc. When necessary, a call to H5Iget_type()
- *          can determine the type of the object that \p id identifies.
+ *          can determine the type of object that the \p id identifies.
  *
  * \since 1.8.3
  *
