@@ -13,27 +13,26 @@
 /*-------------------------------------------------------------------------
  *
  * Created:             H5Oname.c
- *                      Aug 12 1997
- *                      Robb Matzke
  *
- * Purpose:             Object name message.
+ * Purpose:             Object name (comment) message
  *
  *-------------------------------------------------------------------------
  */
 
 #include "H5Omodule.h" /* This source code file is part of the H5O module */
 
-#include "H5private.h"   /* Generic Functions            */
-#include "H5Eprivate.h"  /* Error handling              */
-#include "H5MMprivate.h" /* Memory management            */
-#include "H5Opkg.h"      /* Object headers            */
+#include "H5private.h"   /* Generic Functions			*/
+#include "H5Eprivate.h"  /* Error handling		  	*/
+#include "H5MMprivate.h" /* Memory management			*/
+#include "H5Opkg.h"      /* Object headers			*/
 
 /* PRIVATE PROTOTYPES */
 static void *H5O__name_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags, unsigned *ioflags, size_t p_size,
                               const uint8_t *p);
-static herr_t H5O_name_encode(H5F_t *f, hbool_t disable_shared, uint8_t *p, const void *_mesg);
-static void  *H5O_name_copy(const void *_mesg, void *_dest);
-static size_t H5O_name_size(const H5F_t *f, hbool_t disable_shared, const void *_mesg);
+static herr_t H5O__name_encode(H5F_t *f, bool disable_shared, size_t H5_ATTR_UNUSED p_size, uint8_t *p,
+                               const void *_mesg);
+static void  *H5O__name_copy(const void *_mesg, void *_dest);
+static size_t H5O__name_size(const H5F_t *f, bool disable_shared, const void *_mesg);
 static herr_t H5O__name_reset(void *_mesg);
 static herr_t H5O__name_debug(H5F_t *f, const void *_mesg, FILE *stream, int indent, int fwidth);
 
@@ -44,20 +43,20 @@ const H5O_msg_class_t H5O_MSG_NAME[1] = {{
     sizeof(H5O_name_t), /*native message size           */
     0,                  /* messages are shareable?       */
     H5O__name_decode,   /*decode message                */
-    H5O_name_encode,    /*encode message                */
-    H5O_name_copy,      /*copy the native value         */
-    H5O_name_size,      /*raw message size              */
+    H5O__name_encode,   /*encode message                */
+    H5O__name_copy,     /*copy the native value         */
+    H5O__name_size,     /*raw message size              */
     H5O__name_reset,    /*free internal memory          */
-    NULL,               /* free method            */
-    NULL,               /* file delete method        */
-    NULL,               /* link method            */
-    NULL,               /*set share method        */
-    NULL,               /*can share method        */
+    NULL,               /* free method			*/
+    NULL,               /* file delete method		*/
+    NULL,               /* link method			*/
+    NULL,               /*set share method		*/
+    NULL,               /*can share method		*/
     NULL,               /* pre copy native value to file */
     NULL,               /* copy native value to file    */
     NULL,               /* post copy native value to file    */
-    NULL,               /* get creation index        */
-    NULL,               /* set creation index        */
+    NULL,               /* get creation index		*/
+    NULL,               /* set creation index		*/
     H5O__name_debug     /*debug the message             */
 }};
 
@@ -67,77 +66,71 @@ const H5O_msg_class_t H5O_MSG_NAME[1] = {{
  * Purpose:     Decode a name message and return a pointer to a new
  *              native message struct.
  *
- * Return:      Success:        Ptr to new message in native struct.
- *
- *              Failure:        NULL
- *
- * Programmer:  Robb Matzke
- *              Aug 12 1997
- *
+ * Return:      Success:    Ptr to new message in native struct.
+ *              Failure:    NULL
  *-------------------------------------------------------------------------
  */
 static void *
-H5O__name_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh, unsigned H5_ATTR_UNUSED mesg_flags,
-                 unsigned H5_ATTR_UNUSED *ioflags, size_t H5_ATTR_UNUSED p_size, const uint8_t *p)
+H5O__name_decode(H5F_t H5_ATTR_NDEBUG_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
+                 unsigned H5_ATTR_UNUSED mesg_flags, unsigned H5_ATTR_UNUSED *ioflags, size_t p_size,
+                 const uint8_t *p)
 {
-    H5O_name_t *mesg;
-    void       *ret_value = NULL; /* Return value */
+    H5O_name_t *mesg      = NULL;
+    void       *ret_value = NULL;
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
-    /* check args */
-    HDassert(f);
-    HDassert(p);
+    assert(f);
+    assert(p);
 
-    /* decode */
     if (NULL == (mesg = (H5O_name_t *)H5MM_calloc(sizeof(H5O_name_t))))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
-    if (NULL == (mesg->s = (char *)H5MM_strdup((const char *)p)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
+
+    if (NULL == (mesg->s = (char *)H5MM_strndup((const char *)p, p_size - 1)))
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
 
-    /* Set return value */
     ret_value = mesg;
 
 done:
     if (NULL == ret_value)
-        if (mesg)
-            mesg = (H5O_name_t *)H5MM_xfree(mesg);
+        if (mesg) {
+            H5MM_xfree(mesg->s);
+            H5MM_xfree(mesg);
+        }
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__name_decode() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5O_name_encode
+ * Function:    H5O__name_encode
  *
  * Purpose:     Encodes a name message.
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Robb Matzke
- *              Aug 12 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_name_encode(H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_shared, uint8_t *p, const void *_mesg)
+H5O__name_encode(H5F_t H5_ATTR_UNUSED *f, bool H5_ATTR_UNUSED disable_shared, size_t H5_ATTR_UNUSED p_size,
+                 uint8_t *p, const void *_mesg)
 {
     const H5O_name_t *mesg = (const H5O_name_t *)_mesg;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(f);
-    HDassert(p);
-    HDassert(mesg && mesg->s);
+    assert(f);
+    assert(p);
+    assert(mesg && mesg->s);
 
     /* encode */
-    HDstrcpy((char *)p, mesg->s);
+    strcpy((char *)p, mesg->s);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-}
+} /* end H5O__name_encode() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5O_name_copy
+ * Function:    H5O__name_copy
  *
  * Purpose:     Copies a message from _MESG to _DEST, allocating _DEST if
  *              necessary.
@@ -146,30 +139,27 @@ H5O_name_encode(H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_shared,
  *
  *              Failure:        NULL
  *
- * Programmer:  Robb Matzke
- *              Aug 12 1997
- *
  *-------------------------------------------------------------------------
  */
 static void *
-H5O_name_copy(const void *_mesg, void *_dest)
+H5O__name_copy(const void *_mesg, void *_dest)
 {
     const H5O_name_t *mesg      = (const H5O_name_t *)_mesg;
     H5O_name_t       *dest      = (H5O_name_t *)_dest;
     void             *ret_value = NULL; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(mesg);
+    assert(mesg);
 
     if (!dest && NULL == (dest = (H5O_name_t *)H5MM_calloc(sizeof(H5O_name_t))))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
 
     /* copy */
     *dest = *mesg;
     if (NULL == (dest->s = H5MM_xstrdup(mesg->s)))
-        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
 
     /* Set return value */
     ret_value = dest;
@@ -180,10 +170,10 @@ done:
             dest = (H5O_name_t *)H5MM_xfree(dest);
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_name_copy() */
+} /* end H5O__name_copy() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5O_name_size
+ * Function:    H5O__name_size
  *
  * Purpose:     Returns the size of the raw message in bytes not
  *              counting the message typ or size fields, but only the data
@@ -194,27 +184,24 @@ done:
  *
  *              Failure:        Negative
  *
- * Programmer:  Robb Matzke
- *              Aug 12 1997
- *
  *-------------------------------------------------------------------------
  */
 static size_t
-H5O_name_size(const H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_shared, const void *_mesg)
+H5O__name_size(const H5F_t H5_ATTR_UNUSED *f, bool H5_ATTR_UNUSED disable_shared, const void *_mesg)
 {
     const H5O_name_t *mesg      = (const H5O_name_t *)_mesg;
     size_t            ret_value = 0; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(f);
-    HDassert(mesg);
+    assert(f);
+    assert(mesg);
 
-    ret_value = mesg->s ? HDstrlen(mesg->s) + 1 : 0;
+    ret_value = mesg->s ? strlen(mesg->s) + 1 : 0;
 
     FUNC_LEAVE_NOAPI(ret_value)
-}
+} /* end H5O__name_size() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5O__name_reset
@@ -224,9 +211,6 @@ H5O_name_size(const H5F_t H5_ATTR_UNUSED *f, hbool_t H5_ATTR_UNUSED disable_shar
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Robb Matzke
- *              Aug 12 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -234,10 +218,10 @@ H5O__name_reset(void *_mesg)
 {
     H5O_name_t *mesg = (H5O_name_t *)_mesg;
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(mesg);
+    assert(mesg);
 
     /* reset */
     mesg->s = (char *)H5MM_xfree(mesg->s);
@@ -252,9 +236,6 @@ H5O__name_reset(void *_mesg)
  *
  * Return:      Non-negative on success/Negative on failure
  *
- * Programmer:  Robb Matzke
- *              Aug 12 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -262,16 +243,16 @@ H5O__name_debug(H5F_t H5_ATTR_UNUSED *f, const void *_mesg, FILE *stream, int in
 {
     const H5O_name_t *mesg = (const H5O_name_t *)_mesg;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* check args */
-    HDassert(f);
-    HDassert(mesg);
-    HDassert(stream);
-    HDassert(indent >= 0);
-    HDassert(fwidth >= 0);
+    assert(f);
+    assert(mesg);
+    assert(stream);
+    assert(indent >= 0);
+    assert(fwidth >= 0);
 
-    HDfprintf(stream, "%*s%-*s `%s'\n", indent, "", fwidth, "Name:", mesg->s);
+    fprintf(stream, "%*s%-*s `%s'\n", indent, "", fwidth, "Name:", mesg->s);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O__name_debug() */
