@@ -53,8 +53,8 @@
  * Purpose:     Control the loading of dynamic plugin types.
  *
  *              The plugin_control_mask parameter is a bitfield that controls
- *              whether certain classes of plugins (e.g.: filters)
- *              will be loaded by the library.
+ *              whether certain classes of plugins (e.g.: filters,
+ *              VOL drivers) will be loaded by the library.
  *
  *              plugin bit = 0, will prevent the use of that dynamic plugin type.
  *              plugin bit = 1, will allow the use of that dynamic plugin type.
@@ -77,11 +77,10 @@ H5PLset_loading_state(unsigned int plugin_control_mask)
     herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE1("e", "Iu", plugin_control_mask);
 
     /* Set the plugin control mask */
     if (H5PL__set_plugin_control_mask(plugin_control_mask) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_CANTSET, FAIL, "error setting plugin control mask")
+        HGOTO_ERROR(H5E_ARGS, H5E_CANTSET, FAIL, "error setting plugin control mask");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -91,7 +90,8 @@ done:
  * Function:    H5PLget_loading_state
  *
  * Purpose:     Get the bitmask that controls whether certain classes
- *              of plugins (e.g.: filters) will be loaded by the library.
+ *              of plugins (e.g.: filters, VOL drivers) will be loaded
+ *              by the library.
  *
  *              Zero if all plugin types are disabled
  *              Negative if all plugin types are enabled
@@ -103,19 +103,18 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5PLget_loading_state(unsigned int *plugin_control_mask)
+H5PLget_loading_state(unsigned *plugin_control_mask /*out*/)
 {
     herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE1("e", "*Iu", plugin_control_mask);
 
     if (NULL == plugin_control_mask)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_control_mask parameter cannot be NULL")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_control_mask parameter cannot be NULL");
 
     /* Set the plugin control mask */
     if (H5PL__get_plugin_control_mask(plugin_control_mask) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_CANTGET, FAIL, "error getting plugin control mask")
+        HGOTO_ERROR(H5E_ARGS, H5E_CANTGET, FAIL, "error getting plugin control mask");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -137,17 +136,16 @@ H5PLappend(const char *search_path)
     herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE1("e", "*s", search_path);
 
     /* Check args */
     if (NULL == search_path)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot be NULL")
-    if (0 == HDstrlen(search_path))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot have length zero")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot be NULL");
+    if (0 == strlen(search_path))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot have length zero");
 
     /* Append the search path to the path table */
     if (H5PL__append_path(search_path) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTAPPEND, FAIL, "unable to append search path")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTAPPEND, FAIL, "unable to append search path");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -169,17 +167,16 @@ H5PLprepend(const char *search_path)
     herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE1("e", "*s", search_path);
 
     /* Check args */
     if (NULL == search_path)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot be NULL")
-    if (0 == HDstrlen(search_path))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot have length zero")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot be NULL");
+    if (0 == strlen(search_path))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot have length zero");
 
     /* Prepend the search path to the path table */
     if (H5PL__prepend_path(search_path) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to prepend search path")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to prepend search path");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -202,25 +199,24 @@ H5PLreplace(const char *search_path, unsigned int idx)
     herr_t   ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE2("e", "*sIu", search_path, idx);
 
     /* Check args */
     if (NULL == search_path)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot be NULL")
-    if (0 == HDstrlen(search_path))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot have length zero")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot be NULL");
+    if (0 == strlen(search_path))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot have length zero");
 
     /* Check index */
     num_paths = H5PL__get_num_paths();
     if (0 == num_paths)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "path table is empty")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "path table is empty");
     else if (idx >= num_paths)
         HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL,
-                    "index path out of bounds for table - can't be more than %u", (num_paths - 1))
+                    "index path out of bounds for table - can't be more than %u", (num_paths - 1));
 
     /* Insert the search path into the path table */
     if (H5PL__replace_path(search_path, idx) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to replace search path")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to replace search path");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -244,23 +240,22 @@ H5PLinsert(const char *search_path, unsigned int idx)
     herr_t   ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE2("e", "*sIu", search_path, idx);
 
     /* Check args */
     if (NULL == search_path)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot be NULL")
-    if (0 == HDstrlen(search_path))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot have length zero")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot be NULL");
+    if (0 == strlen(search_path))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "plugin_path parameter cannot have length zero");
 
     /* Check index */
     num_paths = H5PL__get_num_paths();
     if ((0 != num_paths) && (idx >= num_paths))
         HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL,
-                    "index path out of bounds for table - can't be more than %u", (num_paths - 1))
+                    "index path out of bounds for table - can't be more than %u", (num_paths - 1));
 
     /* Insert the search path into the path table */
     if (H5PL__insert_path(search_path, idx) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to insert search path")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to insert search path");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -286,19 +281,18 @@ H5PLremove(unsigned int idx)
     herr_t   ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE1("e", "Iu", idx);
 
     /* Check index */
     num_paths = H5PL__get_num_paths();
     if (0 == num_paths)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "path table is empty")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "path table is empty");
     else if (idx >= num_paths)
         HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL,
-                    "index path out of bounds for table - can't be more than %u", (num_paths - 1))
+                    "index path out of bounds for table - can't be more than %u", (num_paths - 1));
 
     /* Delete the search path from the path table */
     if (H5PL__remove_path(idx) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTDELETE, FAIL, "unable to remove search path")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTDELETE, FAIL, "unable to remove search path");
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -337,28 +331,27 @@ H5PLget(unsigned int idx, char *path_buf, size_t buf_size)
     ssize_t     ret_value = 0;    /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE3("Zs", "Iu*sz", idx, path_buf, buf_size);
 
     /* Check index */
     num_paths = H5PL__get_num_paths();
     if (0 == num_paths)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "path table is empty")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "path table is empty");
     else if (idx >= num_paths)
         HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL,
-                    "index path out of bounds for table - can't be more than %u", (num_paths - 1))
+                    "index path out of bounds for table - can't be more than %u", (num_paths - 1));
 
     /* Check if the search table is empty */
     if (H5PL__get_num_paths() == 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_NOSPACE, (-1), "plugin search path table is empty")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_NOSPACE, (-1), "plugin search path table is empty");
 
     /* Get the path at the specified index and its length */
     if (NULL == (path = H5PL__get_path(idx)))
-        HGOTO_ERROR(H5E_PLUGIN, H5E_BADVALUE, (-1), "no path stored at that index")
-    path_len = HDstrlen(path);
+        HGOTO_ERROR(H5E_PLUGIN, H5E_BADVALUE, (-1), "no path stored at that index");
+    path_len = strlen(path);
 
     /* If the path buffer is not NULL, copy the path to the buffer */
     if (path_buf) {
-        HDstrncpy(path_buf, path, buf_size);
+        strncpy(path_buf, path, buf_size);
         if ((size_t)path_len >= buf_size)
             path_buf[buf_size - 1] = '\0';
     } /* end if */
@@ -386,11 +379,10 @@ H5PLsize(unsigned int *num_paths)
     herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
-    H5TRACE1("e", "*Iu", num_paths);
 
     /* Check arguments */
     if (!num_paths)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "num_paths parameter cannot be NULL")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "num_paths parameter cannot be NULL");
 
     /* Get the number of stored plugin paths */
     *num_paths = H5PL__get_num_paths();
