@@ -34,7 +34,7 @@
 /* Local Typedefs */
 /******************/
 
-/* Udata struct for calls to H5SM_compare_cb and H5SM_compare_iter_op*/
+/* Udata struct for calls to H5SM__compare_cb and H5SM__compare_iter_op*/
 typedef struct H5SM_compare_udata_t {
     const H5SM_mesg_key_t *key; /* Key; compare this against stored message */
     H5O_msg_crt_idx_t      idx; /* Index of the message in the OH, if applicable */
@@ -44,9 +44,9 @@ typedef struct H5SM_compare_udata_t {
 /********************/
 /* Local Prototypes */
 /********************/
-static herr_t H5SM_compare_cb(const void *obj, size_t obj_len, void *udata);
-static herr_t H5SM_compare_iter_op(H5O_t *oh, H5O_mesg_t *mesg, unsigned sequence, unsigned *oh_modified,
-                                   void *udata);
+static herr_t H5SM__compare_cb(const void *obj, size_t obj_len, void *udata);
+static herr_t H5SM__compare_iter_op(H5O_t *oh, H5O_mesg_t *mesg, unsigned sequence, unsigned *oh_modified,
+                                    void *udata);
 
 /*********************/
 /* Package Variables */
@@ -61,7 +61,7 @@ static herr_t H5SM_compare_iter_op(H5O_t *oh, H5O_mesg_t *mesg, unsigned sequenc
 /*******************/
 
 /*-------------------------------------------------------------------------
- * Function:	H5SM_compare_cb
+ * Function:	H5SM__compare_cb
  *
  * Purpose:	Callback for H5HF_op, used in H5SM__message_compare below.
  *              Determines whether the search key passed in in _UDATA is
@@ -71,17 +71,14 @@ static herr_t H5SM_compare_iter_op(H5O_t *oh, H5O_mesg_t *mesg, unsigned sequenc
  *
  * Return:	Negative on error, non-negative on success
  *
- * Programmer:	James Laird
- *              Monday, January 8, 2007
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5SM_compare_cb(const void *obj, size_t obj_len, void *_udata)
+H5SM__compare_cb(const void *obj, size_t obj_len, void *_udata)
 {
     H5SM_compare_udata_t *udata = (H5SM_compare_udata_t *)_udata;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* If the encoding sizes are different, it's not the same object */
     if (udata->key->encoding_size > obj_len)
@@ -90,13 +87,13 @@ H5SM_compare_cb(const void *obj, size_t obj_len, void *_udata)
         udata->ret = -1;
     else
         /* Sizes are the same.  Return result of memcmp */
-        udata->ret = HDmemcmp(udata->key->encoding, obj, obj_len);
+        udata->ret = memcmp(udata->key->encoding, obj, obj_len);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5SM_compare_cb() */
+} /* end H5SM__compare_cb() */
 
 /*-------------------------------------------------------------------------
- * Function:	H5SM_compare_iter_op
+ * Function:	H5SM__compare_iter_op
  *
  * Purpose:	OH iteration callback to compare a key against a message in
  *              an OH
@@ -106,33 +103,30 @@ H5SM_compare_cb(const void *obj, size_t obj_len, void *_udata)
  *                      result returned in udata)
  *              negative on error
  *
- * Programmer:	James Laird
- *              Wednesday, February 7, 2007
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5SM_compare_iter_op(H5O_t *oh, H5O_mesg_t *mesg /*in,out*/, unsigned sequence,
-                     unsigned H5_ATTR_UNUSED *oh_modified, void *_udata /*in,out*/)
+H5SM__compare_iter_op(H5O_t *oh, H5O_mesg_t *mesg /*in,out*/, unsigned sequence,
+                      unsigned H5_ATTR_UNUSED *oh_modified, void *_udata /*in,out*/)
 {
     H5SM_compare_udata_t *udata     = (H5SM_compare_udata_t *)_udata;
     herr_t                ret_value = H5_ITER_CONT;
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     /*
      * Check arguments.
      */
-    HDassert(oh);
-    HDassert(mesg);
-    HDassert(udata && udata->key);
+    assert(oh);
+    assert(mesg);
+    assert(udata && udata->key);
 
     /* Check the creation index for this message */
     if (sequence == udata->idx) {
         size_t aligned_encoded_size = H5O_ALIGN_OH(oh, udata->key->encoding_size);
 
         /* Sanity check the message's length */
-        HDassert(mesg->raw_size > 0);
+        assert(mesg->raw_size > 0);
 
         if (aligned_encoded_size > mesg->raw_size)
             udata->ret = 1;
@@ -143,10 +137,10 @@ H5SM_compare_iter_op(H5O_t *oh, H5O_mesg_t *mesg /*in,out*/, unsigned sequence,
             if (mesg->dirty)
                 if (H5O_msg_flush(udata->key->file, oh, mesg) < 0)
                     HGOTO_ERROR(H5E_SOHM, H5E_CANTENCODE, H5_ITER_ERROR,
-                                "unable to encode object header message")
+                                "unable to encode object header message");
 
-            HDassert(udata->key->encoding_size <= mesg->raw_size);
-            udata->ret = HDmemcmp(udata->key->encoding, mesg->raw, udata->key->encoding_size);
+            assert(udata->key->encoding_size <= mesg->raw_size);
+            udata->ret = memcmp(udata->key->encoding, mesg->raw, udata->key->encoding_size);
         } /* end else */
 
         /* Indicate that we found the message we were looking for */
@@ -155,7 +149,7 @@ H5SM_compare_iter_op(H5O_t *oh, H5O_mesg_t *mesg /*in,out*/, unsigned sequence,
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5SM_compare_iter_op() */
+} /* end H5SM__compare_iter_op() */
 
 /*-------------------------------------------------------------------------
  * Function:	H5SM__message_compare
@@ -168,9 +162,6 @@ done:
  *              Negative if rec1 < rec2
  *              Positive if rec1 > rec2
  *
- * Programmer:	James Laird
- *              Monday, November 6, 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -215,8 +206,8 @@ H5SM__message_compare(const void *rec1, const void *rec2, int *result)
          */
         H5SM_compare_udata_t udata;
 
-        HDassert(key->message.hash == mesg->hash);
-        HDassert(key->encoding_size > 0 && key->encoding);
+        assert(key->message.hash == mesg->hash);
+        assert(key->encoding_size > 0 && key->encoding);
 
         /* Set up user data for callback */
         udata.key = key;
@@ -226,20 +217,20 @@ H5SM__message_compare(const void *rec1, const void *rec2, int *result)
          */
         if (mesg->location == H5SM_IN_HEAP) {
             /* Call heap op routine with comparison callback */
-            if (H5HF_op(key->fheap, &(mesg->u.heap_loc.fheap_id), H5SM_compare_cb, &udata) < 0)
-                HGOTO_ERROR(H5E_HEAP, H5E_CANTCOMPARE, FAIL, "can't compare btree2 records")
+            if (H5HF_op(key->fheap, &(mesg->u.heap_loc.fheap_id), H5SM__compare_cb, &udata) < 0)
+                HGOTO_ERROR(H5E_HEAP, H5E_CANTCOMPARE, FAIL, "can't compare btree2 records");
         } /* end if */
         else {
             H5O_loc_t           oloc; /* Object owning the message */
             H5O_mesg_operator_t op;   /* Message operator */
 
             /* Sanity checks */
-            HDassert(key->file);
-            HDassert(mesg->location == H5SM_IN_OH);
+            assert(key->file);
+            assert(mesg->location == H5SM_IN_OH);
 
             /* Reset the object location */
             if (H5O_loc_reset(&oloc) < 0)
-                HGOTO_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "unable to initialize target location")
+                HGOTO_ERROR(H5E_SYM, H5E_CANTRESET, FAIL, "unable to initialize target location");
 
             /* Set up object location */
             oloc.file = key->file;
@@ -250,9 +241,9 @@ H5SM__message_compare(const void *rec1, const void *rec2, int *result)
 
             /* Locate the right message and compare with it */
             op.op_type  = H5O_MESG_OP_LIB;
-            op.u.lib_op = H5SM_compare_iter_op;
+            op.u.lib_op = H5SM__compare_iter_op;
             if (H5O_msg_iterate(&oloc, mesg->msg_type_id, &op, &udata) < 0)
-                HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "error iterating over links")
+                HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "error iterating over links");
         } /* end else */
 
         *result = udata.ret;
@@ -270,9 +261,6 @@ done:
  * Return:	Non-negative on success
  *              Negative on failure
  *
- * Programmer:	James Laird
- *              Monday, November 6, 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -284,7 +272,7 @@ H5SM__message_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
-    HDassert(ctx);
+    assert(ctx);
 
     *raw++ = (uint8_t)message->location;
     UINT32ENCODE(raw, message->hash);
@@ -294,7 +282,7 @@ H5SM__message_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
         H5MM_memcpy(raw, message->u.heap_loc.fheap_id.id, (size_t)H5O_FHEAP_ID_LEN);
     } /* end if */
     else {
-        HDassert(message->location == H5SM_IN_OH);
+        assert(message->location == H5SM_IN_OH);
 
         *raw++ = 0; /* reserved (possible flags byte) */
         *raw++ = (uint8_t)message->msg_type_id;
@@ -313,9 +301,6 @@ H5SM__message_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
  * Return:	Non-negative on success
  *              Negative on failure
  *
- * Programmer:	James Laird
- *              Monday, November 6, 2006
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -334,7 +319,7 @@ H5SM__message_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
         H5MM_memcpy(message->u.heap_loc.fheap_id.id, raw, (size_t)H5O_FHEAP_ID_LEN);
     } /* end if */
     else {
-        HDassert(message->location == H5SM_IN_OH);
+        assert(message->location == H5SM_IN_OH);
 
         raw++; /* reserved */
         message->msg_type_id = *raw++;
