@@ -11,12 +11,9 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:    Quincey Koziol
- *        Thursday, September 28, 2000
- *
- * Purpose:    This file contains declarations which are visible only within
- *        the H5S package.  Source files outside the H5S package should
- *        include H5Sprivate.h instead.
+ * Purpose: This file contains declarations which are visible only within
+ *          the H5S package.  Source files outside the H5S package should
+ *          include H5Sprivate.h instead.
  */
 #if !(defined H5S_FRIEND || defined H5S_MODULE)
 #error "Do not include this file outside the H5S package!"
@@ -42,11 +39,13 @@
 /* Versions for H5S_SEL_HYPER selection info */
 #define H5S_HYPER_VERSION_1      1
 #define H5S_HYPER_VERSION_2      2
-#define H5S_HYPER_VERSION_LATEST H5S_HYPER_VERSION_2
+#define H5S_HYPER_VERSION_3      3
+#define H5S_HYPER_VERSION_LATEST H5S_HYPER_VERSION_3
 
 /* Versions for H5S_SEL_POINTS selection info */
 #define H5S_POINT_VERSION_1      1
-#define H5S_POINT_VERSION_LATEST H5S_POINT_VERSION_1
+#define H5S_POINT_VERSION_2      2
+#define H5S_POINT_VERSION_LATEST H5S_POINT_VERSION_2
 
 /* Versions for H5S_SEL_NONE selection info */
 #define H5S_NONE_VERSION_1      1
@@ -57,9 +56,11 @@
 #define H5S_ALL_VERSION_LATEST H5S_ALL_VERSION_1
 
 /* Encoded size of selection info for H5S_SEL_POINTS/H5S_SEL_HYPER */
-#define H5S_SELECT_INFO_ENC_SIZE_4    0x04 /* 4 bytes: 32 bits */
-#define H5S_SELECT_INFO_ENC_SIZE_8    0x08 /* 8 bytes: 64 bits */
-#define H5S_SELECT_INFO_ENC_SIZE_BITS (H5S_SELECT_INFO_ENC_SIZE_4 | H5S_SELECT_INFO_ENC_SIZE_8)
+#define H5S_SELECT_INFO_ENC_SIZE_2 0x02 /* 2 bytes: 16 bits */
+#define H5S_SELECT_INFO_ENC_SIZE_4 0x04 /* 4 bytes: 32 bits */
+#define H5S_SELECT_INFO_ENC_SIZE_8 0x08 /* 8 bytes: 64 bits */
+#define H5S_SELECT_INFO_ENC_SIZE_BITS                                                                        \
+    (H5S_SELECT_INFO_ENC_SIZE_2 | H5S_SELECT_INFO_ENC_SIZE_4 | H5S_SELECT_INFO_ENC_SIZE_8)
 
 #define H5S_UINT16_MAX 0x0000FFFF       /* 2^16 - 1 = 65,535                            */
 #define H5S_UINT32_MAX 0xFFFFFFFF       /* 2^32 - 1 = 4,294,967,295                     */
@@ -88,15 +89,6 @@
  * H5S_UNLIMITED) */
 #define H5S_MAX_SIZE ((hsize_t)(hssize_t)(-2))
 
-/* Macro for checking if two ranges overlap one another */
-/*
- * Check for the inverse of whether the ranges are disjoint.  If they are
- * disjoint, then the low bound of one of the ranges must be greater than the
- * high bound of the other.
- */
-/* (Assumes that low & high bounds are _inclusive_) */
-#define H5S_RANGE_OVERLAP(L1, H1, L2, H2) (!((L1) > (H2) || (L2) > (H1)))
-
 /*
  * Dataspace extent information
  */
@@ -231,7 +223,7 @@ typedef struct {
 
 /* Selection information methods */
 /* Method to copy a selection */
-typedef herr_t (*H5S_sel_copy_func_t)(H5S_t *dst, const H5S_t *src, hbool_t share_selection);
+typedef herr_t (*H5S_sel_copy_func_t)(H5S_t *dst, const H5S_t *src, bool share_selection);
 /* Method to release current selection */
 typedef herr_t (*H5S_sel_release_func_t)(H5S_t *space);
 /* Method to determine if current selection is valid for dataspace */
@@ -241,7 +233,8 @@ typedef hssize_t (*H5S_sel_serial_size_func_t)(H5S_t *space);
 /* Method to store current selection in "serialized" form (a byte sequence suitable for storing on disk) */
 typedef herr_t (*H5S_sel_serialize_func_t)(H5S_t *space, uint8_t **p);
 /* Method to create selection from "serialized" form (a byte sequence suitable for storing on disk) */
-typedef herr_t (*H5S_sel_deserialize_func_t)(H5S_t **space, const uint8_t **p);
+typedef herr_t (*H5S_sel_deserialize_func_t)(H5S_t **space, const uint8_t **p, const size_t p_size,
+                                             bool skip);
 /* Method to determine smallest n-D bounding box containing the current selection */
 typedef herr_t (*H5S_sel_bounds_func_t)(const H5S_t *space, hsize_t *start, hsize_t *end);
 /* Method to determine linear offset of initial element in selection within dataspace */
@@ -310,7 +303,7 @@ typedef struct {
 typedef struct {
     const H5S_select_class_t *type; /* Pointer to selection's class info */
 
-    hbool_t  offset_changed;       /* Indicate that the offset for the selection has been changed */
+    bool     offset_changed;       /* Indicate that the offset for the selection has been changed */
     hssize_t offset[H5S_MAX_RANK]; /* Offset within the extent */
 
     hsize_t num_elem; /* Number of elements in selection */
@@ -393,14 +386,17 @@ H5_DLLVAR const unsigned H5O_sdspace_ver_bounds[H5F_LIBVER_NBOUNDS];
 
 /* Extent functions */
 H5_DLL herr_t H5S__extent_release(H5S_extent_t *extent);
-H5_DLL herr_t H5S__extent_copy_real(H5S_extent_t *dst, const H5S_extent_t *src, hbool_t copy_max);
+H5_DLL herr_t H5S__extent_copy_real(H5S_extent_t *dst, const H5S_extent_t *src, bool copy_max);
 
 /* Operations on hyperslab selections */
 H5_DLL uint64_t H5S__hyper_get_op_gen(void);
 H5_DLL void     H5S__hyper_rebuild(H5S_t *space);
 H5_DLL herr_t   H5S__modify_select(H5S_t *space1, H5S_seloper_t op, H5S_t *space2);
 H5_DLL herr_t H5S__hyper_project_intersection(H5S_t *src_space, H5S_t *dst_space, H5S_t *src_intersect_space,
-                                              H5S_t *proj_space, hbool_t share_space);
+                                              H5S_t *proj_space, bool share_space);
+
+/* Operations on selection iterators */
+H5_DLL herr_t H5S__sel_iter_close_cb(H5S_sel_iter_t *_sel_iter, void **request);
 
 /* Testing functions */
 #ifdef H5S_TESTING
@@ -408,6 +404,7 @@ H5_DLL herr_t H5S__get_rebuild_status_test(hid_t space_id, H5S_diminfo_valid_t *
                                            H5S_diminfo_valid_t *status2);
 H5_DLL herr_t H5S__get_diminfo_status_test(hid_t space_id, H5S_diminfo_valid_t *status);
 H5_DLL htri_t H5S__internal_consistency_test(hid_t space_id);
+H5_DLL herr_t H5S__verify_offsets(hid_t space_id, const hssize_t *offset);
 #endif /* H5S_TESTING */
 
 #endif /*H5Spkg_H*/
