@@ -16,12 +16,35 @@
 #ifndef H5Spublic_H
 #define H5Spublic_H
 
-/* Public headers needed by this file */
-#include "H5public.h"
-#include "H5Ipublic.h"
+#include "H5public.h"  /* Generic Functions                        */
+#include "H5Ipublic.h" /* Identifiers                              */
 
 /* Define special dataspaces for dataset I/O operations */
-#define H5S_ALL       (hid_t)0
+
+/**
+ * Used with @ref H5Dread and @ref H5Dwrite to indicate that the entire
+ * dataspace will be selected. In the case of a file dataspace, this means
+ * that the entire file dataspace, as defined by the dataset's dimensions,
+ * will be selected. In the case of a memory dataspace, this means that
+ * the specified file dataspace will also be used for the memory dataspace.
+ * Used in place of a file or memory dataspace @ref hid_t value.
+ */
+#define H5S_ALL 0
+
+/**
+ * Indicates that the buffer provided in a call to @ref H5Dread or @ref H5Dwrite
+ * is a single contiguous block of memory, with the same number of elements
+ * as the file dataspace. Used in place of a memory dataspace @ref hid_t value.
+ */
+#define H5S_BLOCK 1
+
+/**
+ * Used with @ref H5Dread and @ref H5Dwrite to indicate that the file dataspace
+ * selection was set via @ref H5Pset_dataset_io_hyperslab_selection calls.
+ * Used in place of a file dataspace @ref hid_t value.
+ */
+#define H5S_PLIST 2
+
 #define H5S_UNLIMITED HSIZE_UNDEF /**< Value for 'unlimited' dimensions */
 
 /**
@@ -29,6 +52,23 @@
  */
 #define H5S_MAX_RANK 32
 
+/* Flags for selection iterators */
+#define H5S_SEL_ITER_GET_SEQ_LIST_SORTED                                                                     \
+    0x0001 /**< Retrieve elements from iterator in increasing offset order, for                              \
+            * each call to retrieve sequences. Currently, this only applies to                               \
+            * point selections, as hyperslab selections are always returned in                               \
+            * increasing offset order. Note that the order is only increasing                                \
+            * for each call to H5Sget_seq_list(), the next set of sequences                                  \
+            * could start with an earlier offset than the previous one.                                      \
+            */
+#define H5S_SEL_ITER_SHARE_WITH_DATASPACE                                                                    \
+    0x0002 /**< Don't copy the dataspace selection when creating the selection                               \
+            * iterator. This can improve performance of creating the iterator,                               \
+            * but the dataspace \Bold{MUST NOT} be modified or closed until the                              \
+            * selection iterator is closed or the iterator's behavior will be                                \
+            * undefined.                                                                                     \
+            */
+
 /**
  * Types of dataspaces
  */
@@ -126,6 +166,57 @@ extern "C" {
  *
  */
 H5_DLL herr_t H5Sclose(hid_t space_id);
+/**
+ * \ingroup H5S
+ *
+ * \brief Performs an operation on a hyperslab and an existing selection and
+ *        returns the resulting selection
+ *
+ * \space_id
+ * \param[in] op      Operation to perform on the current selection
+ * \param[in] start   Offset of the start of of the hyperslab
+ * \param[in] stride  Hyperslab stride
+ * \param[in] count   Number of blocks included in the hyperslab
+ * \param[in] block   Size of a block in the hyperslab
+ *
+ * \return \hid_t{dataspace}
+ *
+ * \details H5Scombine_hyperslab() combines a hyperslab selection specified
+ *          by \p start, \p stride, \p count and \p block with the current
+ *          selection for the dataspace \p space_id, creating a new dataspace
+ *          to return the generated selection.  If the current selection is
+ *          not a hyperslab, it is freed and the hyperslab parameters passed
+ *          in are combined with the #H5S_SEL_ALL hyperslab (ie. a selection
+ *          composing the entire current extent). If either \p stride or
+ *          \p block is NULL, then it will be set to \p 1.
+ *
+ * \since 1.10.6
+ *
+ */
+H5_DLL hid_t H5Scombine_hyperslab(hid_t space_id, H5S_seloper_t op, const hsize_t start[],
+                                  const hsize_t stride[], const hsize_t count[], const hsize_t block[]);
+/**
+ * \ingroup H5S
+ *
+ * \brief Combine two hyperslab selections with an operation, returning a
+ *        dataspace with the resulting selection
+ *
+ * \space_id{space1_id}
+ * \param[in] op  Selection operator
+ * \space_id{space2_id}
+ *
+ * \return \hid_t{dataspace}
+ *
+ * \details H5Scombine_select() combines two hyperslab selections
+ *          \p space1_id and \p space2_id with an operation, returning a
+ *          new dataspace with the resulting selection. The dataspace extent
+ *          from \p space1_id is copied for the dataspace extent of the
+ *          newly created dataspace.
+ *
+ * \since 1.10.6
+ *
+ */
+H5_DLL hid_t H5Scombine_select(hid_t space1_id, H5S_seloper_t op, hid_t space2_id);
 /**
  * \ingroup H5S
  *
@@ -133,7 +224,7 @@ H5_DLL herr_t H5Sclose(hid_t space_id);
  *
  * \space_id
  *
- * \return \hid_tv{dataspace}
+ * \return \hid_t{dataspace}
  *
  * \details H5Scopy() creates a new dataspace which is an exact copy of the
  *          dataspace identified by \p space_id. The dataspace identifier
@@ -260,38 +351,52 @@ H5_DLL hid_t H5Sdecode(const void *buf);
  * \brief Encodes a data space object description into a binary buffer
  *
  * \space_id{obj_id}
- * \param[in,out] buf     Buffer for the object to be encoded into;
- *                        If the provided buffer is NULL, only the size
- *                        of buffer needed is returned through \p nalloc.
- * \param[in,out] nalloc  The size of the allocated buffer
+ * \param[in,out] buf      Buffer for the object to be encoded into;
+ *                         If the provided buffer is NULL, only the size
+ *                         of buffer needed is returned through \p nalloc.
+ * \param[in,out] nalloc   The size of the allocated buffer
+ * \fapl_id{fapl}
  *
  * \return \herr_t
  *
- * \details Given the data space identifier \p obj_id, H5Sencode() converts
+ * \details Given the data space identifier \p obj_id, H5Sencode2() converts
  *          a data space description into binary form in a buffer. Using this
  *          binary form in the buffer, a data space object can be
  *          reconstructed with H5Sdecode() to return a new object handle
  *          (#hid_t) for this data space.
  *
- *          A preliminary H5Sencode() call can be made to determine the
+ *          A preliminary H5Sencode2() call can be made to determine the
  *          size of the buffer needed. This value is returned in \p nalloc.
  *          That value can then be assigned to \p nalloc for a second
- *           H5Sencode()call, which will retrieve the actual encoded object.
+ *          H5Sencode2() call, which will retrieve the actual encoded object.
  *
  *          If the library determines that \p nalloc is not big enough for the
  *          object, it simply returns the size of the buffer needed through
  *          \p nalloc without encoding the provided buffer.
  *
+ *          The file access property list \p fapl_id is used to control the
+ *          encoding via the \a libver_bounds property (see
+ *          H5Pset_libver_bounds()). If the \a libver_bounds property is missing,
+ *          H5Sencode2() proceeds as if the \a libver_bounds property were set to
+ *          (#H5F_LIBVER_EARLIEST, #H5F_LIBVER_LATEST). (Functionally,
+ *          H5Sencode1() is identical to H5Sencode2() with \a libver_bounds set to
+ *          (#H5F_LIBVER_EARLIEST, #H5F_LIBVER_LATEST).)
+ *
  *          The types of data space that are addressed in this function are
  *          null, scalar, and simple space. For a simple data space, the
  *          information on the selection, for example, hyperslab selection,
  *          is also encoded and decoded. A complex data space has not been
  *          implemented in the library.
  *
- * \since 1.8.0
+ * \note Motivation: This function was introduced in HDF5-1.12 as part of the
+ *       H5Sencode() format change to enable 64-bit selection encodings and
+ *       a dataspace selection that is tied to a file. See the \ref_news_112
+ *       as well as the \ref_sencode_fmt_change.
+ *
+ * \since 1.12.0
  *
  */
-H5_DLL herr_t H5Sencode(hid_t obj_id, void *buf, size_t *nalloc);
+H5_DLL herr_t H5Sencode2(hid_t obj_id, void *buf, size_t *nalloc, hid_t fapl);
 /**
  * \ingroup H5S
  *
@@ -327,214 +432,6 @@ H5_DLL herr_t H5Sextent_copy(hid_t dst_id, hid_t src_id);
  *
  */
 H5_DLL htri_t H5Sextent_equal(hid_t space1_id, hid_t space2_id);
-/**
- * \ingroup H5S
- *
- * \brief Retrieves dataspace dimension size and maximum size
- *
- * \space_id
- * \param[out] dims Pointer to array to store the size of each dimension
- * \param[out] maxdims Pointer to array to store the maximum size of each
- *                     dimension
- *
- * \return Returns the number of dimensions in the dataspace if successful;
- *         otherwise returns a negative value.
- *
- * \details H5Sget_simple_extent_dims() returns the size and maximum sizes
- *          of each dimension of a dataspace \p space_id through the \p dims
- *          and \p maxdims parameters.
- *
- *          Either or both of \p dims and \p maxdims may be NULL.
- *
- *          If a value in the returned array \p maxdims is #H5S_UNLIMITED (-1),
- *          the maximum size of that dimension is unlimited.
- *
- * \version 1.4.0 Fortran subroutine introduced.
- * \since 1.0.0
- *
- */
-H5_DLL int H5Sget_simple_extent_dims(hid_t space_id, hsize_t dims[], hsize_t maxdims[]);
-/**
- * \ingroup H5S
- *
- * \brief Determines the dimensionality of a dataspace
- *
- * \space_id
- *
- * \return Returns the number of dimensions in the dataspace if successful;
- *         otherwise returns a negative value.
- *
- * \details H5Sget_simple_extent_ndims() determines the dimensionality (or
- *          rank) of a dataspace.
- *
- * \version 1.4.0 Fortran subroutine introduced.
- * \since 1.0.0
- *
- */
-H5_DLL int H5Sget_simple_extent_ndims(hid_t space_id);
-/**
- * \ingroup H5S
- *
- * \brief Determines the number of elements in a dataspace
- *
- * \space_id
- *
- * \return Returns the number of elements in the dataspace if successful;
- *         otherwise returns a negative value.
- *
- * \details H5Sget_simple_extent_npoints() determines the number of elements
- *          in a dataspace \p space_id. For example, a simple 3-dimensional
- *          dataspace with dimensions 2, 3, and 4 would have 24 elements.
- *
- * \version 1.4.0 Fortran subroutine introduced.
- * \since 1.0.0
- *
- */
-H5_DLL hssize_t H5Sget_simple_extent_npoints(hid_t space_id);
-/**
- * \ingroup H5S
- *
- * \brief  Determines the current class of a dataspace
- *
- * \space_id
- *
- * \return Returns a dataspace class name if successful;
- *         otherwise #H5S_NO_CLASS (-1).
- *
- * \details H5Sget_simple_extent_type() determines the current class of a
- *          dataspace \p space_id.
- *
- * \version 1.4.0 Fortran subroutine was introduced.
- * \since 1.0.0
- *
- */
-H5_DLL H5S_class_t H5Sget_simple_extent_type(hid_t space_id);
-/**
- * \ingroup H5S
- *
- * \brief Determines whether a dataspace is a simple dataspace
- *
- * \space_id
- *
- * \return \htri_t
- *
- * \details H5Sis_simple() determines whether or not a dataspace is a simple
- *          dataspace.
- *
- * \note Currently, all dataspace objects are simple dataspaces; complex
- *       dataspace support will be added in the future.
- *
- * \version 1.4.0 Fortran subroutine was introduced.
- * \since 1.0.0
- *
- */
-H5_DLL htri_t H5Sis_simple(hid_t space_id);
-/*--------------------------------------------------------------------------*/
-/**\ingroup H5S
- *
- * \brief Resets the extent of a dataspace back to "none"
- *
- * \space_id
- *
- * \return  \herr_t
- *
- * \details H5Sset_extent_none() resets the type of a dataspace to
- *          #H5S_NULL with no extent information stored for the dataspace.
- *
- * \version 1.10.7          To set the class to #H5S_NO_CLASS.
- * \version 1.4.0           Fortran subroutine was introduced.
- * \since 1.0.0
- *
- */
-H5_DLL herr_t H5Sset_extent_none(hid_t space_id);
-/*--------------------------------------------------------------------------*/
-/**\ingroup H5S
- *
- * \brief Sets or resets the size of an existing dataspace
- *
- * \space_id
- * \param[in] rank   Rank, or dimensionality, of the dataspace
- * \param[in] dims   Array containing current size of dataspace
- * \param[in] max    Array containing maximum size of dataspace
- *
- * \return \herr_t
- *
- * \details H5Sset_extent_simple() sets or resets the size of an existing
- *          dataspace.
- *
- *          \p rank is the dimensionality, or number of dimensions, of the
- *          dataspace.
- *
- *          \p dims is an array of size \p rank which contains the new size
- *          of each dimension in the dataspace. \p max is an array of size
- *          \p rank which contains the maximum size of each dimension in
- *          the dataspace.
- *
- *          Any previous extent is removed from the dataspace, the dataspace
- *          type is set to #H5S_SIMPLE, and the extent is set as specified.
- *
- *          Note that a dataset must be chunked if \p dims does not equal
- *          \p max.
- *
- *
- * \version 1.4.0 Fortran subroutine was introduced.
- * \since 1.0.0
- *
- */
-H5_DLL herr_t H5Sset_extent_simple(hid_t space_id, int rank, const hsize_t dims[], const hsize_t max[]);
-
-/* Operations on dataspace selections */
-/**
- * \ingroup H5S
- *
- * \brief Performs an operation on a hyperslab and an existing selection and
- *        returns the resulting selection
- *
- * \space_id
- * \param[in] op      Operation to perform on the current selection
- * \param[in] start   Offset of the start of of the hyperslab
- * \param[in] stride  Hyperslab stride
- * \param[in] count   Number of blocks included in the hyperslab
- * \param[in] block   Size of a block in the hyperslab
- *
- * \return \hid_tv{dataspace}
- *
- * \details H5Scombine_hyperslab() combines a hyperslab selection specified
- *          by \p start, \p stride, \p count and \p block with the current
- *          selection for the dataspace \p space_id, creating a new dataspace
- *          to return the generated selection.  If the current selection is
- *          not a hyperslab, it is freed and the hyperslab parameters passed
- *          in are combined with the #H5S_SEL_ALL hyperslab (ie. a selection
- *          composing the entire current extent). If either \p stride or
- *          \p block is NULL, then it will be set to \p 1.
- *
- * \since 1.10.6
- *
- */
-H5_DLL hid_t H5Scombine_hyperslab(hid_t space_id, H5S_seloper_t op, const hsize_t start[],
-                                  const hsize_t stride[], const hsize_t count[], const hsize_t block[]);
-/**
- * \ingroup H5S
- *
- * \brief Combine two hyperslab selections with an operation, returning a
- *        dataspace with the resulting selection
- *
- * \space_id{space1_id}
- * \param[in] op  Selection operator
- * \space_id{space2_id}
- *
- * \return \hid_t{dataspace}
- *
- * \details H5Scombine_select() combines two hyperslab selections
- *          \p space1_id and \p space2_id with an operation, returning a
- *          new dataspace with the resulting selection. The dataspace extent
- *          from \p space1_id is copied for the dataspace extent of the
- *          newly created dataspace.
- *
- * \since 1.10.6
- *
- */
-H5_DLL hid_t H5Scombine_select(hid_t space1_id, H5S_seloper_t op, hid_t space2_id);
 /**
  * \ingroup H5S
  *
@@ -644,6 +541,8 @@ H5_DLL hssize_t H5Sget_select_elem_npoints(hid_t spaceid);
  * \param[in] numpoints   Number of element points to get
  * \param[out] buf        List of element points selected
  *
+ * \return \herr_t
+ *
  * \details H5Sget_select_elem_pointlist() returns the list of element
  *          points in the current dataspace selection \p space_id. Starting
  *          with the \p startpoint in the list of points, \p numpoints
@@ -776,6 +675,88 @@ H5_DLL hssize_t H5Sget_select_npoints(hid_t spaceid);
  *
  */
 H5_DLL H5S_sel_type H5Sget_select_type(hid_t spaceid);
+/**
+ * \ingroup H5S
+ *
+ * \brief Retrieves dataspace dimension size and maximum size
+ *
+ * \space_id
+ * \param[out] dims Pointer to array to store the size of each dimension
+ * \param[out] maxdims Pointer to array to store the maximum size of each
+ *                     dimension
+ *
+ * \return Returns the number of dimensions in the dataspace if successful;
+ *         otherwise returns a negative value.
+ *
+ * \details H5Sget_simple_extent_dims() returns the size and maximum sizes
+ *          of each dimension of a dataspace \p space_id through the \p dims
+ *          and \p maxdims parameters.
+ *
+ *          Either or both of \p dims and \p maxdims may be NULL.
+ *
+ *          If a value in the returned array \p maxdims is #H5S_UNLIMITED (-1),
+ *          the maximum size of that dimension is unlimited.
+ *
+ * \version 1.4.0 Fortran subroutine introduced.
+ * \since 1.0.0
+ *
+ */
+H5_DLL int H5Sget_simple_extent_dims(hid_t space_id, hsize_t dims[], hsize_t maxdims[]);
+/**
+ * \ingroup H5S
+ *
+ * \brief Determines the dimensionality of a dataspace
+ *
+ * \space_id
+ *
+ * \return Returns the number of dimensions in the dataspace if successful;
+ *         otherwise returns a negative value.
+ *
+ * \details H5Sget_simple_extent_ndims() determines the dimensionality (or
+ *          rank) of a dataspace.
+ *
+ * \version 1.4.0 Fortran subroutine introduced.
+ * \since 1.0.0
+ *
+ */
+H5_DLL int H5Sget_simple_extent_ndims(hid_t space_id);
+/**
+ * \ingroup H5S
+ *
+ * \brief Determines the number of elements in a dataspace
+ *
+ * \space_id
+ *
+ * \return Returns the number of elements in the dataspace if successful;
+ *         otherwise returns a negative value.
+ *
+ * \details H5Sget_simple_extent_npoints() determines the number of elements
+ *          in a dataspace \p space_id. For example, a simple 3-dimensional
+ *          dataspace with dimensions 2, 3, and 4 would have 24 elements.
+ *
+ * \version 1.4.0 Fortran subroutine introduced.
+ * \since 1.0.0
+ *
+ */
+H5_DLL hssize_t H5Sget_simple_extent_npoints(hid_t space_id);
+/**
+ * \ingroup H5S
+ *
+ * \brief  Determines the current class of a dataspace
+ *
+ * \space_id
+ *
+ * \return Returns a dataspace class name if successful;
+ *         otherwise #H5S_NO_CLASS (-1).
+ *
+ * \details H5Sget_simple_extent_type() determines the current class of a
+ *          dataspace \p space_id.
+ *
+ * \version 1.4.0 Fortran subroutine was introduced.
+ * \since 1.0.0
+ *
+ */
+H5_DLL H5S_class_t H5Sget_simple_extent_type(hid_t space_id);
 /**
  * \ingroup H5S
  *
@@ -798,6 +779,26 @@ H5_DLL H5S_sel_type H5Sget_select_type(hid_t spaceid);
  *
  */
 H5_DLL htri_t H5Sis_regular_hyperslab(hid_t spaceid);
+/**
+ * \ingroup H5S
+ *
+ * \brief Determines whether a dataspace is a simple dataspace
+ *
+ * \space_id
+ *
+ * \return \htri_t
+ *
+ * \details H5Sis_simple() determines whether or not a dataspace is a simple
+ *          dataspace.
+ *
+ * \note Currently, all dataspace objects are simple dataspaces; complex
+ *       dataspace support will be added in the future.
+ *
+ * \version 1.4.0 Fortran subroutine was introduced.
+ * \since 1.0.0
+ *
+ */
+H5_DLL htri_t H5Sis_simple(hid_t space_id);
 /**
  * \ingroup H5S
  *
@@ -833,17 +834,123 @@ H5_DLL herr_t H5Smodify_select(hid_t space1_id, H5S_seloper_t op, hid_t space2_i
  *          \p space_id. The offset array must be the same number of
  *          elements as the number of dimensions for the dataspace. If the
  *          \p offset array is set to NULL, the offset for the dataspace is
- *          reset to 0.
+ *          reset to 0 in all dimensions.
  *
  *          This function allows the same shaped selection to be moved to
  *          different locations within a dataspace without requiring it to
  *          be redefined.
  *
+ * \note    Until 1.14.4, setting the offset parameter to NULL was considered
+ *          an error, despite the reference manual stating that it had the
+ *          behavior described above.
+ *
  * \version 1.4.0 Fortran subroutine was introduced.
  * \since 1.0.0
  *
  */
 H5_DLL herr_t H5Soffset_simple(hid_t space_id, const hssize_t *offset);
+/**
+ * \ingroup H5S
+ *
+ * \brief Closes a dataspace selection iterator
+ *
+ * \param[in] sel_iter_id Identifier of the dataspace selection iterator
+ *
+ * \return \herr_t
+ *
+ * \details H5Ssel_iter_close() closes a dataspace selection iterator
+ *          specified by \p sel_iter_id, releasing its state.
+ *
+ * \since 1.12.0
+ *
+ */
+H5_DLL herr_t H5Ssel_iter_close(hid_t sel_iter_id);
+/**\ingroup H5S
+ *
+ * \brief Creates a dataspace selection iterator for a dataspace's selection
+ *
+ * \space_id{spaceid}
+ * \param[in] elmt_size  Size of element in the selection
+ * \param[in] flags      Selection iterator flag, valid values are:
+ *                       \li @ref H5S_SEL_ITER_GET_SEQ_LIST_SORTED
+ *                       \li @ref H5S_SEL_ITER_SHARE_WITH_DATASPACE
+ * \return \hid_t{valid dataspace selection iterator}
+ *
+ * \details H5Ssel_iter_create() creates a selection iterator and initializes
+ *          it to start at the first element selected in the dataspace.
+ *
+ * \since 1.12.0
+ *
+ */
+H5_DLL hid_t H5Ssel_iter_create(hid_t spaceid, size_t elmt_size, unsigned flags);
+/**
+ * \ingroup H5S
+ *
+ * \brief Retrieves a list of offset / length sequences for the elements in
+ *        an iterator
+ *
+ * \param[in]  sel_iter_id Identifier of the dataspace selection iterator
+ * \param[in]  maxseq      Maximum number of sequences to retrieve
+ * \param[in]  maxelmts    Maximum number of elements to retrieve in sequences
+ * \param[out] nseq        Number of sequences retrieved
+ * \param[out] nelmts      Number of elements retrieved, in all sequences
+ * \param[out] off         Array of sequence offsets
+ * \param[out] len         Array of sequence lengths
+ *
+ * \return \herr_t
+ *
+ * \details H5Ssel_iter_get_seq_list() retrieves a list of offset / length
+ *          pairs (a list of "sequences") matching the selected elements for
+ *          an iterator \p sel_iter_id, according to the iteration order for
+ *          the iterator.  The lengths returned are in bytes, not elements.
+ *
+ *          Note that the iteration order for "all" and "hyperslab"
+ *          selections is row-major (i.e. "C-ordered"), but the iteration
+ *          order for "point" selections is "in order selected", unless the
+ *          #H5S_SEL_ITER_GET_SEQ_LIST_SORTED flag is passed to
+ *          H5Ssel_iter_create() for a point selection.
+ *
+ *          \p maxseq and \p maxelmts specify the most sequences or elements
+ *          possible to place into the \p off and \p len arrays. \p nseq and
+ *          \p nelmts return the actual number of sequences and elements put
+ *          into the arrays.
+ *
+ *          Each call to H5Ssel_iter_get_seq_list() will retrieve the next
+ *          set of sequences for the selection being iterated over.
+ *
+ *          The total number of bytes possible to retrieve from a selection
+ *          iterator is the \p elmt_size passed to H5Ssel_iter_create()
+ *          multiplied by the number of elements selected in the dataspace
+ *          the iterator was created from (which can be retrieved with
+ *          H5Sget_select_npoints().  When there are no further sequences of
+ *          elements to retrieve, calls to this routine will set \p nseq
+ *          and \p nelmts to zero.
+ *
+ * \since 1.12.0
+ *
+ */
+H5_DLL herr_t H5Ssel_iter_get_seq_list(hid_t sel_iter_id, size_t maxseq, size_t maxelmts, size_t *nseq,
+                                       size_t *nelmts, hsize_t *off, size_t *len);
+/**
+ * \ingroup H5S
+ *
+ * \brief  Resets a dataspace selection iterator back to an initial state
+ *
+ * \param[in] sel_iter_id   Identifier of the dataspace selection iterator
+ *                          to reset
+ * \param[in] space_id      Identifier of the dataspace with selection to
+ *                          iterate over
+ *
+ * \return \herr_t
+ *
+ * \details H5Ssel_iter_reset() resets a dataspace selection iterator back to
+ *          an initial state so that the iterator may be used for iteration
+ *          once again.
+ *
+ * \since 1.12.1
+ *
+ */
+H5_DLL herr_t H5Ssel_iter_reset(hid_t sel_iter_id, hid_t space_id);
 /**
  * \ingroup H5S
  *
@@ -926,7 +1033,7 @@ H5_DLL herr_t H5Sselect_copy(hid_t dst_id, hid_t src_id);
  *          The \p coord parameter is a pointer to a buffer containing a
  *          serialized 2-dimensional array of size \p num_elements by the
  *          rank of the dataspace. The array lists dataset elements in the
- *          point selection; that is, it’s a list of of zero-based values
+ *          point selection; that is, it's a list of zero-based values
  *          specifying the coordinates in the dataset of the selected
  *          elements. The order of the element coordinates in the \p coord
  *          array specifies the order in which the array elements are
@@ -968,7 +1075,7 @@ H5_DLL herr_t H5Sselect_copy(hid_t dst_id, hid_t src_id);
  *
  *          In the 1D case, we will be selecting five points and a 1D
  *          dataspace has rank 1, so the selection will be described in a
- *          5-by-1 array. To select the 1st, 14th, 17th, 23rd, 8th elements
+ *          5-by-1 array. To select the 1st, 14th, 17th, 23rd and 8th elements
  *          of the dataset, the selection array would be as follows
  *          (remembering that point coordinates are zero-based):
  *          \n      0
@@ -1094,8 +1201,9 @@ H5_DLL herr_t H5Sselect_elements(hid_t space_id, H5S_seloper_t op, size_t num_el
  *          2x2 blocks of array elements starting with location (1,1) with the
  *          selected blocks at locations (1,1), (5,1), (9,1), (1,5), (5,5), etc.;
  *          in Fortran, they will specify a hyperslab consisting of 21 2x2
- *          blocks of array elements starting with location (2,2) with the
- *          selected blocks at locations (2,2), (6,2), (10,2), (2,6), (6,6), etc.
+ *          blocks of array elements starting with location (2,2), since \p start
+ *          is 0-based indexed, with the selected blocks at
+ *          locations (2,2), (6,2), (10,2), (2,6), (6,6), etc.
  *
  *          Regions selected with this function call default to C order
  *          iteration when I/O is performed.
@@ -1206,6 +1314,104 @@ H5_DLL htri_t H5Sselect_shape_same(hid_t space1_id, hid_t space2_id);
  *
  */
 H5_DLL htri_t H5Sselect_valid(hid_t spaceid);
+/*--------------------------------------------------------------------------*/
+/**\ingroup H5S
+ *
+ * \brief Resets the extent of a dataspace back to "none"
+ *
+ * \space_id
+ *
+ * \return  \herr_t
+ *
+ * \details H5Sset_extent_none() resets the type of a dataspace to
+ *          #H5S_NULL with no extent information stored for the dataspace.
+ *
+ * \version 1.10.7, 1.12.1  The function behavior changed. The previous
+ *                          behavior was to set the class to #H5S_NO_CLASS.
+ * \version 1.4.0           Fortran subroutine was introduced.
+ * \since 1.0.0
+ *
+ */
+H5_DLL herr_t H5Sset_extent_none(hid_t space_id);
+/*--------------------------------------------------------------------------*/
+/**\ingroup H5S
+ *
+ * \brief Sets or resets the size of an existing dataspace
+ *
+ * \space_id
+ * \param[in] rank   Rank, or dimensionality, of the dataspace
+ * \param[in] dims   Array containing current size of dataspace
+ * \param[in] max    Array containing maximum size of dataspace
+ *
+ * \return \herr_t
+ *
+ * \details H5Sset_extent_simple() sets or resets the size of an existing
+ *          dataspace.
+ *
+ *          \p dims is an array of size \p rank that contains the new size
+ *          of each dimension in the dataspace. \p max is an array of size
+ *          \p rank that contains the maximum size of each dimension in
+ *          the dataspace.
+ *
+ *          Any previous extent is removed from the dataspace, the dataspace
+ *          type is set to #H5S_SIMPLE, and the extent is set as specified.
+ *
+ * \version 1.4.0 Fortran subroutine was introduced.
+ * \since 1.0.0
+ *
+ */
+H5_DLL herr_t H5Sset_extent_simple(hid_t space_id, int rank, const hsize_t dims[], const hsize_t max[]);
+
+/* Symbols defined for compatibility with previous versions of the HDF5 API.
+ *
+ * Use of these symbols is deprecated.
+ */
+#ifndef H5_NO_DEPRECATED_SYMBOLS
+/* Function prototypes */
+/* --------------------------------------------------------------------------*/
+/**\ingroup H5S
+ *
+ * \brief Encodes a data space object description into a binary buffer
+ *
+ * \space_id{obj_id}
+ * \param[in,out] buf     Buffer for the object to be encoded into;
+ *                        If the provided buffer is NULL, only the size of
+ *                        buffer needed is returned through \p nalloc.
+ * \param[in,out] nalloc  The size of the allocated buffer
+ *
+ * \return \herr_t
+ *
+ * \deprecated Deprecated in favor of H5Sencode2()
+ *
+ * \details Given the data space identifier \p obj_id, H5Sencode1() converts
+ *          a data space description into binary form in a buffer. Using
+ *          this binary form in the buffer, a data space object can be
+ *          reconstructed using H5Sdecode() to return a new object handle
+ *          (\p hid_t) for this data space.
+ *
+ *          A preliminary H5Sencode1() call can be made to find out the size
+ *          of the buffer needed. This value is returned as \p nalloc. That
+ *          value can then be assigned to \p nalloc for a second H5Sencode1()
+ *          call, which will retrieve the actual encoded object.
+ *
+ *          If the library finds out \p nalloc is not big enough for the
+ *          object, it simply returns the size of the buffer needed through
+ *          \p nalloc without encoding the provided buffer.
+ *
+ *          The types of data space addressed in this function are null,
+ *          scalar, and simple space. For a simple data space, the information
+ *          on the selection, for example, hyperslab selection, is also
+ *          encoded and decoded. A complex data space has not been
+ *          implemented in the library.
+ *
+ * \version 1.12.0 The function H5Sencode() was renamed H5Sencode1() and
+ *                 deprecated.
+ * \since 1.8.0
+ *
+ */
+H5_DLL herr_t H5Sencode1(hid_t obj_id, void *buf, size_t *nalloc);
+
+#endif /* H5_NO_DEPRECATED_SYMBOLS */
 
 #ifdef __cplusplus
 }
