@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:         H5Tdbg.c
- *                  Jul 19 2007
- *                  Quincey Koziol
  *
  * Purpose:         Dump debugging information about a datatype
  *
@@ -63,7 +61,7 @@
 /*******************/
 
 /*-------------------------------------------------------------------------
- * Function:    H5T__print_stats
+ * Function:    H5T__print_path_stats
  *
  * Purpose:     Print statistics about a conversion path.  Statistics are
  *              printed only if all the following conditions are true:
@@ -82,7 +80,7 @@
  *-------------------------------------------------------------------------
  */
 herr_t
-H5T__print_stats(H5T_path_t H5_ATTR_UNUSED *path, int H5_ATTR_UNUSED *nprint /*in,out*/)
+H5T__print_path_stats(H5T_path_t H5_ATTR_UNUSED *path, int H5_ATTR_UNUSED *nprint /*in,out*/)
 {
     FUNC_ENTER_PACKAGE_NOERR
 
@@ -99,11 +97,11 @@ H5T__print_stats(H5T_path_t H5_ATTR_UNUSED *path, int H5_ATTR_UNUSED *nprint /*i
                       H5_timer_get_time_string(path->stats.times.elapsed)};
 
         if (nprint && 0 == (*nprint)++) {
-            HDfprintf(H5DEBUG(T), "H5T: type conversion statistics:\n");
-            HDfprintf(H5DEBUG(T), "   %-16s %10s %10s %8s %8s %8s %10s\n", "Conversion", "Elmts", "Calls",
-                      "User", "System", "Elapsed", "Bandwidth");
-            HDfprintf(H5DEBUG(T), "   %-16s %10s %10s %8s %8s %8s %10s\n", "----------", "-----", "-----",
-                      "----", "------", "-------", "---------");
+            fprintf(H5DEBUG(T), "H5T: type conversion statistics:\n");
+            fprintf(H5DEBUG(T), "   %-16s %10s %10s %8s %8s %8s %10s\n", "Conversion", "Elmts", "Calls",
+                    "User", "System", "Elapsed", "Bandwidth");
+            fprintf(H5DEBUG(T), "   %-16s %10s %10s %8s %8s %8s %10s\n", "----------", "-----", "-----",
+                    "----", "------", "-------", "---------");
         } /* end if */
 
         if (path->src && path->dst)
@@ -115,18 +113,18 @@ H5T__print_stats(H5T_path_t H5_ATTR_UNUSED *path, int H5_ATTR_UNUSED *nprint /*i
         else
             nbytes = 0;
         nbytes *= path->stats.nelmts;
-        H5_bandwidth(bandwidth, (double)nbytes, path->stats.times.elapsed);
-        HDfprintf(H5DEBUG(T), "   %-16s %10" PRIdHSIZE " %10u %8s %8s %8s %10s\n", path->name,
-                  path->stats.nelmts, path->stats.ncalls, timestrs.user, timestrs.system, timestrs.elapsed,
-                  bandwidth);
-        HDfree(timestrs.user);
-        HDfree(timestrs.system);
-        HDfree(timestrs.elapsed);
+        H5_bandwidth(bandwidth, sizeof(bandwidth), (double)nbytes, path->stats.times.elapsed);
+        fprintf(H5DEBUG(T), "   %-16s %10" PRIdHSIZE " %10u %8s %8s %8s %10s\n", path->name,
+                path->stats.nelmts, path->stats.ncalls, timestrs.user, timestrs.system, timestrs.elapsed,
+                bandwidth);
+        free(timestrs.user);
+        free(timestrs.system);
+        free(timestrs.elapsed);
     }
 #endif
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5T__print_stats() */
+} /* end H5T__print_path_stats() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5T_debug
@@ -148,8 +146,8 @@ H5T_debug(const H5T_t *dt, FILE *stream)
     FUNC_ENTER_NOAPI_NOINIT
 
     /* Check args */
-    HDassert(dt);
-    HDassert(stream);
+    assert(dt);
+    assert(stream);
 
     switch (dt->shared->type) {
         case H5T_NO_CLASS:
@@ -224,10 +222,10 @@ H5T_debug(const H5T_t *dt, FILE *stream)
             s2 = "[named,open]";
             break;
         default:
-            HDassert(0 && "This Should never be executed!");
+            assert(0 && "This Should never be executed!");
     } /* end switch */
 
-    HDfprintf(stream, "%s%s {nbytes=%lu", s1, s2, (unsigned long)(dt->shared->size));
+    fprintf(stream, "%s%s {nbytes=%lu", s1, s2, (unsigned long)(dt->shared->size));
 
     if (H5T_IS_ATOMIC(dt->shared)) {
         uint64_t tmp;
@@ -259,12 +257,12 @@ H5T_debug(const H5T_t *dt, FILE *stream)
                 break;
         } /* end switch */
 
-        HDfprintf(stream, ", %s", s1);
+        fprintf(stream, ", %s", s1);
 
         if (dt->shared->u.atomic.offset)
-            HDfprintf(stream, ", offset=%lu", (unsigned long)(dt->shared->u.atomic.offset));
+            fprintf(stream, ", offset=%lu", (unsigned long)(dt->shared->u.atomic.offset));
         if (dt->shared->u.atomic.prec != 8 * dt->shared->size)
-            HDfprintf(stream, ", prec=%lu", (unsigned long)(dt->shared->u.atomic.prec));
+            fprintf(stream, ", prec=%lu", (unsigned long)(dt->shared->u.atomic.prec));
 
         switch (dt->shared->type) {
             case H5T_NO_CLASS:
@@ -292,7 +290,7 @@ H5T_debug(const H5T_t *dt, FILE *stream)
 
                 } /* end switch */
                 if (s1)
-                    HDfprintf(stream, ", %s", s1);
+                    fprintf(stream, ", %s", s1);
                 break;
 
             case H5T_FLOAT:
@@ -318,20 +316,20 @@ H5T_debug(const H5T_t *dt, FILE *stream)
                         break;
                 } /* end switch */
 
-                HDfprintf(stream, ", sign=%lu+1", (unsigned long)(dt->shared->u.atomic.u.f.sign));
-                HDfprintf(stream, ", mant=%lu+%lu (%s)", (unsigned long)(dt->shared->u.atomic.u.f.mpos),
-                          (unsigned long)(dt->shared->u.atomic.u.f.msize), s1);
-                HDfprintf(stream, ", exp=%lu+%lu", (unsigned long)(dt->shared->u.atomic.u.f.epos),
-                          (unsigned long)(dt->shared->u.atomic.u.f.esize));
+                fprintf(stream, ", sign=%lu+1", (unsigned long)(dt->shared->u.atomic.u.f.sign));
+                fprintf(stream, ", mant=%lu+%lu (%s)", (unsigned long)(dt->shared->u.atomic.u.f.mpos),
+                        (unsigned long)(dt->shared->u.atomic.u.f.msize), s1);
+                fprintf(stream, ", exp=%lu+%lu", (unsigned long)(dt->shared->u.atomic.u.f.epos),
+                        (unsigned long)(dt->shared->u.atomic.u.f.esize));
                 tmp = dt->shared->u.atomic.u.f.ebias >> 32;
                 if (tmp) {
                     size_t hi = (size_t)tmp;
                     size_t lo = (size_t)(dt->shared->u.atomic.u.f.ebias & 0xffffffff);
-                    HDfprintf(stream, " bias=0x%08lx%08lx", (unsigned long)hi, (unsigned long)lo);
+                    fprintf(stream, " bias=0x%08lx%08lx", (unsigned long)hi, (unsigned long)lo);
                 }
                 else {
                     size_t lo = (size_t)(dt->shared->u.atomic.u.f.ebias & 0xffffffff);
-                    HDfprintf(stream, " bias=0x%08lx", (unsigned long)lo);
+                    fprintf(stream, " bias=0x%08lx", (unsigned long)lo);
                 }
                 break;
 
@@ -353,12 +351,12 @@ H5T_debug(const H5T_t *dt, FILE *stream)
     else if (H5T_COMPOUND == dt->shared->type) {
         /* Compound data type */
         for (i = 0; i < dt->shared->u.compnd.nmembs; i++) {
-            HDfprintf(stream, "\n\"%s\" @%lu", dt->shared->u.compnd.memb[i].name,
-                      (unsigned long)(dt->shared->u.compnd.memb[i].offset));
-            HDfprintf(stream, " ");
+            fprintf(stream, "\n\"%s\" @%lu", dt->shared->u.compnd.memb[i].name,
+                    (unsigned long)(dt->shared->u.compnd.memb[i].offset));
+            fprintf(stream, " ");
             H5T_debug(dt->shared->u.compnd.memb[i].type, stream);
         } /* end for */
-        HDfprintf(stream, "\n");
+        fprintf(stream, "\n");
     }
     else if (H5T_VLEN == dt->shared->type) {
         switch (dt->shared->u.vlen.loc) {
@@ -367,54 +365,53 @@ H5T_debug(const H5T_t *dt, FILE *stream)
                 break;
 
             case H5T_LOC_MEMORY:
-                HDfprintf(stream, ", loc=memory");
+                fprintf(stream, ", loc=memory");
                 break;
 
             case H5T_LOC_DISK:
-                HDfprintf(stream, ", loc=disk");
+                fprintf(stream, ", loc=disk");
                 break;
 
             case H5T_LOC_MAXLOC:
             default:
-                HDfprintf(stream, ", loc=UNKNOWN");
+                fprintf(stream, ", loc=UNKNOWN");
                 break;
         } /* end switch */
 
         if (H5T_IS_VL_STRING(dt->shared))
             /* Variable length string datatype */
-            HDfprintf(stream, ", variable-length");
+            fprintf(stream, ", variable-length");
         else {
             /* Variable length sequence datatype */
-            HDfprintf(stream, " VLEN ");
+            fprintf(stream, " VLEN ");
             H5T_debug(dt->shared->parent, stream);
-            HDfprintf(stream, "\n");
+            fprintf(stream, "\n");
         } /* end else */
     }
     else if (H5T_ENUM == dt->shared->type) {
         size_t base_size;
 
         /* Enumeration data type */
-        HDfprintf(stream, " ");
+        fprintf(stream, " ");
         H5T_debug(dt->shared->parent, stream);
         base_size = dt->shared->parent->shared->size;
         for (i = 0; i < dt->shared->u.enumer.nmembs; i++) {
             size_t k;
 
-            HDfprintf(stream, "\n\"%s\" = 0x", dt->shared->u.enumer.name[i]);
+            fprintf(stream, "\n\"%s\" = 0x", dt->shared->u.enumer.name[i]);
             for (k = 0; k < base_size; k++)
-                HDfprintf(stream, "%02" PRIx8,
-                          *((uint8_t *)dt->shared->u.enumer.value + (i * base_size) + k));
+                fprintf(stream, "%02" PRIx8, *((uint8_t *)dt->shared->u.enumer.value + (i * base_size) + k));
         } /* end for */
-        HDfprintf(stream, "\n");
+        fprintf(stream, "\n");
     }
     else if (H5T_OPAQUE == dt->shared->type) {
-        HDfprintf(stream, ", tag=\"%s\"", dt->shared->u.opaque.tag);
+        fprintf(stream, ", tag=\"%s\"", dt->shared->u.opaque.tag);
     }
     else {
         /* Unknown */
-        HDfprintf(stream, "unknown class %d\n", (int)(dt->shared->type));
+        fprintf(stream, "unknown class %d\n", (int)(dt->shared->type));
     }
-    HDfprintf(stream, "}");
+    fprintf(stream, "}");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
