@@ -20,9 +20,10 @@
 
 #include "H5CXprivate.h" /* API Contexts                         */
 #include "H5Iprivate.h"
+#include "H5VLprivate.h" /* Virtual Object Layer                     */
 
 /* Filename: this is the same as the define in accum.c used by test_swmr_write_big() */
-#define SWMR_FILENAME "accum_swmr_big.h5"
+static const char *FILENAME[] = {"accum", "accum_swmr_big", NULL};
 
 /*-------------------------------------------------------------------------
  * Function:    main
@@ -34,28 +35,29 @@
  *
  * Return:      Success: EXIT_SUCCESS
  *              Failure: EXIT_FAILURE
- *
- * Programmer:  Vailin Choi; June 2013
- *
  *-------------------------------------------------------------------------
  */
 int
 main(void)
 {
-    hid_t    fid  = -1;              /* File ID */
-    hid_t    fapl = -1;              /* file access property list ID */
-    H5F_t   *f    = NULL;            /* File pointer */
-    unsigned u;                      /* Local index variable */
-    uint8_t  rbuf[1024];             /* Buffer for reading */
-    uint8_t  buf[1024];              /* Buffer for holding the expected data */
-    char    *driver         = NULL;  /* VFD string (from env variable) */
-    hbool_t  api_ctx_pushed = FALSE; /* Whether API context pushed */
+    const char *driver_name = NULL;            /* VFD string (from env variable) */
+    hid_t       fid         = H5I_INVALID_HID; /* File ID */
+    hid_t       fapl        = H5I_INVALID_HID; /* file access property list ID */
+    H5F_t      *f           = NULL;            /* File pointer */
+    char        filename[1024];
+    unsigned    u;                      /* Local index variable */
+    uint8_t     rbuf[1024];             /* Buffer for reading */
+    uint8_t     buf[1024];              /* Buffer for holding the expected data */
+    bool        api_ctx_pushed = false; /* Whether API context pushed */
+
+    /* Testing setup */
+    h5_test_init();
 
     /* Skip this test if SWMR I/O is not supported for the VFD specified
      * by the environment variable.
      */
-    driver = HDgetenv("HDF5_DRIVER");
-    if (!H5FD__supports_swmr_test(driver))
+    driver_name = h5_get_test_driver_name();
+    if (!H5FD__supports_swmr_test(driver_name))
         return EXIT_SUCCESS;
 
     /* Initialize buffers */
@@ -65,27 +67,28 @@ main(void)
     }
 
     if ((fapl = h5_fileaccess()) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
+    h5_fixname(FILENAME[1], fapl, filename, sizeof filename);
 
     /* Open the file with SWMR_READ */
-    if ((fid = H5Fopen(SWMR_FILENAME, H5F_ACC_RDONLY | H5F_ACC_SWMR_READ, fapl)) < 0)
-        FAIL_STACK_ERROR
+    if ((fid = H5Fopen(filename, H5F_ACC_RDONLY | H5F_ACC_SWMR_READ, fapl)) < 0)
+        FAIL_STACK_ERROR;
 
     /* Push API context */
     if (H5CX_push() < 0)
-        FAIL_STACK_ERROR
-    api_ctx_pushed = TRUE;
+        FAIL_STACK_ERROR;
+    api_ctx_pushed = true;
 
     /* Get H5F_t * to internal file structure */
-    if (NULL == (f = (H5F_t *)H5I_object(fid)))
-        FAIL_STACK_ERROR
+    if (NULL == (f = (H5F_t *)H5VL_object(fid)))
+        FAIL_STACK_ERROR;
 
     /* Should read in [1024, 2024] with buf data */
     if (H5F_block_read(f, H5FD_MEM_DEFAULT, (haddr_t)1024, (size_t)1024, rbuf) < 0)
         FAIL_STACK_ERROR;
 
     /* Verify the data read is correct */
-    if (HDmemcmp(buf, rbuf, (size_t)1024) != 0)
+    if (memcmp(buf, rbuf, (size_t)1024) != 0)
         TEST_ERROR;
 
     /* CLose the file */
@@ -95,9 +98,9 @@ main(void)
         FAIL_STACK_ERROR;
 
     /* Pop API context */
-    if (api_ctx_pushed && H5CX_pop() < 0)
-        FAIL_STACK_ERROR
-    api_ctx_pushed = FALSE;
+    if (api_ctx_pushed && H5CX_pop(false) < 0)
+        FAIL_STACK_ERROR;
+    api_ctx_pushed = false;
 
     return EXIT_SUCCESS;
 
@@ -107,10 +110,10 @@ error:
         H5Pclose(fapl);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     if (api_ctx_pushed)
-        H5CX_pop();
+        H5CX_pop(false);
 
     return EXIT_FAILURE;
 } /* end main() */
