@@ -30,7 +30,7 @@
 #define FILTER3_ID 259
 #define FILTER4_ID 260
 
-const char *FILENAME[] = {"filter_plugin", NULL};
+static const char *FILENAME[] = {"filter_plugin", NULL};
 #define FILENAME_BUF_SIZE 1024
 
 /* Dataset names */
@@ -50,10 +50,10 @@ const char *FILENAME[] = {"filter_plugin", NULL};
 #define HYPERSLAB_SIZE2   50
 
 /* Global size arrays */
-const hsize_t sizes_g[2]       = {DSET_DIM1, DSET_DIM2};                 /* Dataset dimensions   */
-const hsize_t hs_sizes_g[2]    = {HYPERSLAB_SIZE1, HYPERSLAB_SIZE2};     /* Hyperslab sizes      */
-const hsize_t hs_offsets_g[2]  = {HYPERSLAB_OFFSET1, HYPERSLAB_OFFSET2}; /* Hyperslab offsets    */
-const hsize_t chunk_sizes_g[2] = {CHUNK_DIM1, CHUNK_DIM2};               /* Chunk dimensions     */
+static const hsize_t sizes_g[2]       = {DSET_DIM1, DSET_DIM2};                 /* Dataset dimensions   */
+static const hsize_t hs_sizes_g[2]    = {HYPERSLAB_SIZE1, HYPERSLAB_SIZE2};     /* Hyperslab sizes      */
+static const hsize_t hs_offsets_g[2]  = {HYPERSLAB_OFFSET1, HYPERSLAB_OFFSET2}; /* Hyperslab offsets    */
+static const hsize_t chunk_sizes_g[2] = {CHUNK_DIM1, CHUNK_DIM2};               /* Chunk dimensions     */
 
 /* Limit random number within 20000 */
 #define RANDOM_LIMIT 20000
@@ -64,10 +64,10 @@ const hsize_t chunk_sizes_g[2] = {CHUNK_DIM1, CHUNK_DIM2};               /* Chun
 #define TOP_LEVEL_GROUP_NAME "top-level group"
 
 /* Global arrays in which to save data */
-int **orig_deflate_g = NULL;
-int **orig_dynlib1_g = NULL;
-int **orig_dynlib2_g = NULL;
-int **orig_dynlib4_g = NULL;
+static int **orig_deflate_g = NULL;
+static int **orig_dynlib1_g = NULL;
+static int **orig_dynlib2_g = NULL;
+static int **orig_dynlib4_g = NULL;
 
 /*-------------------------------------------------------------------------
  * Function:  free_2D_array
@@ -84,9 +84,9 @@ free_2D_array(int ***arr)
 {
 
     if (arr && *arr && (*arr)[0])
-        HDfree((*arr)[0]);
+        free((*arr)[0]);
     if (arr && *arr)
-        HDfree(*arr);
+        free(*arr);
     *arr = NULL;
 
     return SUCCEED;
@@ -114,9 +114,9 @@ allocate_and_init_2D_array(int ***arr, const hsize_t *sizes, int **initial_value
     c = (size_t)sizes[1];
 
     /* Allocate and set up pseudo-2D array */
-    if (NULL == (*arr = (int **)HDcalloc(r, sizeof(int *))))
+    if (NULL == (*arr = (int **)calloc(r, sizeof(int *))))
         TEST_ERROR;
-    if (NULL == ((*arr)[0] = (int *)HDcalloc(r * c, sizeof(int))))
+    if (NULL == ((*arr)[0] = (int *)calloc(r * c, sizeof(int))))
         TEST_ERROR;
     for (i = 0; i < r; i++)
         (*arr)[i] = (**arr + c * i);
@@ -124,7 +124,7 @@ allocate_and_init_2D_array(int ***arr, const hsize_t *sizes, int **initial_value
     /* Copy over the data elements */
     if (initial_values) {
         n_bytes = r * c * sizeof(int);
-        HDmemcpy((*arr)[0], initial_values[0], n_bytes);
+        memcpy((*arr)[0], initial_values[0], n_bytes);
     }
 
     return SUCCEED;
@@ -144,11 +144,11 @@ error:
  *-------------------------------------------------------------------------
  */
 static herr_t
-compare_2D_arrays(int **dset1, int **dset2, const hsize_t *sizes, /*OUT*/ hbool_t *are_same)
+compare_2D_arrays(int **dset1, int **dset2, const hsize_t *sizes, /*OUT*/ bool *are_same)
 {
     hsize_t i, j; /* index variables */
 
-    *are_same = TRUE;
+    *are_same = true;
 
     /* Check all the array values. This could optionally emit any
      * bad data, but it's not clear how that would help debugging.
@@ -156,7 +156,7 @@ compare_2D_arrays(int **dset1, int **dset2, const hsize_t *sizes, /*OUT*/ hbool_
     for (i = 0; i < sizes[0]; i++)
         for (j = 0; j < sizes[1]; j++)
             if (dset1[i][j] != dset2[i][j]) {
-                *are_same = FALSE;
+                *are_same = false;
                 return SUCCEED;
             }
 
@@ -176,19 +176,19 @@ compare_2D_arrays(int **dset1, int **dset2, const hsize_t *sizes, /*OUT*/ hbool_
 static herr_t
 ensure_filter_works(hid_t fid, const char *name, hid_t dcpl_id)
 {
-    hid_t   did           = -1;           /* Dataset ID                                   */
-    hid_t   dxpl_id       = -1;           /* Dataset xfer property list ID                */
-    hid_t   write_dxpl_id = -1;           /* Dataset xfer property list ID for writing    */
-    hid_t   sid           = -1;           /* Dataspace ID                                 */
-    void   *tconv_buf     = NULL;         /* Temporary conversion buffer                  */
-    int   **orig          = NULL;         /* Data written to the dataset                  */
-    int   **read          = NULL;         /* Data read from the dataset                   */
-    size_t  r, c;                         /* Data rows and columns                        */
-    size_t  hs_r, hs_c, hs_offr, hs_offc; /* Hypserslab sizes and offsets                 */
-    size_t  i, j;                         /* Local index variables                        */
-    int     n = 0;                        /* Value written to point array                 */
-    hbool_t are_same;                     /* Output from dataset compare function         */
-    int  ***save_array = NULL;            /* (Global) array where the final data go       */
+    hid_t  did           = H5I_INVALID_HID; /* Dataset ID                                   */
+    hid_t  dxpl_id       = H5I_INVALID_HID; /* Dataset xfer property list ID                */
+    hid_t  write_dxpl_id = H5I_INVALID_HID; /* Dataset xfer property list ID for writing    */
+    hid_t  sid           = H5I_INVALID_HID; /* Dataspace ID                                 */
+    void  *tconv_buf     = NULL;            /* Temporary conversion buffer                  */
+    int  **orig          = NULL;            /* Data written to the dataset                  */
+    int  **read          = NULL;            /* Data read from the dataset                   */
+    size_t r, c;                            /* Data rows and columns                        */
+    size_t hs_r, hs_c, hs_offr, hs_offc;    /* Hypserslab sizes and offsets                 */
+    size_t i, j;                            /* Local index variables                        */
+    int    n = 0;                           /* Value written to point array                 */
+    bool   are_same;                        /* Output from dataset compare function         */
+    int ***save_array = NULL;               /* (Global) array where the final data go       */
 
     /* initialize */
     r = (size_t)sizes_g[0];
@@ -212,7 +212,7 @@ ensure_filter_works(hid_t fid, const char *name, hid_t dcpl_id)
      */
     if ((dxpl_id = H5Pcreate(H5P_DATASET_XFER)) < 0)
         TEST_ERROR;
-    if (NULL == (tconv_buf = HDcalloc((size_t)1000, sizeof(char))))
+    if (NULL == (tconv_buf = calloc((size_t)1000, sizeof(char))))
         TEST_ERROR;
     if (H5Pset_buffer(dxpl_id, (size_t)1000, tconv_buf, NULL) < 0)
         TEST_ERROR;
@@ -222,7 +222,7 @@ ensure_filter_works(hid_t fid, const char *name, hid_t dcpl_id)
     TESTING("    filters (setup)");
 
     /* Check if all the filters are available */
-    if (H5Pall_filters_avail(dcpl_id) != TRUE)
+    if (H5Pall_filters_avail(dcpl_id) != true)
         TEST_ERROR;
 
     /* Create the dataset */
@@ -243,7 +243,7 @@ ensure_filter_works(hid_t fid, const char *name, hid_t dcpl_id)
     /* The input buffer was calloc'd and has not been initialized yet */
     if (compare_2D_arrays(orig, read, sizes_g, &are_same) < 0)
         TEST_ERROR;
-    if (FALSE == are_same)
+    if (false == are_same)
         TEST_ERROR;
 
     PASSED();
@@ -278,7 +278,7 @@ ensure_filter_works(hid_t fid, const char *name, hid_t dcpl_id)
     /* Check that the values read are the same as the values written */
     if (compare_2D_arrays(orig, read, sizes_g, &are_same) < 0)
         TEST_ERROR;
-    if (FALSE == are_same)
+    if (false == are_same)
         TEST_ERROR;
 
     PASSED();
@@ -306,7 +306,7 @@ ensure_filter_works(hid_t fid, const char *name, hid_t dcpl_id)
     /* Check that the values read are the same as the values written */
     if (compare_2D_arrays(orig, read, sizes_g, &are_same) < 0)
         TEST_ERROR;
-    if (FALSE == are_same)
+    if (false == are_same)
         TEST_ERROR;
 
     PASSED();
@@ -330,7 +330,7 @@ ensure_filter_works(hid_t fid, const char *name, hid_t dcpl_id)
     /* Check that the values read are the same as the values written */
     if (compare_2D_arrays(orig, read, sizes_g, &are_same) < 0)
         TEST_ERROR;
-    if (FALSE == are_same)
+    if (false == are_same)
         TEST_ERROR;
 
     PASSED();
@@ -366,7 +366,7 @@ ensure_filter_works(hid_t fid, const char *name, hid_t dcpl_id)
     /* Check that the values read are the same as the values written */
     if (compare_2D_arrays(orig, read, sizes_g, &are_same) < 0)
         TEST_ERROR;
-    if (FALSE == are_same)
+    if (false == are_same)
         TEST_ERROR;
 
     PASSED();
@@ -374,13 +374,13 @@ ensure_filter_works(hid_t fid, const char *name, hid_t dcpl_id)
     /* Save the data written to the file for later comparison when the file
      * is reopened for read test.
      */
-    if (!HDstrcmp(name, DSET_DEFLATE_NAME))
+    if (!strcmp(name, DSET_DEFLATE_NAME))
         save_array = &orig_deflate_g;
-    else if (!HDstrcmp(name, DSET_FILTER1_NAME))
+    else if (!strcmp(name, DSET_FILTER1_NAME))
         save_array = &orig_dynlib1_g;
-    else if (!HDstrcmp(name, DSET_FILTER2_NAME))
+    else if (!strcmp(name, DSET_FILTER2_NAME))
         save_array = &orig_dynlib2_g;
-    else if (!HDstrcmp(name, DSET_FILTER3_NAME))
+    else if (!strcmp(name, DSET_FILTER3_NAME))
         save_array = &orig_dynlib4_g;
     else
         TEST_ERROR;
@@ -400,7 +400,7 @@ ensure_filter_works(hid_t fid, const char *name, hid_t dcpl_id)
     free_2D_array(&orig);
     free_2D_array(&read);
 
-    HDfree(tconv_buf);
+    free(tconv_buf);
 
     return SUCCEED;
 
@@ -420,7 +420,7 @@ error:
     free_2D_array(&read);
 
     if (tconv_buf)
-        HDfree(tconv_buf);
+        free(tconv_buf);
 
     return FAIL;
 } /* end ensure_filter_works() */
@@ -437,16 +437,18 @@ error:
 static herr_t
 test_dataset_write_with_filters(hid_t fid)
 {
-    hid_t        dcpl_id = -1;     /* Dataset creation property list ID        */
-    unsigned int compress_level;   /* Deflate compression level                */
-    unsigned int filter1_data;     /* Data used by filter 1                    */
-    unsigned int libver_values[4]; /* Used w/ the filter that makes HDF5 calls */
+    hid_t        dcpl_id = H5I_INVALID_HID; /* Dataset creation property list ID        */
+    unsigned int filter1_data;              /* Data used by filter 1                    */
+    unsigned int libver_values[4];          /* Used w/ the filter that makes HDF5 calls */
+#ifdef H5_HAVE_FILTER_DEFLATE
+    unsigned int compress_level; /* Deflate compression level */
+#endif
 
     /*----------------------------------------------------------
      * STEP 1: Test deflation by itself.
      *----------------------------------------------------------
      */
-    HDputs("Testing dataset writes with deflate filter");
+    puts("Testing dataset writes with deflate filter");
 #ifdef H5_HAVE_FILTER_DEFLATE
     if ((dcpl_id = H5Pcreate(H5P_DATASET_CREATE)) < 0)
         TEST_ERROR;
@@ -465,14 +467,14 @@ test_dataset_write_with_filters(hid_t fid)
         TEST_ERROR;
 #else  /* H5_HAVE_FILTER_DEFLATE */
     SKIPPED();
-    HDputs("    Deflate filter not enabled");
+    puts("    Deflate filter not enabled");
 #endif /* H5_HAVE_FILTER_DEFLATE */
 
     /*----------------------------------------------------------
      * STEP 2: Test filter plugin 1 by itself.
      *----------------------------------------------------------
      */
-    HDputs("    dataset writes with filter plugin 1");
+    puts("    dataset writes with filter plugin 1");
     if ((dcpl_id = H5Pcreate(H5P_DATASET_CREATE)) < 0)
         TEST_ERROR;
     if (H5Pset_chunk(dcpl_id, 2, chunk_sizes_g) < 0)
@@ -504,7 +506,7 @@ test_dataset_write_with_filters(hid_t fid)
      * STEP 3: Test filter plugin 2 by itself.
      *----------------------------------------------------------
      */
-    HDputs("    dataset writes with filter plugin 2");
+    puts("    dataset writes with filter plugin 2");
     if ((dcpl_id = H5Pcreate(H5P_DATASET_CREATE)) < 0)
         TEST_ERROR;
     if (H5Pset_chunk(dcpl_id, 2, chunk_sizes_g) < 0)
@@ -532,7 +534,7 @@ test_dataset_write_with_filters(hid_t fid)
      *         (This filter plugin makes HDF5 API calls)
      *----------------------------------------------------------
      */
-    HDputs("    dataset writes with filter plugin 3");
+    puts("    dataset writes with filter plugin 3");
     if ((dcpl_id = H5Pcreate(H5P_DATASET_CREATE)) < 0)
         TEST_ERROR;
     if (H5Pset_chunk(dcpl_id, 2, chunk_sizes_g) < 0)
@@ -602,7 +604,7 @@ test_read_data(hid_t did, int *origin_data)
     for (i = 0; i < sizes_g[0]; i++)
         for (j = 0; j < sizes_g[1]; j++) {
             if (*data_p != check[i][j])
-                TEST_ERROR
+                TEST_ERROR;
             data_p++;
         }
 
@@ -631,7 +633,7 @@ error:
 static herr_t
 test_dataset_read_with_filters(hid_t fid)
 {
-    hid_t did = -1; /* Dataset ID */
+    hid_t did = H5I_INVALID_HID; /* Dataset ID */
 
     /*----------------------------------------------------------
      * STEP 1: Test deflation by itself.
@@ -640,7 +642,7 @@ test_dataset_read_with_filters(hid_t fid)
     TESTING("dataset read I/O with deflate filter");
 
 #ifdef H5_HAVE_FILTER_DEFLATE
-    if (H5Zfilter_avail(H5Z_FILTER_DEFLATE) != TRUE)
+    if (H5Zfilter_avail(H5Z_FILTER_DEFLATE) != true)
         TEST_ERROR;
 
     if ((did = H5Dopen2(fid, DSET_DEFLATE_NAME, H5P_DEFAULT)) < 0)
@@ -654,7 +656,7 @@ test_dataset_read_with_filters(hid_t fid)
 
 #else  /* H5_HAVE_FILTER_DEFLATE */
     SKIPPED();
-    HDputs("    Deflate filter not enabled");
+    puts("    Deflate filter not enabled");
 #endif /* H5_HAVE_FILTER_DEFLATE */
 
     /*----------------------------------------------------------
@@ -766,8 +768,8 @@ error:
 static herr_t
 test_no_read_when_plugins_disabled(hid_t fid)
 {
-    hid_t    did = -1;     /* Dataset ID */
-    unsigned plugin_flags; /* Plugin access flags */
+    hid_t    did = H5I_INVALID_HID; /* Dataset ID */
+    unsigned plugin_flags;          /* Plugin access flags */
 
     TESTING("filter plugin 1 with filter plugins disabled");
 
@@ -824,9 +826,9 @@ error:
 static herr_t
 test_creating_groups_using_plugins(hid_t fid)
 {
-    hid_t gcpl_id = -1;
-    hid_t gid     = -1;
-    hid_t sub_gid = -1;
+    hid_t gcpl_id = H5I_INVALID_HID;
+    hid_t gid     = H5I_INVALID_HID;
+    hid_t sub_gid = H5I_INVALID_HID;
     int   i;
     char  subgroup_name[256];
 
@@ -845,10 +847,7 @@ test_creating_groups_using_plugins(hid_t fid)
 
     /* Create multiple groups under the top-level group */
     for (i = 0; i < N_SUBGROUPS; i++) {
-        char *sp = subgroup_name;
-
-        sp += HDsprintf(subgroup_name, SUBGROUP_PREFIX);
-        HDsprintf(sp, "%d", i);
+        snprintf(subgroup_name, sizeof(subgroup_name), SUBGROUP_PREFIX "%d", i);
 
         if ((sub_gid = H5Gcreate2(gid, subgroup_name, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT)) < 0)
             TEST_ERROR;
@@ -891,8 +890,8 @@ error:
 static herr_t
 test_opening_groups_using_plugins(hid_t fid)
 {
-    hid_t gid     = -1;
-    hid_t sub_gid = -1;
+    hid_t gid     = H5I_INVALID_HID;
+    hid_t sub_gid = H5I_INVALID_HID;
     int   i;
     char  subgroup_name[256];
 
@@ -904,10 +903,7 @@ test_opening_groups_using_plugins(hid_t fid)
 
     /* Open all the sub-groups under the top-level group */
     for (i = 0; i < N_SUBGROUPS; i++) {
-        char *sp = subgroup_name;
-
-        sp += HDsprintf(subgroup_name, SUBGROUP_PREFIX);
-        HDsprintf(sp, "%d", i);
+        snprintf(subgroup_name, sizeof(subgroup_name), SUBGROUP_PREFIX "%d", i);
 
         if ((sub_gid = H5Gopen2(gid, subgroup_name, H5P_DEFAULT)) < 0)
             TEST_ERROR;
@@ -956,9 +952,9 @@ test_path_api_calls(void)
     char         path[256];
     char         temp_name[256];
 
-    HDputs("Testing access to the filter path table");
+    puts("Testing access to the filter path table");
 
-    if (H5Zfilter_avail(FILTER1_ID) != TRUE)
+    if (H5Zfilter_avail(FILTER1_ID) != true)
         TEST_ERROR;
 
     /* Set the number of paths to create for this test.
@@ -968,16 +964,6 @@ test_path_api_calls(void)
      */
     n_starting_paths = 42;
 
-    /* Check that initialization is correct */
-    TESTING("    initialize");
-
-    if (H5PLsize(&n_paths) < 0)
-        TEST_ERROR;
-    if (n_paths != 2)
-        TEST_ERROR;
-
-    PASSED();
-
     /****************/
     /* H5PLremove() */
     /****************/
@@ -992,7 +978,7 @@ test_path_api_calls(void)
     /* Remove all existing paths */
     for (u = n_paths; u > 0; u--)
         if (H5PLremove(u - 1) < 0) {
-            HDfprintf(stderr, "    at %u: %s\n", u, path);
+            fprintf(stderr, "    at %u: %s\n", u, path);
             TEST_ERROR;
         }
 
@@ -1025,9 +1011,9 @@ test_path_api_calls(void)
 
     /* Add a bunch of paths to the path table */
     for (u = 0; u < n_starting_paths; u++) {
-        HDsprintf(path, "a_path_%u", u);
+        snprintf(path, sizeof(path), "a_path_%u", u);
         if (H5PLappend(path) < 0) {
-            HDfprintf(stderr, "    at %u: %s\n", u, path);
+            fprintf(stderr, "    at %u: %s\n", u, path);
             TEST_ERROR;
         }
     }
@@ -1048,7 +1034,7 @@ test_path_api_calls(void)
     H5E_END_TRY
 
     if (ret >= 0)
-        TEST_ERROR
+        TEST_ERROR;
 
     PASSED();
 
@@ -1060,7 +1046,7 @@ test_path_api_calls(void)
 
     /* Get the path length by passing in NULL */
     if ((path_len = H5PLget(0, NULL, 0)) <= 0) {
-        HDfprintf(stderr, "    get path 0 length failed\n");
+        fprintf(stderr, "    get path 0 length failed\n");
         TEST_ERROR;
     }
     if (path_len != 8)
@@ -1068,11 +1054,11 @@ test_path_api_calls(void)
 
     /* Get the path */
     if ((path_len = H5PLget(0, path, 256)) <= 0) {
-        HDfprintf(stderr, "    get 0 len: %zd : %s\n", path_len, path);
+        fprintf(stderr, "    get 0 len: %zd : %s\n", path_len, path);
         TEST_ERROR;
     }
-    if (HDstrcmp(path, "a_path_0") != 0) {
-        HDfprintf(stderr, "    get 0: %s\n", path);
+    if (strcmp(path, "a_path_0") != 0) {
+        fprintf(stderr, "    get 0: %s\n", path);
         TEST_ERROR;
     }
 
@@ -1083,17 +1069,17 @@ test_path_api_calls(void)
     /* Get path at index 1 */
     if ((path_len = H5PLget(1, path, 256)) <= 0)
         TEST_ERROR;
-    if (HDstrcmp(path, "a_path_1") != 0) {
-        HDfprintf(stderr, "    get 1: %s\n", path);
+    if (strcmp(path, "a_path_1") != 0) {
+        fprintf(stderr, "    get 1: %s\n", path);
         TEST_ERROR;
     }
 
     /* Get path at the last index */
     if ((path_len = H5PLget(n_starting_paths - 1, path, 256)) <= 0)
         TEST_ERROR;
-    HDsprintf(temp_name, "a_path_%u", n_starting_paths - 1);
-    if (HDstrcmp(path, temp_name) != 0) {
-        HDfprintf(stderr, "    get %u: %s\n", n_starting_paths - 1, path);
+    snprintf(temp_name, sizeof(temp_name), "a_path_%u", n_starting_paths - 1);
+    if (strcmp(path, temp_name) != 0) {
+        fprintf(stderr, "    get %u: %s\n", n_starting_paths - 1, path);
         TEST_ERROR;
     }
 
@@ -1129,8 +1115,8 @@ test_path_api_calls(void)
     /* Verify that the entries were moved */
     if ((path_len = H5PLget(8, path, 256)) <= 0)
         TEST_ERROR;
-    if (HDstrcmp(path, "a_path_9") != 0) {
-        HDfprintf(stderr, "    get 8: %s\n", path);
+    if (strcmp(path, "a_path_9") != 0) {
+        fprintf(stderr, "    get 8: %s\n", path);
         TEST_ERROR;
     }
 
@@ -1145,9 +1131,9 @@ test_path_api_calls(void)
     TESTING("    prepend");
 
     /* Prepend one path */
-    HDsprintf(path, "a_path_%d", n_starting_paths + 1);
+    snprintf(path, sizeof(path), "a_path_%d", n_starting_paths + 1);
     if (H5PLprepend(path) < 0) {
-        HDfprintf(stderr, "    prepend %u: %s\n", n_starting_paths + 1, path);
+        fprintf(stderr, "    prepend %u: %s\n", n_starting_paths + 1, path);
         TEST_ERROR;
     }
 
@@ -1160,17 +1146,17 @@ test_path_api_calls(void)
     /* Verify that the entries were moved */
     if (H5PLget(8, path, 256) <= 0)
         TEST_ERROR;
-    if (HDstrcmp(path, "a_path_7") != 0) {
-        HDfprintf(stderr, "    get 8: %s\n", path);
+    if (strcmp(path, "a_path_7") != 0) {
+        fprintf(stderr, "    get 8: %s\n", path);
         TEST_ERROR;
     }
 
     /* Verify that the path was inserted at index zero */
     if (H5PLget(0, path, 256) <= 0)
         TEST_ERROR;
-    HDsprintf(temp_name, "a_path_%d", n_starting_paths + 1);
-    if (HDstrcmp(path, temp_name) != 0) {
-        HDfprintf(stderr, "    get 0: %s\n", path);
+    snprintf(temp_name, sizeof(temp_name), "a_path_%d", n_starting_paths + 1);
+    if (strcmp(path, temp_name) != 0) {
+        fprintf(stderr, "    get 0: %s\n", path);
         TEST_ERROR;
     }
 
@@ -1183,9 +1169,9 @@ test_path_api_calls(void)
     TESTING("    replace");
 
     /* Replace one path at index 1 */
-    HDsprintf(path, "a_path_%u", n_starting_paths + 4);
+    snprintf(path, sizeof(path), "a_path_%u", n_starting_paths + 4);
     if (H5PLreplace(path, 1) < 0) {
-        HDfprintf(stderr, "    replace 1: %s\n", path);
+        fprintf(stderr, "    replace 1: %s\n", path);
         TEST_ERROR;
     }
 
@@ -1202,17 +1188,17 @@ test_path_api_calls(void)
     /* Check path at index 0 */
     if (H5PLget(0, path, 256) <= 0)
         TEST_ERROR;
-    HDsprintf(temp_name, "a_path_%u", n_starting_paths + 1);
-    if (HDstrcmp(path, temp_name) != 0) {
-        HDfprintf(stderr, "    get 0: %s\n", path);
+    snprintf(temp_name, sizeof(temp_name), "a_path_%u", n_starting_paths + 1);
+    if (strcmp(path, temp_name) != 0) {
+        fprintf(stderr, "    get 0: %s\n", path);
         TEST_ERROR;
     }
 
     /* Check path at index 2 */
     if (H5PLget(2, path, 256) <= 0)
         TEST_ERROR;
-    if (HDstrcmp(path, "a_path_1") != 0) {
-        HDfprintf(stderr, "    get 2: %s\n", path);
+    if (strcmp(path, "a_path_1") != 0) {
+        fprintf(stderr, "    get 2: %s\n", path);
         TEST_ERROR;
     }
 
@@ -1235,8 +1221,8 @@ test_path_api_calls(void)
     /* Verify that the entries were moved */
     if (H5PLget(4, path, 256) <= 0)
         TEST_ERROR;
-    if (HDstrcmp(path, "a_path_4") != 0) {
-        HDfprintf(stderr, "    get 4: %s\n", path);
+    if (strcmp(path, "a_path_4") != 0) {
+        fprintf(stderr, "    get 4: %s\n", path);
         TEST_ERROR;
     }
 
@@ -1250,17 +1236,17 @@ test_path_api_calls(void)
     TESTING("    insert");
 
     /* Insert one path at index 3*/
-    HDsprintf(path, "a_path_%d", n_starting_paths + 5);
+    snprintf(path, sizeof(path), "a_path_%d", n_starting_paths + 5);
     if (H5PLinsert(path, 3) < 0) {
-        HDfprintf(stderr, "    insert 3: %s\n", path);
+        fprintf(stderr, "    insert 3: %s\n", path);
         TEST_ERROR;
     }
 
     /* Verify that the entries were moved */
     if (H5PLget(4, path, 256) <= 0)
         TEST_ERROR;
-    if (HDstrcmp(path, "a_path_2") != 0) {
-        HDfprintf(stderr, "    get 4: %s\n", path);
+    if (strcmp(path, "a_path_2") != 0) {
+        fprintf(stderr, "    get 4: %s\n", path);
         TEST_ERROR;
     }
 
@@ -1286,7 +1272,7 @@ test_path_api_calls(void)
     /* Remove all existing paths */
     for (u = n_paths; u > 0; u--)
         if (H5PLremove(u - 1) < 0) {
-            HDfprintf(stderr, "    at %u: %s\n", u, path);
+            fprintf(stderr, "    at %u: %s\n", u, path);
             TEST_ERROR;
         }
 
@@ -1304,6 +1290,102 @@ error:
     return FAIL;
 } /* end test_path_api_calls() */
 
+/*-------------------------------------------------------------------------
+ * Function:  test_filter_numbers
+ *
+ * Purpose:   Tests the filter numbers are handled correctly
+ *
+ * Return:    SUCCEED/FAIL
+ *
+ *-------------------------------------------------------------------------
+ */
+static herr_t
+test_filter_numbers(void)
+{
+    hid_t        dcpl_id = H5I_INVALID_HID;
+    H5Z_filter_t id;
+    herr_t       status = SUCCEED;
+    size_t       nelmts = 0;
+    unsigned int flags;
+    unsigned int filter_config;
+
+    puts("Testing filter number handling");
+
+    /* Check that out-of-range filter numbers are handled correctly */
+    TESTING("    Filter # out of range");
+
+    /* Create property list */
+    if ((dcpl_id = H5Pcreate(H5P_DATASET_CREATE)) < 0)
+        TEST_ERROR;
+
+    nelmts = 0;
+
+    /* Test id > H5Z_FILTER_MAX and < 0, current version */
+
+    H5E_BEGIN_TRY
+    {
+        id     = H5Z_FILTER_MAX + 1;
+        status = H5Pget_filter_by_id2(dcpl_id, id, &flags, &nelmts, NULL, 0, NULL, &filter_config);
+    }
+    H5E_END_TRY
+
+    /* Should fail */
+    if (status != FAIL)
+        TEST_ERROR;
+
+    H5E_BEGIN_TRY
+    {
+        id     = -1;
+        status = H5Pget_filter_by_id2(dcpl_id, id, &flags, &nelmts, NULL, 0, NULL, &filter_config);
+    }
+    H5E_END_TRY
+
+    /* Should fail */
+    if (status != FAIL)
+        TEST_ERROR;
+
+        /* Test id > H5Z_FILTER_MAX and < 0, deprecated version */
+
+#ifndef H5_NO_DEPRECATED_SYMBOLS
+    H5E_BEGIN_TRY
+    {
+        id     = H5Z_FILTER_MAX + 1;
+        status = H5Pget_filter_by_id1(dcpl_id, id, &flags, &nelmts, NULL, 0, NULL);
+    }
+    H5E_END_TRY
+
+    /* Should fail */
+    if (status != FAIL)
+        TEST_ERROR;
+
+    H5E_BEGIN_TRY
+    {
+        id     = -1;
+        status = H5Pget_filter_by_id1(dcpl_id, id, &flags, &nelmts, NULL, 0, NULL);
+    }
+    H5E_END_TRY
+
+    /* Should fail */
+    if (status != FAIL)
+        TEST_ERROR;
+#endif
+
+    if (H5Pclose(dcpl_id) < 0)
+        TEST_ERROR;
+
+    PASSED();
+
+    return SUCCEED;
+
+error:
+    H5E_BEGIN_TRY
+    {
+        H5Pclose(dcpl_id);
+    }
+    H5E_END_TRY
+    return FAIL;
+} /* end test_filter_numbers() */
+
 /*-------------------------------------------------------------------------
  * Function:  disable_chunk_cache
  *
@@ -1345,9 +1427,9 @@ int
 main(void)
 {
     char     filename[FILENAME_BUF_SIZE];
-    hid_t    fid            = -1;
-    hid_t    old_ff_fapl_id = -1;
-    hid_t    new_ff_fapl_id = -1;
+    hid_t    fid            = H5I_INVALID_HID;
+    hid_t    old_ff_fapl_id = H5I_INVALID_HID;
+    hid_t    new_ff_fapl_id = H5I_INVALID_HID;
     unsigned new_format;
     int      nerrors = 0;
 
@@ -1355,11 +1437,11 @@ main(void)
     /* ENSURE THAT WRITING TO DATASETS AND CREATING GROUPS WORKS       */
     /*******************************************************************/
     /* Test with old & new format groups */
-    for (new_format = FALSE; new_format <= TRUE; new_format++) {
+    for (new_format = false; new_format <= true; new_format++) {
         hid_t my_fapl_id;
 
         /* Testing setup */
-        h5_reset();
+        h5_test_init();
 
         /* Get a VFD-dependent filename */
         if ((old_ff_fapl_id = h5_fileaccess()) < 0)
@@ -1374,7 +1456,7 @@ main(void)
 
         /* Set the FAPL for the type of format */
         if (new_format) {
-            HDputs("\nTesting with new file format:");
+            puts("\nTesting with new file format:");
             /* Copy the file access property list and set the latest file format on it */
             if ((new_ff_fapl_id = H5Pcopy(old_ff_fapl_id)) < 0)
                 TEST_ERROR;
@@ -1384,7 +1466,7 @@ main(void)
             my_fapl_id = new_ff_fapl_id;
         }
         else {
-            HDputs("Testing with old file format:");
+            puts("Testing with old file format:");
             my_fapl_id = old_ff_fapl_id;
         }
 
@@ -1409,17 +1491,17 @@ main(void)
                 TEST_ERROR;
         }
 
-        /* Restore the default error handler (set in h5_reset()) */
+        /* Restore the default error handler (set in h5_test_init()) */
         h5_restore_err();
 
         /*******************************************************************/
         /* ENSURE THAT READING FROM DATASETS AND OPENING GROUPS WORKS      */
         /*******************************************************************/
 
-        HDputs("\nTesting reading data with with dynamic plugin filters:");
+        puts("\nTesting reading data with with dynamic plugin filters:");
 
         /* Close the library so that all loaded plugin libraries are unloaded */
-        h5_reset();
+        h5_test_init();
         if ((old_ff_fapl_id = h5_fileaccess()) < 0)
             TEST_ERROR;
 
@@ -1436,6 +1518,12 @@ main(void)
         else
             my_fapl_id = old_ff_fapl_id;
 
+        /* Add extra path to check for correct error process */
+        if (H5PLprepend("bogus") < 0) {
+            fprintf(stderr, "Could not prepend path:bogus\n");
+            TEST_ERROR;
+        }
+
         /* Reopen the file for testing data reading */
         if ((fid = H5Fopen(filename, H5F_ACC_RDONLY, my_fapl_id)) < 0)
             TEST_ERROR;
@@ -1454,7 +1542,7 @@ main(void)
                 TEST_ERROR;
         }
 
-        /* Restore the default error handler (set in h5_reset()) */
+        /* Restore the default error handler (set in h5_test_init()) */
         h5_restore_err();
 
         /*******************************************************************/
@@ -1462,7 +1550,7 @@ main(void)
         /*******************************************************************/
 
         /* Close the library so that all loaded plugin libraries are unloaded */
-        h5_reset();
+        h5_test_init();
         if ((old_ff_fapl_id = h5_fileaccess()) < 0)
             TEST_ERROR;
 
@@ -1500,7 +1588,7 @@ main(void)
                 TEST_ERROR;
         }
         else {
-            /* Restore the default error handler (set in h5_reset()) */
+            /* Restore the default error handler (set in h5_test_init()) */
             h5_restore_err();
 
             if (H5Pclose(old_ff_fapl_id) < 0)
@@ -1523,12 +1611,15 @@ main(void)
     /* Test the APIs for access to the filter plugin path table */
     nerrors += (test_path_api_calls() < 0 ? 1 : 0);
 
+    /* Test filter numbers */
+    nerrors += (test_filter_numbers() < 0 ? 1 : 0);
+
     if (nerrors)
         TEST_ERROR;
 
-    HDprintf("All plugin tests passed.\n");
+    printf("All plugin tests passed.\n");
 
-    HDexit(EXIT_SUCCESS);
+    exit(EXIT_SUCCESS);
 
 error:
     H5E_BEGIN_TRY
@@ -1546,6 +1637,6 @@ error:
     free_2D_array(&orig_dynlib4_g);
 
     nerrors = MAX(1, nerrors);
-    HDprintf("***** %d PLUGIN TEST%s FAILED! *****\n", nerrors, 1 == nerrors ? "" : "S");
-    HDexit(EXIT_FAILURE);
+    printf("***** %d PLUGIN TEST%s FAILED! *****\n", nerrors, 1 == nerrors ? "" : "S");
+    exit(EXIT_FAILURE);
 } /* end main() */
