@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke
- *              Friday, October 23, 1998
- *
  * Purpose:  This is the second half of a two-part test that makes sure
  *    that a file can be read after an application crashes as long
  *    as the file was flushed first.  This half tries to read the
@@ -30,9 +27,9 @@
 /* This is used in the helper routine clear_status_flags() */
 #define H5F_ACS_CLEAR_STATUS_FLAGS_NAME "clear_status_flags"
 
-const char *FILENAME[] = {"flush",          "flush-swmr",          "noflush",
-                          "noflush-swmr",   "flush_extend",        "flush_extend-swmr",
-                          "noflush_extend", "noflush_extend-swmr", NULL};
+static const char *FILENAME[] = {"flush",          "flush-swmr",          "noflush",
+                                 "noflush-swmr",   "flush_extend",        "flush_extend-swmr",
+                                 "noflush_extend", "noflush_extend-swmr", NULL};
 
 /* Number and size of dataset dims, chunk size, etc. */
 #define NELEMENTS        10000
@@ -42,29 +39,26 @@ const char *FILENAME[] = {"flush",          "flush-swmr",          "noflush",
 /* Number of sub-groups created in the containing group */
 #define NGROUPS 100
 
-static hbool_t dset_ok(hid_t fid, const char *dset_name);
-static hbool_t file_ok(const char *filename, hid_t fapl_id, hbool_t check_second_dset);
+static bool dset_ok(hid_t fid, const char *dset_name);
+static bool file_ok(const char *filename, hid_t fapl_id, bool check_second_dset);
 
 /*-------------------------------------------------------------------------
  * Function:    dset_ok
  *
  * Purpose:     Checks if the data in a dataset is what it is supposed to be.
  *
- * Return:      TRUE/FALSE
- *
- * Programmer:	Leon Arber
- *              Oct. 4, 2006.
+ * Return:      true/false
  *
  *-------------------------------------------------------------------------
  */
-static hbool_t
+static bool
 dset_ok(hid_t fid, const char *dset_name)
 {
-    hid_t   sid     = -1;   /* dataspace ID                     */
-    hid_t   did     = -1;   /* dataset ID                       */
-    int    *data    = NULL; /* data buffer                      */
-    hsize_t dims[1] = {0};  /* size of dataset                  */
-    int     i;              /* iterator                         */
+    hid_t   sid     = H5I_INVALID_HID; /* dataspace ID                     */
+    hid_t   did     = H5I_INVALID_HID; /* dataset ID                       */
+    int    *data    = NULL;            /* data buffer                      */
+    hsize_t dims[1] = {0};             /* size of dataset                  */
+    int     i;                         /* iterator                         */
 
     /* Open the dataset and check size */
     if ((did = H5Dopen2(fid, dset_name, H5P_DEFAULT)) < 0)
@@ -77,7 +71,7 @@ dset_ok(hid_t fid, const char *dset_name)
         goto error;
 
     /* Read the data */
-    if (NULL == (data = (int *)HDcalloc((size_t)NELEMENTS, sizeof(int))))
+    if (NULL == (data = (int *)calloc((size_t)NELEMENTS, sizeof(int))))
         goto error;
     if (H5Dread(did, H5T_NATIVE_INT, sid, sid, H5P_DEFAULT, data) < 0)
         goto error;
@@ -90,9 +84,9 @@ dset_ok(hid_t fid, const char *dset_name)
     if (H5Dclose(did) < 0)
         goto error;
 
-    HDfree(data);
+    free(data);
 
-    return TRUE;
+    return true;
 
 error:
     H5E_BEGIN_TRY
@@ -100,11 +94,11 @@ error:
         H5Sclose(sid);
         H5Dclose(did);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
-    HDfree(data);
+    free(data);
 
-    return FALSE;
+    return false;
 } /* end dset_ok() */
 
 /*-------------------------------------------------------------------------
@@ -112,21 +106,18 @@ error:
  *
  * Purpose:     Checks that the contents of a file are what they should be.
  *
- * Return:      TRUE/FALSE
- *
- * Programmer:	Leon Arber
- *              Sept. 26, 2006.
+ * Return:      true/false
  *
  *-------------------------------------------------------------------------
  */
-static hbool_t
-file_ok(const char *filename, hid_t fapl_id, hbool_t check_second_dset)
+static bool
+file_ok(const char *filename, hid_t fapl_id, bool check_second_dset)
 {
-    hid_t fid     = -1;   /* file ID                          */
-    hid_t top_gid = -1;   /* containing group ID              */
-    hid_t gid     = -1;   /* subgroup ID                      */
-    char  group_name[32]; /* group name                       */
-    int   i;              /* iterator                         */
+    hid_t fid     = H5I_INVALID_HID; /* file ID                          */
+    hid_t top_gid = H5I_INVALID_HID; /* containing group ID              */
+    hid_t gid     = H5I_INVALID_HID; /* subgroup ID                      */
+    char  group_name[32];            /* group name                       */
+    int   i;                         /* iterator                         */
 
     /* open file */
     if ((fid = H5Fopen(filename, H5F_ACC_RDONLY, fapl_id)) < 0)
@@ -143,7 +134,7 @@ file_ok(const char *filename, hid_t fapl_id, hbool_t check_second_dset)
     if ((top_gid = H5Gopen2(fid, "top_group", H5P_DEFAULT)) < 0)
         goto error;
     for (i = 0; i < NGROUPS; i++) {
-        HDsprintf(group_name, "group%02d", i);
+        snprintf(group_name, sizeof(group_name), "group%02d", i);
         if ((gid = H5Gopen2(top_gid, group_name, H5P_DEFAULT)) < 0)
             goto error;
         if (H5Gclose(gid) < 0)
@@ -155,7 +146,7 @@ file_ok(const char *filename, hid_t fapl_id, hbool_t check_second_dset)
     if (H5Fclose(fid) < 0)
         goto error;
 
-    return TRUE;
+    return true;
 
 error:
     H5E_BEGIN_TRY
@@ -164,9 +155,9 @@ error:
         H5Gclose(gid);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
-    return FALSE;
+    return false;
 } /* end file_ok() */
 
 /*-------------------------------------------------------------------------
@@ -177,17 +168,14 @@ error:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              July 2013
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
 clear_status_flags(const char *filename, hid_t fapl_id)
 {
-    hid_t   new_fapl_id = -1; /* copy of the file access plist ID */
-    hid_t   fid         = -1; /* file ID                          */
-    hbool_t clear       = TRUE;
+    hid_t new_fapl_id = H5I_INVALID_HID; /* copy of the file access plist ID */
+    hid_t fid         = H5I_INVALID_HID; /* file ID                          */
+    bool  clear       = true;
 
     /* Get a copy of fapl */
     if ((new_fapl_id = H5Pcopy(fapl_id)) < 0)
@@ -217,7 +205,7 @@ error:
         H5Pclose(new_fapl_id);
         H5Fclose(fid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return FAIL;
 } /* end clear_status_flags() */
@@ -230,78 +218,86 @@ error:
  *
  * Return:      EXIT_SUCCESS/EXIT_FAILURE
  *
- * Programmer:	Robb Matzke
- *              Friday, October 23, 1998
- *
  *-------------------------------------------------------------------------
  */
 int
 main(void)
 {
-    char       *driver = NULL;     /* name of current VFD (from env var)       */
-    hbool_t     vfd_supports_swmr; /* whether the current VFD supports SWMR    */
-    hid_t       fapl_id = -1;      /* file access proplist ID                  */
-    char        filename[1024];    /* filename                                 */
-    hbool_t     check_second_dset; /* whether or not to check the second dset  */
-    H5E_auto2_t func;              /* for shutting off error reporting         */
+    const char *driver_name;               /* name of current VFD (from env var)       */
+    bool        vfd_supports_swmr;         /* whether the current VFD supports SWMR    */
+    hid_t       fapl_id = H5I_INVALID_HID; /* file access proplist ID                  */
+    char        filename[1024];            /* filename                                 */
+    bool        check_second_dset;         /* whether or not to check the second dset  */
+    H5E_auto2_t func;                      /* for shutting off error reporting         */
+    bool        driver_is_default_vfd_compatible;
 
-    h5_reset();
+    h5_test_init();
     if ((fapl_id = h5_fileaccess()) < 0)
-        PUTS_ERROR("bad vfd-dependent fapl")
+        PUTS_ERROR("bad vfd-dependent fapl");
 
     /* Check if the current VFD supports SWMR */
-    driver            = HDgetenv("HDF5_DRIVER");
-    vfd_supports_swmr = H5FD__supports_swmr_test(driver);
+    driver_name       = h5_get_test_driver_name();
+    vfd_supports_swmr = H5FD__supports_swmr_test(driver_name);
+
+    if (h5_driver_is_default_vfd_compatible(fapl_id, &driver_is_default_vfd_compatible) < 0) {
+        printf("Can't check if VFD is compatible with default VFD\n");
+        exit(EXIT_FAILURE);
+    }
+
+    if (!driver_is_default_vfd_compatible) {
+        printf("Skipping SWMR tests for VFD incompatible with default VFD\n");
+        exit(EXIT_SUCCESS);
+    }
 
     /* TEST 1 */
     /* Check the case where the file was flushed */
     TESTING("H5Fflush (part2 with flush)");
     h5_fixname(FILENAME[0], fapl_id, filename, sizeof(filename));
-    check_second_dset = FALSE;
+    check_second_dset = false;
     if (file_ok(filename, fapl_id, check_second_dset))
         PASSED();
     else
-        TEST_ERROR
+        TEST_ERROR;
 
     /* TEST 2 */
     /* Check the case where the file was flushed (w/SWMR) */
     TESTING("H5Fflush (part2 with flush + SWMR)");
     if (vfd_supports_swmr) {
         h5_fixname(FILENAME[1], fapl_id, filename, sizeof(filename));
-        check_second_dset = FALSE;
+        check_second_dset = false;
         if (clear_status_flags(filename, fapl_id) < 0)
-            TEST_ERROR
+            TEST_ERROR;
         if (file_ok(filename, fapl_id, check_second_dset))
             PASSED();
         else
-            TEST_ERROR
+            TEST_ERROR;
     } /* end if */
     else
-        SKIPPED()
+        SKIPPED();
 
     /* TEST 3 */
     /* Check the case where the file was not flushed */
     TESTING("H5Fflush (part2 without flush)");
     /* Turn the error stack off (failures expected) */
     if (H5Eget_auto2(H5E_DEFAULT, &func, NULL) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Eset_auto2(H5E_DEFAULT, NULL, NULL) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     h5_fixname(FILENAME[2], fapl_id, filename, sizeof(filename));
-    check_second_dset = FALSE;
+    check_second_dset = false;
     if (file_ok(filename, fapl_id, check_second_dset)) {
 #if defined H5_HAVE_WIN32_API && !defined(hdf5_EXPORTS)
         SKIPPED();
-        HDputs("   the DLL will flush the file even when calling _exit, skip this test temporarily");
+        puts("   the DLL will flush the file even when calling _exit, skip this test temporarily");
 #else
-        TEST_ERROR
+        TEST_ERROR;
 #endif
     } /* end if */
     else
         PASSED();
     /* Turn the error stack back on */
     if (H5Eset_auto2(H5E_DEFAULT, func, NULL) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* TEST 4 */
     /* Check the case where the file was not flushed (w/SWMR) */
@@ -309,41 +305,41 @@ main(void)
     if (vfd_supports_swmr) {
         /* Turn the error stack off (failures expected) */
         if (H5Eget_auto2(H5E_DEFAULT, &func, NULL) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
         if (H5Eset_auto2(H5E_DEFAULT, NULL, NULL) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
         h5_fixname(FILENAME[3], fapl_id, filename, sizeof(filename));
-        check_second_dset = FALSE;
+        check_second_dset = false;
         if (clear_status_flags(filename, fapl_id) < 0)
-            TEST_ERROR
+            TEST_ERROR;
         if (file_ok(filename, fapl_id, check_second_dset)) {
 #if defined H5_HAVE_WIN32_API && !defined(hdf5_EXPORTS)
             SKIPPED();
-            HDputs("   the DLL will flush the file even when calling _exit, skip this test temporarily");
+            puts("   the DLL will flush the file even when calling _exit, skip this test temporarily");
 #else
-            TEST_ERROR
+            TEST_ERROR;
 #endif
         } /* end if */
         else
             PASSED();
         /* Turn the error stack back on */
         if (H5Eset_auto2(H5E_DEFAULT, func, NULL) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
     } /* end if */
     else
-        SKIPPED()
+        SKIPPED();
 
     /* TEST 5 */
     /* Check the case where the file was flushed, but more data was
      * added afterward and then flushed
      */
     TESTING("H5Fflush (part2 with flush and later addition and another flush)");
-    check_second_dset = TRUE;
+    check_second_dset = true;
     h5_fixname(FILENAME[4], fapl_id, filename, sizeof(filename));
     if (file_ok(filename, fapl_id, check_second_dset))
         PASSED();
     else
-        TEST_ERROR
+        TEST_ERROR;
 
     /* TEST 6 */
     /* Check the case where the file was flushed, but more data was
@@ -351,17 +347,17 @@ main(void)
      */
     TESTING("H5Fflush (part2 with flush and later addition and another flush + SWMR)");
     if (vfd_supports_swmr) {
-        check_second_dset = TRUE;
+        check_second_dset = true;
         h5_fixname(FILENAME[5], fapl_id, filename, sizeof(filename));
         if (clear_status_flags(filename, fapl_id) < 0)
-            TEST_ERROR
+            TEST_ERROR;
         if (file_ok(filename, fapl_id, check_second_dset))
             PASSED();
         else
-            TEST_ERROR
+            TEST_ERROR;
     } /* end if */
     else
-        SKIPPED()
+        SKIPPED();
 
     /* TEST 7 */
     /* Check the case where the file was flushed, but more data was added
@@ -370,24 +366,24 @@ main(void)
     TESTING("H5Fflush (part2 with flush and later addition)");
     /* Turn the error stack off (failures expected) */
     if (H5Eget_auto2(H5E_DEFAULT, &func, NULL) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     if (H5Eset_auto2(H5E_DEFAULT, NULL, NULL) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
     h5_fixname(FILENAME[6], fapl_id, filename, sizeof(filename));
-    check_second_dset = TRUE;
+    check_second_dset = true;
     if (file_ok(filename, fapl_id, check_second_dset)) {
 #if defined H5_HAVE_WIN32_API && !defined(hdf5_EXPORTS)
-        SKIPPED()
-        HDputs("   the DLL will flush the file even when calling _exit, skip this test temporarily");
+        SKIPPED();
+        puts("   the DLL will flush the file even when calling _exit, skip this test temporarily");
 #else
-        TEST_ERROR
+        TEST_ERROR;
 #endif
     } /* end if */
     else
         PASSED();
     /* Turn the error stack back on */
     if (H5Eset_auto2(H5E_DEFAULT, func, NULL) < 0)
-        FAIL_STACK_ERROR
+        FAIL_STACK_ERROR;
 
     /* TEST 8 */
     /* Check the case where the file was flushed, but more data was added
@@ -397,37 +393,37 @@ main(void)
     if (vfd_supports_swmr) {
         /* Turn the error stack off (failures expected) */
         if (H5Eget_auto2(H5E_DEFAULT, &func, NULL) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
         if (H5Eset_auto2(H5E_DEFAULT, NULL, NULL) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
         h5_fixname(FILENAME[7], fapl_id, filename, sizeof(filename));
-        check_second_dset = TRUE;
+        check_second_dset = true;
         if (clear_status_flags(filename, fapl_id) < 0)
-            TEST_ERROR
+            TEST_ERROR;
         if (file_ok(filename, fapl_id, check_second_dset)) {
 #if defined H5_HAVE_WIN32_API && !defined(hdf5_EXPORTS)
             SKIPPED();
-            HDputs("   the DLL will flush the file even when calling _exit, skip this test temporarily");
+            puts("   the DLL will flush the file even when calling _exit, skip this test temporarily");
 #else
-            TEST_ERROR
+            TEST_ERROR;
 #endif
         } /* end if */
         else
             PASSED();
         /* Turn the error stack back on */
         if (H5Eset_auto2(H5E_DEFAULT, func, NULL) < 0)
-            FAIL_STACK_ERROR
+            FAIL_STACK_ERROR;
     } /* end if */
     else
-        SKIPPED()
+        SKIPPED();
 
     if (!vfd_supports_swmr)
-        HDprintf("NOTE: Some tests were skipped since the current VFD lacks SWMR support\n");
+        printf("NOTE: Some tests were skipped since the current VFD lacks SWMR support\n");
 
     h5_cleanup(FILENAME, fapl_id);
 
-    HDexit(EXIT_SUCCESS);
+    exit(EXIT_SUCCESS);
 
 error:
-    HDexit(EXIT_FAILURE);
+    exit(EXIT_FAILURE);
 } /* end main() */
