@@ -161,6 +161,9 @@ create_symbol_datatype(void)
  *              Buffer for the created name.  Must be pre-allocated.
  *              Since the name is formulaic, this isn't considered an issue.
  *
+ *              size_t name_buf_length
+ *              The length in bytes of the name_buf buffer
+ *
  *              unsigned level
  *              The dataset's level
  *
@@ -174,11 +177,11 @@ create_symbol_datatype(void)
  *-------------------------------------------------------------------------
  */
 int
-generate_name(char *name_buf, unsigned level, unsigned count)
+generate_name(char *name_buf, size_t name_buf_length, unsigned level, unsigned count)
 {
-    HDassert(name_buf);
+    assert(name_buf);
 
-    HDsprintf(name_buf, "%u-%04u", level, count);
+    snprintf(name_buf, name_buf_length, "%u-%04u", level, count);
 
     return 0;
 } /* end generate_name() */
@@ -201,13 +204,12 @@ generate_symbols(void)
     unsigned u, v; /* Local index variables */
 
     for (u = 0; u < NLEVELS; u++) {
-        symbol_info[u] = (symbol_info_t *)HDmalloc(symbol_count[u] * sizeof(symbol_info_t));
+        symbol_info[u] = malloc(symbol_count[u] * sizeof(symbol_info_t));
         for (v = 0; v < symbol_count[u]; v++) {
             char name_buf[64];
 
-            generate_name(name_buf, u, v);
-            symbol_info[u][v].name = (char *)HDmalloc(HDstrlen(name_buf) + 1);
-            HDstrcpy(symbol_info[u][v].name, name_buf);
+            generate_name(name_buf, sizeof(name_buf), u, v);
+            symbol_info[u][v].name     = strdup(name_buf);
             symbol_info[u][v].dsid     = -1;
             symbol_info[u][v].nrecords = 0;
         } /* end for */
@@ -236,8 +238,8 @@ shutdown_symbols(void)
     /* Clean up the symbols */
     for (u = 0; u < NLEVELS; u++) {
         for (v = 0; v < symbol_count[u]; v++)
-            HDfree(symbol_info[u][v].name);
-        HDfree(symbol_info[u]);
+            free(symbol_info[u][v].name);
+        free(symbol_info[u]);
     } /* end for */
 
     return 0;
@@ -273,12 +275,12 @@ print_metadata_retries_info(hid_t fid)
         if (NULL == info.retries[i])
             continue;
 
-        HDfprintf(stderr, "Metadata read retries for item %u:\n", i);
+        fprintf(stderr, "Metadata read retries for item %u:\n", i);
         power = 1;
         for (j = 0; j < info.nbins; j++) {
             if (info.retries[i][j])
-                HDfprintf(stderr, "\t# of retries for %u - %u retries: %u\n", power, (power * 10) - 1,
-                          info.retries[i][j]);
+                fprintf(stderr, "\t# of retries for %u - %u retries: %u\n", power, (power * 10) - 1,
+                        info.retries[i][j]);
             power *= 10;
         } /* end for */
     }     /* end for */
