@@ -39,22 +39,22 @@
 
 /* Property definitions */
 #define PROP1_NAME "Property 1"
-int prop1_def = 10; /* Property 1 default value */
+static int prop1_def = 10; /* Property 1 default value */
 #define PROP1_SIZE      sizeof(prop1_def)
 #define PROP1_DEF_VALUE (&prop1_def)
 
 #define PROP2_NAME "Property 2"
-float prop2_def = 3.14F; /* Property 2 default value */
+static float prop2_def = 3.14F; /* Property 2 default value */
 #define PROP2_SIZE      sizeof(prop2_def)
 #define PROP2_DEF_VALUE (&prop2_def)
 
 #define PROP3_NAME "Property 3"
-char prop3_def[10] = "Ten chars"; /* Property 3 default value */
+static char prop3_def[10] = "Ten chars"; /* Property 3 default value */
 #define PROP3_SIZE      sizeof(prop3_def)
 #define PROP3_DEF_VALUE (&prop3_def)
 
 #define PROP4_NAME "Property 4"
-double prop4_def = 1.41; /* Property 4 default value */
+static double prop4_def = 1.41; /* Property 4 default value */
 #define PROP4_SIZE      sizeof(prop4_def)
 #define PROP4_DEF_VALUE (&prop4_def)
 
@@ -94,7 +94,7 @@ test_genprop_basic_class(void)
     /* Check class name */
     name = H5Pget_class_name(cid1);
     CHECK_PTR(name, "H5Pget_class_name");
-    if (HDstrcmp(name, CLASS1_NAME) != 0)
+    if (strcmp(name, CLASS1_NAME) != 0)
         TestErrPrintf("Class names don't match!, name=%s, CLASS1_NAME=%s\n", name, CLASS1_NAME);
     H5free_memory(name);
 
@@ -125,7 +125,7 @@ test_genprop_basic_class(void)
     /* Check class name */
     name = H5Pget_class_name(cid1);
     CHECK_PTR(name, "H5Pget_class_name");
-    if (HDstrcmp(name, CLASS2_NAME) != 0)
+    if (strcmp(name, CLASS2_NAME) != 0)
         TestErrPrintf("Class names don't match!, name=%s, CLASS2_NAME=%s\n", name, CLASS2_NAME);
     H5free_memory(name);
 
@@ -194,8 +194,12 @@ test_genprop_basic_class_prop(void)
     CHECK_I(ret, "H5Pregister2");
 
     /* Try to insert the first property again (should fail) */
-    ret =
-        H5Pregister2(cid1, PROP1_NAME, PROP1_SIZE, PROP1_DEF_VALUE, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+    H5E_BEGIN_TRY
+    {
+        ret = H5Pregister2(cid1, PROP1_NAME, PROP1_SIZE, PROP1_DEF_VALUE, NULL, NULL, NULL, NULL, NULL, NULL,
+                           NULL);
+    }
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Pregister2");
 
     /* Check the existence of the first property */
@@ -218,8 +222,12 @@ test_genprop_basic_class_prop(void)
     CHECK_I(ret, "H5Pregister2");
 
     /* Try to insert the second property again (should fail) */
-    ret =
-        H5Pregister2(cid1, PROP2_NAME, PROP2_SIZE, PROP2_DEF_VALUE, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+    H5E_BEGIN_TRY
+    {
+        ret = H5Pregister2(cid1, PROP2_NAME, PROP2_SIZE, PROP2_DEF_VALUE, NULL, NULL, NULL, NULL, NULL, NULL,
+                           NULL);
+    }
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Pregister2");
 
     /* Check the existence of the second property */
@@ -260,7 +268,11 @@ test_genprop_basic_class_prop(void)
     CHECK_I(ret, "H5Punregister");
 
     /* Try to check the size of the first property (should fail) */
-    ret = H5Pget_size(cid1, PROP1_NAME, &size);
+    H5E_BEGIN_TRY
+    {
+        ret = H5Pget_size(cid1, PROP1_NAME, &size);
+    }
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Pget_size");
 
     /* Check the number of properties in class */
@@ -301,7 +313,7 @@ test_genprop_iter1(hid_t H5_ATTR_UNUSED id, const char *name, void *iter_data)
 {
     iter_data_t *idata = (iter_data_t *)iter_data;
 
-    return HDstrcmp(name, idata->names[idata->iter_count++]);
+    return strcmp(name, idata->names[idata->iter_count++]);
 }
 
 /****************************************************************
@@ -401,9 +413,9 @@ test_genprop_cls_cpy_cb1(hid_t new_list_id, hid_t H5_ATTR_UNUSED old_list_id, vo
 }
 
 static herr_t
-test_genprop_cls_cls_cb1(hid_t list_id, void *create_data)
+test_genprop_cls_cls_cb1(hid_t list_id, void *close_data)
 {
-    count_data_t *cdata = (count_data_t *)create_data;
+    count_data_t *cdata = (count_data_t *)close_data;
 
     cdata->count++;
     cdata->id = list_id;
@@ -691,8 +703,8 @@ test_genprop_basic_list(void)
     CHECK_I(ret, "H5Pget");
     /* Verify the floating-poing value in this way to avoid compiler warning. */
     if (!H5_FLT_ABS_EQUAL(prop2_value, *PROP2_DEF_VALUE))
-        HDprintf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
-                 (double)*PROP2_DEF_VALUE, (double)prop2_value, (int)__LINE__, __FILE__);
+        printf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
+               (double)*PROP2_DEF_VALUE, (double)prop2_value, (int)__LINE__, __FILE__);
 
     /* Close list */
     ret = H5Pclose(lid1);
@@ -784,20 +796,20 @@ test_genprop_basic_list_prop(void)
     CHECK_I(ret, "H5Pget");
     /* Verify the floating-poing value in this way to avoid compiler warning. */
     if (!H5_FLT_ABS_EQUAL(prop2_value, *PROP2_DEF_VALUE))
-        HDprintf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
-                 (double)*PROP2_DEF_VALUE, (double)prop2_value, (int)__LINE__, __FILE__);
+        printf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
+               (double)*PROP2_DEF_VALUE, (double)prop2_value, (int)__LINE__, __FILE__);
 
     /* Check values of temporary properties (set with regular values) */
     ret = H5Pget(lid1, PROP3_NAME, &prop3_value);
     CHECK_I(ret, "H5Pget");
-    if (HDmemcmp(&prop3_value, PROP3_DEF_VALUE, PROP3_SIZE) != 0)
+    if (memcmp(&prop3_value, PROP3_DEF_VALUE, PROP3_SIZE) != 0)
         TestErrPrintf("Property #3 doesn't match!, line=%d\n", __LINE__);
     ret = H5Pget(lid1, PROP4_NAME, &prop4_value);
     CHECK_I(ret, "H5Pget");
     /* Verify the floating-poing value in this way to avoid compiler warning. */
     if (!H5_DBL_ABS_EQUAL(prop4_value, *PROP4_DEF_VALUE))
-        HDprintf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
-                 *PROP4_DEF_VALUE, prop4_value, (int)__LINE__, __FILE__);
+        printf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
+               *PROP4_DEF_VALUE, prop4_value, (int)__LINE__, __FILE__);
 
     /* Delete permanent property */
     ret = H5Premove(lid1, PROP2_NAME);
@@ -833,8 +845,8 @@ test_genprop_basic_list_prop(void)
     CHECK_I(ret, "H5Pget");
     /* Verify the floating-poing value in this way to avoid compiler warning. */
     if (!H5_DBL_ABS_EQUAL(prop4_value, *PROP4_DEF_VALUE))
-        HDprintf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
-                 *PROP4_DEF_VALUE, prop4_value, (int)__LINE__, __FILE__);
+        printf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
+               *PROP4_DEF_VALUE, prop4_value, (int)__LINE__, __FILE__);
 
     /* Close list */
     ret = H5Pclose(lid1);
@@ -856,7 +868,7 @@ test_genprop_iter2(hid_t H5_ATTR_UNUSED id, const char *name, void *iter_data)
 {
     iter_data_t *idata = (iter_data_t *)iter_data;
 
-    return HDstrcmp(name, idata->names[idata->iter_count++]);
+    return strcmp(name, idata->names[idata->iter_count++]);
 }
 
 /****************************************************************
@@ -984,9 +996,9 @@ typedef struct {
 } prop_cb_info;
 
 /* Global variables for Callback information */
-prop_cb_info prop1_cb_info; /* Callback statistics for property #1 */
-prop_cb_info prop2_cb_info; /* Callback statistics for property #2 */
-prop_cb_info prop3_cb_info; /* Callback statistics for property #3 */
+static prop_cb_info prop1_cb_info; /* Callback statistics for property #1 */
+static prop_cb_info prop2_cb_info; /* Callback statistics for property #2 */
+static prop_cb_info prop3_cb_info; /* Callback statistics for property #3 */
 
 /****************************************************************
 **
@@ -994,9 +1006,9 @@ prop_cb_info prop3_cb_info; /* Callback statistics for property #3 */
 **
 ****************************************************************/
 static herr_t
-test_genprop_cls_cpy_cb2(hid_t new_list_id, hid_t H5_ATTR_UNUSED old_list_id, void *create_data)
+test_genprop_cls_cpy_cb2(hid_t new_list_id, hid_t H5_ATTR_UNUSED old_list_id, void *copy_data)
 {
-    count_data_t *cdata = (count_data_t *)create_data;
+    count_data_t *cdata = (count_data_t *)copy_data;
 
     cdata->count++;
     cdata->id = new_list_id;
@@ -1014,9 +1026,9 @@ test_genprop_prop_crt_cb1(const char *name, size_t size, void *def_value)
 {
     /* Set the information from the creation call */
     prop1_cb_info.crt_count++;
-    prop1_cb_info.crt_name  = HDstrdup(name);
-    prop1_cb_info.crt_value = HDmalloc(size);
-    HDmemcpy(prop1_cb_info.crt_value, def_value, size);
+    prop1_cb_info.crt_name  = strdup(name);
+    prop1_cb_info.crt_value = malloc(size);
+    memcpy(prop1_cb_info.crt_value, def_value, size);
 
     return (SUCCEED);
 }
@@ -1033,10 +1045,10 @@ test_genprop_prop_set_cb1(hid_t plist_id, const char *name, size_t size, void *v
     prop1_cb_info.set_count++;
     prop1_cb_info.set_plist_id = plist_id;
     if (prop1_cb_info.set_name == NULL)
-        prop1_cb_info.set_name = HDstrdup(name);
+        prop1_cb_info.set_name = strdup(name);
     if (prop1_cb_info.set_value == NULL)
-        prop1_cb_info.set_value = HDmalloc(size);
-    HDmemcpy(prop1_cb_info.set_value, value, size);
+        prop1_cb_info.set_value = malloc(size);
+    memcpy(prop1_cb_info.set_value, value, size);
 
     return (SUCCEED);
 }
@@ -1053,10 +1065,10 @@ test_genprop_prop_get_cb1(hid_t plist_id, const char *name, size_t size, void *v
     prop1_cb_info.get_count++;
     prop1_cb_info.get_plist_id = plist_id;
     if (prop1_cb_info.get_name == NULL)
-        prop1_cb_info.get_name = HDstrdup(name);
+        prop1_cb_info.get_name = strdup(name);
     if (prop1_cb_info.get_value == NULL)
-        prop1_cb_info.get_value = HDmalloc(size);
-    HDmemcpy(prop1_cb_info.get_value, value, size);
+        prop1_cb_info.get_value = malloc(size);
+    memcpy(prop1_cb_info.get_value, value, size);
 
     return (SUCCEED);
 }
@@ -1072,10 +1084,10 @@ test_genprop_prop_cop_cb1(const char *name, size_t size, void *value)
     /* Set the information from the get call */
     prop1_cb_info.cop_count++;
     if (prop1_cb_info.cop_name == NULL)
-        prop1_cb_info.cop_name = HDstrdup(name);
+        prop1_cb_info.cop_name = strdup(name);
     if (prop1_cb_info.cop_value == NULL)
-        prop1_cb_info.cop_value = HDmalloc(size);
-    HDmemcpy(prop1_cb_info.cop_value, value, size);
+        prop1_cb_info.cop_value = malloc(size);
+    memcpy(prop1_cb_info.cop_value, value, size);
 
     return (SUCCEED);
 }
@@ -1091,7 +1103,7 @@ test_genprop_prop_cmp_cb1(const void *value1, const void *value2, size_t size)
     /* Set the information from the comparison call */
     prop1_cb_info.cmp_count++;
 
-    return (HDmemcmp(value1, value2, size));
+    return (memcmp(value1, value2, size));
 }
 
 /****************************************************************
@@ -1105,7 +1117,7 @@ test_genprop_prop_cmp_cb3(const void *value1, const void *value2, size_t size)
     /* Set the information from the comparison call */
     prop3_cb_info.cmp_count++;
 
-    return (HDmemcmp(value1, value2, size));
+    return (memcmp(value1, value2, size));
 }
 
 /****************************************************************
@@ -1119,10 +1131,10 @@ test_genprop_prop_cls_cb1(const char *name, size_t size, void *value)
     /* Set the information from the close call */
     prop1_cb_info.cls_count++;
     if (prop1_cb_info.cls_name == NULL)
-        prop1_cb_info.cls_name = HDstrdup(name);
+        prop1_cb_info.cls_name = strdup(name);
     if (prop1_cb_info.cls_value == NULL)
-        prop1_cb_info.cls_value = HDmalloc(size);
-    HDmemcpy(prop1_cb_info.cls_value, value, size);
+        prop1_cb_info.cls_value = malloc(size);
+    memcpy(prop1_cb_info.cls_value, value, size);
 
     return (SUCCEED);
 }
@@ -1138,9 +1150,9 @@ test_genprop_prop_del_cb2(hid_t plist_id, const char *name, size_t size, void *v
     /* Set the information from the delete call */
     prop2_cb_info.del_count++;
     prop2_cb_info.del_plist_id = plist_id;
-    prop2_cb_info.del_name     = HDstrdup(name);
-    prop2_cb_info.del_value    = HDmalloc(size);
-    HDmemcpy(prop2_cb_info.del_value, value, size);
+    prop2_cb_info.del_name     = strdup(name);
+    prop2_cb_info.del_value    = malloc(size);
+    memcpy(prop2_cb_info.del_value, value, size);
 
     return (SUCCEED);
 }
@@ -1209,9 +1221,9 @@ test_genprop_list_callback(void)
     cop_cb_struct.id    = (-1);
 
     /* Initialize callback information for properties tracked */
-    HDmemset(&prop1_cb_info, 0, sizeof(prop_cb_info));
-    HDmemset(&prop2_cb_info, 0, sizeof(prop_cb_info));
-    HDmemset(&prop3_cb_info, 0, sizeof(prop_cb_info));
+    memset(&prop1_cb_info, 0, sizeof(prop_cb_info));
+    memset(&prop2_cb_info, 0, sizeof(prop_cb_info));
+    memset(&prop3_cb_info, 0, sizeof(prop_cb_info));
 
     /* Create a property list from the class */
     lid1 = H5Pcreate(cid1);
@@ -1226,9 +1238,9 @@ test_genprop_list_callback(void)
 
     /* Verify creation callback information for properties tracked */
     VERIFY(prop1_cb_info.crt_count, 1, "H5Pcreate");
-    if (HDstrcmp(prop1_cb_info.crt_name, PROP1_NAME) != 0)
+    if (strcmp(prop1_cb_info.crt_name, PROP1_NAME) != 0)
         TestErrPrintf("Property #1 name doesn't match!, line=%d\n", __LINE__);
-    if (HDmemcmp(prop1_cb_info.crt_value, PROP1_DEF_VALUE, PROP1_SIZE) != 0)
+    if (memcmp(prop1_cb_info.crt_value, PROP1_DEF_VALUE, PROP1_SIZE) != 0)
         TestErrPrintf("Property #1 value doesn't match!, line=%d\n", __LINE__);
 
     /* Check values of permanent properties (set with default values) */
@@ -1241,13 +1253,13 @@ test_genprop_list_callback(void)
     CHECK_I(ret, "H5Pget");
     /* Verify the floating-poing value in this way to avoid compiler warning. */
     if (!H5_FLT_ABS_EQUAL(prop2_value, *PROP2_DEF_VALUE))
-        HDprintf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
-                 (double)*PROP2_DEF_VALUE, (double)prop2_value, (int)__LINE__, __FILE__);
+        printf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
+               (double)*PROP2_DEF_VALUE, (double)prop2_value, (int)__LINE__, __FILE__);
 
     /* Check values of temporary properties (set with regular values) */
     ret = H5Pget(lid1, PROP3_NAME, &prop3_value);
     CHECK_I(ret, "H5Pget");
-    if (HDmemcmp(&prop3_value, PROP3_DEF_VALUE, PROP3_SIZE) != 0)
+    if (memcmp(&prop3_value, PROP3_DEF_VALUE, PROP3_SIZE) != 0)
         TestErrPrintf("Property #3 doesn't match!, line=%d\n", __LINE__);
     /* The compare callback should not have been called, as there is no get
      * callback for this property */
@@ -1256,15 +1268,15 @@ test_genprop_list_callback(void)
     CHECK_I(ret, "H5Pget");
     /* Verify the floating-poing value in this way to avoid compiler warning. */
     if (!H5_DBL_ABS_EQUAL(prop4_value, *PROP4_DEF_VALUE))
-        HDprintf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
-                 *PROP4_DEF_VALUE, prop4_value, (int)__LINE__, __FILE__);
+        printf("*** UNEXPECTED VALUE from %s should be %f, but is %f at line %4d in %s\n", "H5Pget",
+               *PROP4_DEF_VALUE, prop4_value, (int)__LINE__, __FILE__);
 
     /* Verify get callback information for properties tracked */
     VERIFY(prop1_cb_info.get_count, 1, "H5Pget");
     VERIFY(prop1_cb_info.get_plist_id, lid1, "H5Pget");
-    if (HDstrcmp(prop1_cb_info.get_name, PROP1_NAME) != 0)
+    if (strcmp(prop1_cb_info.get_name, PROP1_NAME) != 0)
         TestErrPrintf("Property #1 name doesn't match!, line=%d\n", __LINE__);
-    if (HDmemcmp(prop1_cb_info.get_value, PROP1_DEF_VALUE, PROP1_SIZE) != 0)
+    if (memcmp(prop1_cb_info.get_value, PROP1_DEF_VALUE, PROP1_SIZE) != 0)
         TestErrPrintf("Property #1 value doesn't match!, line=%d\n", __LINE__);
 
     /* Set value of property #1 to different value */
@@ -1274,9 +1286,9 @@ test_genprop_list_callback(void)
     /* Verify set callback information for properties tracked */
     VERIFY(prop1_cb_info.set_count, 1, "H5Pset");
     VERIFY(prop1_cb_info.set_plist_id, lid1, "H5Pset");
-    if (HDstrcmp(prop1_cb_info.set_name, PROP1_NAME) != 0)
+    if (strcmp(prop1_cb_info.set_name, PROP1_NAME) != 0)
         TestErrPrintf("Property #1 name doesn't match!, line=%d\n", __LINE__);
-    if (HDmemcmp(prop1_cb_info.set_value, &prop1_new_value, PROP1_SIZE) != 0)
+    if (memcmp(prop1_cb_info.set_value, &prop1_new_value, PROP1_SIZE) != 0)
         TestErrPrintf("Property #1 value doesn't match!, line=%d\n", __LINE__);
 
     /* The compare callback should not have been called  */
@@ -1297,9 +1309,9 @@ test_genprop_list_callback(void)
     /* Verify get callback information again for properties tracked */
     VERIFY(prop1_cb_info.get_count, 2, "H5Pget");
     VERIFY(prop1_cb_info.get_plist_id, lid1, "H5Pget");
-    if (HDstrcmp(prop1_cb_info.get_name, PROP1_NAME) != 0)
+    if (strcmp(prop1_cb_info.get_name, PROP1_NAME) != 0)
         TestErrPrintf("Property #1 name doesn't match!, line=%d\n", __LINE__);
-    if (HDmemcmp(prop1_cb_info.get_value, &prop1_new_value, PROP1_SIZE) != 0)
+    if (memcmp(prop1_cb_info.get_value, &prop1_new_value, PROP1_SIZE) != 0)
         TestErrPrintf("Property #1 value doesn't match!, line=%d\n", __LINE__);
 
     /* Delete property #2 */
@@ -1309,9 +1321,9 @@ test_genprop_list_callback(void)
     /* Verify delete callback information for properties tracked */
     VERIFY(prop2_cb_info.del_count, 1, "H5Premove");
     VERIFY(prop2_cb_info.del_plist_id, lid1, "H5Premove");
-    if (HDstrcmp(prop2_cb_info.del_name, PROP2_NAME) != 0)
+    if (strcmp(prop2_cb_info.del_name, PROP2_NAME) != 0)
         TestErrPrintf("Property #2 name doesn't match!, line=%d\n", __LINE__);
-    if (HDmemcmp(prop2_cb_info.del_value, PROP2_DEF_VALUE, PROP2_SIZE) != 0)
+    if (memcmp(prop2_cb_info.del_value, PROP2_DEF_VALUE, PROP2_SIZE) != 0)
         TestErrPrintf("Property #2 value doesn't match!, line=%d\n", __LINE__);
 
     /* Copy first list */
@@ -1320,9 +1332,9 @@ test_genprop_list_callback(void)
 
     /* Verify copy callback information for properties tracked */
     VERIFY(prop1_cb_info.cop_count, 1, "H5Pcopy");
-    if (HDstrcmp(prop1_cb_info.cop_name, PROP1_NAME) != 0)
+    if (strcmp(prop1_cb_info.cop_name, PROP1_NAME) != 0)
         TestErrPrintf("Property #1 name doesn't match!, line=%d\n", __LINE__);
-    if (HDmemcmp(prop1_cb_info.cop_value, &prop1_new_value, PROP1_SIZE) != 0)
+    if (memcmp(prop1_cb_info.cop_value, &prop1_new_value, PROP1_SIZE) != 0)
         TestErrPrintf("Property #1 value doesn't match!, line=%d\n", __LINE__);
 
     /* Verify that the class creation callback occurred */
@@ -1343,9 +1355,9 @@ test_genprop_list_callback(void)
 
     /* Verify close callback information for properties tracked */
     VERIFY(prop1_cb_info.cls_count, 1, "H5Pclose");
-    if (HDstrcmp(prop1_cb_info.cls_name, PROP1_NAME) != 0)
+    if (strcmp(prop1_cb_info.cls_name, PROP1_NAME) != 0)
         TestErrPrintf("Property #1 name doesn't match!, line=%d\n", __LINE__);
-    if (HDmemcmp(prop1_cb_info.cls_value, &prop1_new_value, PROP1_SIZE) != 0)
+    if (memcmp(prop1_cb_info.cls_value, &prop1_new_value, PROP1_SIZE) != 0)
         TestErrPrintf("Property #1 value doesn't match!, line=%d\n", __LINE__);
 
     /* Close second list */
@@ -1356,18 +1368,18 @@ test_genprop_list_callback(void)
     VERIFY(prop1_cb_info.cls_count, 2, "H5Pclose");
 
     /* Free memory allocated for tracking properties */
-    HDfree(prop1_cb_info.crt_name);
-    HDfree(prop1_cb_info.crt_value);
-    HDfree(prop1_cb_info.get_name);
-    HDfree(prop1_cb_info.get_value);
-    HDfree(prop1_cb_info.set_name);
-    HDfree(prop1_cb_info.set_value);
-    HDfree(prop1_cb_info.cop_name);
-    HDfree(prop1_cb_info.cop_value);
-    HDfree(prop1_cb_info.cls_name);
-    HDfree(prop1_cb_info.cls_value);
-    HDfree(prop2_cb_info.del_name);
-    HDfree(prop2_cb_info.del_value);
+    free(prop1_cb_info.crt_name);
+    free(prop1_cb_info.crt_value);
+    free(prop1_cb_info.get_name);
+    free(prop1_cb_info.get_value);
+    free(prop1_cb_info.set_name);
+    free(prop1_cb_info.set_value);
+    free(prop1_cb_info.cop_name);
+    free(prop1_cb_info.cop_value);
+    free(prop1_cb_info.cls_name);
+    free(prop1_cb_info.cls_value);
+    free(prop2_cb_info.del_name);
+    free(prop2_cb_info.del_value);
 
     /* Close class */
     ret = H5Pclose_class(cid1);
@@ -1797,7 +1809,7 @@ test_genprop_path(void)
     /* Get full path for first class */
     path = H5P__get_class_path_test(cid1);
     CHECK_PTR(path, "H5P__get_class_path_test");
-    if (HDstrcmp(path, CLASS1_PATH) != 0)
+    if (strcmp(path, CLASS1_PATH) != 0)
         TestErrPrintf("Class names don't match!, path=%s, CLASS1_PATH=%s\n", path, CLASS1_PATH);
     H5free_memory(path);
 
@@ -1813,7 +1825,7 @@ test_genprop_path(void)
     /* Get full path for second class */
     path = H5P__get_class_path_test(cid2);
     CHECK_PTR(path, "H5P__get_class_path_test");
-    if (HDstrcmp(path, CLASS2_PATH) != 0)
+    if (strcmp(path, CLASS2_PATH) != 0)
         TestErrPrintf("Class names don't match!, path=%s, CLASS2_PATH=%s\n", path, CLASS2_PATH);
 
     /* Open a copy of the class with the path name */
@@ -1874,7 +1886,7 @@ test_genprop_refcount(void)
     /* Check class name */
     name = H5Pget_class_name(cid1);
     CHECK_PTR(name, "H5Pget_class_name");
-    if (HDstrcmp(name, CLASS1_NAME) != 0)
+    if (strcmp(name, CLASS1_NAME) != 0)
         TestErrPrintf("Class names don't match!, name=%s, CLASS1_NAME=%s\n", name, CLASS1_NAME);
     H5free_memory(name);
 
@@ -1893,7 +1905,7 @@ test_genprop_refcount(void)
     /* Check class name */
     name = H5Pget_class_name(cid1);
     CHECK_PTR(name, "H5Pget_class_name");
-    if (HDstrcmp(name, CLASS1_NAME) != 0)
+    if (strcmp(name, CLASS1_NAME) != 0)
         TestErrPrintf("Class names don't match!, name=%s, CLASS1_NAME=%s\n", name, CLASS1_NAME);
     H5free_memory(name);
 
@@ -1904,7 +1916,7 @@ test_genprop_refcount(void)
     /* Check class name */
     name = H5Pget_class_name(cid1);
     CHECK_PTR(name, "H5Pget_class_name");
-    if (HDstrcmp(name, CLASS1_NAME) != 0)
+    if (strcmp(name, CLASS1_NAME) != 0)
         TestErrPrintf("Class names don't match!, name=%s, CLASS1_NAME=%s\n", name, CLASS1_NAME);
     H5free_memory(name);
 
@@ -1950,7 +1962,11 @@ test_genprop_deprec_class(void)
     CHECK_I(ret, "H5Pregister1");
 
     /* Try to insert the first property again (should fail) */
-    ret = H5Pregister1(cid1, PROP1_NAME, PROP1_SIZE, PROP1_DEF_VALUE, NULL, NULL, NULL, NULL, NULL, NULL);
+    H5E_BEGIN_TRY
+    {
+        ret = H5Pregister1(cid1, PROP1_NAME, PROP1_SIZE, PROP1_DEF_VALUE, NULL, NULL, NULL, NULL, NULL, NULL);
+    }
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Pregister1");
 
     /* Check the existence of the first property */
@@ -1972,7 +1988,11 @@ test_genprop_deprec_class(void)
     CHECK_I(ret, "H5Pregister1");
 
     /* Try to insert the second property again (should fail) */
-    ret = H5Pregister1(cid1, PROP2_NAME, PROP2_SIZE, PROP2_DEF_VALUE, NULL, NULL, NULL, NULL, NULL, NULL);
+    H5E_BEGIN_TRY
+    {
+        ret = H5Pregister1(cid1, PROP2_NAME, PROP2_SIZE, PROP2_DEF_VALUE, NULL, NULL, NULL, NULL, NULL, NULL);
+    }
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Pregister1");
 
     /* Check the existence of the second property */
@@ -2012,7 +2032,11 @@ test_genprop_deprec_class(void)
     CHECK_I(ret, "H5Punregister");
 
     /* Try to check the size of the first property (should fail) */
-    ret = H5Pget_size(cid1, PROP1_NAME, &size);
+    H5E_BEGIN_TRY
+    {
+        ret = H5Pget_size(cid1, PROP1_NAME, &size);
+    }
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Pget_size");
 
     /* Check the number of properties in class */
@@ -2161,15 +2185,14 @@ test_genprop(void)
  *
  * Return:    none
  *
- * Programmer:    Quincey Koziol
- *              June 8, 1999
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 void
 cleanup_genprop(void)
 {
-    HDremove(FILENAME);
+    H5E_BEGIN_TRY
+    {
+        H5Fdelete(FILENAME, H5P_DEFAULT);
+    }
+    H5E_END_TRY
 }
