@@ -49,7 +49,7 @@ typedef struct {
 } iter_info;
 
 /* Definition for test_corrupted_attnamelen */
-#define CORRUPTED_ATNAMELEN_FILE "corrupted_name_len.h5"
+#define CORRUPTED_ATNAMELEN_FILE "memleak_H5O_dtype_decode_helper_H5Odtype.h5"
 #define DSET_NAME                "image"
 typedef struct searched_err_t {
     char message[256];
@@ -62,8 +62,8 @@ static int find_err_msg_cb(unsigned n, const H5E_error2_t *err_desc, void *_clie
 /* Local functions */
 int           iter_strcmp(const void *s1, const void *s2);
 int           iter_strcmp2(const void *s1, const void *s2);
-static herr_t liter_cb(hid_t group, const char *name, const H5L_info_t *info, void *op_data);
-static herr_t liter_cb2(hid_t group, const char *name, const H5L_info_t *info, void *op_data);
+static herr_t liter_cb(hid_t group, const char *name, const H5L_info2_t *info, void *op_data);
+static herr_t liter_cb2(hid_t group, const char *name, const H5L_info2_t *info, void *op_data);
 herr_t        aiter_cb(hid_t group, const char *name, const H5A_info_t *ainfo, void *op_data);
 
 /****************************************************************
@@ -74,7 +74,7 @@ herr_t        aiter_cb(hid_t group, const char *name, const H5A_info_t *ainfo, v
 H5_ATTR_PURE int
 iter_strcmp(const void *s1, const void *s2)
 {
-    return (HDstrcmp(*(const char *const *)s1, *(const char *const *)s2));
+    return (strcmp(*(const char *const *)s1, *(const char *const *)s2));
 }
 
 /****************************************************************
@@ -83,14 +83,21 @@ iter_strcmp(const void *s1, const void *s2)
 **
 ****************************************************************/
 static herr_t
-liter_cb(hid_t H5_ATTR_UNUSED group, const char *name, const H5L_info_t H5_ATTR_UNUSED *link_info,
+liter_cb(hid_t H5_ATTR_UNUSED group, const char *name, const H5L_info2_t H5_ATTR_UNUSED *link_info,
          void *op_data)
 {
     iter_info *info   = (iter_info *)op_data;
     static int count  = 0;
     static int count2 = 0;
 
-    HDstrcpy(info->name, name);
+    if (!(vol_cap_flags_g & H5VL_CAP_FLAG_ITERATE)) {
+        SKIPPED();
+        printf("    API functions for iterate aren't "
+               "supported with this connector\n");
+        return 1;
+    }
+
+    strcpy(info->name, name);
 
     switch (info->command) {
         case RET_ZERO:
@@ -108,7 +115,7 @@ liter_cb(hid_t H5_ATTR_UNUSED group, const char *name, const H5L_info_t H5_ATTR_
             return (count2 > 10 ? 1 : 0);
 
         default:
-            HDprintf("invalid iteration command");
+            printf("invalid iteration command");
             return (-1);
     } /* end switch */
 } /* end liter_cb() */
@@ -119,7 +126,7 @@ liter_cb(hid_t H5_ATTR_UNUSED group, const char *name, const H5L_info_t H5_ATTR_
 **
 ****************************************************************/
 static void
-test_iter_group(hid_t fapl, hbool_t new_format)
+test_iter_group(hid_t fapl, bool new_format)
 {
     hid_t      file;                  /* File ID */
     hid_t      dataset;               /* Dataset ID */
@@ -138,6 +145,14 @@ test_iter_group(hid_t fapl, hbool_t new_format)
     /* Output message about test being performed */
     MESSAGE(5, ("Testing Group Iteration Functionality\n"));
 
+    if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_GROUP_BASIC) ||
+        !(vol_cap_flags_g & H5VL_CAP_FLAG_GROUP_MORE) || !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) ||
+        !(vol_cap_flags_g & H5VL_CAP_FLAG_STORED_DATATYPES) || !(vol_cap_flags_g & H5VL_CAP_FLAG_LINK_MORE) ||
+        !(vol_cap_flags_g & H5VL_CAP_FLAG_ITERATE)) {
+        MESSAGE(5, (" -- SKIPPED --\n"));
+        return;
+    }
+
     /* Create the test file with the datasets */
     file = H5Fcreate(DATAFILE, H5F_ACC_TRUNC, H5P_DEFAULT, fapl);
     CHECK(file, FAIL, "H5Fcreate");
@@ -145,8 +160,8 @@ test_iter_group(hid_t fapl, hbool_t new_format)
     /* Test iterating over empty group */
     info.command = RET_ZERO;
     idx          = 0;
-    ret          = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info);
-    VERIFY(ret, SUCCEED, "H5Literate");
+    ret          = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info);
+    VERIFY(ret, SUCCEED, "H5Literate2");
 
     datatype = H5Tcopy(H5T_NATIVE_INT);
     CHECK(datatype, FAIL, "H5Tcopy");
@@ -155,12 +170,12 @@ test_iter_group(hid_t fapl, hbool_t new_format)
     CHECK(filespace, FAIL, "H5Screate");
 
     for (i = 0; i < NDATASETS; i++) {
-        HDsprintf(name, "Dataset %d", i);
+        snprintf(name, sizeof(name), "Dataset %d", i);
         dataset = H5Dcreate2(file, name, datatype, filespace, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
         CHECK(dataset, FAIL, "H5Dcreate2");
 
         /* Keep a copy of the dataset names around for later */
-        lnames[i] = HDstrdup(name);
+        lnames[i] = strdup(name);
         CHECK_PTR(lnames[i], "strdup");
 
         ret = H5Dclose(dataset);
@@ -171,13 +186,13 @@ test_iter_group(hid_t fapl, hbool_t new_format)
     grp = H5Gcreate2(file, "grp", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Gcreate2");
 
-    lnames[NDATASETS] = HDstrdup("grp");
+    lnames[NDATASETS] = strdup("grp");
     CHECK_PTR(lnames[NDATASETS], "strdup");
 
     ret = H5Tcommit2(file, "dtype", datatype, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Tcommit2");
 
-    lnames[NDATASETS + 1] = HDstrdup("dtype");
+    lnames[NDATASETS + 1] = strdup("dtype");
     CHECK_PTR(lnames[NDATASETS], "strdup");
 
     /* Close everything up */
@@ -194,7 +209,7 @@ test_iter_group(hid_t fapl, hbool_t new_format)
     CHECK(ret, FAIL, "H5Fclose");
 
     /* Sort the dataset names */
-    HDqsort(lnames, (size_t)(NDATASETS + 2), sizeof(char *), iter_strcmp);
+    qsort(lnames, (size_t)(NDATASETS + 2), sizeof(char *), iter_strcmp);
 
     /* Iterate through the datasets in the root group in various ways */
     file = H5Fopen(DATAFILE, H5F_ACC_RDONLY, fapl);
@@ -211,19 +226,19 @@ test_iter_group(hid_t fapl, hbool_t new_format)
     VERIFY(ginfo.nlinks, (NDATASETS + 2), "H5Gget_info");
 
     for (i = 0; i < (int)ginfo.nlinks; i++) {
-        H5O_info_t oinfo; /* Object info */
+        H5O_info2_t oinfo; /* Object info */
 
         ret = (herr_t)H5Lget_name_by_idx(root_group, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i,
                                          dataset_name, (size_t)NAMELEN, H5P_DEFAULT);
         CHECK(ret, FAIL, "H5Lget_name_by_idx");
 
-        //! [H5Oget_info_by_idx2_snip]
+        //! [H5Oget_info_by_idx3_snip]
 
-        ret = H5Oget_info_by_idx2(root_group, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &oinfo,
+        ret = H5Oget_info_by_idx3(root_group, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &oinfo,
                                   H5O_INFO_BASIC, H5P_DEFAULT);
         CHECK(ret, FAIL, "H5Oget_info_by_idx");
 
-        //! [H5Oget_info_by_idx2_snip]
+        //! [H5Oget_info_by_idx3_snip]
 
     } /* end for */
 
@@ -233,7 +248,7 @@ test_iter_group(hid_t fapl, hbool_t new_format)
             (herr_t)H5Lget_name_by_idx(root_group, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)(NDATASETS + 3),
                                        dataset_name, (size_t)NAMELEN, H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Lget_name_by_idx");
 
     ret = H5Gclose(root_group);
@@ -248,15 +263,15 @@ test_iter_group(hid_t fapl, hbool_t new_format)
     VERIFY(ginfo.nlinks, NDATASETS + 2, "H5Gget_info");
 
     for (i = 0; i < (int)ginfo.nlinks; i++) {
-        H5O_info_t oinfo; /* Object info */
+        H5O_info2_t oinfo; /* Object info */
 
         ret = (herr_t)H5Lget_name_by_idx(file, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, dataset_name,
                                          (size_t)NAMELEN, H5P_DEFAULT);
         CHECK(ret, FAIL, "H5Lget_name_by_idx");
 
-        ret = H5Oget_info_by_idx2(file, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &oinfo, H5O_INFO_BASIC,
+        ret = H5Oget_info_by_idx3(file, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &oinfo, H5O_INFO_BASIC,
                                   H5P_DEFAULT);
-        CHECK(ret, FAIL, "H5Oget_info_by_idx");
+        CHECK(ret, FAIL, "H5Oget_info_by_idx3");
     } /* end for */
 
     H5E_BEGIN_TRY
@@ -264,7 +279,7 @@ test_iter_group(hid_t fapl, hbool_t new_format)
         ret = (herr_t)H5Lget_name_by_idx(file, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)(NDATASETS + 3),
                                          dataset_name, (size_t)NAMELEN, H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Lget_name_by_idx");
 
     /* Test invalid indices for starting iteration */
@@ -272,33 +287,33 @@ test_iter_group(hid_t fapl, hbool_t new_format)
     idx          = (hsize_t)-1;
     H5E_BEGIN_TRY
     {
-        ret = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info);
+        ret = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info);
     }
-    H5E_END_TRY;
-    VERIFY(ret, FAIL, "H5Literate");
+    H5E_END_TRY
+    VERIFY(ret, FAIL, "H5Literate2");
 
     /* Test skipping exactly as many entries as in the group */
     idx = NDATASETS + 2;
     H5E_BEGIN_TRY
     {
-        ret = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info);
+        ret = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info);
     }
-    H5E_END_TRY;
-    VERIFY(ret, FAIL, "H5Literate");
+    H5E_END_TRY
+    VERIFY(ret, FAIL, "H5Literate2");
 
     /* Test skipping more entries than are in the group */
     idx = NDATASETS + 3;
     H5E_BEGIN_TRY
     {
-        ret = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info);
+        ret = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info);
     }
-    H5E_END_TRY;
-    VERIFY(ret, FAIL, "H5Literate");
+    H5E_END_TRY
+    VERIFY(ret, FAIL, "H5Literate2");
 
     /* Test all objects in group, when callback always returns 0 */
     info.command = RET_ZERO;
     idx          = 0;
-    if ((ret = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) > 0)
+    if ((ret = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) > 0)
         TestErrPrintf("Group iteration function didn't return zero correctly!\n");
 
     /* Test all objects in group, when callback always returns 1 */
@@ -306,25 +321,28 @@ test_iter_group(hid_t fapl, hbool_t new_format)
     info.command = RET_TWO;
     i            = 0;
     idx          = 0;
-    while ((ret = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) > 0) {
+    memset(info.name, 0, NAMELEN);
+    while ((ret = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) > 0) {
         /* Verify return value from iterator gets propagated correctly */
-        VERIFY(ret, 2, "H5Literate");
+        VERIFY(ret, 2, "H5Literate2");
 
         /* Increment the number of times "2" is returned */
         i++;
 
         /* Verify that the index is the correct value */
-        VERIFY(idx, (hsize_t)i, "H5Literate");
+        VERIFY(idx, (hsize_t)i, "H5Literate2");
+        if (idx != (hsize_t)i)
+            break;
         if (idx > (NDATASETS + 2))
             TestErrPrintf("Group iteration function walked too far!\n");
 
         /* Verify that the correct name is retrieved */
-        if (HDstrcmp(info.name, lnames[(size_t)(idx - 1)]) != 0)
+        if (strncmp(info.name, lnames[(size_t)(idx - 1)], NAMELEN) != 0)
             TestErrPrintf(
                 "Group iteration function didn't return name correctly for link - lnames[%u] = '%s'!\n",
                 (unsigned)(idx - 1), lnames[(size_t)(idx - 1)]);
     } /* end while */
-    VERIFY(ret, -1, "H5Literate");
+    VERIFY(ret, -1, "H5Literate2");
 
     if (i != (NDATASETS + 2))
         TestErrPrintf("%u: Group iteration function didn't perform multiple iterations correctly!\n",
@@ -335,25 +353,28 @@ test_iter_group(hid_t fapl, hbool_t new_format)
     info.command = new_format ? RET_CHANGE2 : RET_CHANGE;
     i            = 0;
     idx          = 0;
-    while ((ret = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) >= 0) {
+    memset(info.name, 0, NAMELEN);
+    while ((ret = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb, &info)) >= 0) {
         /* Verify return value from iterator gets propagated correctly */
-        VERIFY(ret, 1, "H5Literate");
+        VERIFY(ret, 1, "H5Literate2");
 
         /* Increment the number of times "1" is returned */
         i++;
 
         /* Verify that the index is the correct value */
-        VERIFY(idx, (hsize_t)(i + 10), "H5Literate");
+        VERIFY(idx, (hsize_t)(i + 10), "H5Literate2");
+        if (idx != (hsize_t)(i + 10))
+            break;
         if (idx > (NDATASETS + 2))
             TestErrPrintf("Group iteration function walked too far!\n");
 
         /* Verify that the correct name is retrieved */
-        if (HDstrcmp(info.name, lnames[(size_t)(idx - 1)]) != 0)
+        if (strncmp(info.name, lnames[(size_t)(idx - 1)], NAMELEN) != 0)
             TestErrPrintf(
                 "Group iteration function didn't return name correctly for link - lnames[%u] = '%s'!\n",
                 (unsigned)(idx - 1), lnames[(size_t)(idx - 1)]);
     } /* end while */
-    VERIFY(ret, -1, "H5Literate");
+    VERIFY(ret, -1, "H5Literate2");
 
     if (i != 42 || idx != 52)
         TestErrPrintf("%u: Group iteration function didn't perform multiple iterations correctly!\n",
@@ -364,7 +385,7 @@ test_iter_group(hid_t fapl, hbool_t new_format)
 
     /* Free the dataset names */
     for (i = 0; i < (NDATASETS + 2); i++)
-        HDfree(lnames[i]);
+        free(lnames[i]);
 } /* test_iter_group() */
 
 /****************************************************************
@@ -379,7 +400,7 @@ aiter_cb(hid_t H5_ATTR_UNUSED group, const char *name, const H5A_info_t H5_ATTR_
     static int count  = 0;
     static int count2 = 0;
 
-    HDstrcpy(info->name, name);
+    strcpy(info->name, name);
 
     switch (info->command) {
         case RET_ZERO:
@@ -397,7 +418,7 @@ aiter_cb(hid_t H5_ATTR_UNUSED group, const char *name, const H5A_info_t H5_ATTR_
             return (count2 > 10 ? 1 : 0);
 
         default:
-            HDprintf("invalid iteration command");
+            printf("invalid iteration command");
             return (-1);
     } /* end switch */
 } /* end aiter_cb() */
@@ -408,7 +429,7 @@ aiter_cb(hid_t H5_ATTR_UNUSED group, const char *name, const H5A_info_t H5_ATTR_
 **
 ****************************************************************/
 static void
-test_iter_attr(hid_t fapl, hbool_t new_format)
+test_iter_attr(hid_t fapl, bool new_format)
 {
     hid_t     file;          /* File ID */
     hid_t     dataset;       /* Common Dataset ID */
@@ -424,6 +445,14 @@ test_iter_attr(hid_t fapl, hbool_t new_format)
     /* Output message about test being performed */
     MESSAGE(5, ("Testing Attribute Iteration Functionality\n"));
 
+    if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) ||
+        !(vol_cap_flags_g & H5VL_CAP_FLAG_ATTR_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_ITERATE)) {
+        MESSAGE(5, (" -- SKIPPED --\n"));
+        return;
+    }
+
+    memset(&info, 0, sizeof(iter_info));
+
     /* Create the test file with the datasets */
     file = H5Fcreate(DATAFILE, H5F_ACC_TRUNC, H5P_DEFAULT, fapl);
     CHECK(file, FAIL, "H5Fcreate");
@@ -435,12 +464,12 @@ test_iter_attr(hid_t fapl, hbool_t new_format)
     CHECK(dataset, FAIL, "H5Dcreate2");
 
     for (i = 0; i < NATTR; i++) {
-        HDsprintf(name, "Attribute %02d", i);
+        snprintf(name, sizeof(name), "Attribute %02d", i);
         attribute = H5Acreate2(dataset, name, H5T_NATIVE_INT, filespace, H5P_DEFAULT, H5P_DEFAULT);
         CHECK(attribute, FAIL, "H5Acreate2");
 
         /* Keep a copy of the attribute names around for later */
-        anames[i] = HDstrdup(name);
+        anames[i] = strdup(name);
         CHECK_PTR(anames[i], "strdup");
 
         ret = H5Aclose(attribute);
@@ -473,7 +502,7 @@ test_iter_attr(hid_t fapl, hbool_t new_format)
     {
         ret = H5Aiterate2(dataset, H5_INDEX_NAME, H5_ITER_INC, &idx, aiter_cb, &info);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Aiterate2");
 
     /* Test skipping more attributes than there are */
@@ -482,7 +511,7 @@ test_iter_attr(hid_t fapl, hbool_t new_format)
     {
         ret = H5Aiterate2(dataset, H5_INDEX_NAME, H5_ITER_INC, &idx, aiter_cb, &info);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Aiterate2");
 
     /* Test all attributes on dataset, when callback always returns 0 */
@@ -491,7 +520,7 @@ test_iter_attr(hid_t fapl, hbool_t new_format)
     if ((ret = H5Aiterate2(dataset, H5_INDEX_NAME, H5_ITER_INC, &idx, aiter_cb, &info)) > 0)
         TestErrPrintf("Attribute iteration function didn't return zero correctly!\n");
 
-    /* Test all attributes on dataset, when callback always returns 1 */
+    /* Test all attributes on dataset, when callback always returns 2 */
     /* This also tests the "restarting" ability, because the index changes */
     info.command = RET_TWO;
     i            = 0;
@@ -509,10 +538,14 @@ test_iter_attr(hid_t fapl, hbool_t new_format)
         /* Don't check name when new format is used */
         if (!new_format) {
             /* Verify that the correct name is retrieved */
-            if (HDstrcmp(info.name, anames[(size_t)idx - 1]) != 0)
-                TestErrPrintf("%u: Attribute iteration function didn't set names correctly, info.name = "
-                              "'%s', anames[%u] = '%s'!\n",
-                              __LINE__, info.name, (unsigned)(idx - 1), anames[(size_t)idx - 1]);
+            if (idx > 0) {
+                if (strcmp(info.name, anames[(size_t)idx - 1]) != 0)
+                    TestErrPrintf("%u: Attribute iteration function didn't set names correctly, info.name = "
+                                  "'%s', anames[%u] = '%s'!\n",
+                                  __LINE__, info.name, (unsigned)(idx - 1), anames[(size_t)idx - 1]);
+            }
+            else
+                TestErrPrintf("%u: 'idx' was not set correctly!\n", __LINE__);
         } /* end if */
     }     /* end while */
     VERIFY(ret, -1, "H5Aiterate2");
@@ -538,10 +571,14 @@ test_iter_attr(hid_t fapl, hbool_t new_format)
         /* Don't check name when new format is used */
         if (!new_format) {
             /* Verify that the correct name is retrieved */
-            if (HDstrcmp(info.name, anames[(size_t)idx - 1]) != 0)
-                TestErrPrintf("%u: Attribute iteration function didn't set names correctly, info.name = "
-                              "'%s', anames[%u] = '%s'!\n",
-                              __LINE__, info.name, (unsigned)(idx - 1), anames[(size_t)idx - 1]);
+            if (idx > 0) {
+                if (strcmp(info.name, anames[(size_t)idx - 1]) != 0)
+                    TestErrPrintf("%u: Attribute iteration function didn't set names correctly, info.name = "
+                                  "'%s', anames[%u] = '%s'!\n",
+                                  __LINE__, info.name, (unsigned)(idx - 1), anames[(size_t)idx - 1]);
+            }
+            else
+                TestErrPrintf("%u: 'idx' was not set correctly!\n", __LINE__);
         } /* end if */
     }     /* end while */
     VERIFY(ret, -1, "H5Aiterate2");
@@ -557,7 +594,7 @@ test_iter_attr(hid_t fapl, hbool_t new_format)
 
     /* Free the attribute names */
     for (i = 0; i < NATTR; i++)
-        HDfree(anames[i]);
+        free(anames[i]);
 
 } /* test_iter_attr() */
 
@@ -569,7 +606,7 @@ test_iter_attr(hid_t fapl, hbool_t new_format)
 H5_ATTR_PURE int
 iter_strcmp2(const void *s1, const void *s2)
 {
-    return (HDstrcmp((const char *)s1, (const char *)s2));
+    return (strcmp((const char *)s1, (const char *)s2));
 } /* end iter_strcmp2() */
 
 /****************************************************************
@@ -578,13 +615,20 @@ iter_strcmp2(const void *s1, const void *s2)
 **
 ****************************************************************/
 static herr_t
-liter_cb2(hid_t loc_id, const char *name, const H5L_info_t H5_ATTR_UNUSED *link_info, void *opdata)
+liter_cb2(hid_t loc_id, const char *name, const H5L_info2_t H5_ATTR_UNUSED *link_info, void *opdata)
 {
     const iter_info *test_info = (const iter_info *)opdata;
-    H5O_info_t       oinfo;
+    H5O_info2_t      oinfo;
     herr_t           ret; /* Generic return value        */
 
-    if (HDstrcmp(name, test_info->name) != 0) {
+    if (!(vol_cap_flags_g & H5VL_CAP_FLAG_ITERATE) || !(vol_cap_flags_g & H5VL_CAP_FLAG_LINK_BASIC)) {
+        SKIPPED();
+        printf("    API functions for iterate and basic links aren't "
+               "supported with this connector\n");
+        return 1;
+    }
+
+    if (strcmp(name, test_info->name) != 0) {
         TestErrPrintf("name = '%s', test_info = '%s'\n", name, test_info->name);
         return (H5_ITER_ERROR);
     } /* end if */
@@ -592,8 +636,8 @@ liter_cb2(hid_t loc_id, const char *name, const H5L_info_t H5_ATTR_UNUSED *link_
     /*
      * Get type of the object and check it.
      */
-    ret = H5Oget_info_by_name2(loc_id, name, &oinfo, H5O_INFO_BASIC, H5P_DEFAULT);
-    CHECK(ret, FAIL, "H5Oget_info_by_name");
+    ret = H5Oget_info_by_name3(loc_id, name, &oinfo, H5O_INFO_BASIC, H5P_DEFAULT);
+    CHECK(ret, FAIL, "H5Oget_info_by_name3");
 
     if (test_info->type != oinfo.type) {
         TestErrPrintf("test_info->type = %d, oinfo.type = %d\n", test_info->type, (int)oinfo.type);
@@ -632,12 +676,19 @@ test_iter_group_large(hid_t fapl)
     } s1_t;
 
     /* Allocate & initialize array */
-    names = (iter_info *)HDcalloc(sizeof(iter_info), (ITER_NGROUPS + 2));
-    CHECK_PTR(names, "HDcalloc");
+    names = (iter_info *)calloc(sizeof(iter_info), (ITER_NGROUPS + 2));
+    CHECK_PTR(names, "calloc");
 
     /* Output message about test being performed */
     MESSAGE(5, ("Testing Large Group Iteration Functionality\n"));
 
+    if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_GROUP_BASIC) ||
+        !(vol_cap_flags_g & H5VL_CAP_FLAG_DATASET_BASIC) ||
+        !(vol_cap_flags_g & H5VL_CAP_FLAG_STORED_DATATYPES) || !(vol_cap_flags_g & H5VL_CAP_FLAG_ITERATE)) {
+        MESSAGE(5, (" -- SKIPPED --\n"));
+        return;
+    }
+
     /* Create file */
     file = H5Fcreate(DATAFILE, H5F_ACC_TRUNC, H5P_DEFAULT, fapl);
     CHECK(file, FAIL, "H5Fcreate");
@@ -648,10 +699,10 @@ test_iter_group_large(hid_t fapl)
 
     /* Create a bunch of groups */
     for (i = 0; i < ITER_NGROUPS; i++) {
-        HDsprintf(gname, "Group_%d", i);
+        snprintf(gname, sizeof(gname), "Group_%d", i);
 
         /* Add the name to the list of objects in the root group */
-        HDstrcpy(names[i].name, gname);
+        strcpy(names[i].name, gname);
         names[i].type = H5O_TYPE_GROUP;
 
         /* Create a group */
@@ -668,7 +719,7 @@ test_iter_group_large(hid_t fapl)
     CHECK(dataset, FAIL, "H5Dcreate2");
 
     /* Add the name to the list of objects in the root group */
-    HDstrcpy(names[ITER_NGROUPS].name, "Dataset1");
+    strcpy(names[ITER_NGROUPS].name, "Dataset1");
     names[ITER_NGROUPS].type = H5O_TYPE_DATASET;
 
     /* Close Dataset */
@@ -698,7 +749,7 @@ test_iter_group_large(hid_t fapl)
     CHECK(ret, FAIL, "H5Tcommit2");
 
     /* Add the name to the list of objects in the root group */
-    HDstrcpy(names[ITER_NGROUPS + 1].name, "Datatype1");
+    strcpy(names[ITER_NGROUPS + 1].name, "Datatype1");
     names[ITER_NGROUPS + 1].type = H5O_TYPE_NAMED_DATATYPE;
 
     /* Close datatype */
@@ -706,18 +757,18 @@ test_iter_group_large(hid_t fapl)
     CHECK(ret, FAIL, "H5Tclose");
 
     /* Need to sort the names in the root group, cause that's what the library does */
-    HDqsort(names, (size_t)(ITER_NGROUPS + 2), sizeof(iter_info), iter_strcmp2);
+    qsort(names, (size_t)(ITER_NGROUPS + 2), sizeof(iter_info), iter_strcmp2);
 
     /* Iterate through the file to see members of the root group */
     curr_name = &names[0];
-    ret       = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, NULL, liter_cb2, curr_name);
-    CHECK(ret, FAIL, "H5Literate");
+    ret       = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, NULL, liter_cb2, curr_name);
+    CHECK(ret, FAIL, "H5Literate2");
     for (i = 1; i < 100; i++) {
         hsize_t idx = (hsize_t)i;
 
         curr_name = &names[i];
-        ret       = H5Literate(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb2, curr_name);
-        CHECK(ret, FAIL, "H5Literate");
+        ret       = H5Literate2(file, H5_INDEX_NAME, H5_ITER_INC, &idx, liter_cb2, curr_name);
+        CHECK(ret, FAIL, "H5Literate2");
     } /* end for */
 
     /* Close file */
@@ -725,7 +776,7 @@ test_iter_group_large(hid_t fapl)
     CHECK(ret, FAIL, "H5Fclose");
 
     /* Release memory */
-    HDfree(names);
+    free(names);
 } /* test_iterate_group_large() */
 
 /****************************************************************
@@ -765,12 +816,12 @@ test_grp_memb_funcs(hid_t fapl)
     CHECK(filespace, FAIL, "H5Screate");
 
     for (i = 0; i < NDATASETS; i++) {
-        HDsprintf(name, "Dataset %d", i);
+        snprintf(name, sizeof(name), "Dataset %d", i);
         dataset = H5Dcreate2(file, name, datatype, filespace, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
         CHECK(dataset, FAIL, "H5Dcreate2");
 
         /* Keep a copy of the dataset names around for later */
-        dnames[i] = HDstrdup(name);
+        dnames[i] = strdup(name);
         CHECK_PTR(dnames[i], "strdup");
 
         ret = H5Dclose(dataset);
@@ -781,13 +832,13 @@ test_grp_memb_funcs(hid_t fapl)
     grp = H5Gcreate2(file, "grp", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Gcreate2");
 
-    dnames[NDATASETS] = HDstrdup("grp");
+    dnames[NDATASETS] = strdup("grp");
     CHECK_PTR(dnames[NDATASETS], "strdup");
 
     ret = H5Tcommit2(file, "dtype", datatype, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Tcommit2");
 
-    dnames[NDATASETS + 1] = HDstrdup("dtype");
+    dnames[NDATASETS + 1] = strdup("dtype");
     CHECK_PTR(dnames[NDATASETS], "strdup");
 
     /* Close everything up */
@@ -804,7 +855,7 @@ test_grp_memb_funcs(hid_t fapl)
     CHECK(ret, FAIL, "H5Fclose");
 
     /* Sort the dataset names */
-    HDqsort(dnames, (size_t)(NDATASETS + 2), sizeof(char *), iter_strcmp);
+    qsort(dnames, (size_t)(NDATASETS + 2), sizeof(char *), iter_strcmp);
 
     /* Iterate through the datasets in the root group in various ways */
     file = H5Fopen(DATAFILE, H5F_ACC_RDONLY, fapl);
@@ -821,7 +872,7 @@ test_grp_memb_funcs(hid_t fapl)
     VERIFY(ginfo.nlinks, (NDATASETS + 2), "H5Gget_info");
 
     for (i = 0; i < (int)ginfo.nlinks; i++) {
-        H5O_info_t oinfo; /* Object info */
+        H5O_info2_t oinfo; /* Object info */
 
         /* Test with NULL for name, to query length */
         name_len = H5Lget_name_by_idx(root_group, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, NULL,
@@ -836,18 +887,18 @@ test_grp_memb_funcs(hid_t fapl)
         VERIFY(ret, name_len, "H5Lget_name_by_idx");
 
         /* Keep a copy of the dataset names around for later */
-        obj_names[i] = HDstrdup(dataset_name);
+        obj_names[i] = strdup(dataset_name);
         CHECK_PTR(obj_names[i], "strdup");
 
-        ret = H5Oget_info_by_idx2(root_group, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &oinfo,
+        ret = H5Oget_info_by_idx3(root_group, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &oinfo,
                                   H5O_INFO_BASIC, H5P_DEFAULT);
-        CHECK(ret, FAIL, "H5Oget_info_by_idx");
+        CHECK(ret, FAIL, "H5Oget_info_by_idx3");
 
-        if (!HDstrcmp(dataset_name, "grp"))
+        if (!strcmp(dataset_name, "grp"))
             VERIFY(oinfo.type, H5O_TYPE_GROUP, "H5Lget_name_by_idx");
-        if (!HDstrcmp(dataset_name, "dtype"))
+        if (!strcmp(dataset_name, "dtype"))
             VERIFY(oinfo.type, H5O_TYPE_NAMED_DATATYPE, "H5Lget_name_by_idx");
-        if (!HDstrncmp(dataset_name, "Dataset", (size_t)7))
+        if (!strncmp(dataset_name, "Dataset", (size_t)7))
             VERIFY(oinfo.type, H5O_TYPE_DATASET, "H5Lget_name_by_idx");
     } /* end for */
 
@@ -857,16 +908,16 @@ test_grp_memb_funcs(hid_t fapl)
             (herr_t)H5Lget_name_by_idx(root_group, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)(NDATASETS + 3),
                                        dataset_name, (size_t)NAMELEN, H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Lget_name_by_idx");
 
     /* Sort the dataset names */
-    HDqsort(obj_names, (size_t)(NDATASETS + 2), sizeof(char *), iter_strcmp);
+    qsort(obj_names, (size_t)(NDATASETS + 2), sizeof(char *), iter_strcmp);
 
     /* Compare object names */
     for (i = 0; i < (int)ginfo.nlinks; i++) {
-        ret = HDstrcmp(dnames[i], obj_names[i]);
-        VERIFY(ret, 0, "HDstrcmp");
+        ret = strcmp(dnames[i], obj_names[i]);
+        VERIFY(ret, 0, "strcmp");
     } /* end for */
 
     ret = H5Gclose(root_group);
@@ -877,8 +928,8 @@ test_grp_memb_funcs(hid_t fapl)
 
     /* Free the dataset names */
     for (i = 0; i < (NDATASETS + 2); i++) {
-        HDfree(dnames[i]);
-        HDfree(obj_names[i]);
+        free(dnames[i]);
+        free(obj_names[i]);
     } /* end for */
 } /* test_grp_memb_funcs() */
 
@@ -925,8 +976,8 @@ test_links(hid_t fapl)
 
     /* Test these two functions, H5Oget_info_by_idx and H5Lget_name_by_idx */
     for (i = 0; i < ginfo.nlinks; i++) {
-        H5O_info_t oinfo; /* Object info */
-        H5L_info_t linfo; /* Link info */
+        H5O_info2_t oinfo; /* Object info */
+        H5L_info2_t linfo; /* Link info */
 
         /* Get link name */
         name_len = H5Lget_name_by_idx(gid, ".", H5_INDEX_NAME, H5_ITER_INC, i, obj_name, (size_t)NAMELEN,
@@ -934,21 +985,21 @@ test_links(hid_t fapl)
         CHECK(name_len, FAIL, "H5Lget_name_by_idx");
 
         /* Get link type */
-        ret = H5Lget_info_by_idx(gid, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &linfo, H5P_DEFAULT);
-        CHECK(ret, FAIL, "H5Lget_info_by_idx");
+        ret = H5Lget_info_by_idx2(gid, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &linfo, H5P_DEFAULT);
+        CHECK(ret, FAIL, "H5Lget_info_by_idx2");
 
         /* Get object type */
         if (linfo.type == H5L_TYPE_HARD) {
-            ret = H5Oget_info_by_idx2(gid, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &oinfo,
+            ret = H5Oget_info_by_idx3(gid, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &oinfo,
                                       H5O_INFO_BASIC, H5P_DEFAULT);
-            CHECK(ret, FAIL, "H5Oget_info_by_idx");
+            CHECK(ret, FAIL, "H5Oget_info_by_idx3");
         } /* end if */
 
-        if (!HDstrcmp(obj_name, "g1.1"))
+        if (!strcmp(obj_name, "g1.1"))
             VERIFY(oinfo.type, H5O_TYPE_GROUP, "H5Lget_name_by_idx");
-        else if (!HDstrcmp(obj_name, "hardlink"))
+        else if (!strcmp(obj_name, "hardlink"))
             VERIFY(oinfo.type, H5O_TYPE_GROUP, "H5Lget_name_by_idx");
-        else if (!HDstrcmp(obj_name, "softlink"))
+        else if (!strcmp(obj_name, "softlink"))
             VERIFY(linfo.type, H5L_TYPE_SOFT, "H5Lget_name_by_idx");
         else
             ERROR("unknown object name");
@@ -1003,19 +1054,39 @@ find_err_msg_cb(unsigned H5_ATTR_UNUSED n, const H5E_error2_t *err_desc, void *_
 static void
 test_corrupted_attnamelen(void)
 {
-    hid_t          fid = -1;   /* File ID */
-    hid_t          did = -1;   /* Dataset ID */
-    searched_err_t err_caught; /* Data to be passed to callback func */
-    int            err_status; /* Status returned by H5Aiterate2 */
-    herr_t         ret;        /* Return value */
+    hid_t          fid = H5I_INVALID_HID; /* File ID */
+    hid_t          did = H5I_INVALID_HID; /* Dataset ID */
+    searched_err_t err_caught;            /* Data to be passed to callback func */
+    int            err_status;            /* Status returned by H5Aiterate2 */
+    herr_t         ret;                   /* Return value */
+    bool           vol_is_native;
+    bool           driver_is_default_compatible;
     const char    *testfile = H5_get_srcdir_filename(CORRUPTED_ATNAMELEN_FILE); /* Corrected test file name */
 
-    const char *err_message = "attribute name has different length than stored length";
-    /* the error message produced when the failure occurs */
+    /* The error message produced when the failure occurs
+     *
+     * FIXME: This is incredibly fragile!
+     */
+    const char *err_message = "ran off end of input buffer while decoding";
 
     /* Output message about test being performed */
     MESSAGE(5, ("Testing the Handling of Corrupted Attribute's Name Length\n"));
 
+    /* Check if native VOL is being used */
+    CHECK(h5_using_native_vol(H5P_DEFAULT, H5I_INVALID_HID, &vol_is_native), FAIL, "h5_using_native_vol");
+    if (!vol_is_native) {
+        MESSAGE(5, (" -- SKIPPED --\n"));
+        return;
+    }
+
+    ret = h5_driver_is_default_vfd_compatible(H5P_DEFAULT, &driver_is_default_compatible);
+    CHECK(ret, FAIL, "h5_driver_is_default_vfd_compatible");
+
+    if (!driver_is_default_compatible) {
+        MESSAGE(5, (" -- SKIPPED --\n"));
+        return;
+    }
+
     fid = H5Fopen(testfile, H5F_ACC_RDONLY, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fopen");
 
@@ -1031,7 +1102,7 @@ test_corrupted_attnamelen(void)
     /* Make sure the intended error was caught */
     if (err_status == -1) {
         /* Initialize client data */
-        HDstrcpy(err_caught.message, err_message);
+        strcpy(err_caught.message, err_message);
         err_caught.found = false;
 
         /* Look for the correct error message */
@@ -1051,6 +1122,99 @@ test_corrupted_attnamelen(void)
 
 } /* test_corrupted_attnamelen() */
 
+#ifndef H5_NO_DEPRECATED_SYMBOLS
+/****************************************************************
+**
+**  test_links_deprec(): Test soft and hard link iteration
+**
+****************************************************************/
+static void
+test_links_deprec(hid_t fapl)
+{
+    hid_t      file;              /* File ID */
+    char       obj_name[NAMELEN]; /* Names of the object in group */
+    ssize_t    name_len;          /* Length of object's name */
+    hid_t      gid, gid1;
+    H5G_info_t ginfo; /* Buffer for querying object's info */
+    hsize_t    i;
+    bool       vol_is_native;
+    herr_t     ret; /* Generic return value */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing Soft and Hard Link Iteration Functionality Using Deprecated Routines\n"));
+
+    /* Create the test file with the datasets */
+    file = H5Fcreate(DATAFILE, H5F_ACC_TRUNC, H5P_DEFAULT, fapl);
+    CHECK(file, FAIL, "H5Fcreate");
+
+    /* Check if native VOL is being used */
+    CHECK(h5_using_native_vol(fapl, file, &vol_is_native), FAIL, "h5_using_native_vol");
+    if (!vol_is_native) {
+        CHECK(H5Fclose(file), FAIL, "H5Fclose");
+        MESSAGE(5, (" -- SKIPPED --\n"));
+        return;
+    }
+
+    /* create groups */
+    gid = H5Gcreate2(file, "/g1", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(gid, FAIL, "H5Gcreate2");
+
+    gid1 = H5Gcreate2(file, "/g1/g1.1", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(gid1, FAIL, "H5Gcreate2");
+
+    /* create soft and hard links to the group "/g1". */
+    ret = H5Lcreate_soft("something", gid, "softlink", H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(ret, FAIL, "H5Lcreate_soft");
+
+    ret = H5Lcreate_hard(gid, "/g1", H5L_SAME_LOC, "hardlink", H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(ret, FAIL, "H5Lcreate_hard");
+
+    ret = H5Gget_info(gid, &ginfo);
+    CHECK(ret, FAIL, "H5Gget_info");
+    VERIFY(ginfo.nlinks, 3, "H5Gget_info");
+
+    /* Test these two functions, H5Oget_info_by_idx and H5Lget_name_by_idx */
+    for (i = 0; i < ginfo.nlinks; i++) {
+        H5O_info2_t oinfo; /* Object info */
+        H5L_info2_t linfo; /* Link info */
+
+        /* Get link name */
+        name_len = H5Lget_name_by_idx(gid, ".", H5_INDEX_NAME, H5_ITER_INC, i, obj_name, (size_t)NAMELEN,
+                                      H5P_DEFAULT);
+        CHECK(name_len, FAIL, "H5Lget_name_by_idx");
+
+        /* Get link type */
+        ret = H5Lget_info_by_idx2(gid, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &linfo, H5P_DEFAULT);
+        CHECK(ret, FAIL, "H5Lget_info_by_idx1");
+
+        /* Get object type */
+        if (linfo.type == H5L_TYPE_HARD) {
+            ret = H5Oget_info_by_idx3(gid, ".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)i, &oinfo,
+                                      H5O_INFO_BASIC, H5P_DEFAULT);
+            CHECK(ret, FAIL, "H5Oget_info_by_idx");
+        } /* end if */
+
+        if (!strcmp(obj_name, "g1.1"))
+            VERIFY(oinfo.type, H5O_TYPE_GROUP, "H5Lget_name_by_idx");
+        else if (!strcmp(obj_name, "hardlink"))
+            VERIFY(oinfo.type, H5O_TYPE_GROUP, "H5Lget_name_by_idx");
+        else if (!strcmp(obj_name, "softlink"))
+            VERIFY(linfo.type, H5L_TYPE_SOFT, "H5Lget_name_by_idx");
+        else
+            ERROR("unknown object name");
+    } /* end for */
+
+    ret = H5Gclose(gid);
+    CHECK(ret, FAIL, "H5Gclose");
+
+    ret = H5Gclose(gid1);
+    CHECK(ret, FAIL, "H5Gclose");
+
+    ret = H5Fclose(file);
+    CHECK(ret, FAIL, "H5Fclose");
+} /* test_links_deprec() */
+#endif
+
 /****************************************************************
 **
 **  test_iterate(): Main iteration testing routine.
@@ -1079,13 +1243,16 @@ test_iterate(void)
     CHECK(ret, FAIL, "H5Pset_libver_bounds");
 
     /* These next tests use the same file */
-    for (new_format = FALSE; new_format <= TRUE; new_format++) {
+    for (new_format = false; new_format <= true; new_format++) {
         test_iter_group(new_format ? fapl2 : fapl, new_format); /* Test group iteration */
         test_iter_group_large(new_format ? fapl2 : fapl); /* Test group iteration for large # of objects */
         test_iter_attr(new_format ? fapl2 : fapl, new_format); /* Test attribute iteration */
         test_grp_memb_funcs(new_format ? fapl2 : fapl);        /* Test group member information functions */
         test_links(new_format ? fapl2 : fapl);                 /* Test soft and hard link iteration */
-    }                                                          /* end for */
+#ifndef H5_NO_DEPRECATED_SYMBOLS
+        test_links_deprec(new_format ? fapl2 : fapl); /* Test soft and hard link iteration */
+#endif
+    } /* end for */
 
     /* Test the fix for issue HDFFV-10588 */
     test_corrupted_attnamelen();
@@ -1104,15 +1271,14 @@ test_iterate(void)
  *
  * Return:    none
  *
- * Programmer:    Quincey Koziol
- *              April 5, 2000
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 void
 cleanup_iterate(void)
 {
-    HDremove(DATAFILE);
+    H5E_BEGIN_TRY
+    {
+        H5Fdelete(DATAFILE, H5P_DEFAULT);
+    }
+    H5E_END_TRY
 }
