@@ -11,9 +11,6 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Bill Wendling
- *              Tuesday, 6. March 2001
- *
  * Purpose:     Support functions for the various tools.
  */
 #ifndef H5TOOLS_UTILS_H
@@ -39,64 +36,18 @@ H5TOOLS_DLLVAR FILE         *overflow_file;
 H5TOOLS_DLLVAR hsize_t H5TOOLS_MALLOCSIZE;
 /* size of hyperslab buffer when a dataset is bigger than H5TOOLS_MALLOCSIZE */
 H5TOOLS_DLLVAR hsize_t H5TOOLS_BUFSIZE;
-/*
- * begin get_option section
- */
-H5TOOLS_DLLVAR int         opt_err; /* getoption prints errors if this is on    */
-H5TOOLS_DLLVAR int         opt_ind; /* token pointer                            */
-H5TOOLS_DLLVAR const char *opt_arg; /* flag argument (or value)                 */
-
-/*
- * get_option determines which options are specified on the command line and
- * returns a pointer to any arguments possibly associated with the option in
- * the ``opt_arg'' variable. get_option returns the shortname equivalent of
- * the option. The long options are specified in the following way:
- *
- * struct long_options foo[] = {
- *   { "filename", require_arg, 'f' },
- *   { "append", no_arg, 'a' },
- *   { "width", require_arg, 'w' },
- *   { NULL, 0, 0 }
- * };
- *
- * Long named options can have arguments specified as either:
- *
- *   ``--param=arg'' or ``--param arg''
- *
- * Short named options can have arguments specified as either:
- *
- *   ``-w80'' or ``-w 80''
- *
- * and can have more than one short named option specified at one time:
- *
- *   -aw80
- *
- * in which case those options which expect an argument need to come at the
- * end.
- */
-typedef struct long_options {
-    const char *name;     /* name of the long option              */
-    int         has_arg;  /* whether we should look for an arg    */
-    char        shortval; /* the shortname equivalent of long arg
-                           * this gets returned from get_option   */
-} long_options;
-
-H5TOOLS_DLL int get_option(int argc, const char *const *argv, const char *opt,
-                           const struct long_options *l_opt);
-/*
- * end get_option section
- */
 
 /*struct taken from the dumper. needed in table struct*/
 typedef struct obj_t {
-    haddr_t objno;
-    char   *objname;
-    hbool_t displayed; /* Flag to indicate that the object has been displayed */
-    hbool_t recorded;  /* Flag for named datatypes to indicate they were found in the group hierarchy */
+    H5O_token_t obj_token;
+    char       *objname;
+    bool        displayed; /* Flag to indicate that the object has been displayed */
+    bool        recorded;  /* Flag for named datatypes to indicate they were found in the group hierarchy */
 } obj_t;
 
 /*struct for the tables that the find_objs function uses*/
 typedef struct table_t {
+    hid_t  fid;
     size_t size;
     size_t nobjs;
     obj_t *objs;
@@ -110,16 +61,27 @@ typedef struct find_objs_t {
     table_t *dset_table;
 } find_objs_t;
 
+#ifdef H5_HAVE_ROS3_VFD
+/*extended configuration struct for holding the configuration data to the #H5FD_ROS3 driver */
+typedef struct H5FD_ros3_fapl_ext_t {
+    H5FD_ros3_fapl_t fa;                                      /* ROS3 configuration struct*/
+    char             token[H5FD_ROS3_MAX_SECRET_TOK_LEN + 1]; /* Session/security token*/
+} H5FD_ros3_fapl_ext_t;
+#endif /* H5_HAVE_ROS3_VFD */
+
 H5TOOLS_DLLVAR unsigned h5tools_nCols; /*max number of columns for outputting  */
 
 /* Definitions of useful routines */
+H5TOOLS_DLL struct subset_t *parse_subset_params(const char *dset);
+
 H5TOOLS_DLL void   indentation(unsigned);
 H5TOOLS_DLL void   print_version(const char *progname);
-H5TOOLS_DLL void   parallel_print(const char *format, ...);
+H5TOOLS_DLL void   parallel_print(const char *format, ...) H5_ATTR_FORMAT(printf, 1, 2);
+H5TOOLS_DLL void   parse_hsize_list(const char *h_list, subset_d *d);
 H5TOOLS_DLL herr_t parse_tuple(const char *start, int sep, char **cpy_out, unsigned *nelems,
                                char ***ptrs_out);
-H5TOOLS_DLL void   error_msg(const char *fmt, ...);
-H5TOOLS_DLL void   warn_msg(const char *fmt, ...);
+H5TOOLS_DLL void   error_msg(const char *fmt, ...) H5_ATTR_FORMAT(printf, 1, 2);
+H5TOOLS_DLL void   warn_msg(const char *fmt, ...) H5_ATTR_FORMAT(printf, 1, 2);
 H5TOOLS_DLL void   help_ref_msg(FILE *output);
 H5TOOLS_DLL void   free_table(table_t *table);
 #ifdef H5DUMP_DEBUG
@@ -127,7 +89,7 @@ H5TOOLS_DLL void dump_tables(find_objs_t *info);
 #endif /* H5DUMP_DEBUG */
 H5TOOLS_DLL herr_t init_objs(hid_t fid, find_objs_t *info, table_t **group_table, table_t **dset_table,
                              table_t **type_table);
-H5TOOLS_DLL obj_t *search_obj(table_t *temp, haddr_t objno);
+H5TOOLS_DLL obj_t *search_obj(table_t *temp, const H5O_token_t *obj_token);
 #ifndef H5_HAVE_TMPFILE
 H5TOOLS_DLL FILE *tmpfile(void);
 #endif
@@ -153,18 +115,18 @@ typedef struct {
 
 /* obtain link info from H5tools_get_symlink_info() */
 typedef struct {
-    H5O_type_t trg_type;  /* OUT: target type */
-    char      *trg_path;  /* OUT: target obj path. This must be freed
-                           *      when used with H5tools_get_symlink_info() */
-    haddr_t       objno;  /* OUT: target object address */
-    unsigned long fileno; /* OUT: File number that target object is located in */
-    H5L_info_t    linfo;  /* OUT: link info */
-    h5tool_opt_t  opt;    /* IN: options */
+    H5O_type_t trg_type;     /* OUT: target type */
+    char      *trg_path;     /* OUT: target obj path. This must be freed
+                              *      when used with H5tools_get_symlink_info() */
+    H5O_token_t   obj_token; /* OUT: target object token */
+    unsigned long fileno;    /* OUT: File number that target object is located in */
+    H5L_info2_t   linfo;     /* OUT: link info */
+    h5tool_opt_t  opt;       /* IN: options */
 } h5tool_link_info_t;
 
 /* Definitions of routines */
 H5TOOLS_DLL int H5tools_get_symlink_info(hid_t file_id, const char *linkpath, h5tool_link_info_t *link_info,
-                                         hbool_t get_obj_type);
+                                         bool get_obj_type);
 H5TOOLS_DLL const char *h5tools_getprogname(void);
 H5TOOLS_DLL void        h5tools_setprogname(const char *progname);
 H5TOOLS_DLL int         h5tools_getstatus(void);
@@ -172,8 +134,8 @@ H5TOOLS_DLL void        h5tools_setstatus(int d_status);
 H5TOOLS_DLL int         h5tools_getenv_update_hyperslab_bufsize(void);
 #ifdef H5_HAVE_ROS3_VFD
 H5TOOLS_DLL herr_t h5tools_parse_ros3_fapl_tuple(const char *tuple_str, int delim,
-                                                 H5FD_ros3_fapl_t *fapl_config_out);
-H5TOOLS_DLL herr_t h5tools_populate_ros3_fapl(H5FD_ros3_fapl_t *fa, const char **values);
+                                                 H5FD_ros3_fapl_ext_t *fapl_config_out);
+H5TOOLS_DLL int    h5tools_populate_ros3_fapl(H5FD_ros3_fapl_ext_t *fa, const char **values);
 #endif /* H5_HAVE_ROS3_VFD */
 #ifdef H5_HAVE_LIBHDFS
 H5TOOLS_DLL herr_t h5tools_parse_hdfs_fapl_tuple(const char *tuple_str, int delim,
