@@ -5,13 +5,13 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /* changes:
  * rename pio_timer.c as io_timer.c;
- * Removed pio_perf.h so that it is not dependant on it;
+ * Removed pio_perf.h so that it is not dependent on it;
  * Removed set_timer_type() and get_timer_type() since no one calls them;
  * Merged sio_timer.c into io_timer.c;
  */
@@ -23,7 +23,6 @@
  */
 
 #include "H5private.h"
-#include "hdf5.h"
 
 #include "io_timer.h"
 
@@ -31,27 +30,24 @@
  * The number to divide the tv_usec field with to get a nice decimal to add to
  * the number of seconds.
  */
-#define MICROSECOND     1000000.0F
+#define MICROSECOND 1000000.0F
 
 /* global variables */
-io_time_t   *timer_g;            /* timer: global for stub functions     */
+static io_time_t *timer_g; /* timer: global for stub functions     */
 
 /*
  * Function:  sub_time
  * Purpose:   Struct two time values, and return the difference, in microseconds
  *
  *         Note that the function assumes that a > b
- * Programmer: Leon Arber, 1/27/06
  */
-static double sub_time(struct timeval* a, struct timeval* b)
+static double
+sub_time(struct timeval *a, struct timeval *b)
 {
-    return (((double)a->tv_sec +
-     ((double)a->tv_usec) / (double)MICROSECOND) -
-  ((double)b->tv_sec +
-   ((double)b->tv_usec) / (double)MICROSECOND));
+    return (((double)a->tv_sec + ((double)a->tv_usec) / (double)MICROSECOND) -
+            ((double)b->tv_sec + ((double)b->tv_usec) / (double)MICROSECOND));
 }
 
-
 /*
  * Function:    io_time_new
  * Purpose:     Build us a brand, spankin', new performance time object.
@@ -59,13 +55,11 @@ static double sub_time(struct timeval* a, struct timeval* b)
  *              what type of timer they want (MPI_CLOCK for MPI_Wtime or
  *              SYS_CLOCK for system time).
  * Return:      Pointer to io_time object
- * Programmer:  Bill Wendling, 01. October 2001
- * Modifications:
  */
 io_time_t *
 io_time_new(clock_type type)
 {
-    io_time_t *pt = (io_time_t *)HDcalloc(1, sizeof(struct io_time_t));
+    io_time_t *pt = (io_time_t *)calloc(1, sizeof(struct io_time_t));
 
     /* set global timer variable */
     timer_g = pt;
@@ -80,13 +74,11 @@ io_time_new(clock_type type)
  *              need to call on a pointer allocated with the ``io_time_new''
  *              function.
  * Return:      Nothing
- * Programmer:  Bill Wendling, 01. October 2001
- * Modifications:
  */
 void
 io_time_destroy(io_time_t *pt)
 {
-    HDfree(pt);
+    free(pt);
     /* reset the global timer pointer too. */
     timer_g = NULL;
 }
@@ -99,8 +91,6 @@ io_time_destroy(io_time_t *pt)
  *              This really only needs to be called if you didn't construct a
  *              timer with the pio_timer_new function (shame!).
  * Return:      Nothing
- * Programmer:  Bill Wendling, 04. October 2001
- * Modifications:
  */
 void
 set_timer_type(io_time_t *pt, clock_type type)
@@ -112,8 +102,6 @@ set_timer_type(io_time_t *pt, clock_type type)
  * Function:    get_timer_type
  * Purpose:     Get the type of the timer.
  * Return:      MPI_CLOCK or SYS_CLOCK.
- * Programmer:  Bill Wendling, 04. October 2001
- * Modifications:
  */
 clock_type
 get_timer_type(io_time_t *pt)
@@ -123,79 +111,83 @@ get_timer_type(io_time_t *pt)
 #endif
 
 /*
- * Function:    set_time
+ * Function:    io_time_set
  * Purpose:     Set the time in a ``io_time_t'' object.
  * Return:      Pointer to the passed in ``io_time_t'' object if SUCCEED; Null otherwise.
- * Programmer:  Bill Wendling, 01. October 2001
- * Modifications:
  */
 io_time_t *
-set_time(io_time_t *pt, timer_type t, int start_stop)
+io_time_set(io_time_t *pt, timer_type t, int start_stop)
 {
     /* sanity check */
-    HDassert(pt);
+    assert(pt);
 
-    switch(pt->type){
+    switch (pt->type) {
 #ifdef H5_HAVE_PARALLEL
-    case MPI_CLOCK:
-	if (start_stop == TSTART) {
-	    pt->mpi_timer[t] = MPI_Wtime();
+        case MPI_CLOCK:
+            if (start_stop == TSTART) {
+                pt->mpi_timer[t] = MPI_Wtime();
 
-	    /* When we start the timer for HDF5_FINE_WRITE_FIXED_DIMS or HDF5_FINE_READ_FIXED_DIMS
-	     * we compute the time it took to only open the file */
-	    if(t == HDF5_FINE_WRITE_FIXED_DIMS)
-		pt->total_time[HDF5_FILE_WRITE_OPEN] += pt->mpi_timer[t] - pt->mpi_timer[HDF5_GROSS_WRITE_FIXED_DIMS];
-	    else if(t == HDF5_FINE_READ_FIXED_DIMS)
-		pt->total_time[HDF5_FILE_READ_OPEN] += pt->mpi_timer[t] - pt->mpi_timer[HDF5_GROSS_READ_FIXED_DIMS];
+                /* When we start the timer for HDF5_FINE_WRITE_FIXED_DIMS or HDF5_FINE_READ_FIXED_DIMS
+                 * we compute the time it took to only open the file */
+                if (t == HDF5_FINE_WRITE_FIXED_DIMS)
+                    pt->total_time[HDF5_FILE_WRITE_OPEN] +=
+                        pt->mpi_timer[t] - pt->mpi_timer[HDF5_GROSS_WRITE_FIXED_DIMS];
+                else if (t == HDF5_FINE_READ_FIXED_DIMS)
+                    pt->total_time[HDF5_FILE_READ_OPEN] +=
+                        pt->mpi_timer[t] - pt->mpi_timer[HDF5_GROSS_READ_FIXED_DIMS];
+            }
+            else {
+                pt->total_time[t] += MPI_Wtime() - pt->mpi_timer[t];
+                pt->mpi_timer[t] = MPI_Wtime();
 
-	} else {
-	    pt->total_time[t] += MPI_Wtime() - pt->mpi_timer[t];
-	    pt->mpi_timer[t] = MPI_Wtime();
-
-	    /* When we stop the timer for HDF5_GROSS_WRITE_FIXED_DIMS or HDF5_GROSS_READ_FIXED_DIMS
-	     * we compute the time it took to close the file after the last read/write finished */
-	    if(t == HDF5_GROSS_WRITE_FIXED_DIMS)
-		pt->total_time[HDF5_FILE_WRITE_CLOSE] += pt->mpi_timer[t] - pt->mpi_timer[HDF5_FINE_WRITE_FIXED_DIMS];
-	    else if(t == HDF5_GROSS_READ_FIXED_DIMS)
-		pt->total_time[HDF5_FILE_READ_CLOSE] += pt->mpi_timer[t] - pt->mpi_timer[HDF5_FINE_READ_FIXED_DIMS];
-	}
-	break;
+                /* When we stop the timer for HDF5_GROSS_WRITE_FIXED_DIMS or HDF5_GROSS_READ_FIXED_DIMS
+                 * we compute the time it took to close the file after the last read/write finished */
+                if (t == HDF5_GROSS_WRITE_FIXED_DIMS)
+                    pt->total_time[HDF5_FILE_WRITE_CLOSE] +=
+                        pt->mpi_timer[t] - pt->mpi_timer[HDF5_FINE_WRITE_FIXED_DIMS];
+                else if (t == HDF5_GROSS_READ_FIXED_DIMS)
+                    pt->total_time[HDF5_FILE_READ_CLOSE] +=
+                        pt->mpi_timer[t] - pt->mpi_timer[HDF5_FINE_READ_FIXED_DIMS];
+            }
+            break;
 #else
-    case MPI_CLOCK:
-	    HDfprintf(stderr, "MPI clock set in serial library\n");
-	    return NULL;
+        case MPI_CLOCK:
+            fprintf(stderr, "MPI clock set in serial library\n");
+            return NULL;
 #endif /* H5_HAVE_PARALLEL */
-    case SYS_CLOCK:
+        case SYS_CLOCK:
             if (start_stop == TSTART) {
                 HDgettimeofday(&pt->sys_timer[t], NULL);
 
-		/* When we start the timer for HDF5_FINE_WRITE_FIXED_DIMS or HDF5_FINE_READ_FIXED_DIMS
-		 * we compute the time it took to only open the file */
-		if(t == HDF5_FINE_WRITE_FIXED_DIMS)
-		    pt->total_time[HDF5_FILE_WRITE_OPEN] += sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_GROSS_WRITE_FIXED_DIMS]));
-		else if(t == HDF5_FINE_READ_FIXED_DIMS)
-		    pt->total_time[HDF5_FILE_READ_OPEN] += sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_GROSS_READ_FIXED_DIMS]));
-
-
-            } else {
+                /* When we start the timer for HDF5_FINE_WRITE_FIXED_DIMS or HDF5_FINE_READ_FIXED_DIMS
+                 * we compute the time it took to only open the file */
+                if (t == HDF5_FINE_WRITE_FIXED_DIMS)
+                    pt->total_time[HDF5_FILE_WRITE_OPEN] +=
+                        sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_GROSS_WRITE_FIXED_DIMS]));
+                else if (t == HDF5_FINE_READ_FIXED_DIMS)
+                    pt->total_time[HDF5_FILE_READ_OPEN] +=
+                        sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_GROSS_READ_FIXED_DIMS]));
+            }
+            else {
                 struct timeval sys_t;
 
                 HDgettimeofday(&sys_t, NULL);
                 pt->total_time[t] += sub_time(&sys_t, &(pt->sys_timer[t]));
 
-		/* When we stop the timer for HDF5_GROSS_WRITE_FIXED_DIMS or HDF5_GROSS_READ_FIXED_DIMS
-		 * we compute the time it took to close the file after the last read/write finished */
-		if(t == HDF5_GROSS_WRITE_FIXED_DIMS)
-		    pt->total_time[HDF5_FILE_WRITE_CLOSE] += sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_FINE_WRITE_FIXED_DIMS]));
-		else if(t == HDF5_GROSS_READ_FIXED_DIMS)
-		    pt->total_time[HDF5_FILE_READ_CLOSE] += sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_FINE_READ_FIXED_DIMS]));
-
+                /* When we stop the timer for HDF5_GROSS_WRITE_FIXED_DIMS or HDF5_GROSS_READ_FIXED_DIMS
+                 * we compute the time it took to close the file after the last read/write finished */
+                if (t == HDF5_GROSS_WRITE_FIXED_DIMS)
+                    pt->total_time[HDF5_FILE_WRITE_CLOSE] +=
+                        sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_FINE_WRITE_FIXED_DIMS]));
+                else if (t == HDF5_GROSS_READ_FIXED_DIMS)
+                    pt->total_time[HDF5_FILE_READ_CLOSE] +=
+                        sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_FINE_READ_FIXED_DIMS]));
             }
-	break;
+            break;
 
-    default:
-	    HDfprintf(stderr, "Unknown time clock type (%d)\n", pt->type);
-	    return NULL;
+        default:
+            fprintf(stderr, "Unknown time clock type (%d)\n", pt->type);
+            return NULL;
     } /* end switch */
 
 #if 0
@@ -207,24 +199,15 @@ set_time(io_time_t *pt, timer_type t, int start_stop)
 }
 
 /*
- * Function:    get_time
+ * Function:    io_time_get
  * Purpose:     Get the time from a ``io_time_t'' object.
  * Return:      The number of seconds as a DOUBLE.
- * Programmer:  Bill Wendling, 01. October 2001
- * Modifications:
  */
 H5_ATTR_PURE double
-get_time(io_time_t *pt, timer_type t)
+io_time_get(io_time_t *pt, timer_type t)
 {
     /* sanity check */
-    HDassert(pt);
+    assert(pt);
 
     return pt->total_time[t];
 }
-
-#if 0
-/* standalone is not working yet. Need fix later. -AKC- */
-#ifdef STANDALONE
-#include "pio_standalone.c"
-#endif
-#endif
