@@ -18,23 +18,23 @@
 #define PROGRAMNAME "h5copy"
 
 /* command-line options: short and long-named parameters */
-static const char         *s_opts    = "d:f:hi:o:ps:vVE*";
-static struct long_options l_opts[]  = {{"destination", require_arg, 'd'},
-                                       {"flag", require_arg, 'f'},
-                                       {"help", no_arg, 'h'},
-                                       {"input", require_arg, 'i'},
-                                       {"output", require_arg, 'o'},
-                                       {"parents", no_arg, 'p'},
-                                       {"source", require_arg, 's'},
-                                       {"verbose", no_arg, 'v'},
-                                       {"version", no_arg, 'V'},
-                                       {"enable-error-stack", optional_arg, 'E'},
-                                       {NULL, 0, '\0'}};
-char                      *fname_src = NULL;
-char                      *fname_dst = NULL;
-char                      *oname_src = NULL;
-char                      *oname_dst = NULL;
-char                      *str_flag  = NULL;
+static const char            *s_opts    = "d:f:hi:o:ps:vVE*";
+static struct h5_long_options l_opts[]  = {{"destination", require_arg, 'd'},
+                                          {"flag", require_arg, 'f'},
+                                          {"help", no_arg, 'h'},
+                                          {"input", require_arg, 'i'},
+                                          {"output", require_arg, 'o'},
+                                          {"parents", no_arg, 'p'},
+                                          {"source", require_arg, 's'},
+                                          {"verbose", no_arg, 'v'},
+                                          {"version", no_arg, 'V'},
+                                          {"enable-error-stack", optional_arg, 'E'},
+                                          {NULL, 0, '\0'}};
+static char                  *fname_src = NULL;
+static char                  *fname_dst = NULL;
+static char                  *oname_src = NULL;
+static char                  *oname_dst = NULL;
+static char                  *str_flag  = NULL;
 
 /*-------------------------------------------------------------------------
  * Function:    leave
@@ -43,29 +43,24 @@ char                      *str_flag  = NULL;
  *
  * Return:      Does not return
  *
- * Programmer:  Quincey Koziol
- *              Saturday, 31. January 2004
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static void
 leave(int ret)
 {
     if (fname_src)
-        HDfree(fname_src);
+        free(fname_src);
     if (fname_dst)
-        HDfree(fname_dst);
+        free(fname_dst);
     if (oname_dst)
-        HDfree(oname_dst);
+        free(oname_dst);
     if (oname_src)
-        HDfree(oname_src);
+        free(oname_src);
     if (str_flag)
-        HDfree(str_flag);
+        free(str_flag);
 
     h5tools_close();
-    HDexit(ret);
+    exit(ret);
 }
 
 /*-------------------------------------------------------------------------
@@ -75,10 +70,6 @@ leave(int ret)
  *
  * Return: void
  *
- * Programmer: Pedro Vicente Nunes, 7/8/2006
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -157,10 +148,6 @@ usage(void)
  * Return: Success:    SUCCEED
  *         Failure:    FAIL
  *
- * Programmer: Pedro Vicente Nunes, 7/8/2006
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 
@@ -169,25 +156,25 @@ parse_flag(const char *s_flag, unsigned *flag)
 {
     unsigned fla = 0;
 
-    if (HDstrcmp(s_flag, "shallow") == 0) {
+    if (strcmp(s_flag, "shallow") == 0) {
         fla = H5O_COPY_SHALLOW_HIERARCHY_FLAG;
     }
-    else if (HDstrcmp(s_flag, "soft") == 0) {
+    else if (strcmp(s_flag, "soft") == 0) {
         fla = H5O_COPY_EXPAND_SOFT_LINK_FLAG;
     }
-    else if (HDstrcmp(s_flag, "ext") == 0) {
+    else if (strcmp(s_flag, "ext") == 0) {
         fla = H5O_COPY_EXPAND_EXT_LINK_FLAG;
     }
-    else if (HDstrcmp(s_flag, "ref") == 0) {
+    else if (strcmp(s_flag, "ref") == 0) {
         fla = H5O_COPY_EXPAND_REFERENCE_FLAG;
     }
-    else if (HDstrcmp(s_flag, "noattr") == 0) {
+    else if (strcmp(s_flag, "noattr") == 0) {
         fla = H5O_COPY_WITHOUT_ATTR_FLAG;
     }
-    else if (HDstrcmp(s_flag, "allflags") == 0) {
+    else if (strcmp(s_flag, "allflags") == 0) {
         fla = H5O_COPY_ALL;
     }
-    else if (HDstrcmp(s_flag, "nullmsg") == 0) {
+    else if (strcmp(s_flag, "nullmsg") == 0) {
         fla = H5O_COPY_PRESERVE_NULL_FLAG;
     }
     else {
@@ -205,10 +192,6 @@ parse_flag(const char *s_flag, unsigned *flag)
  *
  * Purpose: main program
  *
- * Programmer: Pedro Vicente Nunes
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 
@@ -234,7 +217,7 @@ main(int argc, char *argv[])
     h5tools_init();
 
     /* init linkinfo struct */
-    HDmemset(&linkinfo, 0, sizeof(h5tool_link_info_t));
+    memset(&linkinfo, 0, sizeof(h5tool_link_info_t));
 
     /* Check for no command line parameters */
     if (argc == 1) {
@@ -243,19 +226,19 @@ main(int argc, char *argv[])
     } /* end if */
 
     /* parse command line options */
-    while ((opt = get_option(argc, (const char *const *)argv, s_opts, l_opts)) != EOF) {
+    while ((opt = H5_get_option(argc, (const char *const *)argv, s_opts, l_opts)) != EOF) {
         switch ((char)opt) {
             case 'd':
-                oname_dst = HDstrdup(opt_arg);
+                oname_dst = strdup(H5_optarg);
                 break;
 
             case 'f':
                 /* validate flag */
-                if (parse_flag(opt_arg, &flag) < 0) {
+                if (parse_flag(H5_optarg, &flag) < 0) {
                     usage();
                     leave(EXIT_FAILURE);
                 }
-                str_flag = HDstrdup(opt_arg);
+                str_flag = strdup(H5_optarg);
                 break;
 
             case 'h':
@@ -264,11 +247,11 @@ main(int argc, char *argv[])
                 break;
 
             case 'i':
-                fname_src = HDstrdup(opt_arg);
+                fname_src = strdup(H5_optarg);
                 break;
 
             case 'o':
-                fname_dst = HDstrdup(opt_arg);
+                fname_dst = strdup(H5_optarg);
                 break;
 
             case 'p':
@@ -276,7 +259,7 @@ main(int argc, char *argv[])
                 break;
 
             case 's':
-                oname_src = HDstrdup(opt_arg);
+                oname_src = strdup(H5_optarg);
                 break;
 
             case 'V':
@@ -289,8 +272,8 @@ main(int argc, char *argv[])
                 break;
 
             case 'E':
-                if (opt_arg != NULL)
-                    enable_error_stack = HDatoi(opt_arg);
+                if (H5_optarg != NULL)
+                    enable_error_stack = atoi(H5_optarg);
                 else
                     enable_error_stack = 1;
                 break;
@@ -339,13 +322,13 @@ main(int argc, char *argv[])
     /* Attempt to open an existing HDF5 file first. Need to open the dst file
        before the src file just in case that the dst and src are the same file
      */
-    fid_dst = h5tools_fopen(fname_dst, H5F_ACC_RDWR, H5P_DEFAULT, FALSE, NULL, 0);
+    fid_dst = h5tools_fopen(fname_dst, H5F_ACC_RDWR, H5P_DEFAULT, false, NULL, 0);
 
     /*-------------------------------------------------------------------------
      * open input file
      *-------------------------------------------------------------------------*/
 
-    fid_src = h5tools_fopen(fname_src, H5F_ACC_RDONLY, H5P_DEFAULT, FALSE, NULL, 0);
+    fid_src = h5tools_fopen(fname_src, H5F_ACC_RDONLY, H5P_DEFAULT, false, NULL, 0);
 
     /*-------------------------------------------------------------------------
      * test for error in opening input file
@@ -377,10 +360,10 @@ main(int argc, char *argv[])
      *-------------------------------------------------------------------------*/
 
     if (verbose) {
-        HDprintf("Copying file <%s> and object <%s> to file <%s> and object <%s>\n", fname_src, oname_src,
-                 fname_dst, oname_dst);
+        printf("Copying file <%s> and object <%s> to file <%s> and object <%s>\n", fname_src, oname_src,
+               fname_dst, oname_dst);
         if (flag) {
-            HDprintf("Using %s flag\n", str_flag);
+            printf("Using %s flag\n", str_flag);
         }
     }
 
@@ -414,28 +397,28 @@ main(int argc, char *argv[])
 
         /* Display some output if requested */
         if (verbose)
-            HDprintf("%s: Creating parent groups\n", h5tools_getprogname());
+            printf("%s: Creating parent groups\n", h5tools_getprogname());
     } /* end if */
     else {
         /* error, if parent groups doesn't already exist in destination file */
         size_t i, len;
 
-        len = HDstrlen(oname_dst);
+        len = strlen(oname_dst);
 
         /* check if all the parents groups exist. skip root group */
         for (i = 1; i < len; i++) {
             if ('/' == oname_dst[i]) {
                 char *str_ptr;
 
-                str_ptr = (char *)HDcalloc(i + 1, sizeof(char));
-                HDstrncpy(str_ptr, oname_dst, i);
+                str_ptr = (char *)calloc(i + 1, sizeof(char));
+                strncpy(str_ptr, oname_dst, i);
                 str_ptr[i] = '\0';
                 if (H5Lexists(fid_dst, str_ptr, H5P_DEFAULT) <= 0) {
                     error_msg("group <%s> doesn't exist. Use -p to create parent groups.\n", str_ptr);
-                    HDfree(str_ptr);
+                    free(str_ptr);
                     H5TOOLS_GOTO_ERROR(EXIT_FAILURE, "H5Lexists failed");
                 }
-                HDfree(str_ptr);
+                free(str_ptr);
             }
         }
     }
@@ -466,7 +449,7 @@ main(int argc, char *argv[])
 
     /* free link info path */
     if (linkinfo.trg_path)
-        HDfree(linkinfo.trg_path);
+        free(linkinfo.trg_path);
 
     /* close propertis */
     if (H5Pclose(ocpl_id) < 0)
@@ -483,11 +466,11 @@ main(int argc, char *argv[])
     leave(EXIT_SUCCESS);
 
 done:
-    HDprintf("Error in copy...Exiting\n");
+    printf("Error in copy...Exiting\n");
 
     /* free link info path */
     if (linkinfo.trg_path)
-        HDfree(linkinfo.trg_path);
+        free(linkinfo.trg_path);
 
     H5E_BEGIN_TRY
     {
@@ -496,7 +479,7 @@ done:
         H5Fclose(fid_src);
         H5Fclose(fid_dst);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     leave(ret_value);
 }
