@@ -24,24 +24,60 @@ static int check_d_input(const char *);
  * Command-line options: The user can specify short or long-named
  * parameters.
  */
-static const char         *s_opts   = "hVrv*qn:d:p:NcelxE:A:S*";
-static struct long_options l_opts[] = {{"help", no_arg, 'h'},
-                                       {"version", no_arg, 'V'},
-                                       {"report", no_arg, 'r'},
-                                       {"verbose", optional_arg, 'v'},
-                                       {"quiet", no_arg, 'q'},
-                                       {"count", require_arg, 'n'},
-                                       {"delta", require_arg, 'd'},
-                                       {"relative", require_arg, 'p'},
-                                       {"nan", no_arg, 'N'},
-                                       {"compare", no_arg, 'c'},
-                                       {"use-system-epsilon", no_arg, 'e'},
-                                       {"follow-symlinks", no_arg, 'l'},
-                                       {"no-dangling-links", no_arg, 'x'},
-                                       {"exclude-path", require_arg, 'E'},
-                                       {"exclude-attribute", require_arg, 'A'},
-                                       {"enable-error-stack", optional_arg, 'S'},
-                                       {NULL, 0, '\0'}};
+static const char            *s_opts   = "cd:ehln:p:qrv*xA:CE:K:NS*V";
+static struct h5_long_options l_opts[] = {{"compare", no_arg, 'c'},
+                                          {"delta", require_arg, 'd'},
+                                          {"use-system-epsilon", no_arg, 'e'},
+                                          {"help", no_arg, 'h'},
+                                          {"follow-symlinks", no_arg, 'l'},
+                                          {"count", require_arg, 'n'},
+                                          {"relative", require_arg, 'p'},
+                                          {"quiet", no_arg, 'q'},
+                                          {"report", no_arg, 'r'},
+                                          {"verbose", optional_arg, 'v'},
+                                          {"no-dangling-links", no_arg, 'x'},
+                                          {"exclude-attribute", require_arg, 'A'},
+                                          {"no-compact-subset", no_arg, 'C'},
+                                          {"exclude-path", require_arg, 'E'},
+                                          {"page-buffer-size", require_arg, 'K'},
+                                          {"nan", no_arg, 'N'},
+                                          {"enable-error-stack", optional_arg, 'S'},
+                                          {"version", no_arg, 'V'},
+                                          {"vol-value-1", require_arg, '1'},
+                                          {"vol-name-1", require_arg, '2'},
+                                          {"vol-info-1", require_arg, '3'},
+                                          {"vol-value-2", require_arg, '4'},
+                                          {"vol-name-2", require_arg, '5'},
+                                          {"vol-info-2", require_arg, '6'},
+                                          {"vfd-value-1", require_arg, '7'},
+                                          {"vfd-name-1", require_arg, '8'},
+                                          {"vfd-info-1", require_arg, '9'},
+                                          {"vfd-value-2", require_arg, '0'},
+                                          {"vfd-name-2", require_arg, 'Y'},
+                                          {"vfd-info-2", require_arg, 'Z'},
+                                          {NULL, 0, '\0'}};
+
+static H5FD_onion_fapl_info_t onion_fa_g_1 = {
+    H5FD_ONION_FAPL_INFO_VERSION_CURR,
+    H5P_DEFAULT,                   /* backing_fapl_id                */
+    32,                            /* page_size                      */
+    H5FD_ONION_STORE_TARGET_ONION, /* store_target                   */
+    H5FD_ONION_FAPL_INFO_REVISION_ID_LATEST,
+    0,                  /* force_write_open               */
+    0,                  /* creation_flags                 */
+    "first input file", /* comment                        */
+};
+
+static H5FD_onion_fapl_info_t onion_fa_g_2 = {
+    H5FD_ONION_FAPL_INFO_VERSION_CURR,
+    H5P_DEFAULT,                   /* backing_fapl_id                */
+    32,                            /* page_size                      */
+    H5FD_ONION_STORE_TARGET_ONION, /* store_target                   */
+    H5FD_ONION_FAPL_INFO_REVISION_ID_LATEST,
+    0,                   /* force_write_open               */
+    0,                   /* creation_flags                 */
+    "second input file", /* comment                        */
+};
 
 /*-------------------------------------------------------------------------
  * Function: check_options
@@ -60,131 +96,15 @@ check_options(diff_opt_t *opts)
      * These options are mutually exclusive.
      */
     if ((opts->delta_bool + opts->percent_bool + opts->use_system_epsilon) > 1) {
-        HDprintf("%s error: -d, -p and --use-system-epsilon options are mutually-exclusive;\n", PROGRAMNAME);
-        HDprintf("use no more than one.\n");
-        HDprintf("Try '-h' or '--help' option for more information or see the %s entry in the 'HDF5 "
-                 "Reference Manual'.\n",
-                 PROGRAMNAME);
+        printf("%s error: -d, -p and --use-system-epsilon options are mutually-exclusive;\n", PROGRAMNAME);
+        printf("use no more than one.\n");
+        printf("Try '-h' or '--help' option for more information or see the %s entry in the 'HDF5 "
+               "Reference Manual'.\n",
+               PROGRAMNAME);
         h5diff_exit(EXIT_FAILURE);
     }
 }
 
-/*-------------------------------------------------------------------------
- * Function:    parse_hsize_list
- *
- * Purpose:     Parse a list of comma or space separated integers and return
- *              them in a list. The string being passed into this function
- *              should be at the start of the list you want to parse. You are
- *              responsible for freeing the array returned from here.
- *
- *              Lists in the so-called "terse" syntax are separated by
- *              semicolons (;). The lists themselves can be separated by
- *              either commas (,) or white spaces.
- *
- * Return:      <none>
- *-------------------------------------------------------------------------
- */
-static void
-parse_hsize_list(const char *h_list, subset_d *d)
-{
-    hsize_t     *p_list;
-    const char  *ptr;
-    unsigned int size_count = 0;
-    unsigned int i          = 0;
-    unsigned int last_digit = 0;
-
-    if (!h_list || !*h_list || *h_list == ';')
-        return;
-
-    H5TOOLS_START_DEBUG(" - h_list:%s", h_list);
-    /* count how many integers do we have */
-    for (ptr = h_list; ptr && *ptr && *ptr != ';' && *ptr != ']'; ptr++)
-        if (HDisdigit(*ptr)) {
-            if (!last_digit)
-                /* the last read character wasn't a digit */
-                size_count++;
-
-            last_digit = 1;
-        }
-        else
-            last_digit = 0;
-
-    if (size_count == 0) {
-        /* there aren't any integers to read */
-        H5TOOLS_ENDDEBUG("No integers to read");
-        return;
-    }
-    H5TOOLS_DEBUG("Number integers to read=%ld", size_count);
-
-    /* allocate an array for the integers in the list */
-    if ((p_list = (hsize_t *)HDcalloc(size_count, sizeof(hsize_t))) == NULL)
-        H5TOOLS_INFO("Unable to allocate space for subset data");
-
-    for (ptr = h_list; i < size_count && ptr && *ptr && *ptr != ';' && *ptr != ']'; ptr++)
-        if (HDisdigit(*ptr)) {
-            /* we should have an integer now */
-            p_list[i++] = (hsize_t)HDstrtoull(ptr, NULL, 0);
-
-            while (HDisdigit(*ptr))
-                /* scroll to end of integer */
-                ptr++;
-        }
-    d->data = p_list;
-    d->len  = size_count;
-    H5TOOLS_ENDDEBUG(" ");
-}
-
-/*-------------------------------------------------------------------------
- * Function:    parse_subset_params
- *
- * Purpose:     Parse the so-called "terse" syntax for specifying subsetting parameters.
- *
- * Return:      Success:    struct subset_t object
- *              Failure:    NULL
- *-------------------------------------------------------------------------
- */
-static struct subset_t *
-parse_subset_params(const char *dset)
-{
-    struct subset_t *s = NULL;
-    char            *brace;
-
-    H5TOOLS_START_DEBUG(" - dset:%s", dset);
-    if ((brace = HDstrrchr(dset, '[')) != NULL) {
-        *brace++ = '\0';
-
-        s = (struct subset_t *)HDcalloc(1, sizeof(struct subset_t));
-        parse_hsize_list(brace, &s->start);
-
-        while (*brace && *brace != ';')
-            brace++;
-
-        if (*brace)
-            brace++;
-
-        parse_hsize_list(brace, &s->stride);
-
-        while (*brace && *brace != ';')
-            brace++;
-
-        if (*brace)
-            brace++;
-
-        parse_hsize_list(brace, &s->count);
-
-        while (*brace && *brace != ';')
-            brace++;
-
-        if (*brace)
-            brace++;
-
-        parse_hsize_list(brace, &s->block);
-    }
-    H5TOOLS_ENDDEBUG(" ");
-
-    return s;
-}
-
 /*-------------------------------------------------------------------------
  * Function: parse_command_line
  *
@@ -203,7 +123,7 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
 
     H5TOOLS_START_DEBUG(" ");
     /* process the command-line */
-    HDmemset(opts, 0, sizeof(diff_opt_t));
+    memset(opts, 0, sizeof(diff_opt_t));
 
     /* assume equal contents initially */
     opts->contents = 1;
@@ -218,6 +138,9 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
     /**this is bad in mixing option with results**/
     opts->not_cmp = 0;
 
+    /* init for page buffer cache size option */
+    opts->page_cache = 0;
+
     /* init for exclude-path option */
     exclude_head = NULL;
 
@@ -225,7 +148,7 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
     exclude_attr_head = NULL;
 
     /* parse command line options */
-    while ((opt = get_option(argc, argv, s_opts, l_opts)) != EOF) {
+    while ((opt = H5_get_option(argc, argv, s_opts, l_opts)) != EOF) {
         switch ((char)opt) {
             default:
                 usage();
@@ -249,20 +172,20 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
                      * special check for short opt
                      */
                     if (!strcmp(argv[i], "-v")) {
-                        if (opt_arg != NULL)
-                            opt_ind--;
+                        if (H5_optarg != NULL)
+                            H5_optind--;
                         opts->mode_verbose_level = 0;
                         break;
                     }
                     else if (!strncmp(argv[i], "-v", (size_t)2)) {
-                        if (opt_arg != NULL)
-                            opt_ind--;
+                        if (H5_optarg != NULL)
+                            H5_optind--;
                         opts->mode_verbose_level = atoi(&argv[i][2]);
                         break;
                     }
                     else {
-                        if (opt_arg != NULL)
-                            opts->mode_verbose_level = HDatoi(opt_arg);
+                        if (H5_optarg != NULL)
+                            opts->mode_verbose_level = atoi(H5_optarg);
                         else
                             opts->mode_verbose_level = 0;
                     }
@@ -279,7 +202,7 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
                 break;
 
             case 'l':
-                opts->follow_links = TRUE;
+                opts->follow_links = true;
                 break;
 
             case 'x':
@@ -287,8 +210,8 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
                 break;
 
             case 'S':
-                if (opt_arg != NULL)
-                    enable_error_stack = HDatoi(opt_arg);
+                if (H5_optarg != NULL)
+                    enable_error_stack = atoi(H5_optarg);
                 else
                     enable_error_stack = 1;
                 break;
@@ -297,14 +220,14 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
                 opts->exclude_path = 1;
 
                 /* create linked list of excluding objects */
-                if ((exclude_node = (struct exclude_path_list *)HDmalloc(sizeof(struct exclude_path_list))) ==
+                if ((exclude_node = (struct exclude_path_list *)malloc(sizeof(struct exclude_path_list))) ==
                     NULL) {
-                    HDprintf("Error: lack of memory!\n");
+                    printf("Error: lack of memory!\n");
                     h5diff_exit(EXIT_FAILURE);
                 }
 
                 /* init */
-                exclude_node->obj_path = opt_arg;
+                exclude_node->obj_path = H5_optarg;
                 exclude_node->obj_type = H5TRAV_TYPE_UNKNOWN;
                 exclude_prev           = exclude_head;
 
@@ -321,18 +244,22 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
                 }
                 break;
 
+            case 'C':
+                opts->disable_compact_subset = true;
+                break;
+
             case 'A':
                 opts->exclude_attr_path = 1;
 
                 /* create linked list of excluding objects */
                 if ((exclude_attr_node =
-                         (struct exclude_path_list *)HDmalloc(sizeof(struct exclude_path_list))) == NULL) {
-                    HDprintf("Error: lack of memory!\n");
+                         (struct exclude_path_list *)malloc(sizeof(struct exclude_path_list))) == NULL) {
+                    printf("Error: lack of memory!\n");
                     h5diff_exit(EXIT_FAILURE);
                 }
 
                 /* init */
-                exclude_attr_node->obj_path = opt_arg;
+                exclude_attr_node->obj_path = H5_optarg;
                 exclude_attr_node->obj_type = H5TRAV_TYPE_UNKNOWN;
                 exclude_attr_prev           = exclude_attr_head;
 
@@ -352,23 +279,23 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
             case 'd':
                 opts->delta_bool = 1;
 
-                if (check_d_input(opt_arg) == -1) {
-                    HDprintf("<-d %s> is not a valid option\n", opt_arg);
+                if (check_d_input(H5_optarg) == -1) {
+                    printf("<-d %s> is not a valid option\n", H5_optarg);
                     usage();
                     h5diff_exit(EXIT_FAILURE);
                 }
-                opts->delta = HDatof(opt_arg);
+                opts->delta = atof(H5_optarg);
                 /* do not check against default, the DBL_EPSILON is being replaced by user */
                 break;
 
             case 'p':
                 opts->percent_bool = 1;
-                if (check_p_input(opt_arg) == -1) {
-                    HDprintf("<-p %s> is not a valid option\n", opt_arg);
+                if (check_p_input(H5_optarg) == -1) {
+                    printf("<-p %s> is not a valid option\n", H5_optarg);
                     usage();
                     h5diff_exit(EXIT_FAILURE);
                 }
-                opts->percent = HDatof(opt_arg);
+                opts->percent = atof(H5_optarg);
 
                 /* -p 0 is the same as default */
                 if (H5_DBL_ABS_EQUAL(opts->percent, 0.0))
@@ -377,12 +304,12 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
 
             case 'n':
                 opts->count_bool = 1;
-                if (check_n_input(opt_arg) == -1) {
-                    HDprintf("<-n %s> is not a valid option\n", opt_arg);
+                if (check_n_input(H5_optarg) == -1) {
+                    printf("<-n %s> is not a valid option\n", H5_optarg);
                     usage();
                     h5diff_exit(EXIT_FAILURE);
                 }
-                opts->count = HDstrtoull(opt_arg, NULL, 0);
+                opts->count = strtoull(H5_optarg, NULL, 0);
                 break;
 
             case 'N':
@@ -396,9 +323,111 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
             case 'e':
                 opts->use_system_epsilon = 1;
                 break;
+
+            case 'K':
+                opts->page_cache = strtoul(H5_optarg, NULL, 0);
+                break;
+
+            case '1':
+                opts->vol_info[0].type    = VOL_BY_VALUE;
+                opts->vol_info[0].u.value = (H5VL_class_value_t)atoi(H5_optarg);
+                opts->custom_vol[0]       = true;
+                break;
+
+            case '2':
+                opts->vol_info[0].type   = VOL_BY_NAME;
+                opts->vol_info[0].u.name = H5_optarg;
+                opts->custom_vol[0]      = true;
+                break;
+
+            case '3':
+                opts->vol_info[0].info_string = H5_optarg;
+                break;
+
+            case '4':
+                opts->vol_info[1].type    = VOL_BY_VALUE;
+                opts->vol_info[1].u.value = (H5VL_class_value_t)atoi(H5_optarg);
+                opts->custom_vol[1]       = true;
+                break;
+
+            case '5':
+                opts->vol_info[1].type   = VOL_BY_NAME;
+                opts->vol_info[1].u.name = H5_optarg;
+                opts->custom_vol[1]      = true;
+                break;
+
+            case '6':
+                opts->vol_info[1].info_string = H5_optarg;
+                break;
+
+            case '7':
+                opts->vfd_info[0].type    = VFD_BY_VALUE;
+                opts->vfd_info[0].u.value = (H5FD_class_value_t)atoi(H5_optarg);
+                opts->custom_vfd[0]       = true;
+                break;
+
+            case '8':
+                opts->vfd_info[0].type   = VFD_BY_NAME;
+                opts->vfd_info[0].u.name = H5_optarg;
+                opts->custom_vfd[0]      = true;
+                break;
+
+            case '9':
+                opts->vfd_info[0].info = (const void *)H5_optarg;
+                break;
+
+            case '0':
+                opts->vfd_info[1].type    = VFD_BY_VALUE;
+                opts->vfd_info[1].u.value = (H5FD_class_value_t)atoi(H5_optarg);
+                opts->custom_vfd[1]       = true;
+                break;
+
+            case 'Y':
+                opts->vfd_info[1].type   = VFD_BY_NAME;
+                opts->vfd_info[1].u.name = H5_optarg;
+                opts->custom_vfd[1]      = true;
+                break;
+
+            case 'Z':
+                opts->vfd_info[1].info = (const void *)H5_optarg;
+                break;
         }
     }
 
+    /* If file 1 uses the onion VFD, get the revision number */
+    if (opts->vfd_info[0].u.name && !strcmp(opts->vfd_info[0].u.name, "onion")) {
+        if (opts->vfd_info[0].info) {
+            errno                     = 0;
+            onion_fa_g_1.revision_num = strtoull(opts->vfd_info[0].info, NULL, 10);
+            if (errno == ERANGE) {
+                printf("Invalid onion revision specified for file 1\n");
+                usage();
+                h5diff_exit(EXIT_FAILURE);
+            }
+        }
+        else
+            onion_fa_g_1.revision_num = 0;
+
+        opts->vfd_info[0].info = &onion_fa_g_1;
+    }
+
+    /* If file 2 uses the onion VFD, get the revision number */
+    if (opts->vfd_info[1].u.name && !strcmp(opts->vfd_info[1].u.name, "onion")) {
+        if (opts->vfd_info[1].info) {
+            errno                     = 0;
+            onion_fa_g_2.revision_num = strtoull(opts->vfd_info[1].info, NULL, 10);
+            if (errno == ERANGE) {
+                printf("Invalid onion revision specified for file 2\n");
+                usage();
+                h5diff_exit(EXIT_FAILURE);
+            }
+        }
+        else
+            onion_fa_g_2.revision_num = 0;
+
+        opts->vfd_info[1].info = &onion_fa_g_2;
+    }
+
     /* check options */
     check_options(opts);
 
@@ -411,15 +440,15 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
         opts->exclude_attr = exclude_attr_head;
 
     /* check for file names to be processed */
-    if (argc <= opt_ind || argv[opt_ind + 1] == NULL) {
+    if (argc <= H5_optind || argv[H5_optind + 1] == NULL) {
         error_msg("missing file names\n");
         usage();
         h5diff_exit(EXIT_FAILURE);
     }
 
-    *fname1   = argv[opt_ind];
-    *fname2   = argv[opt_ind + 1];
-    *objname1 = argv[opt_ind + 2];
+    *fname1   = argv[H5_optind];
+    *fname2   = argv[H5_optind + 1];
+    *objname1 = argv[H5_optind + 2];
     H5TOOLS_DEBUG("file1 = %s", *fname1);
     H5TOOLS_DEBUG("file2 = %s", *fname2);
 
@@ -430,21 +459,18 @@ parse_command_line(int argc, const char *const *argv, const char **fname1, const
     }
     H5TOOLS_DEBUG("objname1 = %s", *objname1);
 
-    if (argv[opt_ind + 3] != NULL) {
-        *objname2 = argv[opt_ind + 3];
+    if (argv[H5_optind + 3] != NULL) {
+        *objname2 = argv[H5_optind + 3];
     }
     else {
         *objname2 = *objname1;
     }
     H5TOOLS_DEBUG("objname2 = %s", *objname2);
 
-    /*
-     * TRILABS_227 is complete except for an issue with printing indices
-     * the following calls will enable subsetting
-     */
-    opts->sset[0] = parse_subset_params(*objname1);
-
-    opts->sset[1] = parse_subset_params(*objname2);
+    if (!opts->disable_compact_subset) {
+        opts->sset[0] = parse_subset_params(*objname1);
+        opts->sset[1] = parse_subset_params(*objname2);
+    }
 
     H5TOOLS_ENDDEBUG(" ");
 }
@@ -462,20 +488,20 @@ print_info(diff_opt_t *opts)
         return;
 
     if (opts->cmn_objs == 0) {
-        HDprintf("No common objects found. Files are not comparable.\n");
+        printf("No common objects found. Files are not comparable.\n");
         if (!opts->mode_verbose)
-            HDprintf("Use -v for a list of objects.\n");
+            printf("Use -v for a list of objects.\n");
     }
 
     if (opts->not_cmp == 1) {
         if (opts->mode_list_not_cmp == 0) {
-            HDprintf("--------------------------------\n");
-            HDprintf("Some objects are not comparable\n");
-            HDprintf("--------------------------------\n");
+            printf("--------------------------------\n");
+            printf("Some objects are not comparable\n");
+            printf("--------------------------------\n");
             if (opts->mode_verbose)
-                HDprintf("Use -c for a list of objects without details of differences.\n");
+                printf("Use -c for a list of objects without details of differences.\n");
             else
-                HDprintf("Use -c for a list of objects.\n");
+                printf("Use -c for a list of objects.\n");
         }
     }
 }
@@ -494,7 +520,7 @@ check_n_input(const char *str)
     unsigned i;
     char     c;
 
-    for (i = 0; i < HDstrlen(str); i++) {
+    for (i = 0; i < strlen(str); i++) {
         c = str[i];
         if (i == 0) {
             if (c < 49 || c > 57) /* ascii values between 1 and 9 */
@@ -523,10 +549,10 @@ check_p_input(const char *str)
      * the atof return value on a hexadecimal input is different
      * on some systems; we do a character check for this
      */
-    if (HDstrlen(str) > 2 && str[0] == '0' && str[1] == 'x')
+    if (strlen(str) > 2 && str[0] == '0' && str[1] == 'x')
         return -1;
 
-    x = HDatof(str);
+    x = atof(str);
     if (x < 0)
         return -1;
 
@@ -550,10 +576,10 @@ check_d_input(const char *str)
      * the atof return value on a hexadecimal input is different
      * on some systems; we do a character check for this
      */
-    if (HDstrlen(str) > 2 && str[0] == '0' && str[1] == 'x')
+    if (strlen(str) > 2 && str[0] == '0' && str[1] == 'x')
         return -1;
 
-    x = HDatof(str);
+    x = atof(str);
     if (x < 0)
         return -1;
 
@@ -604,6 +630,51 @@ usage(void)
     PRINTVALSTREAM(rawoutstream, "          3 : All level 2 information plus file names.\n");
     PRINTVALSTREAM(rawoutstream, "   -q, --quiet\n");
     PRINTVALSTREAM(rawoutstream, "         Quiet mode. Do not produce output.\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --page-buffer-size=N    Set the page buffer cache size, N=non-negative integers\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vol-value-1           Value (ID) of the VOL connector to use for opening the\n");
+    PRINTVALSTREAM(rawoutstream, "                           first HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vol-name-1            Name of the VOL connector to use for opening the first\n");
+    PRINTVALSTREAM(rawoutstream, "                           HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vol-info-1            VOL-specific info to pass to the VOL connector used for\n");
+    PRINTVALSTREAM(rawoutstream, "                           opening the first HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vol-value-2           Value (ID) of the VOL connector to use for opening the\n");
+    PRINTVALSTREAM(rawoutstream, "                           second HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vol-name-2            Name of the VOL connector to use for opening the second\n");
+    PRINTVALSTREAM(rawoutstream, "                           HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vol-info-2            VOL-specific info to pass to the VOL connector used for\n");
+    PRINTVALSTREAM(rawoutstream, "                           opening the second HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream, "                           If none of the above options are used to "
+                                 "specify a VOL for a file, then\n");
+    PRINTVALSTREAM(
+        rawoutstream,
+        "                           the VOL named by HDF5_VOL_CONNECTOR (or the native VOL connector,\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "                           if that environment variable is unset) will be used\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vfd-value-1           Value (ID) of the VFL driver to use for opening the\n");
+    PRINTVALSTREAM(rawoutstream, "                           first HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vfd-name-1            Name of the VFL driver to use for opening the first\n");
+    PRINTVALSTREAM(rawoutstream, "                           HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vfd-info-1            VFD-specific info to pass to the VFL driver used for\n");
+    PRINTVALSTREAM(rawoutstream, "                           opening the first HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vfd-value-2           Value (ID) of the VFL driver to use for opening the\n");
+    PRINTVALSTREAM(rawoutstream, "                           second HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vfd-name-2            Name of the VFL driver to use for opening the second\n");
+    PRINTVALSTREAM(rawoutstream, "                           HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --vfd-info-2            VFD-specific info to pass to the VFL driver used for\n");
+    PRINTVALSTREAM(rawoutstream, "                           opening the second HDF5 file specified\n");
     PRINTVALSTREAM(rawoutstream, "   --follow-symlinks\n");
     PRINTVALSTREAM(rawoutstream,
                    "         Follow symbolic links (soft links and external links and compare the)\n");
@@ -752,7 +823,7 @@ usage(void)
                    "      specified group) and generates a report of objects that appear in only\n");
     PRINTVALSTREAM(rawoutstream,
                    "      one group or in both groups. Common objects are then compared recursively.\n");
-    PRINTVALSTREAM(rawoutstream, "  2) Datasets\n");
+    PRINTVALSTREAM(rawoutstream, "  2) Attributes and Datasets\n");
     PRINTVALSTREAM(rawoutstream,
                    "      Array rank and dimensions, datatypes, and data values are compared.\n");
     PRINTVALSTREAM(rawoutstream, "  3) Datatypes\n");
@@ -767,6 +838,9 @@ usage(void)
      * the following will be needed for subsetting
      */
     PRINTVALSTREAM(rawoutstream, " Subsetting options:\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "  --no-compact-subset  Disable compact form of subsetting and allow the use\n");
+    PRINTVALSTREAM(rawoutstream, "                          of \"[\" in dataset names.\n");
     PRINTVALSTREAM(rawoutstream,
                    "  Subsetting is available by using the fcompact form of subsetting, as follows:\n");
     PRINTVALSTREAM(rawoutstream, "    obj1 /foo/mydataset[START;STRIDE;COUNT;BLOCK]\n");
