@@ -41,7 +41,7 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
 {
     size_t      i, m, u;
     char        c;
-    size_t      len = HDstrlen(str);
+    size_t      len = strlen(str);
     int         f, k, l, p, q, end_obj = -1, no_param = 0;
     unsigned    j, n;
     char        sobj[MAX_NC_NAME];
@@ -52,7 +52,7 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
     unsigned    pixels_per_block;
 
     /* initialize compression  info */
-    HDmemset(filt, 0, sizeof(filter_info_t));
+    memset(filt, 0, sizeof(filter_info_t));
     *is_glb = 0;
 
     /* check for the end of object list and number of objects */
@@ -77,7 +77,7 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
     else
         *n_objs = n;
 
-    obj_list = (obj_list_t *)HDmalloc(n * sizeof(obj_list_t));
+    obj_list = (obj_list_t *)malloc(n * sizeof(obj_list_t));
     if (obj_list == NULL) {
         error_msg("could not allocate object list\n");
         return NULL;
@@ -94,8 +94,8 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
                 else
                     sobj[k + 1] = '\0';
 
-                HDstrcpy(obj_list[n].obj, sobj);
-                HDmemset(sobj, 0, sizeof(sobj));
+                strcpy(obj_list[n].obj, sobj);
+                memset(sobj, 0, sizeof(sobj));
                 n++;
                 k = -1;
             }
@@ -103,9 +103,9 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
     /* nothing after : */
     if (end_obj + 1 == (int)len) {
         if (obj_list)
-            HDfree(obj_list);
+            free(obj_list);
         error_msg("input Error: Invalid compression type in <%s>\n", str);
-        HDexit(EXIT_FAILURE);
+        exit(EXIT_FAILURE);
     }
 
     /* get filter additional parameters */
@@ -123,7 +123,7 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
                  * example SZIP=8,NN
                  *-------------------------------------------------------------------------
                  */
-                if (HDstrcmp(scomp, "SZIP") == 0) {
+                if (strcmp(scomp, "SZIP") == 0) {
                     l = -1; /* mask index check */
                     for (m = 0, u = i + 1; u < len; u++, m++) {
                         if (str[u] == ',') {
@@ -132,11 +132,11 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
                             u++;             /* skip ',' */
                         }
                         c = str[u];
-                        if (!HDisdigit(c) && l == -1) {
+                        if (!isdigit(c) && l == -1) {
                             if (obj_list)
-                                HDfree(obj_list);
+                                free(obj_list);
                             error_msg("compression parameter not digit in <%s>\n", str);
-                            HDexit(EXIT_FAILURE);
+                            exit(EXIT_FAILURE);
                         }
                         if (l == -1)
                             stype[m] = c;
@@ -146,13 +146,13 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
                             if (l == 2) {
                                 smask[l] = '\0';
                                 i        = len - 1; /* end */
-                                if (HDstrcmp(smask, "NN") == 0)
+                                if (strcmp(smask, "NN") == 0)
                                     filt->cd_values[j++] = H5_SZIP_NN_OPTION_MASK;
-                                else if (HDstrcmp(smask, "EC") == 0)
+                                else if (strcmp(smask, "EC") == 0)
                                     filt->cd_values[j++] = H5_SZIP_EC_OPTION_MASK;
                                 else {
                                     error_msg("szip mask must be 'NN' or 'EC' \n");
-                                    HDexit(EXIT_FAILURE);
+                                    exit(EXIT_FAILURE);
                                 }
                             }
                         }
@@ -173,7 +173,7 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
                  *  SOFF=3,DF
                  *-------------------------------------------------------------------------
                  */
-                else if (HDstrcmp(scomp, "SOFF") == 0) {
+                else if (strcmp(scomp, "SOFF") == 0) {
                     l = -1; /* mask index check */
                     for (m = 0, u = i + 1; u < len; u++, m++) {
                         if (str[u] == ',') {
@@ -182,11 +182,11 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
                             u++;             /* skip ',' */
                         }
                         c = str[u];
-                        if (!HDisdigit(c) && l == -1) {
+                        if (!isdigit(c) && l == -1) {
                             if (obj_list)
-                                HDfree(obj_list);
+                                free(obj_list);
                             error_msg("compression parameter is not a digit in <%s>\n", str);
-                            HDexit(EXIT_FAILURE);
+                            exit(EXIT_FAILURE);
                         }
                         if (l == -1)
                             stype[m] = c;
@@ -196,13 +196,13 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
                             if (l == 2) {
                                 smask[l] = '\0';
                                 i        = len - 1; /* end */
-                                if (HDstrcmp(smask, "IN") == 0)
+                                if (strcmp(smask, "IN") == 0)
                                     filt->cd_values[j++] = H5Z_SO_INT;
-                                else if (HDstrcmp(smask, "DS") == H5Z_SO_FLOAT_DSCALE)
+                                else if (strcmp(smask, "DS") == H5Z_SO_FLOAT_DSCALE)
                                     filt->cd_values[j++] = H5Z_SO_FLOAT_DSCALE;
                                 else {
                                     error_msg("scale type must be 'IN' or 'DS' \n");
-                                    HDexit(EXIT_FAILURE);
+                                    exit(EXIT_FAILURE);
                                 }
                             }
                         }
@@ -216,7 +216,7 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
                  *  UD=307,0,1,9
                  *-------------------------------------------------------------------------
                  */
-                else if (HDstrcmp(scomp, "UD") == 0) {
+                else if (strcmp(scomp, "UD") == 0) {
                     l = -1; /* filter number index check */
                     f = -1; /* filter flag index check */
                     p = -1; /* CD_VAL count check */
@@ -224,35 +224,35 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
                         if (str[u] == ',') {
                             stype[q] = '\0'; /* end digit */
                             if (l == -1) {
-                                filt->filtn = HDatoi(stype);
+                                filt->filtn = atoi(stype);
                                 l           = 0;
                             }
                             else if (f == -1) {
-                                filt->filt_flag = (unsigned)HDstrtoul(stype, NULL, 0);
+                                filt->filt_flag = (unsigned)strtoul(stype, NULL, 0);
                                 f               = 0;
                             }
                             else if (p == -1) {
-                                filt->cd_nelmts = HDstrtoull(stype, NULL, 0);
+                                filt->cd_nelmts = strtoull(stype, NULL, 0);
                                 p               = 0;
                             }
                             else {
-                                filt->cd_values[j++] = (unsigned)HDstrtoul(stype, NULL, 0);
+                                filt->cd_values[j++] = (unsigned)strtoul(stype, NULL, 0);
                             }
                             q = 0;
                             u++; /* skip ',' */
                         }
                         c = str[u];
-                        if (!HDisdigit(c) && l == -1) {
+                        if (!isdigit(c) && l == -1) {
                             if (obj_list)
-                                HDfree(obj_list);
+                                free(obj_list);
                             error_msg("filter number parameter is not a digit in <%s>\n", str);
-                            HDexit(EXIT_FAILURE);
+                            exit(EXIT_FAILURE);
                         }
-                        else if (!HDisdigit(c) && f == -1) {
+                        else if (!isdigit(c) && f == -1) {
                             if (obj_list)
-                                HDfree(obj_list);
+                                free(obj_list);
                             error_msg("filter flag parameter is not a digit in <%s>\n", str);
-                            HDexit(EXIT_FAILURE);
+                            exit(EXIT_FAILURE);
                         }
                         stype[q] = c;
                     } /* for u */
@@ -267,11 +267,11 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
                     /* here we could have 1 or 2 digits  */
                     for (m = 0, u = i + 1; u < len; u++, m++) {
                         c = str[u];
-                        if (!HDisdigit(c)) {
+                        if (!isdigit(c)) {
                             if (obj_list)
-                                HDfree(obj_list);
+                                free(obj_list);
                             error_msg("compression parameter is not a digit in <%s>\n", str);
-                            HDexit(EXIT_FAILURE);
+                            exit(EXIT_FAILURE);
                         }
                         stype[m] = c;
                     } /* u */
@@ -279,7 +279,7 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
                     stype[m] = '\0';
                 } /*if */
 
-                filt->cd_values[j++] = (unsigned)HDstrtoul(stype, NULL, 0);
+                filt->cd_values[j++] = (unsigned)strtoul(stype, NULL, 0);
                 if (filt->cd_nelmts == 0)
                     j = 0;
                 i += m; /* jump */
@@ -298,7 +298,7 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
              * H5Z_FILTER_NONE
              *-------------------------------------------------------------------------
              */
-            if (HDstrcmp(scomp, "NONE") == 0) {
+            if (strcmp(scomp, "NONE") == 0) {
                 filt->filtn     = H5Z_FILTER_NONE;
                 filt->cd_nelmts = 0;
             }
@@ -307,14 +307,14 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
              * H5Z_FILTER_DEFLATE
              *-------------------------------------------------------------------------
              */
-            else if (HDstrcmp(scomp, "GZIP") == 0) {
+            else if (strcmp(scomp, "GZIP") == 0) {
                 filt->filtn     = H5Z_FILTER_DEFLATE;
                 filt->cd_nelmts = 1;
                 if (no_param) { /*no more parameters, GZIP must have parameter */
                     if (obj_list)
-                        HDfree(obj_list);
+                        free(obj_list);
                     error_msg("missing compression parameter in <%s>\n", str);
-                    HDexit(EXIT_FAILURE);
+                    exit(EXIT_FAILURE);
                 }
             }
 
@@ -322,14 +322,14 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
              * H5Z_FILTER_SZIP
              *-------------------------------------------------------------------------
              */
-            else if (HDstrcmp(scomp, "SZIP") == 0) {
+            else if (strcmp(scomp, "SZIP") == 0) {
                 filt->filtn     = H5Z_FILTER_SZIP;
                 filt->cd_nelmts = 2;
                 if (no_param) { /*no more parameters, SZIP must have parameter */
                     if (obj_list)
-                        HDfree(obj_list);
+                        free(obj_list);
                     error_msg("missing compression parameter in <%s>\n", str);
-                    HDexit(EXIT_FAILURE);
+                    exit(EXIT_FAILURE);
                 }
             }
 
@@ -337,76 +337,76 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
              * H5Z_FILTER_SHUFFLE
              *-------------------------------------------------------------------------
              */
-            else if (HDstrcmp(scomp, "SHUF") == 0) {
+            else if (strcmp(scomp, "SHUF") == 0) {
                 filt->filtn     = H5Z_FILTER_SHUFFLE;
                 filt->cd_nelmts = 0;
                 if (m > 0) { /*shuffle does not have parameter */
                     if (obj_list)
-                        HDfree(obj_list);
+                        free(obj_list);
                     error_msg("extra parameter in SHUF <%s>\n", str);
-                    HDexit(EXIT_FAILURE);
+                    exit(EXIT_FAILURE);
                 }
             }
             /*-------------------------------------------------------------------------
              * H5Z_FILTER_FLETCHER32
              *-------------------------------------------------------------------------
              */
-            else if (HDstrcmp(scomp, "FLET") == 0) {
+            else if (strcmp(scomp, "FLET") == 0) {
                 filt->filtn     = H5Z_FILTER_FLETCHER32;
                 filt->cd_nelmts = 0;
                 if (m > 0) { /*shuffle does not have parameter */
                     if (obj_list)
-                        HDfree(obj_list);
+                        free(obj_list);
                     error_msg("extra parameter in FLET <%s>\n", str);
-                    HDexit(EXIT_FAILURE);
+                    exit(EXIT_FAILURE);
                 }
             }
             /*-------------------------------------------------------------------------
              * H5Z_FILTER_NBIT
              *-------------------------------------------------------------------------
              */
-            else if (HDstrcmp(scomp, "NBIT") == 0) {
+            else if (strcmp(scomp, "NBIT") == 0) {
                 filt->filtn     = H5Z_FILTER_NBIT;
                 filt->cd_nelmts = 0;
                 if (m > 0) { /*nbit does not have parameter */
                     if (obj_list)
-                        HDfree(obj_list);
+                        free(obj_list);
                     error_msg("extra parameter in NBIT <%s>\n", str);
-                    HDexit(EXIT_FAILURE);
+                    exit(EXIT_FAILURE);
                 }
             }
             /*-------------------------------------------------------------------------
              * H5Z_FILTER_SCALEOFFSET
              *-------------------------------------------------------------------------
              */
-            else if (HDstrcmp(scomp, "SOFF") == 0) {
+            else if (strcmp(scomp, "SOFF") == 0) {
                 filt->filtn     = H5Z_FILTER_SCALEOFFSET;
                 filt->cd_nelmts = 2;
                 if (no_param) { /*no more parameters, SOFF must have parameter */
                     if (obj_list)
-                        HDfree(obj_list);
+                        free(obj_list);
                     error_msg("missing compression parameter in <%s>\n", str);
-                    HDexit(EXIT_FAILURE);
+                    exit(EXIT_FAILURE);
                 }
             }
             /*-------------------------------------------------------------------------
              * User Defined Filter
              *-------------------------------------------------------------------------
              */
-            else if (HDstrcmp(scomp, "UD") == 0) {
+            else if (strcmp(scomp, "UD") == 0) {
                 /* parameters does not match count */
                 if (filt->cd_nelmts != j) {
                     if (obj_list)
-                        HDfree(obj_list);
+                        free(obj_list);
                     error_msg("incorrect number of compression parameters in <%s>\n", str);
-                    HDexit(EXIT_FAILURE);
+                    exit(EXIT_FAILURE);
                 }
             }
             else {
                 if (obj_list)
-                    HDfree(obj_list);
+                    free(obj_list);
                 error_msg("invalid filter type in <%s>\n", str);
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
             break;
         }
@@ -425,9 +425,9 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
         case H5Z_FILTER_DEFLATE:
             if (filt->cd_values[0] > 9) {
                 if (obj_list)
-                    HDfree(obj_list);
+                    free(obj_list);
                 error_msg("invalid compression parameter in <%s>\n", str);
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
             break;
             /*-------------------------------------------------------------------------
@@ -438,26 +438,26 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
             pixels_per_block = filt->cd_values[0];
             if ((pixels_per_block % 2) == 1) {
                 if (obj_list)
-                    HDfree(obj_list);
+                    free(obj_list);
                 error_msg("pixels_per_block is not even in <%s>\n", str);
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
             if (pixels_per_block > H5_SZIP_MAX_PIXELS_PER_BLOCK) {
                 if (obj_list)
-                    HDfree(obj_list);
+                    free(obj_list);
                 error_msg("pixels_per_block is too large in <%s>\n", str);
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
-            if ((HDstrcmp(smask, "NN") != 0) && (HDstrcmp(smask, "EC") != 0)) {
+            if ((strcmp(smask, "NN") != 0) && (strcmp(smask, "EC") != 0)) {
                 if (obj_list)
-                    HDfree(obj_list);
+                    free(obj_list);
                 error_msg("szip mask must be 'NN' or 'EC' \n");
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
             break;
         default:
             break;
-    };
+    }
 
     return obj_list;
 }
@@ -477,10 +477,6 @@ parse_filter(const char *str, unsigned *n_objs, filter_info_t *filt, pack_opt_t
  * Example:
  * "AA,B,CDE:CHUNK=10X10"
  *
- * Programmer: Pedro Vicente
- *
- * Date: December 30, 2003
- *
  *-------------------------------------------------------------------------
  */
 obj_list_t *
@@ -490,15 +486,15 @@ parse_layout(const char *str, unsigned *n_objs, pack_info_t *pack, /* info about
     obj_list_t *obj_list = NULL;
     unsigned    i, j, n;
     char        c;
-    size_t      len = HDstrlen(str);
+    size_t      len = strlen(str);
     int         k, end_obj = -1, c_index;
     char        sobj[MAX_NC_NAME];
     char        sdim[10];
     char        slayout[10];
 
-    HDmemset(sdim, '\0', sizeof(sdim));
-    HDmemset(sobj, '\0', sizeof(sobj));
-    HDmemset(slayout, '\0', sizeof(slayout));
+    memset(sdim, '\0', sizeof(sdim));
+    memset(sobj, '\0', sizeof(sobj));
+    memset(slayout, '\0', sizeof(slayout));
 
     /* check for the end of object list and number of objects */
     for (i = 0, n = 0; i < len; i++) {
@@ -514,7 +510,7 @@ parse_layout(const char *str, unsigned *n_objs, pack_info_t *pack, /* info about
     }
 
     n++;
-    obj_list = (obj_list_t *)HDmalloc(n * sizeof(obj_list_t));
+    obj_list = (obj_list_t *)malloc(n * sizeof(obj_list_t));
     if (obj_list == NULL) {
         error_msg("could not allocate object list\n");
         return NULL;
@@ -531,8 +527,8 @@ parse_layout(const char *str, unsigned *n_objs, pack_info_t *pack, /* info about
                     sobj[k] = '\0';
                 else
                     sobj[k + 1] = '\0';
-                HDstrcpy(obj_list[n].obj, sobj);
-                HDmemset(sobj, 0, sizeof(sobj));
+                strcpy(obj_list[n].obj, sobj);
+                memset(sobj, 0, sizeof(sobj));
                 n++;
                 k = -1;
             }
@@ -541,24 +537,24 @@ parse_layout(const char *str, unsigned *n_objs, pack_info_t *pack, /* info about
     /* nothing after : */
     if (end_obj + 1 == (int)len) {
         if (obj_list)
-            HDfree(obj_list);
+            free(obj_list);
         error_msg("in parse layout, no characters after : in <%s>\n", str);
-        HDexit(EXIT_FAILURE);
+        exit(EXIT_FAILURE);
     }
 
     /* get layout info */
     for (j = (unsigned)(end_obj + 1), n = 0; n <= 5; j++, n++) {
         if (n == 5) {
             slayout[n] = '\0'; /*cut string */
-            if (HDstrcmp(slayout, "COMPA") == 0)
+            if (strcmp(slayout, "COMPA") == 0)
                 pack->layout = H5D_COMPACT;
-            else if (HDstrcmp(slayout, "CONTI") == 0)
+            else if (strcmp(slayout, "CONTI") == 0)
                 pack->layout = H5D_CONTIGUOUS;
-            else if (HDstrcmp(slayout, "CHUNK") == 0)
+            else if (strcmp(slayout, "CHUNK") == 0)
                 pack->layout = H5D_CHUNKED;
             else {
                 error_msg("in parse layout, not a valid layout in <%s>\n", str);
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
         }
         else {
@@ -575,9 +571,9 @@ parse_layout(const char *str, unsigned *n_objs, pack_info_t *pack, /* info about
         k = 0;
         if (j > len) {
             if (obj_list)
-                HDfree(obj_list);
+                free(obj_list);
             error_msg("in parse layout,  <%s> Chunk dimensions missing\n", str);
-            HDexit(EXIT_FAILURE);
+            exit(EXIT_FAILURE);
         }
 
         for (i = j, c_index = 0; i < len; i++) {
@@ -585,39 +581,39 @@ parse_layout(const char *str, unsigned *n_objs, pack_info_t *pack, /* info about
             sdim[k] = c;
             k++; /*increment sdim index */
 
-            if (!HDisdigit(c) && c != 'x' && c != 'N' && c != 'O' && c != 'N' && c != 'E') {
+            if (!isdigit(c) && c != 'x' && c != 'N' && c != 'O' && c != 'N' && c != 'E') {
                 if (obj_list)
-                    HDfree(obj_list);
+                    free(obj_list);
                 error_msg("in parse layout, <%s> Not a valid character in <%s>\n", sdim, str);
-                HDexit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
 
             if (c == 'x' || i == len - 1) {
                 if (c == 'x') {
                     sdim[k - 1]                        = '\0';
                     k                                  = 0;
-                    pack->chunk.chunk_lengths[c_index] = HDstrtoull(sdim, NULL, 0);
+                    pack->chunk.chunk_lengths[c_index] = strtoull(sdim, NULL, 0);
                     if (pack->chunk.chunk_lengths[c_index] == 0) {
                         if (obj_list)
-                            HDfree(obj_list);
+                            free(obj_list);
                         error_msg("in parse layout, <%s> conversion to number in <%s>\n", sdim, str);
-                        HDexit(EXIT_FAILURE);
+                        exit(EXIT_FAILURE);
                     }
                     c_index++;
                 }
                 else if (i == len - 1) { /*no more parameters */
                     sdim[k] = '\0';
                     k       = 0;
-                    if (HDstrcmp(sdim, "NONE") == 0) {
+                    if (strcmp(sdim, "NONE") == 0) {
                         pack->chunk.rank = -2;
                     }
                     else {
-                        pack->chunk.chunk_lengths[c_index] = HDstrtoull(sdim, NULL, 0);
+                        pack->chunk.chunk_lengths[c_index] = strtoull(sdim, NULL, 0);
                         if (pack->chunk.chunk_lengths[c_index] == 0) {
                             if (obj_list)
-                                HDfree(obj_list);
+                                free(obj_list);
                             error_msg("in parse layout, <%s> conversion to number in <%s>\n", sdim, str);
-                            HDexit(EXIT_FAILURE);
+                            exit(EXIT_FAILURE);
                         }
                         pack->chunk.rank = c_index + 1;
                     }
