@@ -10,9 +10,6 @@
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Programmer:    Raymond Lu
- *        13 February 2013
- *
  * Purpose:    Tests the plugin module (H5PL)
  */
 
@@ -26,7 +23,7 @@ static size_t H5Z_filter_dynlib1(unsigned int flags, size_t cd_nelmts, const uns
                                  size_t nbytes, size_t *buf_size, void **buf);
 
 /* This message derives from H5Z */
-const H5Z_class2_t H5Z_DYNLIB1[1] = {{
+static const H5Z_class2_t H5Z_DYNLIB1[1] = {{
     H5Z_CLASS_T_VERS,   /* H5Z_class_t version             */
     H5Z_FILTER_DYNLIB1, /* Filter id number        */
     1, 1,               /* Encoding and decoding enabled   */
@@ -59,9 +56,6 @@ H5PLget_plugin_info(void)
  *
  *        Failure:    0
  *
- * Programmer:    Raymond Lu
- *              29 March 2013
- *
  *-------------------------------------------------------------------------
  */
 static size_t
